@@ -27,7 +27,7 @@
  */
 class RGBF16HalfPlugin : public KParts::Plugin
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     RGBF16HalfPlugin(TQObject *parent, const char *name, const TQStringList &);
