@@ -132,7 +132,7 @@ private:
     };
     struct F32OpacityTest {
         inline bool operator()(const float& opacity) const {
-            return opacity > F32_OPACITY_TRANSPARENT + 1e-6; // #define EPSILON in the .cc
+            return opacity > F32_OPACITY_TRANSPARENT + 1e-6; // #define EPSILON in the .cpp
         }
     };
 };
