@@ -19,15 +19,15 @@
 #ifndef RGB_U16_PLUGIN_H_
 #define RGB_U16_PLUGIN_H_
 
-#include <kparts/plugin.h>
+#include <tdeparts/plugin.h>
 
 /**
  * A plugin wrapper around the RGB U16 colour space strategy.
  */
 class RGBU16Plugin : public KParts::Plugin
 {
-    Q_OBJECT
-  TQ_OBJECT
+    TQ_OBJECT
+  
 public:
     RGBU16Plugin(TQObject *parent, const char *name, const TQStringList &);
     virtual ~RGBU16Plugin();
