@@ -26,7 +26,7 @@
  */
 class RGBPlugin : public KParts::Plugin
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     RGBPlugin(TQObject *parent, const char *name, const TQStringList &);
