@@ -26,7 +26,7 @@
  */
 class YCbCrU16Plugin : public KParts::Plugin
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     YCbCrU16Plugin(TQObject *parent, const char *name, const TQStringList &);
