@@ -287,7 +287,7 @@ bool KisBrush::save()
 {
     TQFile file(filename());
     file.open(IO_WriteOnly | IO_Truncate);
-    bool ok = saveToDevice(TQT_TQIODEVICE(&file));
+    bool ok = saveToDevice(&file);
     file.close();
     return ok;
 }
