@@ -231,7 +231,7 @@ class KisGradientSegment {
 
 class KisGradient : public KisResource {
     typedef KisResource super;
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
