@@ -277,7 +277,7 @@ KisPaintDevice::KisPaintDevice(KisLayer *parent, KisColorSpace * colorSpace, con
 
         if (!m_longRunningFilters.isEmpty()) {
             m_longRunningFilterTimer = new TQTimer(this);
-            connect(m_longRunningFilterTimer, TQT_SIGNAL(timeout()), this, TQT_SLOT(runBackgroundFilters()));
+            connect(m_longRunningFilterTimer, TQ_SIGNAL(timeout()), this, TQ_SLOT(runBackgroundFilters()));
             m_longRunningFilterTimer->start(2000);
         }
     }
