@@ -28,7 +28,7 @@
 class KisPaintLayer : public KisLayer, public KisLayerSupportsIndirectPainting {
     typedef KisLayer super;
 
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
