@@ -37,7 +37,7 @@ class KisInputDevice;
 class KRITACORE_EXPORT KisPaintOpRegistry : public TQObject, public KisGenericRegistry<KisPaintOpFactorySP>
 {
 
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
