@@ -50,7 +50,7 @@ struct KisPaletteEntry {
 class KisPalette : public KisResource {
     typedef KisResource super;
 
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
