@@ -32,7 +32,7 @@ class WdgColorifyBase;
 
 class KisWdgColorify : public KisFilterConfigWidget
 {
-    Q_OBJECT
+    TQ_OBJECT
   
     public:
         KisWdgColorify( KisFilter* nfilter, TQWidget * parent, const char * name);
