@@ -21,7 +21,7 @@
 #include <stdlib.h>
 
 #include <tdelocale.h>
-#include <kinstance.h>
+#include <tdeinstance.h>
 #include <kgenericfactory.h>
 
 #include <kis_convolution_painter.h>
