@@ -22,7 +22,7 @@
 #ifndef EXAMPLE_H
 #define EXAMPLE_H
 
-#include <kparts/plugin.h>
+#include <tdeparts/plugin.h>
 
 class ChalkImageEnhancement : public KParts::Plugin
 {
