@@ -28,7 +28,7 @@ class KisFilter;
 
 class KisWdgLensCorrection : public KisFilterConfigWidget
 {
-    Q_OBJECT
+    TQ_OBJECT
   
     public:
         KisWdgLensCorrection(KisFilter* nfilter, TQWidget* parent = 0, const char* name = 0);
