@@ -20,7 +20,7 @@
 #ifndef LEVEL_H
 #define LEVEL_H
 
-#include <kparts/plugin.h>
+#include <tdeparts/plugin.h>
 
 class KisColorSpace;
 class KisColorAdjustment;
