@@ -26,7 +26,7 @@
  */
 class DefaultPaintOpsPlugin : public KParts::Plugin
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     DefaultPaintOpsPlugin(TQObject *parent, const char *name, const TQStringList &);
