@@ -32,7 +32,7 @@ class KisRect;
 class KisToolEllipse : public KisToolShape {
 
     typedef KisToolShape super;
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
