@@ -36,7 +36,7 @@ class KisSelectionOptions;
 class KisToolSelectOutline : public KisToolNonPaint {
 
     typedef KisToolNonPaint super;
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     KisToolSelectOutline();
