@@ -32,7 +32,7 @@ class KisSelectionOptions;
 class KisToolSelectRectangular : public KisToolNonPaint {
 
     typedef KisToolNonPaint super;
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
