@@ -33,7 +33,7 @@
  */
 class SelectionTools : public KParts::Plugin
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     SelectionTools(TQObject *parent, const char *name, const TQStringList &);
