@@ -40,7 +40,7 @@ class WdgToolCrop;
 class KisToolCrop : public KisToolNonPaint {
 
     typedef KisToolNonPaint super;
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
