@@ -43,7 +43,7 @@ double pointToSegmentDistance(const KisPoint& p, const KisPoint& l0, const KisPo
 class KisToolCurve : public KisToolPaint {
 
     typedef KisToolPaint super;
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
