@@ -25,7 +25,7 @@
 
 class ToolCurves : public KParts::Plugin
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     ToolCurves(TQObject *parent, const char *name, const TQStringList &);
