@@ -26,7 +26,7 @@
  */
 class ToolPolygon : public KParts::Plugin
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
