@@ -37,7 +37,7 @@ class KisRect;
 class KisToolPolyline : public KisToolPaint {
 
     typedef KisToolPaint super;
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
