@@ -28,7 +28,7 @@ class KisView;
  */
 class ToolPolyline : public KParts::Plugin
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     ToolPolyline(TQObject *parent, const char *name, const TQStringList &);
