@@ -28,7 +28,7 @@ class KisView;
  */
 class ToolTransform : public KParts::Plugin
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     ToolTransform(TQObject *parent, const char *name, const TQStringList &);
