@@ -201,29 +201,29 @@ DlgColorRange::DlgColorRange( KisView * view, KisPaintDeviceSP dev, TQWidget *
     m_mode = SELECTION_ADD;
     m_currentAction = REDS;
 
-    connect(this, TQT_SIGNAL(okClicked()),
-        this, TQT_SLOT(okClicked()));
+    connect(this, TQ_SIGNAL(okClicked()),
+        this, TQ_SLOT(okClicked()));
 
-    connect(this, TQT_SIGNAL(cancelClicked()),
-        this, TQT_SLOT(cancelClicked()));
+    connect(this, TQ_SIGNAL(cancelClicked()),
+        this, TQ_SLOT(cancelClicked()));
 
-    connect(m_page->chkInvert, TQT_SIGNAL(clicked()),
-        this, TQT_SLOT(slotInvertClicked()));
+    connect(m_page->chkInvert, TQ_SIGNAL(clicked()),
+        this, TQ_SLOT(slotInvertClicked()));
 
-    connect(m_page->cmbSelect, TQT_SIGNAL(activated(int)),
-        this, TQT_SLOT(slotSelectionTypeChanged(int)));
+    connect(m_page->cmbSelect, TQ_SIGNAL(activated(int)),
+        this, TQ_SLOT(slotSelectionTypeChanged(int)));
 
-    connect (m_page->radioAdd, TQT_SIGNAL(toggled(bool)),
-         this, TQT_SLOT(slotAdd(bool)));
+    connect (m_page->radioAdd, TQ_SIGNAL(toggled(bool)),
+         this, TQ_SLOT(slotAdd(bool)));
 
-    connect (m_page->radioSubtract, TQT_SIGNAL(toggled(bool)),
-         this, TQT_SLOT(slotSubtract(bool)));
+    connect (m_page->radioSubtract, TQ_SIGNAL(toggled(bool)),
+         this, TQ_SLOT(slotSubtract(bool)));
 
-    connect (m_page->bnSelect, TQT_SIGNAL(clicked()),
-        this, TQT_SLOT(slotSelectClicked()));
+    connect (m_page->bnSelect, TQ_SIGNAL(clicked()),
+        this, TQ_SLOT(slotSelectClicked()));
 
-    connect (m_page->bnDeselect, TQT_SIGNAL(clicked()),
-        this, TQT_SLOT(slotDeselectClicked()));
+    connect (m_page->bnDeselect, TQ_SIGNAL(clicked()),
+        this, TQ_SLOT(slotDeselectClicked()));
 
 }
 
