@@ -56,7 +56,7 @@ enum enumAction {
  */
 class DlgColorRange: public KDialogBase {
     typedef KDialogBase super;
-    Q_OBJECT
+    TQ_OBJECT
   
 
 
