@@ -31,7 +31,7 @@ class WdgConvertColorSpace;
  */
 class DlgColorSpaceConversion: public KDialogBase {
     typedef KDialogBase super;
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
