@@ -31,7 +31,7 @@ namespace Plugins {
 namespace FiltersGallery {
     class ChalkFiltersGallery : public KParts::Plugin
     {
-        Q_OBJECT
+        TQ_OBJECT
   
         public:
             ChalkFiltersGallery(TQObject *parent, const char *name, const TQStringList &);
