@@ -31,7 +31,7 @@
 class KisView;
 
 class KisImageRasteredCache : public TQObject {
-Q_OBJECT
+TQ_OBJECT
   
 
 public:
