@@ -32,7 +32,7 @@
 
 #include <tdelocale.h>
 #include <kiconloader.h>
-#include <kinstance.h>
+#include <tdeinstance.h>
 #include <kdialogbase.h>
 #include <tdemessagebox.h>
 #include <kstandarddirs.h>
