@@ -30,7 +30,7 @@ class KisID;
 
 class PerfTest : public KParts::Plugin
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     PerfTest(TQObject *parent, const char *name, const TQStringList &);
