@@ -26,7 +26,7 @@ class KisView;
 
 class RotateImage : public KParts::Plugin
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     RotateImage(TQObject *parent, const char *name, const TQStringList &);
