@@ -26,7 +26,7 @@ class KSnapshot;
 
 class Screenshot : public KParts::Plugin
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     Screenshot(TQObject *parent, const char *name, const TQStringList &);
