@@ -32,7 +32,7 @@ namespace Kross {
 	@author Cyrille Berger <cberger@cberger.net>
 */
 class KisScriptMonitor : public TQObject {
-    Q_OBJECT
+    TQ_OBJECT
   
     private:
         KisScriptMonitor();
