@@ -31,7 +31,7 @@ class WdgSeparations;
  */
 class DlgSeparate: public KDialogBase {
     typedef KDialogBase super;
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
