@@ -47,7 +47,7 @@ enum enumSepOutput {
 
 class KisChannelSeparator : public KisProgressSubject {
 
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
