@@ -27,7 +27,7 @@ class KisView;
 
 class Variations : public KParts::Plugin
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
         Variations(TQObject *parent, const char *name, const TQStringList &);
