@@ -69,7 +69,7 @@ void KisCanvasWidgetPainter::setPen(const TQPen& /*pen*/)
 {
 }
 
-void KisCanvasWidgetPainter::setPen(Qt::PenStyle /*penStyle*/)
+void KisCanvasWidgetPainter::setPen(TQt::PenStyle /*penStyle*/)
 {
 }
 
@@ -108,12 +108,12 @@ void KisCanvasWidgetPainter::setBackgroundColor(const TQColor& /*color*/)
 {
 }
 
-Qt::BGMode KisCanvasWidgetPainter::backgroundMode() const
+TQt::BGMode KisCanvasWidgetPainter::backgroundMode() const
 {
-    return Qt::TransparentMode;
+    return TQt::TransparentMode;
 }
 
-void KisCanvasWidgetPainter::setBackgroundMode(Qt::BGMode /*bgMode*/)
+void KisCanvasWidgetPainter::setBackgroundMode(TQt::BGMode /*bgMode*/)
 {
 }
 
@@ -641,7 +641,7 @@ void KisCanvasPainter::setPen(const TQPen& pen)
     }
 }
 
-void KisCanvasPainter::setPen(Qt::PenStyle penStyle)
+void KisCanvasPainter::setPen(TQt::PenStyle penStyle)
 {
     if (m_canvasWidgetPainter != 0) {
         m_canvasWidgetPainter->setPen(penStyle);
@@ -707,15 +707,15 @@ void KisCanvasPainter::setBackgroundColor(const TQColor& color)
     }
 }
 
-Qt::BGMode KisCanvasPainter::backgroundMode() const
+TQt::BGMode KisCanvasPainter::backgroundMode() const
 {
     if (m_canvasWidgetPainter != 0) {
         return m_canvasWidgetPainter->backgroundMode();
     }
-    return Qt::TransparentMode;
+    return TQt::TransparentMode;
 }
 
-void KisCanvasPainter::setBackgroundMode(Qt::BGMode bgMode)
+void KisCanvasPainter::setBackgroundMode(TQt::BGMode bgMode)
 {
     if (m_canvasWidgetPainter != 0) {
         m_canvasWidgetPainter->setBackgroundMode(bgMode);
