@@ -33,7 +33,7 @@ class TQImage;
  */
 class KisClipboard : public TQObject {
 
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
