@@ -33,7 +33,7 @@ class KValueSelector;
 
 class KisColorPopup : public TQFrame {
 
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
@@ -55,7 +55,7 @@ private:
 
 class KRITAUI_EXPORT KisColorCup : public TQPushButton {
 
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
