@@ -51,7 +51,7 @@ class KisView;
 
 class KisPopupFrame : public TQPopupMenu {
 
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
@@ -75,7 +75,7 @@ private:
  */
 class KisControlFrame : public TQObject  //: public TDEToolBar
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
