@@ -37,7 +37,7 @@ class TQGroupBox;
 class KisDlgAdjustmentLayer : public KDialogBase
 {
 
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
