@@ -27,7 +27,7 @@ class KisColorSpace;
 
 class KisDlgLayerProperties : public KDialogBase {
     typedef KDialogBase super;
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
