@@ -43,7 +43,7 @@ class KisPreviewDialog;
  */
 class KRITACORE_EXPORT KisFilterManager : public TQObject {
 
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
