@@ -28,7 +28,7 @@ class TQToolButton;
 class KProgress;
 
 class KisLabelProgress : public TQLabel, public KisProgressDisplayInterface {
-    Q_OBJECT
+    TQ_OBJECT
   
     typedef TQLabel super;
 
