@@ -95,27 +95,27 @@ KisLayerBox::KisLayerBox(KisCanvasSubject *subject, TQWidget *parent, const char
                                                     loadPixmap("unlocked.png", il, TDEIcon::SizeSmallMedium));
 
 
-    connect(list()->contextMenu(), TQT_SIGNAL(aboutToShow()), TQT_SLOT(slotAboutToShow()));
-    connect(list(), TQT_SIGNAL(activated(LayerItem*)),
-                    TQT_SLOT(slotLayerActivated(LayerItem*)));
-    connect(list(), TQT_SIGNAL(displayNameChanged(LayerItem*, const TQString&)),
-                    TQT_SLOT(slotLayerDisplayNameChanged(LayerItem*, const TQString&)));
-    connect(list(), TQT_SIGNAL(propertyChanged(LayerItem*, const TQString&, bool)),
-                    TQT_SLOT(slotLayerPropertyChanged(LayerItem*, const TQString&, bool)));
-    connect(list(), TQT_SIGNAL(layerMoved(LayerItem*, LayerItem*, LayerItem*)),
-                    TQT_SLOT(slotLayerMoved(LayerItem*, LayerItem*, LayerItem*)));
-    connect(list(), TQT_SIGNAL(requestNewLayer(LayerItem*, LayerItem*)),
-                    TQT_SLOT(slotRequestNewLayer(LayerItem*, LayerItem*)));
-    connect(list(), TQT_SIGNAL(requestNewFolder(LayerItem*, LayerItem*)),
-                    TQT_SLOT(slotRequestNewFolder(LayerItem*, LayerItem*)));
-    connect(list(), TQT_SIGNAL(requestNewAdjustmentLayer(LayerItem*, LayerItem*)),
-                    TQT_SLOT(slotRequestNewAdjustmentLayer(LayerItem*, LayerItem*)));
-    connect(list(), TQT_SIGNAL(requestNewObjectLayer(LayerItem*, LayerItem*, const KoDocumentEntry&)),
-                    TQT_SLOT(slotRequestNewObjectLayer(LayerItem*, LayerItem*, const KoDocumentEntry&)));
-    connect(list(), TQT_SIGNAL(requestRemoveLayer(LayerItem*)),
-                    TQT_SLOT(slotRequestRemoveLayer(LayerItem*)));
-    connect(list(), TQT_SIGNAL(requestLayerProperties(LayerItem*)),
-                    TQT_SLOT(slotRequestLayerProperties(LayerItem*)));
+    connect(list()->contextMenu(), TQ_SIGNAL(aboutToShow()), TQ_SLOT(slotAboutToShow()));
+    connect(list(), TQ_SIGNAL(activated(LayerItem*)),
+                    TQ_SLOT(slotLayerActivated(LayerItem*)));
+    connect(list(), TQ_SIGNAL(displayNameChanged(LayerItem*, const TQString&)),
+                    TQ_SLOT(slotLayerDisplayNameChanged(LayerItem*, const TQString&)));
+    connect(list(), TQ_SIGNAL(propertyChanged(LayerItem*, const TQString&, bool)),
+                    TQ_SLOT(slotLayerPropertyChanged(LayerItem*, const TQString&, bool)));
+    connect(list(), TQ_SIGNAL(layerMoved(LayerItem*, LayerItem*, LayerItem*)),
+                    TQ_SLOT(slotLayerMoved(LayerItem*, LayerItem*, LayerItem*)));
+    connect(list(), TQ_SIGNAL(requestNewLayer(LayerItem*, LayerItem*)),
+                    TQ_SLOT(slotRequestNewLayer(LayerItem*, LayerItem*)));
+    connect(list(), TQ_SIGNAL(requestNewFolder(LayerItem*, LayerItem*)),
+                    TQ_SLOT(slotRequestNewFolder(LayerItem*, LayerItem*)));
+    connect(list(), TQ_SIGNAL(requestNewAdjustmentLayer(LayerItem*, LayerItem*)),
+                    TQ_SLOT(slotRequestNewAdjustmentLayer(LayerItem*, LayerItem*)));
+    connect(list(), TQ_SIGNAL(requestNewObjectLayer(LayerItem*, LayerItem*, const KoDocumentEntry&)),
+                    TQ_SLOT(slotRequestNewObjectLayer(LayerItem*, LayerItem*, const KoDocumentEntry&)));
+    connect(list(), TQ_SIGNAL(requestRemoveLayer(LayerItem*)),
+                    TQ_SLOT(slotRequestRemoveLayer(LayerItem*)));
+    connect(list(), TQ_SIGNAL(requestLayerProperties(LayerItem*)),
+                    TQ_SLOT(slotRequestLayerProperties(LayerItem*)));
 
     m_newLayerMenu = new TDEPopupMenu(this);
     m_lst->bnAdd->setPopup(m_newLayerMenu);
@@ -123,24 +123,24 @@ KisLayerBox::KisLayerBox(KisCanvasSubject *subject, TQWidget *parent, const char
     m_newLayerMenu->insertItem( SmallIconSet( "document-new" ), i18n( "&New Layer..." ), PAINT_LAYER );
     m_newLayerMenu->insertItem( SmallIconSet( "folder" ), i18n( "New &Group Layer..." ), GROUP_LAYER );
     m_newLayerMenu->insertItem( SmallIconSet( "tool_filter" ), i18n( "New &Adjustment Layer..." ), ADJUSTMENT_LAYER );
-    m_partLayerAction = new KoPartSelectAction( i18n( "New &Object Layer" ), "gear", TQT_TQOBJECT(this) );
+    m_partLayerAction = new KoPartSelectAction( i18n( "New &Object Layer" ), "gear", this );
     m_partLayerAction->plug( m_newLayerMenu );
-    connect(m_partLayerAction, TQT_SIGNAL(activated()), this, TQT_SLOT(slotAddMenuActivated()));
-    connect(m_newLayerMenu, TQT_SIGNAL(activated(int)), this, TQT_SLOT(slotAddMenuActivated(int)));
+    connect(m_partLayerAction, TQ_SIGNAL(activated()), this, TQ_SLOT(slotAddMenuActivated()));
+    connect(m_newLayerMenu, TQ_SIGNAL(activated(int)), this, TQ_SLOT(slotAddMenuActivated(int)));
 
 
-    connect(m_lst->bnDelete, TQT_SIGNAL(clicked()), TQT_SLOT(slotRmClicked()));
-    connect(m_lst->bnRaise, TQT_SIGNAL(clicked()), TQT_SLOT(slotRaiseClicked()));
-    connect(m_lst->bnLower, TQT_SIGNAL(clicked()), TQT_SLOT(slotLowerClicked()));
-    connect(m_lst->bnProperties, TQT_SIGNAL(clicked()), TQT_SLOT(slotPropertiesClicked()));
-    connect(m_lst->intOpacity, TQT_SIGNAL(valueChanged(int, bool)), TQT_SIGNAL(sigOpacityChanged(int, bool)));
-    connect(m_lst->intOpacity, TQT_SIGNAL(finishedChanging(int, int)), TQT_SIGNAL(sigOpacityFinishedChanging(int, int)));
-    connect(m_lst->cmbComposite, TQT_SIGNAL(activated(const KisCompositeOp&)), TQT_SIGNAL(sigItemComposite(const KisCompositeOp&)));
+    connect(m_lst->bnDelete, TQ_SIGNAL(clicked()), TQ_SLOT(slotRmClicked()));
+    connect(m_lst->bnRaise, TQ_SIGNAL(clicked()), TQ_SLOT(slotRaiseClicked()));
+    connect(m_lst->bnLower, TQ_SIGNAL(clicked()), TQ_SLOT(slotLowerClicked()));
+    connect(m_lst->bnProperties, TQ_SIGNAL(clicked()), TQ_SLOT(slotPropertiesClicked()));
+    connect(m_lst->intOpacity, TQ_SIGNAL(valueChanged(int, bool)), TQ_SIGNAL(sigOpacityChanged(int, bool)));
+    connect(m_lst->intOpacity, TQ_SIGNAL(finishedChanging(int, int)), TQ_SIGNAL(sigOpacityFinishedChanging(int, int)));
+    connect(m_lst->cmbComposite, TQ_SIGNAL(activated(const KisCompositeOp&)), TQ_SIGNAL(sigItemComposite(const KisCompositeOp&)));
 
     Q_ASSERT(subject->document() != 0);
 
     if (subject->document()) {
-        connect(subject->document(), TQT_SIGNAL(sigCommandExecuted()), TQT_SLOT(updateThumbnails()));
+        connect(subject->document(), TQ_SIGNAL(sigCommandExecuted()), TQ_SLOT(updateThumbnails()));
     }
 }
 
@@ -165,16 +165,16 @@ void KisLayerBox::setImage(KisImageSP img)
 
     if (img)
     {
-        connect(img, TQT_SIGNAL(sigLayerActivated(KisLayerSP)), this, TQT_SLOT(slotLayerActivated(KisLayerSP)));
-        connect(img, TQT_SIGNAL(sigLayerAdded(KisLayerSP)), this, TQT_SLOT(slotLayerAdded(KisLayerSP)));
-        connect(img, TQT_SIGNAL(sigLayerRemoved(KisLayerSP, KisGroupLayerSP, KisLayerSP)),
-                this, TQT_SLOT(slotLayerRemoved(KisLayerSP, KisGroupLayerSP, KisLayerSP)));
-        connect(img, TQT_SIGNAL(sigLayerPropertiesChanged(KisLayerSP)),
-                this, TQT_SLOT(slotLayerPropertiesChanged(KisLayerSP)));
-        connect(img, TQT_SIGNAL(sigLayerMoved(KisLayerSP, KisGroupLayerSP, KisLayerSP)),
-                this, TQT_SLOT(slotLayerMoved(KisLayerSP, KisGroupLayerSP, KisLayerSP)));
-        connect(img, TQT_SIGNAL(sigLayersChanged(KisGroupLayerSP)), this, TQT_SLOT(slotLayersChanged(KisGroupLayerSP)));
-        connect(img, TQT_SIGNAL(sigLayerUpdated(KisLayerSP, TQRect)), this, TQT_SLOT(slotLayerUpdated(KisLayerSP, TQRect)));
+        connect(img, TQ_SIGNAL(sigLayerActivated(KisLayerSP)), this, TQ_SLOT(slotLayerActivated(KisLayerSP)));
+        connect(img, TQ_SIGNAL(sigLayerAdded(KisLayerSP)), this, TQ_SLOT(slotLayerAdded(KisLayerSP)));
+        connect(img, TQ_SIGNAL(sigLayerRemoved(KisLayerSP, KisGroupLayerSP, KisLayerSP)),
+                this, TQ_SLOT(slotLayerRemoved(KisLayerSP, KisGroupLayerSP, KisLayerSP)));
+        connect(img, TQ_SIGNAL(sigLayerPropertiesChanged(KisLayerSP)),
+                this, TQ_SLOT(slotLayerPropertiesChanged(KisLayerSP)));
+        connect(img, TQ_SIGNAL(sigLayerMoved(KisLayerSP, KisGroupLayerSP, KisLayerSP)),
+                this, TQ_SLOT(slotLayerMoved(KisLayerSP, KisGroupLayerSP, KisLayerSP)));
+        connect(img, TQ_SIGNAL(sigLayersChanged(KisGroupLayerSP)), this, TQ_SLOT(slotLayersChanged(KisGroupLayerSP)));
+        connect(img, TQ_SIGNAL(sigLayerUpdated(KisLayerSP, TQRect)), this, TQ_SLOT(slotLayerUpdated(KisLayerSP, TQRect)));
         slotLayersChanged(img->rootLayer());
         updateThumbnails();
     }
