@@ -29,7 +29,7 @@ class KisLayer;
 
 class KisLayerList: public LayerList
 {
-    Q_OBJECT
+    TQ_OBJECT
   
     typedef LayerList super;
 
