@@ -28,7 +28,7 @@
 class KisDelayedActionIntegerInput : public KIntNumInput
 {
 
-    Q_OBJECT
+    TQ_OBJECT
   
             
 public:
@@ -64,7 +64,7 @@ typedef std::vector<KisIntegerWidgetParam> vKisIntegerWidgetParam;
 
 class KRITA_EXPORT KisMultiIntegerFilterWidget : public KisFilterConfigWidget
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     KisMultiIntegerFilterWidget(TQWidget * parent,  const char * name, const char *caption, vKisIntegerWidgetParam iwparam);
