@@ -78,14 +78,14 @@ KisPaletteWidget::KisPaletteWidget( TQWidget *parent, int minWidth, int cols)
 
     //setFixedSize(sizeHint());
 
-    connect(combo, TQT_SIGNAL(activated(const TQString &)),
-            this, TQT_SLOT(slotSetPalette(const TQString &)));
-    connect(m_view, TQT_SIGNAL(colorSelected(const KisColor &)),
-            this, TQT_SIGNAL(colorSelected(const KisColor &)));
-    connect(m_view, TQT_SIGNAL(colorSelected(const TQColor &)),
-            this, TQT_SIGNAL(colorSelected(const TQColor &)));
-    connect(m_view, TQT_SIGNAL(colorDoubleClicked(const KisColor &, const TQString &)),
-            this, TQT_SIGNAL(colorDoubleClicked(const KisColor &, const TQString &)));
+    connect(combo, TQ_SIGNAL(activated(const TQString &)),
+            this, TQ_SLOT(slotSetPalette(const TQString &)));
+    connect(m_view, TQ_SIGNAL(colorSelected(const KisColor &)),
+            this, TQ_SIGNAL(colorSelected(const KisColor &)));
+    connect(m_view, TQ_SIGNAL(colorSelected(const TQColor &)),
+            this, TQ_SIGNAL(colorSelected(const TQColor &)));
+    connect(m_view, TQ_SIGNAL(colorDoubleClicked(const KisColor &, const TQString &)),
+            this, TQ_SIGNAL(colorDoubleClicked(const KisColor &, const TQString &)));
 }
 
 KisPaletteWidget::~KisPaletteWidget()
