@@ -38,7 +38,7 @@ class KisColor;
  */
 class KisPaletteWidget : public TQWidget
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     KisPaletteWidget( TQWidget *parent, int minWidth=210, int cols = 16);
