@@ -72,7 +72,7 @@ protected:
  * Embedded parts should get loaded and saved to the Native Chalk Fileformat natively.
  */
 class KisPartLayerImpl : public KisPartLayer {
-    Q_OBJECT
+    TQ_OBJECT
   
     typedef KisPartLayer super;
 public:
