@@ -47,7 +47,7 @@ class KisLabelProgress;
  */
 class KisPreviewWidget : public PreviewWidgetBase
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
