@@ -81,7 +81,7 @@ public:
 
     virtual void setWorldXForm(bool);
     virtual const TQWMatrix&worldMatrix() const;
-    virtual void setWorldMatrix(const TQWMatrix&, bool combine=FALSE);
+    virtual void setWorldMatrix(const TQWMatrix&, bool combine=false);
 
     virtual void saveWorldMatrix();
     virtual void restoreWorldMatrix();
@@ -138,7 +138,7 @@ public:
     virtual void drawChord(const TQRect&, int a, int alen);
     virtual void drawLineSegments(const TQPointArray&, int index=0, int nlines=-1);
     virtual void drawPolyline(const TQPointArray&, int index=0, int npoints=-1);
-    virtual void drawPolygon(const TQPointArray&, bool winding=FALSE, int index=0, int npoints=-1);
+    virtual void drawPolygon(const TQPointArray&, bool winding=false, int index=0, int npoints=-1);
     virtual void drawConvexPolygon(const TQPointArray&, int index=0, int npoints=-1);
     virtual void drawCubicBezier(const TQPointArray&, int index=0);
     virtual void drawPixmap(int x, int y, const TQPixmap&, int sx=0, int sy=0, int sw=-1, int sh=-1);
