@@ -102,142 +102,142 @@ void KisSelectionManager::setup(TDEActionCollection * collection)
     // XXX: setup shortcuts!
 
     m_cut = KStdAction::cut(this,
-            TQT_SLOT(cut()),
+            TQ_SLOT(cut()),
             collection,
             "cut");
 
     m_copy = KStdAction::copy(this,
-                TQT_SLOT(copy()),
+                TQ_SLOT(copy()),
                 collection,
                 "copy");
 
     m_paste = KStdAction::paste(this,
-                TQT_SLOT(paste()),
+                TQ_SLOT(paste()),
                 collection,
                 "paste");
 
     m_pasteNew = new TDEAction(i18n("Paste into &New Image"),
                 0, 0,
-                this, TQT_SLOT(pasteNew()),
+                this, TQ_SLOT(pasteNew()),
                 collection,
                 "paste_new");
 
 
     m_selectAll = KStdAction::selectAll(this,
-                    TQT_SLOT(selectAll()),
+                    TQ_SLOT(selectAll()),
                     collection,
                     "select_all");
 
     m_deselect = KStdAction::deselect(this,
-                    TQT_SLOT(deselect()),
+                    TQ_SLOT(deselect()),
                     collection,
                     "deselect");
 
 
     m_clear = KStdAction::clear(this,
-                TQT_SLOT(clear()),
+                TQ_SLOT(clear()),
                 collection,
                 "clear");
 
     m_reselect = new TDEAction(i18n("&Reselect"),
                 0, "Ctrl+Shift+D",
-                this, TQT_SLOT(reselect()),
+                this, TQ_SLOT(reselect()),
                 collection, "reselect");
 
     m_invert = new TDEAction(i18n("&Invert"),
                 0, "Ctrl+I",
-                this, TQT_SLOT(invert()),
+                this, TQ_SLOT(invert()),
                 collection, "invert");
 
 
     m_toNewLayer = new TDEAction(i18n("Copy Selection to New Layer"),
                 0, "Ctrl+J",
-                this, TQT_SLOT(copySelectionToNewLayer()),
+                this, TQ_SLOT(copySelectionToNewLayer()),
                 collection, "copy_selection_to_new_layer");
 
 
     m_cutToNewLayer = new TDEAction(i18n("Cut Selection to New Layer"),
             0, "Ctrl+Shift+J",
-            this, TQT_SLOT(cutToNewLayer()),
+            this, TQ_SLOT(cutToNewLayer()),
             collection, "cut_selection_to_new_layer");
 
     m_feather = new TDEAction(i18n("Feather"),
                 0, "Ctrl+Alt+D",
-                this, TQT_SLOT(feather()),
+                this, TQ_SLOT(feather()),
                 collection, "feather");
 
     m_fillForegroundColor = new TDEAction(i18n("Fill with Foreground Color"),
                                              "Alt+backspace", this,
-                                             TQT_SLOT(fillForegroundColor()),
+                                             TQ_SLOT(fillForegroundColor()),
                                              collection,
                                              "fill_selection_foreground_color");
     m_fillBackgroundColor = new TDEAction(i18n("Fill with Background Color"),
                                              "backspace", this,
-                                             TQT_SLOT(fillBackgroundColor()),
+                                             TQ_SLOT(fillBackgroundColor()),
                                              collection,
                                              "fill_selection_background_color");
     m_fillPattern = new TDEAction(i18n("Fill with Pattern"),
                                              0, this,
-                                             TQT_SLOT(fillPattern()),
+                                             TQ_SLOT(fillPattern()),
                                              collection,
                                              "fill_selection_pattern");
 
-    m_toggleDisplaySelection = new TDEToggleAction(i18n("Display Selection"), "Ctrl+h", this, TQT_SLOT(toggleDisplaySelection()), collection, "toggle_display_selection");
+    m_toggleDisplaySelection = new TDEToggleAction(i18n("Display Selection"), "Ctrl+h", this, TQ_SLOT(toggleDisplaySelection()), collection, "toggle_display_selection");
     m_toggleDisplaySelection->setCheckedState(KGuiItem(i18n("Hide Selection")));
     m_toggleDisplaySelection->setChecked(true);
 
     m_border =
         new TDEAction(i18n("Border..."),
                 0, 0,
-                this, TQT_SLOT(border()),
+                this, TQ_SLOT(border()),
                 collection, "border");
     m_expand =
         new TDEAction(i18n("Expand..."),
                 0, 0,
-                this, TQT_SLOT(expand()),
+                this, TQ_SLOT(expand()),
                 collection, "expand");
 
     m_smooth =
         new TDEAction(i18n("Smooth..."),
                 0, 0,
-                this, TQT_SLOT(smooth()),
+                this, TQ_SLOT(smooth()),
                 collection, "smooth");
 
 
     m_contract =
         new TDEAction(i18n("Contract..."),
                 0, 0,
-                this, TQT_SLOT(contract()),
+                this, TQ_SLOT(contract()),
                 collection, "contract");
     m_similar =
         new TDEAction(i18n("Similar"),
                 0, 0,
-                this, TQT_SLOT(similar()),
+                this, TQ_SLOT(similar()),
                 collection, "similar");
 
 
     m_transform
         = new TDEAction(i18n("Transform..."),
                   0, 0,
-                  this, TQT_SLOT(transform()),
+                  this, TQ_SLOT(transform()),
                   collection, "transform_selection");
 
 
 //     m_load
 //         = new TDEAction(i18n("Load..."),
 //                   0, 0,
-//                   this, TQT_SLOT(load()),
+//                   this, TQ_SLOT(load()),
 //                   collection, "load_selection");
 //
 //
 //     m_save
 //         = new TDEAction(i18n("Save As..."),
 //                   0, 0,
-//                   this, TQT_SLOT(save()),
+//                   this, TQ_SLOT(save()),
 //                   collection, "save_selection");
 
         TQClipboard *cb = TQApplication::clipboard();
-        connect(cb, TQT_SIGNAL(dataChanged()), TQT_SLOT(clipboardDataChanged()));
+        connect(cb, TQ_SIGNAL(dataChanged()), TQ_SLOT(clipboardDataChanged()));
 }
 
 void KisSelectionManager::clipboardDataChanged()
