@@ -48,7 +48,7 @@ class KisTextBrushResource : public KisBrush
 
 class KisTextBrush : public KisWdgTextBrush
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	KisTextBrush(TQWidget *parent, const char* name, const TQString& caption);
