@@ -117,7 +117,7 @@ class KRITA_EXPORT KisView
       private KisCanvasController
 {
 
-    Q_OBJECT
+    TQ_OBJECT
   
 
     typedef KoView super;
