@@ -119,7 +119,7 @@ public:
           m_list( list )
     {
         TQFrame::setPalette( TQToolTip::palette() );
-        connect( &m_timer, TQT_SIGNAL( timeout() ), m_list, TQT_SLOT( hideTip() ) );
+        connect( &m_timer, TQ_SIGNAL( timeout() ), m_list, TQ_SLOT( hideTip() ) );
         tqApp->installEventFilter( this );
     }
 
@@ -302,12 +302,12 @@ LayerList::LayerList( TQWidget *parent, const char *name )
 
     setNumRows( 2 );
 
-    connect( this, TQT_SIGNAL( itemRenamed( TQListViewItem*, const TQString&, int ) ),
-                 TQT_SLOT( slotItemRenamed( TQListViewItem*, const TQString&, int ) ) );
-    connect( this, TQT_SIGNAL( moved( TQPtrList<TQListViewItem>&, TQPtrList<TQListViewItem>&, TQPtrList<TQListViewItem>& ) ),
-             TQT_SLOT( slotItemMoved( TQPtrList<TQListViewItem>&, TQPtrList<TQListViewItem>&, TQPtrList<TQListViewItem>& ) ) );
-    connect( this, TQT_SIGNAL( onItem( TQListViewItem* ) ), TQT_SLOT( hideTip() ) );
-    connect( this, TQT_SIGNAL( onViewport() ), TQT_SLOT( hideTip() ) );
+    connect( this, TQ_SIGNAL( itemRenamed( TQListViewItem*, const TQString&, int ) ),
+                 TQ_SLOT( slotItemRenamed( TQListViewItem*, const TQString&, int ) ) );
+    connect( this, TQ_SIGNAL( moved( TQPtrList<TQListViewItem>&, TQPtrList<TQListViewItem>&, TQPtrList<TQListViewItem>& ) ),
+             TQ_SLOT( slotItemMoved( TQPtrList<TQListViewItem>&, TQPtrList<TQListViewItem>&, TQPtrList<TQListViewItem>& ) ) );
+    connect( this, TQ_SIGNAL( onItem( TQListViewItem* ) ), TQ_SLOT( hideTip() ) );
+    connect( this, TQ_SIGNAL( onViewport() ), TQ_SLOT( hideTip() ) );
 }
 
 LayerList::~LayerList()
@@ -671,7 +671,7 @@ void LayerList::contentsMousePressEvent( TQMouseEvent *e )
     else
     {
         super::contentsMousePressEvent( e );
-        if( e->button() == Qt::RightButton )
+        if( e->button() == TQt::RightButton )
             showContextMenu();
     }
 }
@@ -1170,11 +1170,11 @@ TQFontMetrics LayerItem::fontMetrics() const
 
 bool LayerItem::mousePressEvent( TQMouseEvent *e )
 {
-    if( e->button() == Qt::RightButton )
+    if( e->button() == TQt::RightButton )
     {
         if ( !(e->state() & TQt::ControlButton) && !(e->state() & TQt::ShiftButton) )
             setActive();
-        TQTimer::singleShot( 0, listView(), TQT_SLOT( showContextMenu() ) );
+        TQTimer::singleShot( 0, listView(), TQ_SLOT( showContextMenu() ) );
         return false;
     }
 
