@@ -33,7 +33,7 @@ template<class T> class TQPtrList;
 
 class LayerList: public TDEListView
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
