@@ -81,7 +81,7 @@ private:
  */
 class SqueezedComboBox : public TQComboBox
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
