@@ -29,7 +29,7 @@ class ExamplePart;
 
 class ExampleView : public KoView
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     ExampleView( ExamplePart* part, TQWidget* parent = 0, const char* name = 0 );
