@@ -23,7 +23,7 @@
 #include <KoFilter.h>
 
 class KisJPEGExport : public KoFilter {
-    Q_OBJECT
+    TQ_OBJECT
   
     public:
         KisJPEGExport(KoFilter *parent, const char *name, const TQStringList&);
