@@ -23,7 +23,7 @@
 #include <KoFilter.h>
 
 class KisOpenEXRExport : public KoFilter {
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
