@@ -35,8 +35,8 @@ KisDlgOptionsTIFF::KisDlgOptionsTIFF(TQWidget *parent, const char *name)
 {
     optionswdg = new KisWdgOptionsTIFF(this);
     activated(0);
-    connect(optionswdg->kComboBoxCompressionType, TQT_SIGNAL(activated ( int )), this, TQT_SLOT(activated ( int ) ));
-    connect(optionswdg->flatten, TQT_SIGNAL(toggled(bool)), this, TQT_SLOT(flattenToggled( bool) ) );
+    connect(optionswdg->kComboBoxCompressionType, TQ_SIGNAL(activated ( int )), this, TQ_SLOT(activated ( int ) ));
+    connect(optionswdg->flatten, TQ_SIGNAL(toggled(bool)), this, TQ_SLOT(flattenToggled( bool) ) );
     setMainWidget(optionswdg);
     kapp->restoreOverrideCursor();
     setSizePolicy(TQSizePolicy(TQSizePolicy::Minimum, TQSizePolicy::Minimum) );
