@@ -67,7 +67,7 @@ struct KisTIFFOptions {
 };
 
 class KisTIFFConverter : public KisProgressSubject {
-        Q_OBJECT
+        TQ_OBJECT
   
     public:
         KisTIFFConverter(KisDoc *doc, KisUndoAdapter *adapter);
