@@ -670,7 +670,7 @@ TQByteArray& AIElement::asByteArray()
 }
 
 /*!
-  Returns TRUE if the aielement's type can be cast to the requested
+  Returns true if the aielement's type can be cast to the requested
   type, \p t. Such casting is done automatically when calling the
   toInt(), ... or asInt(), ... methods.
 
@@ -686,19 +686,19 @@ TQByteArray& AIElement::asByteArray()
 bool AIElement::canCast( Type t ) const
 {
   if ( d->typ == t )
-	  return TRUE;
+	  return true;
   if ( t == Int && ( d->typ == String || d->typ == Double || d->typ == UInt || d->typ == Byte) )
-	  return TRUE;
+	  return true;
   if ( t == UInt && ( d->typ == String || d->typ == Double || d->typ == Int || d->typ == Byte) )
-	  return TRUE;
+	  return true;
   if ( t == Double && ( d->typ == String || d->typ == Int || d->typ == UInt || d->typ == Byte) )
-	  return TRUE;
+	  return true;
   if ( t == CString && d->typ == String )
-	  return TRUE;
+	  return true;
   if ( t == String && ( d->typ == CString || d->typ == Int || d->typ == UInt || d->typ == Double || d->typ == Byte) )
-	  return TRUE;
+	  return true;
 
-  return FALSE;
+  return false;
 }
 
 /*!
@@ -710,8 +710,8 @@ bool AIElement::canCast( Type t ) const
   AIElement::String, an empty point array if the requested type \p t is
   AIElement::PointArray, etc).
 
-  \returns TRUE if the current type of the
-  aielement was successfully casted; otherwise returns FALSE.
+  \returns true if the current type of the
+  aielement was successfully casted; otherwise returns false.
 
   \see canCast()
 */
@@ -756,14 +756,14 @@ bool AIElement::cast( Type t )
   return canCast( t );
 }
 
-/*!  Compares this AIElement with \a v and returns TRUE if they are
-  equal; otherwise returns FALSE.
+/*!  Compares this AIElement with \a v and returns true if they are
+  equal; otherwise returns false.
 */
 
 bool AIElement::operator==( const AIElement &v ) const
 {
   if ( !v.canCast( type() ) )
-	  return FALSE;
+	  return false;
   switch( d->typ ) {
 /*    case List:
 	     return v.toList() == toList(); */
@@ -791,11 +791,11 @@ bool AIElement::operator==( const AIElement &v ) const
     case Invalid:
 	     break;
     }
-    return FALSE;
+    return false;
 }
 
-/*!  Compares this AIElement with \a v and returns TRUE if they are
-  not equal; otherwise returns FALSE.
+/*!  Compares this AIElement with \a v and returns true if they are
+  not equal; otherwise returns false.
 */
 
 bool AIElement::operator!=( const AIElement &v ) const
