@@ -26,7 +26,7 @@
 
 class KontourImport : public KoFilter
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 
 public:
