@@ -38,7 +38,7 @@ class VPath;
 
 class SvgImport : public KoFilter
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 
 public:
