@@ -88,12 +88,12 @@ private:
     void  drawPie( int x, int y, int w, int h, int a, int alen );
     void  drawChord( int x, int y, int w, int h, int a, int alen );
     void  drawPolyline( const TQPointArray &pa );
-    void  drawPolygon( const TQPointArray &pa, bool winding=FALSE );
+    void  drawPolygon( const TQPointArray &pa, bool winding=false );
     /**
      * drawPolyPolygon draw the XOR of a list of polygons
      * listPa : list of polygons
      */
-    void  drawPolyPolygon( TQPtrList<TQPointArray>& listPa, bool winding=FALSE );
+    void  drawPolyPolygon( TQPtrList<TQPointArray>& listPa, bool winding=false );
     void  drawImage( int x, int y, const TQImage &, int sx = 0, int sy = 0, int sw = -1, int sh = -1 );
 
     // Text drawing 
@@ -102,7 +102,7 @@ private:
     void  drawText( int x, int y, int w, int h, int flags, const TQString &s, double rotation );
 
     // matrix transformation : only used in some bitmap manipulation
-    void  setWorldMatrix( const TQWMatrix &, bool combine=FALSE );
+    void  setWorldMatrix( const TQWMatrix &, bool combine=false );
 
     //-----------------------------------------------------------------------------
     // Utilities 
