@@ -24,7 +24,7 @@
 
 class XpmExport : public ImageExport
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
