@@ -37,7 +37,7 @@ namespace KFormula {
 
 class PNGExportDia : public KDialogBase
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
