@@ -31,7 +31,7 @@ class KoStore;
 
 class OoImpressExport : public KoFilter
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     OoImpressExport( KoFilter * parent, const char * name, const TQStringList & );
