@@ -40,7 +40,7 @@ struct animationList
 
 class OoImpressImport : public KoFilter
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     OoImpressImport( KoFilter * parent, const char * name, const TQStringList & );
