@@ -50,7 +50,7 @@ typedef struct
 
 class APPLIXSPREADImport : public KoFilter {
 
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
