@@ -90,24 +90,24 @@ CSVDialog::CSVDialog(TQWidget* parent, TQByteArray& fileArray, const TQString /*
 
     m_dialog->m_sheet->setSelectionMode( TQTable::Multi );
 
-    connect(m_dialog->m_formatComboBox, TQT_SIGNAL(activated( const TQString& )),
-            this, TQT_SLOT(formatChanged( const TQString& )));
-    connect(m_dialog->m_delimiterBox, TQT_SIGNAL(clicked(int)),
-            this, TQT_SLOT(delimiterClicked(int)));
-    connect(m_dialog->m_delimiterEdit, TQT_SIGNAL(returnPressed()),
-            this, TQT_SLOT(returnPressed()));
-    connect(m_dialog->m_delimiterEdit, TQT_SIGNAL(textChanged ( const TQString & )),
-            this, TQT_SLOT(formatChanged ( const TQString & ) ));
-    connect(m_dialog->m_comboQuote, TQT_SIGNAL(activated(const TQString &)),
-            this, TQT_SLOT(textquoteSelected(const TQString &)));
-    connect(m_dialog->m_sheet, TQT_SIGNAL(currentChanged(int, int)),
-            this, TQT_SLOT(currentCellChanged(int, int)));
-    connect(m_dialog->m_ignoreDuplicates, TQT_SIGNAL(stateChanged(int)),
-            this, TQT_SLOT(ignoreDuplicatesChanged(int)));
-    connect(m_dialog->m_updateButton, TQT_SIGNAL(clicked()),
-            this, TQT_SLOT(updateClicked()));
-    connect(m_dialog->comboBoxEncoding, TQT_SIGNAL(textChanged ( const TQString & )),
-            this, TQT_SLOT(encodingChanged ( const TQString & ) ));
+    connect(m_dialog->m_formatComboBox, TQ_SIGNAL(activated( const TQString& )),
+            this, TQ_SLOT(formatChanged( const TQString& )));
+    connect(m_dialog->m_delimiterBox, TQ_SIGNAL(clicked(int)),
+            this, TQ_SLOT(delimiterClicked(int)));
+    connect(m_dialog->m_delimiterEdit, TQ_SIGNAL(returnPressed()),
+            this, TQ_SLOT(returnPressed()));
+    connect(m_dialog->m_delimiterEdit, TQ_SIGNAL(textChanged ( const TQString & )),
+            this, TQ_SLOT(formatChanged ( const TQString & ) ));
+    connect(m_dialog->m_comboQuote, TQ_SIGNAL(activated(const TQString &)),
+            this, TQ_SLOT(textquoteSelected(const TQString &)));
+    connect(m_dialog->m_sheet, TQ_SIGNAL(currentChanged(int, int)),
+            this, TQ_SLOT(currentCellChanged(int, int)));
+    connect(m_dialog->m_ignoreDuplicates, TQ_SIGNAL(stateChanged(int)),
+            this, TQ_SLOT(ignoreDuplicatesChanged(int)));
+    connect(m_dialog->m_updateButton, TQ_SIGNAL(clicked()),
+            this, TQ_SLOT(updateClicked()));
+    connect(m_dialog->comboBoxEncoding, TQ_SIGNAL(textChanged ( const TQString & )),
+            this, TQ_SLOT(encodingChanged ( const TQString & ) ));
 }
 
 CSVDialog::~CSVDialog()
