@@ -31,7 +31,7 @@ class Sheet;
 
 class CSVExport : public KoFilter 
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
   public:
