@@ -33,7 +33,7 @@ class Map;
 
 class CSVExportDialog : public KDialogBase
 {
-  Q_OBJECT
+  TQ_OBJECT
   
  public:
   CSVExportDialog(TQWidget * parent);
