@@ -24,7 +24,7 @@
 
 class CSVFilter : public KoFilter {
 
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
