@@ -41,7 +41,7 @@ class Validity;
 
 class OpenCalcImport : public KoFilter
 {
-  Q_OBJECT
+  TQ_OBJECT
   
  public:
   OpenCalcImport( KoFilter * parent, const char * name, const TQStringList & );
