@@ -30,7 +30,7 @@ class Sheet;
 
 class QpImport : public KoFilter {
 
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
