@@ -40,7 +40,7 @@
 
 class ABIWORDExport : public KoFilter {
 
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
