@@ -579,7 +579,7 @@ AmiProFormat::AmiProFormat()
   pos = len = 0;
   bold = italic = underline = 
   word_underline = double_underline = 
-  subscript = superscript = strikethrough = FALSE;
+  subscript = superscript = strikethrough = false;
   fontFamily = "";
   fontSize = 12;
   fontColor = TQt::black;
@@ -637,7 +637,7 @@ AmiProLayout::AmiProLayout()
   fontColor = TQt::black;
   bold = italic = underline = 
   word_underline = double_underline = 
-  subscript = superscript = strikethrough = FALSE;
+  subscript = superscript = strikethrough = false;
   align = TQt::AlignLeft;
   linespace = AmiPro::LS_Single;
   spaceBefore = spaceAfter = 0;
@@ -702,7 +702,7 @@ AmiProStyle::AmiProStyle()
   fontColor = TQt::black;
   bold = italic = underline = 
   word_underline = double_underline = 
-  subscript = superscript = strikethrough = FALSE;
+  subscript = superscript = strikethrough = false;
   linespace = AmiPro::LS_Single;
   spaceBefore = spaceAfter = 0;
 }
