@@ -57,7 +57,7 @@ class TQDomElement;
 
 class ASCIIImport : public KoFilter {
 
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
