@@ -32,7 +32,7 @@
 
 class HTMLExport : public KoFilter {
 
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
