@@ -30,7 +30,7 @@
 
 class HTMLImport : public KoFilter {
 
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
