@@ -107,7 +107,7 @@ void KWord13OasisGenerator::preparePageLayout( void )
         // ### TODO: test
         TQBuffer buffer;
         buffer.open( IO_WriteOnly );
-        KoXmlWriter element ( TQT_TQIODEVICE(&buffer) );
+        KoXmlWriter element ( &buffer );
         element.startElement("style:columns");
         element.addAttribute( "fo:column-count", columns );
         element.addAttributePt( "fo:column-gap", positiveNumberOrNull( m_kwordDocument->getProperty( "PAPER:columnspacing", "PAPER:ptColumnspc" ) ) );
@@ -760,7 +760,7 @@ void KWord13OasisGenerator::writeMetaXml(void)
     if ( dt.isValid() )
     {
         writer->startElement( "meta:creation-date");
-        writer->addTextNode( dt.toString( Qt::ISODate) );
+        writer->addTextNode( dt.toString( TQt::ISODate) );
         writer->endElement();
     }
 
@@ -768,7 +768,7 @@ void KWord13OasisGenerator::writeMetaXml(void)
     if ( dt.isValid() )
     {
         writer->startElement( "dc:date");
-        writer->addTextNode( dt.toString( Qt::ISODate) );
+        writer->addTextNode( dt.toString( TQt::ISODate) );
         writer->endElement();
     }
 
@@ -776,7 +776,7 @@ void KWord13OasisGenerator::writeMetaXml(void)
     if ( dt.isValid() )
     {
         writer->startElement( "meta:print-date");
-        writer->addTextNode( dt.toString( Qt::ISODate) );
+        writer->addTextNode( dt.toString( TQt::ISODate) );
         writer->endElement();
     }
 
@@ -839,7 +839,7 @@ void KWord13OasisGenerator::writePreviewFile(void)
     }
 
     // We have a 256x256x8 preview and we need a 128x128x32 preview with alpha channel
-    TQImage preview( image.convertDepth( 32, Qt::ColorOnly ).smoothScale( 128, 128 ) );
+    TQImage preview( image.convertDepth( 32, TQt::ColorOnly ).smoothScale( 128, 128 ) );
     if ( preview.isNull() )
     {
         kdWarning(30520) << "Could not create preview!" << endl;
@@ -932,7 +932,7 @@ bool KWord13OasisGenerator::generate ( const TQString& fileName, KWord13Document
     TQByteArray manifestData;
     TQBuffer manifestBuffer( manifestData );
     manifestBuffer.open( IO_WriteOnly );
-    m_manifestWriter = new KoXmlWriter( TQT_TQIODEVICE(&manifestBuffer) );
+    m_manifestWriter = new KoXmlWriter( &manifestBuffer );
     m_manifestWriter->startDocument( "manifest:manifest" );
     m_manifestWriter->startElement( "manifest:manifest" );
     m_manifestWriter->addAttribute( "xmlns:manifest", "urn:oasis:names:tc:openoffice:xmlns:manifest:1.0" );
