@@ -31,7 +31,7 @@
 class LATEXImport : public KoFilter
 {
 
-	Q_OBJECT
+	TQ_OBJECT
   
 
 	public:
