@@ -52,7 +52,7 @@ class LATEXImportDia : public KDialogBase, public DCOPObject
 {
 	K_DCOP
 	
-	Q_OBJECT
+	TQ_OBJECT
   
 	
 	TQString _fileIn;
