@@ -1188,7 +1188,7 @@ public:
 					outBuffer.open (IO_WriteOnly);
 
 					// write BMP
-					imageIO.setIODevice (TQT_TQIODEVICE(&outBuffer));
+					imageIO.setIODevice (&outBuffer);
 					imageIO.setFormat ("BMP");
 					if (!imageIO.write ())
 					{
