@@ -24,7 +24,7 @@
 
 class MSWriteExport : public KoFilter
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 
 public:
