@@ -45,7 +45,7 @@ PalmDB::PalmDB()
   setCreator( TQString() );
 
   // crash if autodelete ?
-  records.setAutoDelete( TRUE );
+  records.setAutoDelete( true );
 }
 
 PalmDB::~PalmDB()
@@ -58,13 +58,13 @@ bool PalmDB::load( const char* filename )
   // open input file
   TQFile in (filename);
   if (!in.open (IO_ReadOnly))
-    return FALSE;
+    return false;
 
   TQDataStream stream;
   stream.setDevice (&in);
 
   unsigned filesize = stream.device()->size();
-  if( filesize < 72 ) return FALSE;
+  if( filesize < 72 ) return false;
 
   // always big-endian
   stream.setByteOrder (TQDataStream::BigEndian);
@@ -194,7 +194,7 @@ bool PalmDB::load( const char* filename )
   // close input file
   in.close();
 
-  return TRUE;
+  return true;
 }
 
 bool PalmDB::save( const char* filename )
@@ -202,7 +202,7 @@ bool PalmDB::save( const char* filename )
   // open output file
   TQFile out( filename );
   if( !out.open( IO_WriteOnly ) )
-    return FALSE;
+    return false;
 
   TQDataStream stream;
   stream.setDevice( &out );
@@ -321,7 +321,7 @@ bool PalmDB::save( const char* filename )
   // close output file
   out.close();
 
-  return TRUE;
+  return true;
 }
 
 void PalmDB::setType( const TQString& t )
