@@ -28,7 +28,7 @@
 
 class PdfImport : public KoFilter
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     PdfImport(KoFilter *parent, const char *name, const TQStringList&);
