@@ -888,7 +888,7 @@ bool RTFWorker::doFooter(const FooterData& footer)
 
 bool RTFWorker::doOpenFile(const TQString& filenameOut, const TQString& /*to*/)
 {
-    m_ioDevice=TQT_TQIODEVICE(new TQFile(filenameOut));
+    m_ioDevice=new TQFile(filenameOut);
 
     if (!m_ioDevice)
     {
