@@ -27,7 +27,7 @@
 
 class WMLImport : public KoFilter
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
   public:
