@@ -38,7 +38,7 @@ class TQCString;
 //            stream.data prt after use!
 class FilterBase : public TQObject {
 
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
