@@ -370,8 +370,8 @@ void OLEFilter::convert( const TQCString& mimeTypeHint )
                 myFilter=new WordFilter(main, table0, table1, data);
 
                 // forward the internal communication calls
-                connect( this, TQT_SIGNAL( internalCommShapeID( unsigned int& ) ), myFilter, TQT_SIGNAL( internalCommShapeID( unsigned int& ) ) );
-                connect( this, TQT_SIGNAL( internalCommDelayStream( const char* ) ), myFilter, TQT_SIGNAL( internalCommDelayStream( const char* ) ) );
+                connect( this, TQ_SIGNAL( internalCommShapeID( unsigned int& ) ), myFilter, TQ_SIGNAL( internalCommShapeID( unsigned int& ) ) );
+                connect( this, TQ_SIGNAL( internalCommDelayStream( const char* ) ), myFilter, TQ_SIGNAL( internalCommDelayStream( const char* ) ) );
             }
         }
         else if ( mimeType == "application/x-kspread" ) {
@@ -477,27 +477,27 @@ void OLEFilter::convert( const TQCString& mimeTypeHint )
 void OLEFilter::connectCommon(FilterBase **myFilter) {
     TQObject::connect(
         *myFilter,
-        TQT_SIGNAL(signalSaveDocumentInformation(const TQString &, const TQString &, const TQString &, const TQString &, const TQString &, const TQString &, const TQString &, const TQString &, const TQString &, const TQString &, const TQString &, const TQString &)),
+        TQ_SIGNAL(signalSaveDocumentInformation(const TQString &, const TQString &, const TQString &, const TQString &, const TQString &, const TQString &, const TQString &, const TQString &, const TQString &, const TQString &, const TQString &, const TQString &)),
         this,
-        TQT_SLOT(slotSaveDocumentInformation(const TQString &, const TQString &, const TQString &, const TQString &, const TQString &, const TQString &, const TQString &, const TQString &, const TQString &, const TQString &, const TQString &, const TQString &)));
+        TQ_SLOT(slotSaveDocumentInformation(const TQString &, const TQString &, const TQString &, const TQString &, const TQString &, const TQString &, const TQString &, const TQString &, const TQString &, const TQString &, const TQString &, const TQString &)));
 
     TQObject::connect(
         *myFilter,
-        TQT_SIGNAL(signalSavePic(const TQString &, TQString &, const TQString &, unsigned int, const char *)),
+        TQ_SIGNAL(signalSavePic(const TQString &, TQString &, const TQString &, unsigned int, const char *)),
         this,
-        TQT_SLOT(slotSavePic(const TQString &, TQString &, const TQString &, unsigned int, const char *)));
+        TQ_SLOT(slotSavePic(const TQString &, TQString &, const TQString &, unsigned int, const char *)));
     TQObject::connect(
         *myFilter,
-        TQT_SIGNAL(signalSavePart(const TQString &, TQString &, TQString &, const TQString &, unsigned int, const char *)),
+        TQ_SIGNAL(signalSavePart(const TQString &, TQString &, TQString &, const TQString &, unsigned int, const char *)),
         this,
-        TQT_SLOT(slotSavePart(const TQString &, TQString &, TQString &, const TQString &, unsigned int, const char *)));
-    TQObject::connect(*myFilter, TQT_SIGNAL(signalPart(const TQString&, TQString &, TQString &)),
-                     this, TQT_SLOT(slotPart(const TQString&, TQString &, TQString &)));
-    TQObject::connect(*myFilter, TQT_SIGNAL(signalGetStream(const int &, myFile &)), this,
-                     TQT_SLOT(slotGetStream(const int &, myFile &)));
-    TQObject::connect(*myFilter, TQT_SIGNAL(signalGetStream(const TQString &, myFile &)), this,
-                     TQT_SLOT(slotGetStream(const TQString &, myFile &)));
-    TQObject::connect(*myFilter, TQT_SIGNAL(sigProgress(int)), this, TQT_SIGNAL(sigProgress(int)));
+        TQ_SLOT(slotSavePart(const TQString &, TQString &, TQString &, const TQString &, unsigned int, const char *)));
+    TQObject::connect(*myFilter, TQ_SIGNAL(signalPart(const TQString&, TQString &, TQString &)),
+                     this, TQ_SLOT(slotPart(const TQString&, TQString &, TQString &)));
+    TQObject::connect(*myFilter, TQ_SIGNAL(signalGetStream(const int &, myFile &)), this,
+                     TQ_SLOT(slotGetStream(const int &, myFile &)));
+    TQObject::connect(*myFilter, TQ_SIGNAL(signalGetStream(const TQString &, myFile &)), this,
+                     TQ_SLOT(slotGetStream(const TQString &, myFile &)));
+    TQObject::connect(*myFilter, TQ_SIGNAL(sigProgress(int)), this, TQ_SIGNAL(sigProgress(int)));
 }
 
 TQCString OLEFilter::mimeTypeHelper()
