@@ -32,7 +32,7 @@ class KoStore;
 
 class OLEFilter : public KoEmbeddingFilter {
 
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
