@@ -142,7 +142,7 @@ private:
  */
 class VCommandHistory : public TQObject
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 
 public:
