@@ -33,7 +33,7 @@ class KoRGBWidget;
 
 class VColorDocker : public TQWidget
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 
 public:
