@@ -102,7 +102,7 @@ VDocumentPreview::eventFilter( TQObject* object, TQEvent* event )
 	}
 	KoRect rect = m_view->canvasWidget()->boundingBox();
 
-	TQMouseEvent* mouseEvent = TQT_TQMOUSEEVENT( event );
+	TQMouseEvent* mouseEvent = static_cast<TQMouseEvent*>( event );
 	if( event->type() == TQEvent::MouseButtonPress )
 	{
 		m_firstPoint.setX( mouseEvent->pos().x() );
@@ -175,7 +175,7 @@ VDocumentPreview::paintEvent( TQPaintEvent* )
 	{
 		delete m_docpixmap;
 		m_docpixmap = new TQPixmap( width(), height() );
-		VKoPainter p( TQT_TQPAINTDEVICE(m_docpixmap), width(), height() );
+		VKoPainter p( m_docpixmap, width(), height() );
 		p.clear( TQColor( 195, 194, 193 ) );
 		p.setWorldMatrix( TQWMatrix( 1, 0, 0, -1, xoffset * scaleFactor, height() - yoffset * scaleFactor ) );
 		p.setZoomFactor( scaleFactor );
@@ -252,10 +252,10 @@ VDocumentTab::VDocumentTab( KarbonView* view, TQWidget* parent )
 	m_layers->setAlignment( AlignRight );
 	m_format->setAlignment( AlignRight );
 
-	connect( view->part()->commandHistory(), TQT_SIGNAL( commandAdded( VCommand* ) ), this, TQT_SLOT( slotCommandAdded( VCommand* ) ) );
-	connect( view->part()->commandHistory(), TQT_SIGNAL( commandExecuted() ), this, TQT_SLOT( slotCommandExecuted() ) );
-	connect( view, TQT_SIGNAL( pageLayoutChanged() ), this, TQT_SLOT( slotCommandExecuted() ) );
-	connect( view->canvasWidget(), TQT_SIGNAL( viewportChanged() ), this, TQT_SLOT( slotViewportChanged() ) );
+	connect( view->part()->commandHistory(), TQ_SIGNAL( commandAdded( VCommand* ) ), this, TQ_SLOT( slotCommandAdded( VCommand* ) ) );
+	connect( view->part()->commandHistory(), TQ_SIGNAL( commandExecuted() ), this, TQ_SLOT( slotCommandExecuted() ) );
+	connect( view, TQ_SIGNAL( pageLayoutChanged() ), this, TQ_SLOT( slotCommandExecuted() ) );
+	connect( view->canvasWidget(), TQ_SIGNAL( viewportChanged() ), this, TQ_SLOT( slotViewportChanged() ) );
 
 	updateDocumentInfo();
 } // VDocumentTab::VDocumentTab
@@ -334,7 +334,7 @@ VObjectListViewItem::update()
 	// draw thumb preview (16x16)
 	TQPixmap preview;
 	preview.resize( 16, 16 );
-	VKoPainter p( TQT_TQPAINTDEVICE(&preview), 16, 16, false );
+	VKoPainter p( &preview, 16, 16, false );
 	// Y mirroring
 	TQWMatrix mat;
 	mat.scale( 1, -1 );
@@ -390,7 +390,7 @@ VLayerListViewItem::update()
 	// draw thumb preview (16x16)
 	TQPixmap preview;
 	preview.resize( 16, 16 );
-	VKoPainter p( TQT_TQPAINTDEVICE(&preview), 16, 16, false );
+	VKoPainter p( &preview, 16, 16, false );
 	// Y mirroring
 	TQWMatrix mat;
 	mat.scale( 1, -1 );
@@ -490,12 +490,12 @@ VLayersTab::VLayersTab( KarbonView* view, TQWidget* parent )
 	m_layersListView->setRootIsDecorated( true );
 	m_layersListView->setSelectionMode( TQListView::Extended );
 
-	connect( m_layersListView, TQT_SIGNAL( clicked( TQListViewItem*, const TQPoint&, int ) ), this, TQT_SLOT( itemClicked( TQListViewItem*, const TQPoint&, int ) ) );
-	connect( m_layersListView, TQT_SIGNAL( rightButtonClicked( TQListViewItem*, const TQPoint&, int ) ), this, TQT_SLOT( renameItem( TQListViewItem*, const TQPoint&, int ) ) );
-	connect( m_layersListView, TQT_SIGNAL( selectionChanged() ), this, TQT_SLOT( selectionChangedFromList() ) );
-	connect( m_view, TQT_SIGNAL( selectionChange() ), this, TQT_SLOT( selectionChangedFromTool() ) );
-	connect( m_buttonGroup, TQT_SIGNAL( clicked( int ) ), this, TQT_SLOT( slotButtonClicked( int ) ) );
-	connect( view->part()->commandHistory(), TQT_SIGNAL( commandExecuted( VCommand*) ), this, TQT_SLOT( slotCommandExecuted( VCommand* ) ) );
+	connect( m_layersListView, TQ_SIGNAL( clicked( TQListViewItem*, const TQPoint&, int ) ), this, TQ_SLOT( itemClicked( TQListViewItem*, const TQPoint&, int ) ) );
+	connect( m_layersListView, TQ_SIGNAL( rightButtonClicked( TQListViewItem*, const TQPoint&, int ) ), this, TQ_SLOT( renameItem( TQListViewItem*, const TQPoint&, int ) ) );
+	connect( m_layersListView, TQ_SIGNAL( selectionChanged() ), this, TQ_SLOT( selectionChangedFromList() ) );
+	connect( m_view, TQ_SIGNAL( selectionChange() ), this, TQ_SLOT( selectionChangedFromTool() ) );
+	connect( m_buttonGroup, TQ_SIGNAL( clicked( int ) ), this, TQ_SLOT( slotButtonClicked( int ) ) );
+	connect( view->part()->commandHistory(), TQ_SIGNAL( commandExecuted( VCommand*) ), this, TQ_SLOT( slotCommandExecuted( VCommand* ) ) );
 
 	layout->activate();
 	updateLayers();
@@ -1243,17 +1243,17 @@ VHistoryTab::VHistoryTab( KarbonPart* part, TQWidget* parent )
 	}
 	m_history->sort();
 
-	connect( m_history, TQT_SIGNAL( mouseButtonClicked( int, TQListViewItem*, const TQPoint&, int ) ), this, TQT_SLOT( commandClicked( int, TQListViewItem*, const TQPoint&, int ) ) );
-	connect( m_groupCommands, TQT_SIGNAL( stateChanged( int ) ), this, TQT_SLOT( groupingChanged( int ) ) );
-	connect( part->commandHistory(), TQT_SIGNAL( historyCleared() ), this, TQT_SLOT( historyCleared() ) );
-	connect( part->commandHistory(), TQT_SIGNAL( commandAdded( VCommand* ) ), this, TQT_SLOT( slotCommandAdded( VCommand* ) ) );
-	connect( part->commandHistory(), TQT_SIGNAL( commandExecuted( VCommand* ) ), this, TQT_SLOT( commandExecuted( VCommand* ) ) );
-	connect( part->commandHistory(), TQT_SIGNAL( firstCommandRemoved() ), this, TQT_SLOT( removeFirstCommand() ) );
-	connect( part->commandHistory(), TQT_SIGNAL( lastCommandRemoved() ), this, TQT_SLOT( removeLastCommand() ) );
-	connect( this, TQT_SIGNAL( undoCommand( VCommand* ) ), part->commandHistory(), TQT_SLOT( undo( VCommand* ) ) );
-	connect( this, TQT_SIGNAL( redoCommand( VCommand* ) ), part->commandHistory(), TQT_SLOT( redo( VCommand* ) ) );
-	connect( this, TQT_SIGNAL( undoCommandsTo( VCommand* ) ), part->commandHistory(), TQT_SLOT( undoAllTo( VCommand* ) ) );
-	connect( this, TQT_SIGNAL( redoCommandsTo( VCommand* ) ), part->commandHistory(), TQT_SLOT( redoAllTo( VCommand* ) ) );
+	connect( m_history, TQ_SIGNAL( mouseButtonClicked( int, TQListViewItem*, const TQPoint&, int ) ), this, TQ_SLOT( commandClicked( int, TQListViewItem*, const TQPoint&, int ) ) );
+	connect( m_groupCommands, TQ_SIGNAL( stateChanged( int ) ), this, TQ_SLOT( groupingChanged( int ) ) );
+	connect( part->commandHistory(), TQ_SIGNAL( historyCleared() ), this, TQ_SLOT( historyCleared() ) );
+	connect( part->commandHistory(), TQ_SIGNAL( commandAdded( VCommand* ) ), this, TQ_SLOT( slotCommandAdded( VCommand* ) ) );
+	connect( part->commandHistory(), TQ_SIGNAL( commandExecuted( VCommand* ) ), this, TQ_SLOT( commandExecuted( VCommand* ) ) );
+	connect( part->commandHistory(), TQ_SIGNAL( firstCommandRemoved() ), this, TQ_SLOT( removeFirstCommand() ) );
+	connect( part->commandHistory(), TQ_SIGNAL( lastCommandRemoved() ), this, TQ_SLOT( removeLastCommand() ) );
+	connect( this, TQ_SIGNAL( undoCommand( VCommand* ) ), part->commandHistory(), TQ_SLOT( undo( VCommand* ) ) );
+	connect( this, TQ_SIGNAL( redoCommand( VCommand* ) ), part->commandHistory(), TQ_SLOT( redo( VCommand* ) ) );
+	connect( this, TQ_SIGNAL( undoCommandsTo( VCommand* ) ), part->commandHistory(), TQ_SLOT( undoAllTo( VCommand* ) ) );
+	connect( this, TQ_SIGNAL( redoCommandsTo( VCommand* ) ), part->commandHistory(), TQ_SLOT( redoAllTo( VCommand* ) ) );
 } // VHistoryTab::VHistoryTab
 
 VHistoryTab::~VHistoryTab()
