@@ -30,7 +30,7 @@ class VRoundCornersDlg;
 
 class KARBONBASE_EXPORT VRoundCornersPlugin : public KParts::Plugin
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	VRoundCornersPlugin( KarbonView *parent, const char* name, const TQStringList & );
@@ -47,7 +47,7 @@ class KDoubleNumInput;
 
 class VRoundCornersDlg : public KDialogBase
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 
 public:
