@@ -30,7 +30,7 @@ class VShadowEffectDlg;
 
 class ShadowEffectPlugin : public KParts::Plugin
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	ShadowEffectPlugin( KarbonView *parent, const char* name, const TQStringList & );
@@ -47,7 +47,7 @@ class KIntNumInput;
 
 class VShadowEffectDlg : public KDialogBase
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 
 public:
