@@ -153,7 +153,7 @@ VTQPainter::fillPath()
 {
 	// we probably dont need filling for qpainter
 	//m_index = 0;
-	m_painter->drawPolygon( m_pa, FALSE, 0, m_index );
+	m_painter->drawPolygon( m_pa, false, 0, m_index );
 }
 
 void
