@@ -33,7 +33,7 @@ class TQWidget;
 
 class VEllipseOptionsWidget : public KDialogBase
 {
-Q_OBJECT
+TQ_OBJECT
   
 public:
 	VEllipseOptionsWidget( KarbonPart *part, TQWidget *parent = 0L, const char *name = 0L );
