@@ -44,7 +44,7 @@ class TQCursor;
 
 class VPencilOptionsWidget : public KDialogBase
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 	public:
 		VPencilOptionsWidget( KarbonView*view, TQWidget* parent = 0L, const char* name = 0L );
