@@ -31,7 +31,7 @@ class KDoubleNumInput;
 
 class VTranslate : public TQWidget
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 
 public:
