@@ -38,7 +38,7 @@ class KChartParams;
 
 class KChartBackgroundPixmapConfigPage : public TQWidget
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
