@@ -73,7 +73,7 @@ void kchartDataSpinBox::stepDown()
 
 bool kchartDataSpinBox::eventFilter( TQObject *obj, TQEvent *ev )
 {
-    if ( TQT_BASE_OBJECT(obj) == TQT_BASE_OBJECT(editor()) ) {
+    if ( obj == editor() ) {
         if ( ev->type() == TQEvent::FocusOut ) {
             //kdDebug() << "Focus out" << endl;
             setValue(editor()->text().toInt());
@@ -178,8 +178,8 @@ kchartDataEditor::kchartDataEditor(TQWidget* parent) :
     m_table->setRowMovingEnabled(true);
     m_table->setColumnMovingEnabled(true);
 
-    connect( m_table, TQT_SIGNAL( currentChanged(int, int) ),
-	     this,    TQT_SLOT( currentChanged(int, int) ) );
+    connect( m_table, TQ_SIGNAL( currentChanged(int, int) ),
+	     this,    TQ_SLOT( currentChanged(int, int) ) );
   
     // Create the Rows setting
     m_rowsLA = new TQLabel( i18n("# Rows:" ), page );
@@ -210,8 +210,8 @@ kchartDataEditor::kchartDataEditor(TQWidget* parent) :
 					   TDEIcon::DefaultState,
 					   KChartFactory::global() ) );
     //m_insertRowButton = new TQPushButton( i18n("Insert Row") , page);
-    connect( m_insertRowButton, TQT_SIGNAL( clicked() ),
-	     this,              TQT_SLOT( insertRow() ) );
+    connect( m_insertRowButton, TQ_SIGNAL( clicked() ),
+	     this,              TQ_SLOT( insertRow() ) );
     
     m_removeRowButton = new TQPushButton( page );
     m_removeRowButton->setPixmap( BarIcon( TQString("delete_table_row"),
@@ -219,8 +219,8 @@ kchartDataEditor::kchartDataEditor(TQWidget* parent) :
 					   TDEIcon::DefaultState,
 					   KChartFactory::global() ) );
     //m_removeRowButton = new TQPushButton( i18n("Remove Row") , page);
-    connect( m_removeRowButton, TQT_SIGNAL( clicked() ),
-	     this,              TQT_SLOT( removeCurrentRow() ) );
+    connect( m_removeRowButton, TQ_SIGNAL( clicked() ),
+	     this,              TQ_SLOT( removeCurrentRow() ) );
     
     m_insertColButton = new TQPushButton( page );
     m_insertColButton->setPixmap( BarIcon( TQString("insert_table_col"),
@@ -228,8 +228,8 @@ kchartDataEditor::kchartDataEditor(TQWidget* parent) :
 					   TDEIcon::DefaultState,
 					   KChartFactory::global() ) );
     //m_insertColButton = new TQPushButton( i18n("Insert Column") , page);
-    connect( m_insertColButton, TQT_SIGNAL( clicked() ),
-	     this,              TQT_SLOT( insertColumn() ) );
+    connect( m_insertColButton, TQ_SIGNAL( clicked() ),
+	     this,              TQ_SLOT( insertColumn() ) );
     
     m_removeColButton = new TQPushButton( page );
     m_removeColButton->setPixmap( BarIcon( TQString("delete_table_col"),
@@ -237,8 +237,8 @@ kchartDataEditor::kchartDataEditor(TQWidget* parent) :
 					   TDEIcon::DefaultState,
 					   KChartFactory::global() ) );
     //m_removeColButton = new TQPushButton( i18n("Remove Column") , page);
-    connect( m_removeColButton, TQT_SIGNAL( clicked() ),
-	     this,              TQT_SLOT( removeCurrentColumn() ) );
+    connect( m_removeColButton, TQ_SIGNAL( clicked() ),
+	     this,              TQ_SLOT( removeCurrentColumn() ) );
 
     // Start the layout.  The buttons are at the top.
     TQVBoxLayout  *topLayout = new TQVBoxLayout( page );
@@ -283,24 +283,24 @@ kchartDataEditor::kchartDataEditor(TQWidget* parent) :
     topLayout->setStretchFactor(insertRemoveLayout,1);
 
     // Connect signals from the spin boxes.
-    connect(m_rowsSB, TQT_SIGNAL(valueChangedSpecial(int)), 
-	    this,     TQT_SLOT(setRows(int)));
-    connect(m_colsSB, TQT_SIGNAL(valueChangedSpecial(int)), 
-	    this,     TQT_SLOT(setCols(int)));
+    connect(m_rowsSB, TQ_SIGNAL(valueChangedSpecial(int)), 
+	    this,     TQ_SLOT(setRows(int)));
+    connect(m_colsSB, TQ_SIGNAL(valueChangedSpecial(int)), 
+	    this,     TQ_SLOT(setCols(int)));
 
     
 #if 0
     // -- Changed data editor to use top row and leftmost column for
     //    series names and labels so this is no longer necessary.
 
-    connect(m_table->horizontalHeader(), TQT_SIGNAL(clicked(int)), 
-	    this,                        TQT_SLOT(column_clicked(int)) );
-    connect(m_table->verticalHeader(),   TQT_SIGNAL(clicked(int)),
-	    this,                        TQT_SLOT(row_clicked(int)) );
+    connect(m_table->horizontalHeader(), TQ_SIGNAL(clicked(int)), 
+	    this,                        TQ_SLOT(column_clicked(int)) );
+    connect(m_table->verticalHeader(),   TQ_SIGNAL(clicked(int)),
+	    this,                        TQ_SLOT(row_clicked(int)) );
 #endif
   
-    connect(m_table, TQT_SIGNAL(valueChanged(int, int)),
-	    this,    TQT_SLOT(tableChanged(int, int)) );
+    connect(m_table, TQ_SIGNAL(valueChanged(int, int)),
+	    this,    TQ_SLOT(tableChanged(int, int)) );
 
     // At first, assume that any shrinking of the table is a mistake.
     // A confirmation dialog will make sure that the user knows what
