@@ -44,7 +44,7 @@ class KChartParams;
 
 class KChartPieConfigPage : public TQWidget
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
