@@ -22,7 +22,7 @@ class KChartParams;
 
 class KCHART_EXPORT KChartPart : public KoChart::Part
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
