@@ -65,100 +65,100 @@ KChartView::KChartView( KChartPart* part, TQWidget* parent, const char* name )
     dcopObject(); // build it
 
     m_importData = new TDEAction( i18n( "Import Data..." ), 0,
-				TQT_TQOBJECT(this), TQT_SLOT( importData() ),
+				this, TQ_SLOT( importData() ),
 				actionCollection(), "import_data" );
 #if 0
     TDEAction * actionExtraCreateTemplate	=
 #endif
 	new TDEAction( i18n( "&Create Template From Document..." ), 0,
-		       TQT_TQOBJECT(this), TQT_SLOT( extraCreateTemplate() ),
+		       this, TQ_SLOT( extraCreateTemplate() ),
 		       actionCollection(), "extra_template" );
 
     m_wizard = new TDEAction( i18n("Customize with &Wizard..."),
                             "wizard", 0,
-                            TQT_TQOBJECT(this), TQT_SLOT( wizard() ),
+                            this, TQ_SLOT( wizard() ),
                             actionCollection(), "wizard");
     m_edit = new TDEAction( i18n("Edit &Data..."), "edit", 0,
-                          TQT_TQOBJECT(this), TQT_SLOT( editData() ),
+                          this, TQ_SLOT( editData() ),
                           actionCollection(), "editdata");
     m_config = new TDEAction( i18n( "&Chart..." ), "configure", 0,
 
-                            TQT_TQOBJECT(this), TQT_SLOT( slotConfig() ),
+                            this, TQ_SLOT( slotConfig() ),
                             actionCollection(), "config" );
 
     // One TDEToggleAction per chart type
-    m_chartbars = new TDEToggleAction( i18n("&Bar"), "chart_bar_3d", 0, TQT_TQOBJECT(this),
-                                     TQT_SLOT( barsChart() ), actionCollection(),
+    m_chartbars = new TDEToggleAction( i18n("&Bar"), "chart_bar_3d", 0, this,
+                                     TQ_SLOT( barsChart() ), actionCollection(),
                                      "barschart");
     m_chartbars->setExclusiveGroup( "charttypes" );
     m_chartbars->setChecked( true );
 
-    m_chartline = new TDEToggleAction( i18n("&Line"), "chart_line", 0, TQT_TQOBJECT(this),
-                                     TQT_SLOT( lineChart() ), actionCollection(),
+    m_chartline = new TDEToggleAction( i18n("&Line"), "chart_line", 0, this,
+                                     TQ_SLOT( lineChart() ), actionCollection(),
                                      "linechart");
     m_chartline->setExclusiveGroup( "charttypes" );
 
-    m_chartareas = new TDEToggleAction( i18n("&Area"), "chart_area", 0, TQT_TQOBJECT(this),
-                                      TQT_SLOT( areasChart() ), actionCollection(),
+    m_chartareas = new TDEToggleAction( i18n("&Area"), "chart_area", 0, this,
+                                      TQ_SLOT( areasChart() ), actionCollection(),
                                       "areaschart");
     m_chartareas->setExclusiveGroup( "charttypes" );
 
-    m_charthilo = new TDEToggleAction( i18n("&HiLo"), "chart_hilo", 0, TQT_TQOBJECT(this),
-                                     TQT_SLOT( hiLoChart() ), actionCollection(),
+    m_charthilo = new TDEToggleAction( i18n("&HiLo"), "chart_hilo", 0, this,
+                                     TQ_SLOT( hiLoChart() ), actionCollection(),
                                      "hilochart");
     m_charthilo->setExclusiveGroup( "charttypes" );
 
-    m_chartbw = new TDEToggleAction( i18n("Bo&x && Whiskers"), "chart_boxwhisker", 0, TQT_TQOBJECT(this),
-                                     TQT_SLOT( bwChart() ), actionCollection(),
+    m_chartbw = new TDEToggleAction( i18n("Bo&x && Whiskers"), "chart_boxwhisker", 0, this,
+                                     TQ_SLOT( bwChart() ), actionCollection(),
                                      "bwchart");
     m_chartbw->setExclusiveGroup( "charttypes" );
 
-    m_chartpie = new TDEToggleAction( i18n("&Pie"), "chart_pie", 0, TQT_TQOBJECT(this),
-                                    TQT_SLOT( pieChart() ), actionCollection(),
+    m_chartpie = new TDEToggleAction( i18n("&Pie"), "chart_pie", 0, this,
+                                    TQ_SLOT( pieChart() ), actionCollection(),
                                     "piechart");
     m_chartpie->setExclusiveGroup( "charttypes" );
 
-    m_chartring = new TDEToggleAction( i18n("&Ring"), "chart_ring", 0, TQT_TQOBJECT(this),
-                                     TQT_SLOT( ringChart() ), actionCollection(),
+    m_chartring = new TDEToggleAction( i18n("&Ring"), "chart_ring", 0, this,
+                                     TQ_SLOT( ringChart() ), actionCollection(),
                                      "ringchart");
     m_chartring->setExclusiveGroup( "charttypes" );
 
-    m_chartpolar = new TDEToggleAction( i18n("&Polar"), "chart_polar", 0, TQT_TQOBJECT(this),
-                                     TQT_SLOT( polarChart() ), actionCollection(),
+    m_chartpolar = new TDEToggleAction( i18n("&Polar"), "chart_polar", 0, this,
+                                     TQ_SLOT( polarChart() ), actionCollection(),
                                      "polarchart");
     m_chartpolar->setExclusiveGroup( "charttypes" );
 
     // Configuration TDEActions
     m_colorConfig = new TDEAction( i18n( "&Colors..." ), 0,
-                            TQT_TQOBJECT(this), TQT_SLOT( slotConfigColor() ),
+                            this, TQ_SLOT( slotConfigColor() ),
                             actionCollection(), "color_config" );
 
     m_fontConfig = new TDEAction( i18n( "&Font..." ), 0,
-                            TQT_TQOBJECT(this), TQT_SLOT( slotConfigFont() ),
+                            this, TQ_SLOT( slotConfigFont() ),
                             actionCollection(), "font_config" );
 
     m_backConfig = new TDEAction( i18n( "&Background..." ), 0,
-                            TQT_TQOBJECT(this), TQT_SLOT( slotConfigBack() ),
+                            this, TQ_SLOT( slotConfigBack() ),
                             actionCollection(), "back_config" );
 
     m_legendConfig = new TDEAction( i18n( "&Legend..." ), 0,
-                            TQT_TQOBJECT(this), TQT_SLOT( slotConfigLegend() ),
+                            this, TQ_SLOT( slotConfigLegend() ),
                             actionCollection(), "legend_config" );
 
     m_subTypeChartConfig = new TDEAction( i18n( "Chart &Sub-type..." ), 0,
-                            TQT_TQOBJECT(this), TQT_SLOT( slotConfigSubTypeChart() ),
+                            this, TQ_SLOT( slotConfigSubTypeChart() ),
                             actionCollection(), "legend_subtype" );
 
     m_dataFormatConfig = new TDEAction( i18n( "&Data Format..." ), 0,
-                            TQT_TQOBJECT(this), TQT_SLOT( slotConfigDataFormat() ),
+                            this, TQ_SLOT( slotConfigDataFormat() ),
                             actionCollection(), "data_format" );
 
     m_headerFooterConfig = new TDEAction( i18n( "&Header && Footer..." ), 0,
-                            TQT_TQOBJECT(this), TQT_SLOT( slotConfigHeaderFooterChart() ),
+                            this, TQ_SLOT( slotConfigHeaderFooterChart() ),
                             actionCollection(), "headerfooter_subtype" );
 
     m_pageLayoutConfig = new TDEAction( i18n( "Page Layout..." ), 0,
-                            TQT_TQOBJECT(this), TQT_SLOT( slotConfigPageLayout() ),
+                            this, TQ_SLOT( slotConfigPageLayout() ),
                             actionCollection(), "page_layout" );
 
     // initialize the configuration
@@ -230,8 +230,8 @@ void KChartView::editData()
     ed.setColLabels(((KChartPart*)koDocument())->colLabelTexts());
 
     // Activate the Apply button in the editor.
-    connect(&ed,  TQT_SIGNAL(applyClicked(kchartDataEditor *)),
-	    TQT_TQOBJECT(this), TQT_SLOT(applyEdit(kchartDataEditor *)));
+    connect(&ed,  TQ_SIGNAL(applyClicked(kchartDataEditor *)),
+	    this, TQ_SLOT(applyEdit(kchartDataEditor *)));
 
     // Execute the data editor.
     if ( ed.exec() != TQDialog::Accepted ) {
@@ -339,8 +339,8 @@ void KChartView::config(int flags)
     KChartConfigDialog  *d      = new KChartConfigDialog( params, this, flags,
 							  dat );
 
-    connect( d, TQT_SIGNAL( dataChanged() ),
-             TQT_TQOBJECT(this), TQT_SLOT( slotRepaint() ) );
+    connect( d, TQ_SIGNAL( dataChanged() ),
+             this, TQ_SLOT( slotRepaint() ) );
     d->exec();
     delete d;
 }
@@ -545,7 +545,7 @@ void KChartView::mousePressEvent ( TQMouseEvent *e )
 {
     if (!koDocument()->isReadWrite() || !factory())
         return;
-    if ( e->button() == Qt::RightButton )
+    if ( e->button() == TQt::RightButton )
         ((TQPopupMenu*)factory()->container("action_popup",this))->popup(TQCursor::pos());
 }
 
@@ -611,8 +611,8 @@ void KChartView::slotConfigPageLayout()
     KChartPageLayout  *dialog = new KChartPageLayout(params, this,
 						     "Page Layout");
 
-    connect( dialog, TQT_SIGNAL( dataChanged() ),
-             this,   TQT_SLOT( slotRepaint() ) );
+    connect( dialog, TQ_SIGNAL( dataChanged() ),
+             this,   TQ_SLOT( slotRepaint() ) );
 
     dialog->exec();
     delete dialog;
