@@ -131,7 +131,7 @@ class KDChartParams;
 
 class KDCHART_EXPORT KDChartAxisParams : public TQObject
 {
-    Q_OBJECT
+    TQ_OBJECT
     
     TQ_ENUMS(AxisType)
     TQ_ENUMS(AxisPos)
@@ -246,8 +246,8 @@ public slots:
     bool axisShowFractionalValuesDelimiters() const { return _axisShowFractionalValuesDelimiters; }
     void setAxisShowGrid( bool axisShowGrid );
     bool axisShowGrid() const { return _axisShowGrid; }
-    void setAxisGridStyle( Qt::PenStyle axisGridStyle );
-    Qt::PenStyle axisGridStyle() const { return _axisGridStyle; }
+    void setAxisGridStyle( TQt::PenStyle axisGridStyle );
+    TQt::PenStyle axisGridStyle() const { return _axisGridStyle; }
     void setAxisGridColor( TQColor axisGridColor );
     TQColor axisGridColor() const { return _axisGridColor; }
     void setAxisGridLineWidth( int axisGridLineWidth );
@@ -255,8 +255,8 @@ public slots:
     // sub grid:
     void setAxisShowSubDelimiters( bool axisShowSubDelimiters );
     bool axisShowSubDelimiters() const { return _axisShowSubDelimiters; }
-    void setAxisGridSubStyle( Qt::PenStyle axisGridSubStyle );
-    Qt::PenStyle axisGridSubStyle() const { return _axisGridSubStyle; }
+    void setAxisGridSubStyle( TQt::PenStyle axisGridSubStyle );
+    TQt::PenStyle axisGridSubStyle() const { return _axisGridSubStyle; }
     void setAxisGridSubColor( TQColor axisGridSubColor );
     TQColor axisGridSubColor() const { return _axisGridSubColor; }
     void setAxisGridSubLineWidth( int axisGridSubLineWidth );
@@ -451,12 +451,12 @@ private:
     bool     _axisShowGrid;
     TQColor   _axisGridColor;
     int      _axisGridLineWidth;
-    Qt::PenStyle _axisGridStyle;
+    TQt::PenStyle _axisGridStyle;
 
     bool     _axisShowSubDelimiters;
     TQColor   _axisGridSubColor;
     int      _axisGridSubLineWidth;
-    Qt::PenStyle _axisGridSubStyle;
+    TQt::PenStyle _axisGridSubStyle;
 
     TQColor _axisZeroLineColor;
     bool _axisLabelsVisible;
