@@ -7,7 +7,7 @@ class KDChartCustomBox;
 class KDChartTextPiece;
 class KDChartCustomBoxWrapper :public TQObject
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
