@@ -1,4 +1,4 @@
-/* -*- Mode: C++ -*-
+/*
    KDChart - a multi-platform charting engine
    */
 
@@ -118,7 +118,7 @@ void KDChartPropertySet::fillValueMembersWithDummyValues()
     // fill with dummy values to avoid problems when saving us into a stream
     mLineWidth         = 1;
     mLineColor         = TQt::black;
-    mLineStyle         = Qt::SolidLine;
+    mLineStyle         = TQt::SolidLine;
     mShowMarker        = true;
     mMarkerAlign       = TQt::AlignCenter;
     mMarkerSize        = TQSize(6,6);
@@ -129,7 +129,7 @@ void KDChartPropertySet::fillValueMembersWithDummyValues()
     mExtraLinesLength  = -20;
     mExtraLinesWidth   = 1;
     mExtraLinesColor   = TQt::black;
-    mExtraLinesStyle   = Qt::SolidLine;
+    mExtraLinesStyle   = TQt::SolidLine;
     mExtraMarkersAlign = TQt::AlignLeft|TQt::AlignTop;
     mExtraMarkersSize  = TQSize(6,6);
     mExtraMarkersColor = TQt::black;
@@ -371,7 +371,7 @@ bool KDChartPropertySet::loadXML( const TQDomElement& element, KDChartPropertySe
                             set.mExtraMarkersStyle
                                 = KDChartParams::stringToLineMarkerStyle( element.attribute( "Style" ) );
                     } else {
-                        qDebug( "Unknown subelement of KDChartPropertySet found: %s", tagName.latin1() );
+                        tqDebug( "Unknown subelement of KDChartPropertySet found: %s", tagName.latin1() );
                     }
                 }
                 node = node.nextSibling();
