@@ -1,4 +1,4 @@
-/* -*- Mode: C++ -*-
+/*
    KDChart - a multi-platform charting engine
    */
 
@@ -46,13 +46,13 @@ namespace KDXML {
 
 
     void createOrientationNode( TQDomDocument& doc, TQDomNode& parent,
-            const TQString& elementName, Qt::Orientation value )
+            const TQString& elementName, TQt::Orientation value )
     {
         TQDomElement newElement =
             doc.createElement( elementName );
         parent.appendChild( newElement );
         TQDomText elementContent =
-            doc.createTextNode( (Qt::Vertical == value) ? "vertical" : "horizontal" );
+            doc.createTextNode( (TQt::Vertical == value) ? "vertical" : "horizontal" );
         newElement.appendChild( elementContent );
     }
 
@@ -222,10 +222,6 @@ namespace KDXML {
         createIntNode( doc, fontElement, "PointSize", font.pointSize() );
         createIntNode( doc, fontElement, "Weight", font.weight() );
         createBoolNode( doc, fontElement, "Italic", font.italic() );
-#if COMPAT_TQT_VERSION < 0x030000
-        // TQt 3 handles the charset internally.
-        createIntNode( doc, fontElement, "CharSet", font.charSet() );
-#endif
     }
 
 
@@ -278,7 +274,7 @@ namespace KDXML {
     }
 
 
-    TQString penStyleToString( Qt::PenStyle style )
+    TQString penStyleToString( TQt::PenStyle style )
     {
         switch( style ) {
             case TQt::NoPen:
@@ -300,39 +296,39 @@ namespace KDXML {
 
 
 
-    TQString brushStyleToString( Qt::BrushStyle style )
+    TQString brushStyleToString( TQt::BrushStyle style )
     {
         // PENDING(kalle) Support custom patterns
         switch( style ) {
-            case Qt::NoBrush:
+            case TQt::NoBrush:
                 return "NoBrush";
-            case Qt::SolidPattern:
+            case TQt::SolidPattern:
                 return "SolidPattern";
-            case Qt::Dense1Pattern:
+            case TQt::Dense1Pattern:
                 return "Dense1Pattern";
-            case Qt::Dense2Pattern:
+            case TQt::Dense2Pattern:
                 return "Dense2Pattern";
-            case Qt::Dense3Pattern:
+            case TQt::Dense3Pattern:
                 return "Dense3Pattern";
-            case Qt::Dense4Pattern:
+            case TQt::Dense4Pattern:
                 return "Dense4Pattern";
-            case Qt::Dense5Pattern:
+            case TQt::Dense5Pattern:
                 return "Dense5Pattern";
-            case Qt::Dense6Pattern:
+            case TQt::Dense6Pattern:
                 return "Dense6Pattern";
-            case Qt::Dense7Pattern:
+            case TQt::Dense7Pattern:
                 return "Dense7Pattern";
-            case Qt::HorPattern:
+            case TQt::HorPattern:
                 return "HorPattern";
-            case Qt::VerPattern:
+            case TQt::VerPattern:
                 return "VerPattern";
-            case Qt::CrossPattern:
+            case TQt::CrossPattern:
                 return "CrossPattern";
-            case Qt::BDiagPattern:
+            case TQt::BDiagPattern:
                 return "BDiagPattern";
-            case Qt::FDiagPattern:
+            case TQt::FDiagPattern:
                 return "FDiagPattern";
-            case Qt::DiagCrossPattern:
+            case TQt::DiagCrossPattern:
                 return "DiagCrossPattern";
             default: // should not happen (but can for a custom pattern)
                 return "SolidPattern";
@@ -380,13 +376,13 @@ namespace KDXML {
     }
 
 
-    bool readOrientationNode( const TQDomElement& element, Qt::Orientation& value )
+    bool readOrientationNode( const TQDomElement& element, TQt::Orientation& value )
     {
         if( element.text() == "vertical" ) {
-            value = Qt::Vertical;
+            value = TQt::Vertical;
             return true;
         } else if( element.text() == "horizontal" ) {
-            value = Qt::Horizontal;
+            value = TQt::Horizontal;
             return true;
         } else
             return false;
@@ -442,7 +438,7 @@ namespace KDXML {
     {
         bool ok = true;
         TQColor tempColor;
-        Qt::BrushStyle tempStyle=Qt::SolidPattern;
+        TQt::BrushStyle tempStyle=TQt::SolidPattern;
         TQPixmap tempPixmap;
         TQDomNode node = element.firstChild();
         while( !node.isNull() ) {
@@ -458,7 +454,7 @@ namespace KDXML {
                 } else if( tagName == "Pixmap" ) {
                     ok = ok & readPixmapNode( element, tempPixmap );
                 } else {
-                    qDebug( "Unknown tag in brush" );
+                    tqDebug( "Unknown tag in brush" );
                 }
             }
             node = node.nextSibling();
@@ -490,7 +486,7 @@ namespace KDXML {
                     ok = ok & readStringNode( element, formatName );
 #ifndef NDEBUG
                     if( formatName != "XPM.GZ" )
-                        qDebug( "Unsupported pixmap format in XML file" );
+                        tqDebug( "Unsupported pixmap format in XML file" );
 #endif
                 } else if( tagName == "Length" ) {
                     int itempLength;
@@ -499,7 +495,7 @@ namespace KDXML {
                 } else if( tagName == "Data" ) {
                     ok = ok & readStringNode( element, tempData );
                 } else {
-                    qDebug( "Unknown tag in Pixmap" );
+                    tqDebug( "Unknown tag in Pixmap" );
                 }
             }
             node = node.nextSibling();
@@ -550,7 +546,7 @@ namespace KDXML {
         bool ok = true;
         int tempWidth;
         TQColor tempColor;
-        Qt::PenStyle tempStyle=Qt::SolidLine;
+        TQt::PenStyle tempStyle=TQt::SolidLine;
         TQDomNode node = element.firstChild();
         while( !node.isNull() ) {
             TQDomElement element = node.toElement();
@@ -565,7 +561,7 @@ namespace KDXML {
                     ok = ok & readStringNode( element, value );
                     tempStyle = stringToPenStyle( value );
                 } else {
-                    qDebug( "Unknown tag in brush" );
+                    tqDebug( "Unknown tag in brush" );
                 }
             }
             node = node.nextSibling();
@@ -603,7 +599,7 @@ namespace KDXML {
                 } else if( tagName == "CharSet" ) {
                     ok = ok & readIntNode( element, charSet );
                 } else {
-                    qDebug( "Unknown tag in color map" );
+                    tqDebug( "Unknown tag in color map" );
                 }
             }
             node = node.nextSibling();
@@ -614,10 +610,6 @@ namespace KDXML {
             font.setPointSize( pointSize );
             font.setWeight( weight );
             font.setItalic( italic );
-#if COMPAT_TQT_VERSION < 0x030000
-            // TQt 3 handles charsets internally.
-            font.setCharSet( (TQFont::CharSet)charSet );
-#endif
         }
 
         return ok;
@@ -641,7 +633,7 @@ namespace KDXML {
                 } else if( tagName == "Y" ) {
                     ok = ok & readIntNode( element, y );
                 } else {
-                    qDebug( "Unknown tag in rect" );
+                    tqDebug( "Unknown tag in rect" );
                 }
             }
             node = node.nextSibling();
@@ -674,7 +666,7 @@ namespace KDXML {
                 } else if( tagName == "Time" ) {
                     ok = ok & readTimeNode( element, tempTime );
                 } else {
-                    qDebug( "Unknown tag in datetime" );
+                    tqDebug( "Unknown tag in datetime" );
                 }
             }
             node = node.nextSibling();
@@ -750,60 +742,60 @@ namespace KDXML {
 
 
 
-    Qt::PenStyle stringToPenStyle( const TQString& style )
+    TQt::PenStyle stringToPenStyle( const TQString& style )
     {
         if( style == "NoPen" )
-            return Qt::NoPen;
+            return TQt::NoPen;
         else if( style == "SolidLine" )
-            return Qt::SolidLine;
+            return TQt::SolidLine;
         else if( style == "DashLine" )
-            return Qt::DashLine;
+            return TQt::DashLine;
         else if( style == "DotLine" )
-            return Qt::DotLine;
+            return TQt::DotLine;
         else if( style == "DashDotLine" )
-            return Qt::DashDotLine;
+            return TQt::DashDotLine;
         else if( style == "DashDotDotLine" )
-            return Qt::DashDotDotLine;
+            return TQt::DashDotDotLine;
         else // should not happen
-            return Qt::SolidLine;
+            return TQt::SolidLine;
     }
 
 
-    Qt::BrushStyle stringToBrushStyle( const TQString& style )
+    TQt::BrushStyle stringToBrushStyle( const TQString& style )
     {
         // PENDING(kalle) Support custom patterns
         if( style == "NoBrush" )
-            return Qt::NoBrush;
+            return TQt::NoBrush;
         else if( style == "SolidPattern" )
-            return Qt::SolidPattern;
+            return TQt::SolidPattern;
         else if( style == "Dense1Pattern" )
-            return Qt::Dense1Pattern;
+            return TQt::Dense1Pattern;
         else if( style == "Dense2Pattern" )
-            return Qt::Dense2Pattern;
+            return TQt::Dense2Pattern;
         else if( style == "Dense3Pattern" )
-            return Qt::Dense3Pattern;
+            return TQt::Dense3Pattern;
         else if( style == "Dense4Pattern" )
-            return Qt::Dense4Pattern;
+            return TQt::Dense4Pattern;
         else if( style == "Dense5Pattern" )
-            return Qt::Dense5Pattern;
+            return TQt::Dense5Pattern;
         else if( style == "Dense6Pattern" )
-            return Qt::Dense6Pattern;
+            return TQt::Dense6Pattern;
         else if( style == "Dense7Pattern" )
-            return Qt::Dense7Pattern;
+            return TQt::Dense7Pattern;
         else if( style == "HorPattern" )
-            return Qt::HorPattern;
+            return TQt::HorPattern;
         else if( style == "VerPattern" )
-            return Qt::VerPattern;
+            return TQt::VerPattern;
         else if( style == "CrossPattern" )
-            return Qt::CrossPattern;
+            return TQt::CrossPattern;
         else if( style == "BDiagPattern" )
-            return Qt::BDiagPattern;
+            return TQt::BDiagPattern;
         else if( style == "FDiagPattern" )
-            return Qt::FDiagPattern;
+            return TQt::FDiagPattern;
         else if( style == "DiagCrossPattern" )
-            return Qt::DiagCrossPattern;
+            return TQt::DiagCrossPattern;
         else // should not happen (but can with custom patterns)
-            return Qt::SolidPattern;
+            return TQt::SolidPattern;
     }
 
 }
