@@ -65,7 +65,7 @@
 
 KDGanttSemiSizingControl::KDGanttSemiSizingControl( TQWidget* parent,
                                           const char* name ) :
-    KDGanttSizingControl( parent, name ), _orient(Qt::Horizontal ), 
+    KDGanttSizingControl( parent, name ), _orient(TQt::Horizontal ), 
     _arrowPos( Before ), _minimizedWidget(0), _maximizedWidget(0)
 {
     init();
@@ -84,7 +84,7 @@ KDGanttSemiSizingControl::KDGanttSemiSizingControl( TQWidget* parent,
   the base class.
 */
 
-KDGanttSemiSizingControl::KDGanttSemiSizingControl( Qt::Orientation orientation,
+KDGanttSemiSizingControl::KDGanttSemiSizingControl( TQt::Orientation orientation,
                                           TQWidget* parent,
                                           const char* name ) :
     KDGanttSizingControl( parent, name ), _orient( orientation ), 
@@ -108,7 +108,7 @@ KDGanttSemiSizingControl::KDGanttSemiSizingControl( Qt::Orientation orientation,
 */
 
 KDGanttSemiSizingControl::KDGanttSemiSizingControl( ArrowPosition arrowPosition,
-                                          Qt::Orientation orientation,
+                                          TQt::Orientation orientation,
                                           TQWidget* parent,
                                           const char* name ) :
     KDGanttSizingControl( parent, name ), _orient( orientation ), 
@@ -186,7 +186,7 @@ TQWidget* KDGanttSemiSizingControl::maximizedWidget() const
   \sa orientation()
 */
 
-void KDGanttSemiSizingControl::setOrientation( Qt::Orientation orientation )
+void KDGanttSemiSizingControl::setOrientation( TQt::Orientation orientation )
 {
     if ( _orient != orientation ) {
         _orient = orientation;
@@ -201,7 +201,7 @@ void KDGanttSemiSizingControl::setOrientation( Qt::Orientation orientation )
   \sa setOrientation()
 */
 
-Qt::Orientation KDGanttSemiSizingControl::orientation() const
+TQt::Orientation KDGanttSemiSizingControl::orientation() const
 {
     return _orient;
 }
@@ -248,7 +248,7 @@ void KDGanttSemiSizingControl::init()
 {
     _but = new TQPushButton( this );
     _but->setSizePolicy( TQSizePolicy( TQSizePolicy::Fixed, TQSizePolicy::Fixed ) );
-    connect( _but, TQT_SIGNAL( clicked() ), this, TQT_SLOT(changeState()) );
+    connect( _but, TQ_SIGNAL( clicked() ), this, TQ_SLOT(changeState()) );
     _layout = 0;
     TQWhatsThis::add( _but, "Click on this button to show the \nlegend at the bottom of the widget");
     TQToolTip::add( _but, "Show / hide legend");
@@ -262,12 +262,12 @@ void KDGanttSemiSizingControl::setup()
     delete _layout;
     TQBoxLayout* butLayout; // _layout will delete me
 
-    if ( _orient ==Qt::Horizontal || isMinimized() )
+    if ( _orient ==TQt::Horizontal || isMinimized() )
         _layout = new TQHBoxLayout( this );
     else
         _layout = new TQVBoxLayout( this );
 
-    if ( _orient ==Qt::Vertical && !isMinimized() )
+    if ( _orient ==TQt::Vertical && !isMinimized() )
         butLayout = new TQHBoxLayout( _layout );
     else
         butLayout = new TQVBoxLayout( _layout );
@@ -288,7 +288,7 @@ void KDGanttSemiSizingControl::setup()
     }
 
     //------------------------------ Setup the button at the correct possition
-    if ( _arrowPos == After && _orient ==Qt::Vertical && !isMinimized() ) {
+    if ( _arrowPos == After && _orient ==TQt::Vertical && !isMinimized() ) {
         butLayout->addStretch( 1 );
         butLayout->addWidget( _but, 0, TQt::AlignLeft );
     }
@@ -305,7 +305,7 @@ void KDGanttSemiSizingControl::setup()
        else
        widget = _maximizedWidget;
        if( widget ) {
-       if ( _arrowPos == Before  || _orient ==Qt::Vertical && !isMinimized() )
+       if ( _arrowPos == Before  || _orient ==TQt::Vertical && !isMinimized() )
        _layout->addWidget( widget, 1 );
        else
        _layout->insertWidget( 0, widget, 1 );
@@ -318,20 +318,20 @@ void KDGanttSemiSizingControl::setup()
     if ( isMinimized() ) {
        widget = _minimizedWidget;
        if( widget ) {
-	 if ( _arrowPos == Before  || _orient ==Qt::Vertical && !isMinimized() )
+	 if ( _arrowPos == Before  || _orient ==TQt::Vertical && !isMinimized() )
 	   _layout->addWidget( widget, 1 );
 	 else
 	   _layout->insertWidget( 0, widget, 1 );
        }
     }
     else {
-      if ( _arrowPos == Before  || _orient ==Qt::Vertical && !isMinimized() )
+      if ( _arrowPos == Before  || _orient ==TQt::Vertical && !isMinimized() )
 	_layout->addStretch( 1 );
       else
 	_layout->insertStretch( 0, 1 );
       widget = _maximizedWidget;
       // the following is only the special case
-      // arrowPos == Before  and  _orient ==Qt::Vertical
+      // arrowPos == Before  and  _orient ==TQt::Vertical
       //widget->move( 0+x(), _but->height()+y());
     }
 }
