@@ -506,20 +506,20 @@ int sqlite3OsReadLock(OsFile *id){
     params.ioParam.ioRefNum = id->refNumRF;
     params.ioParam.ioPosMode = fsFromStart;
     params.ioParam.ioPosOffset = FIRST_LOCKBYTE;
-    params.ioParam.ioRetqCount = 1;
+    params.ioParam.ioReqCount = 1;
     while( cnt-->0 && (res = PBLockRangeSync(&params))!=noErr ){
       UInt32 finalTicks;
       Delay(1, &finalTicks); /* 1/60 sec */
     }
     if( res == noErr ){
       params.ioParam.ioPosOffset = FIRST_LOCKBYTE+1;
-      params.ioParam.ioRetqCount = N_LOCKBYTE;
+      params.ioParam.ioReqCount = N_LOCKBYTE;
       PBUnlockRangeSync(&params);
       params.ioParam.ioPosOffset = FIRST_LOCKBYTE+lk;
-      params.ioParam.ioRetqCount = 1;
+      params.ioParam.ioReqCount = 1;
       res = PBLockRangeSync(&params);
       params.ioParam.ioPosOffset = FIRST_LOCKBYTE;
-      params.ioParam.ioRetqCount = 1;
+      params.ioParam.ioReqCount = 1;
       PBUnlockRangeSync(&params);
     }
     if( res == noErr ){
@@ -550,24 +550,24 @@ int sqlite3OsWriteLock(OsFile *id){
     params.ioParam.ioRefNum = id->refNumRF;
     params.ioParam.ioPosMode = fsFromStart;
     params.ioParam.ioPosOffset = FIRST_LOCKBYTE;
-    params.ioParam.ioRetqCount = 1;
+    params.ioParam.ioReqCount = 1;
     while( cnt-->0 && (res = PBLockRangeSync(&params))!=noErr ){
       UInt32 finalTicks;
       Delay(1, &finalTicks); /* 1/60 sec */
     }
     if( res == noErr ){
       params.ioParam.ioPosOffset = FIRST_LOCKBYTE + id->locked;
-      params.ioParam.ioRetqCount = 1;
+      params.ioParam.ioReqCount = 1;
       if( id->locked==0 
             || PBUnlockRangeSync(&params)==noErr ){
         params.ioParam.ioPosOffset = FIRST_LOCKBYTE+1;
-        params.ioParam.ioRetqCount = N_LOCKBYTE;
+        params.ioParam.ioReqCount = N_LOCKBYTE;
         res = PBLockRangeSync(&params);
       }else{
         res = afpRangeNotLocked;
       }
       params.ioParam.ioPosOffset = FIRST_LOCKBYTE;
-      params.ioParam.ioRetqCount = 1;
+      params.ioParam.ioReqCount = 1;
       PBUnlockRangeSync(&params);
     }
     if( res == noErr ){
@@ -596,13 +596,13 @@ int sqlite3OsUnlock(OsFile *id){
     rc = SQLITE_OK;
   }else if( id->locked<0 ){
     params.ioParam.ioPosOffset = FIRST_LOCKBYTE+1;
-    params.ioParam.ioRetqCount = N_LOCKBYTE;
+    params.ioParam.ioReqCount = N_LOCKBYTE;
     PBUnlockRangeSync(&params);
     rc = SQLITE_OK;
     id->locked = 0;
   }else{
     params.ioParam.ioPosOffset = FIRST_LOCKBYTE+id->locked;
-    params.ioParam.ioRetqCount = 1;
+    params.ioParam.ioReqCount = 1;
     PBUnlockRangeSync(&params);
     rc = SQLITE_OK;
     id->locked = 0;
