@@ -27,7 +27,7 @@ class KexiActionProxy;
 //! Helper class for KexiActionProxy::plugSharedActionToExternalGUI() method.
 class TDEAction_setEnabled_Helper : public TQObject
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 	public:
 		TDEAction_setEnabled_Helper(KexiActionProxy* proxy);
