@@ -44,7 +44,7 @@ namespace KexiPart {
  */
 class KEXICORE_EXPORT KexiMainWindow : public KMdiMainFrm, public KexiSharedActionHost
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 	public:
 		//! Used by printActionForItem()
