@@ -64,7 +64,7 @@ enum ObjectTypes {
  */
 class KEXICORE_EXPORT Part : public TQObject
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 
 	public:
