@@ -50,7 +50,7 @@ EventEater::EventEater(TQWidget *widget, TQObject *container)
 	m_widget = widget;
 	m_container = container;
 
-	installRecursiveEventFilter(TQT_TQOBJECT(m_widget), this);
+	installRecursiveEventFilter(m_widget, this);
 }
 
 bool
@@ -63,8 +63,8 @@ EventEater::eventFilter(TQObject *, TQEvent *ev)
 	// we need to simulate the Press event
 	if(ev->type() == TQEvent::MouseButtonRelease && m_widget->inherits("TQTabWidget"))
 	{
-		TQMouseEvent *mev = TQT_TQMOUSEEVENT(ev);
-		if(mev->button() == Qt::LeftButton)
+		TQMouseEvent *mev = static_cast<TQMouseEvent*>(ev);
+		if(mev->button() == TQt::LeftButton)
 		{
 			TQMouseEvent *myev = new TQMouseEvent(TQEvent::MouseButtonPress, mev->pos(), mev->button(), mev->state());
 			m_container->eventFilter(m_widget, myev);
@@ -83,7 +83,7 @@ EventEater::eventFilter(TQObject *, TQEvent *ev)
 EventEater::~EventEater()
 {
 	if(m_widget)
-		removeRecursiveEventFilter(TQT_TQOBJECT(m_widget), TQT_TQOBJECT(this));
+		removeRecursiveEventFilter(m_widget, this);
 }
 
 // Container itself
@@ -127,10 +127,10 @@ Container::Container(Container *toplevel, TQWidget *container, TQObject *parent,
 		else
 			m_form->objectTree()->addItem(toplevel->objectTree(), it);
 
-		connect(toplevel, TQT_SIGNAL(destroyed()), this, TQT_SLOT(widgetDeleted()));
+		connect(toplevel, TQ_SIGNAL(destroyed()), this, TQ_SLOT(widgetDeleted()));
 	}
 
-	connect(container, TQT_SIGNAL(destroyed()), this, TQT_SLOT(widgetDeleted()));
+	connect(container, TQ_SIGNAL(destroyed()), this, TQ_SLOT(widgetDeleted()));
 }
 
 Container::~Container()
@@ -161,8 +161,8 @@ Container::eventFilter(TQObject *s, TQEvent *e)
 				<< "of type " << s->className() << endl;
 			kdDebug() << "TQEvent::MouseButtonPress this          = " << name() << endl;
 
-			m_moving = TQT_TQWIDGET(s);
-			TQMouseEvent *mev = TQT_TQMOUSEEVENT(e);
+			m_moving = static_cast<TQWidget*>(s);
+			TQMouseEvent *mev = static_cast<TQMouseEvent*>(e);
 			m_grab = TQPoint(mev->x(), mev->y());
 
 			// we are drawing a connection
@@ -171,7 +171,7 @@ Container::eventFilter(TQObject *s, TQEvent *e)
 				return true;
 			}
 
-			if(((mev->state() == ControlButton) || (mev->state() == ShiftButton)) 
+			if(((mev->state() == TQt::ControlButton) || (mev->state() == TQt::ShiftButton))
 				&& (!FormManager::self()->isInserting())) // multiple selection mode
 			{
 				if(m_form->selectedWidgets()->findRef(m_moving) != -1) // widget is already selected
@@ -187,22 +187,22 @@ Container::eventFilter(TQObject *s, TQEvent *e)
 					}
 				}
 				else // the widget is not yet selected, we add it
-					setSelectedWidget(m_moving, true, (mev->button() == Qt::RightButton));
+					setSelectedWidget(m_moving, true, (mev->button() == TQt::RightButton));
 			}
 			else if((m_form->selectedWidgets()->count() > 1))//&& (!m_form->manager()->isInserting())) // more than one widget selected
 			{
 				if(m_form->selectedWidgets()->findRef(m_moving) == -1) // widget is not selected, it becomes the only selected widget
-					setSelectedWidget(m_moving, false, (mev->button() == Qt::RightButton));
+					setSelectedWidget(m_moving, false, (mev->button() == TQt::RightButton));
 				// If the widget is already selected, we do nothing (to ease widget moving, etc.)
 			}
 			else// if(!m_form->manager()->isInserting())
-				setSelectedWidget(m_moving, false, (mev->button() == Qt::RightButton));
+				setSelectedWidget(m_moving, false, (mev->button() == TQt::RightButton));
 
 			// we are inserting a widget or drawing a selection rect in the form
 			if((/*s == m_container &&*/ FormManager::self()->isInserting()) || ((s == m_container) && !m_toplevel))
 			{
 				int tmpx,tmpy;
-				if(!FormManager::self()->snapWidgetsToGrid() || (mev->state() == (Qt::LeftButton|ControlButton|AltButton)))
+				if(!FormManager::self()->snapWidgetsToGrid() || (mev->state() == (TQt::LeftButton|TQt::ControlButton|TQt::AltButton)))
 				{
 					tmpx = mev->x();
 					tmpy = mev->y();
@@ -217,7 +217,7 @@ Container::eventFilter(TQObject *s, TQEvent *e)
 					tmpy *= gridX;
 				}
 
-				m_insertBegin = (TQT_TQWIDGET(s))->mapTo(m_container, TQPoint(tmpx, tmpy));
+				m_insertBegin = (static_cast<TQWidget*>(s))->mapTo(m_container, TQPoint(tmpx, tmpy));
 				if(m_form->formWidget())
 					m_form->formWidget()->initBuffer();
 
@@ -239,7 +239,7 @@ Container::eventFilter(TQObject *s, TQEvent *e)
 
 		case TQEvent::MouseButtonRelease:
 		{
-			TQMouseEvent *mev = TQT_TQMOUSEEVENT(e);
+			TQMouseEvent *mev = static_cast<TQMouseEvent*>(e);
 			if (!m_mousePressEventReceived) {
 				m_mouseReleaseEvent = *mev;
 				m_objectForMouseReleaseEvent = s;
@@ -252,9 +252,9 @@ Container::eventFilter(TQObject *s, TQEvent *e)
 
 		case TQEvent::MouseMove:
 		{
-			TQMouseEvent *mev = TQT_TQMOUSEEVENT(e);
-			if(m_insertBegin!=TQPoint(-1,-1) && FormManager::self()->isInserting() && ((mev->state() == Qt::LeftButton) || (mev->state() == (Qt::LeftButton|ControlButton)) ||
-			(mev->state() == (Qt::LeftButton|ControlButton|AltButton)) || (mev->state() == (Qt::LeftButton|ShiftButton)) ) )
+			TQMouseEvent *mev = static_cast<TQMouseEvent*>(e);
+			if(m_insertBegin!=TQPoint(-1,-1) && FormManager::self()->isInserting() && ((mev->state() == TQt::LeftButton) || (mev->state() == (TQt::LeftButton|TQt::ControlButton)) ||
+			(mev->state() == (TQt::LeftButton|TQt::ControlButton|TQt::AltButton)) || (mev->state() == (TQt::LeftButton|TQt::ShiftButton)) ) )
 			// draw the insert rect
 			{
 				drawInsertRect(mev, s);
@@ -268,11 +268,11 @@ Container::eventFilter(TQObject *s, TQEvent *e)
 					return true;
 
 				if(m_form->formWidget() && (tree->widget() != s))
-					m_form->formWidget()->highlightWidgets(tree->widget(), TQT_TQWIDGET(s));
+					m_form->formWidget()->highlightWidgets(tree->widget(), static_cast<TQWidget*>(s));
 			}
-			else if(m_insertBegin!=TQPoint(-1,-1) && s == m_container && !m_toplevel && (mev->state() != ControlButton) && !FormManager::self()->isCreatingConnection()) // draw the selection rect
+			else if(m_insertBegin!=TQPoint(-1,-1) && s == m_container && !m_toplevel && (mev->state() != TQt::ControlButton) && !FormManager::self()->isCreatingConnection()) // draw the selection rect
 			{
-				if((mev->state() != Qt::LeftButton) || /*m_inlineEditing*/ m_state == InlineEditing)
+				if((mev->state() != TQt::LeftButton) || /*m_inlineEditing*/ m_state == InlineEditing)
 					return true;
 				int topx = (m_insertBegin.x() < mev->x()) ? m_insertBegin.x() :  mev->x();
 				int topy = (m_insertBegin.y() < mev->y()) ? m_insertBegin.y() : mev->y();
@@ -287,14 +287,14 @@ Container::eventFilter(TQObject *s, TQEvent *e)
 				m_state = DoingNothing;
 				return true;
 			}
-			else if(mev->state() == (Qt::LeftButton|ControlButton)) // draw the insert rect for the copied widget
+			else if(mev->state() == (TQt::LeftButton|TQt::ControlButton)) // draw the insert rect for the copied widget
 			{
 				if(s == m_container)// || (m_form->selectedWidgets()->count() > 1))
 					return true;
 				drawCopiedWidgetRect(mev);
 				return true;
 			}
-			else if( ( (mev->state() == Qt::LeftButton) || (mev->state() == (Qt::LeftButton|ControlButton|AltButton)) )
+			else if( ( (mev->state() == TQt::LeftButton) || (mev->state() == (TQt::LeftButton|TQt::ControlButton|TQt::AltButton)) )
 			  && !FormManager::self()->isInserting() && (m_state != CopyingWidget)) // we are dragging the widget(s) to move it
 			{
 				if(!m_toplevel && m_moving == m_container) // no effect for form
@@ -343,7 +343,7 @@ Container::eventFilter(TQObject *s, TQEvent *e)
 		//case TQEvent::AccelOverride:
 		case TQEvent::KeyPress:
 		{
-			TQKeyEvent *kev = TQT_TQKEYEVENT(e);
+			TQKeyEvent *kev = static_cast<TQKeyEvent*>(e);
 
 			if(kev->key() == Key_F2) // pressing F2 == double-clicking
 			{
@@ -372,14 +372,14 @@ Container::eventFilter(TQObject *s, TQEvent *e)
 				if(!m_moving)
 					return true;
 				// we simulate a mouse move event to update screen
-				TQMouseEvent *mev = new TQMouseEvent(TQEvent::MouseMove, m_moving->mapFromGlobal(TQCursor::pos()), Qt::NoButton,
-				Qt::LeftButton|ControlButton );
-				eventFilter(TQT_TQOBJECT(m_moving), TQT_TQEVENT(mev));
+				TQMouseEvent *mev = new TQMouseEvent(TQEvent::MouseMove, m_moving->mapFromGlobal(TQCursor::pos()), TQt::NoButton,
+				TQt::LeftButton|TQt::ControlButton );
+				eventFilter(m_moving, mev);
 				delete mev;
 			}
 			else if(kev->key() == FormManager::self()->contextMenuKey())
 			{
-					FormManager::self()->createContextMenu(TQT_TQWIDGET(s), this, false);
+					FormManager::self()->createContextMenu(static_cast<TQWidget*>(s), this, false);
 					return true;
 			}
 			else if (kev->key() == Key_Delete)
@@ -435,7 +435,7 @@ Container::eventFilter(TQObject *s, TQEvent *e)
 
 		case TQEvent::KeyRelease:
 		{
-			TQKeyEvent *kev = TQT_TQKEYEVENT(e);
+			TQKeyEvent *kev = static_cast<TQKeyEvent*>(e);
 			if((kev->key() == Key_Control) && (m_state == CopyingWidget)) {
 				// cancel copying
 				//m_copyRect = TQRect();
@@ -448,7 +448,7 @@ Container::eventFilter(TQObject *s, TQEvent *e)
 		case TQEvent::MouseButtonDblClick: // editing
 		{
 			kdDebug() << "Container: Mouse dbl click for widget " << s->name() << endl;
-			TQWidget *w = TQT_TQWIDGET(s);
+			TQWidget *w = static_cast<TQWidget*>(s);
 			if(!w)
 				return false;
 
@@ -487,16 +487,16 @@ Container::handleMouseReleaseEvent(TQObject *s, TQMouseEvent *mev)
 		m_insertRect = TQRect();
 		return true;
 	}
-	else if(s == m_container && !m_toplevel && (mev->button() != Qt::RightButton) && m_insertRect.isValid()) // we are drawing a rect to select widgets
+	else if(s == m_container && !m_toplevel && (mev->button() != TQt::RightButton) && m_insertRect.isValid()) // we are drawing a rect to select widgets
 	{
 		drawSelectionRect(mev);
 		return true;
 	}
-	if(mev->button() == Qt::RightButton) // Right-click -> context menu
+	if(mev->button() == TQt::RightButton) // Right-click -> context menu
 	{
-		FormManager::self()->createContextMenu(TQT_TQWIDGET(s), this);
+		FormManager::self()->createContextMenu(static_cast<TQWidget*>(s), this);
 	}
-	else if(mev->state() == (Qt::LeftButton|TQt::ControlButton))// && (m_copyRect.isValid()))
+	else if(mev->state() == (TQt::LeftButton|TQt::ControlButton))// && (m_copyRect.isValid()))
 	{
 		// copying a widget by Ctrl+dragging
 
@@ -519,7 +519,7 @@ Container::handleMouseReleaseEvent(TQObject *s, TQMouseEvent *mev)
 		if(m_form->selectedWidgets()->count() > 1)
 			FormManager::self()->setInsertPoint( mev->pos() );
 		else
-			FormManager::self()->setInsertPoint( TQT_TQWIDGET(s)->mapTo(m_container, mev->pos() - m_grab) );
+			FormManager::self()->setInsertPoint( static_cast<TQWidget*>(s)->mapTo(m_container, mev->pos() - m_grab) );
 		FormManager::self()->pasteWidget();
 		m_form->setInteractiveMode(true);
 
@@ -620,7 +620,7 @@ Container::setLayout(LayoutType type)
 		case  HFlow:
 		{
 			KexiFlowLayout *flow = new KexiFlowLayout(m_container,m_margin, m_spacing);
-			flow->setOrientation(Qt::Horizontal);
+			flow->setOrientation(TQt::Horizontal);
 			m_layout = (TQLayout*)flow;
 			createFlowLayout();
 			break;
@@ -628,7 +628,7 @@ Container::setLayout(LayoutType type)
 		case VFlow:
 		{
 			KexiFlowLayout *flow = new KexiFlowLayout(m_container,m_margin, m_spacing);
-			flow->setOrientation(Qt::Vertical);
+			flow->setOrientation(TQt::Vertical);
 			m_layout = (TQLayout*)flow;
 			createFlowLayout();
 			break;
@@ -674,7 +674,7 @@ Container::createFlowLayout()
 
 	const int offset = 15;
 	WidgetList *list=0, *list2=0;
-	if(flow->orientation() ==Qt::Horizontal) {
+	if(flow->orientation() ==TQt::Horizontal) {
 		list = new VerWidgetList(m_form->toplevelContainer()->widget());
 		list2 = new HorWidgetList(m_form->toplevelContainer()->widget());
 	}
@@ -688,7 +688,7 @@ Container::createFlowLayout()
 		list->append( tree->widget());
 	list->sort();
 
-	if(flow->orientation() ==Qt::Horizontal) {
+	if(flow->orientation() ==TQt::Horizontal) {
 		int y = list->first()->y();
 		for(TQWidget *w = list->first(); w; w = list->next()) {
 			if( (w->y() > y +offset)) {
@@ -943,7 +943,7 @@ Container::stringToLayoutType(const TQString &name)
 void
 Container::drawConnection(TQMouseEvent *mev)
 {
-	if(mev->button() != Qt::LeftButton)
+	if(mev->button() != TQt::LeftButton)
 	{
 		FormManager::self()->resetCreatedConnection();
 		return;
@@ -1020,10 +1020,10 @@ void
 Container::drawInsertRect(TQMouseEvent *mev, TQObject *s)
 {
 	int tmpx, tmpy;
-	TQPoint pos = TQT_TQWIDGET(s)->mapTo(m_container, mev->pos());
+	TQPoint pos = static_cast<TQWidget*>(s)->mapTo(m_container, mev->pos());
 	int gridX = m_form->gridSize();
 	int gridY = m_form->gridSize();
-	if(!FormManager::self()->snapWidgetsToGrid() || (mev->state() == (Qt::LeftButton|ControlButton|AltButton)) )
+	if(!FormManager::self()->snapWidgetsToGrid() || (mev->state() == (TQt::LeftButton|TQt::ControlButton|TQt::AltButton)) )
 	{
 		tmpx = pos.x();
 		tmpy = pos.y();
@@ -1144,7 +1144,7 @@ Container::moveSelectedWidgetsBy(int realdx, int realdy, TQMouseEvent *mev)
 		}
 
 		int tmpx, tmpy;
-		if(!FormManager::self()->snapWidgetsToGrid() || (mev && mev->state() == (Qt::LeftButton|ControlButton|AltButton)) )
+		if(!FormManager::self()->snapWidgetsToGrid() || (mev && mev->state() == (TQt::LeftButton|TQt::ControlButton|TQt::AltButton)) )
 		{
 			tmpx = w->x() + dx;
 			tmpy = w->y() + dy;
@@ -1175,7 +1175,7 @@ void
 DesignTimeDynamicChildWidgetHandler::childWidgetAdded(TQWidget* w)
 {
 	if (m_item) {
-		installRecursiveEventFilter(TQT_TQOBJECT(w), m_item->eventEater());
+		installRecursiveEventFilter(w, m_item->eventEater());
 	}
 }
 
