@@ -48,7 +48,7 @@ namespace KFormDesigner {
  using TDEListViewItem::setRenameable(). Pixmaps are not yet supported. */
 class KFORMEDITOR_EXPORT EditListViewDialog : public KDialogBase
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 
 	public:
