@@ -520,7 +520,7 @@ ContainerFactory::createWidget(const TQCString &c, TQWidget *p, const char *n,
 		KFDTabWidget *tab = new KFDTabWidget(p, n);
 #if defined(USE_KTabWidget) && TDE_VERSION >= TDE_MAKE_VERSION(3,1,9)
 		tab->setTabReorderingEnabled(true);
-		connect(tab, TQT_SIGNAL(movedTab(int,int)), this, TQT_SLOT(reorderTabs(int,int)));
+		connect(tab, TQ_SIGNAL(movedTab(int,int)), this, TQ_SLOT(reorderTabs(int,int)));
 #endif
 		container->form()->objectTree()->addItem(container->objectTree(),
 			new KFormDesigner::ObjectTreeItem(
@@ -541,7 +541,7 @@ ContainerFactory::createWidget(const TQCString &c, TQWidget *p, const char *n,
 	else if(c == "TQWidget" || c=="ContainerWidget")
 	{
 		TQWidget *w = new ContainerWidget(p, n);
-		new KFormDesigner::Container(container, w, TQT_TQOBJECT(p));
+		new KFormDesigner::Container(container, w, p);
 		return w;
 	}
 	else if(c == "TQGroupBox" || c == "GroupBox")
@@ -610,7 +610,7 @@ ContainerFactory::createWidget(const TQCString &c, TQWidget *p, const char *n,
 		TQSplitter *split = new TQSplitter(p, n);
 		if (0 == (options & WidgetFactory::AnyOrientation))
 			split->setOrientation(
-				(options & WidgetFactory::VerticalOrientation) ? Qt::Vertical : Qt::Horizontal);
+				(options & WidgetFactory::VerticalOrientation) ? TQt::Vertical : TQt::Horizontal);
 		new KFormDesigner::Container(container, split, container);
 		return split;
 	}
@@ -660,9 +660,9 @@ ContainerFactory::createMenuActions(const TQCString &classname, TQWidget *w, TQP
 //			m_container = m_container->toplevel();
 		}
 
-		int id = menu->insertItem(SmallIconSet("tab_new"), i18n("Add Page"), this, TQT_SLOT(addTabPage()) );
-		id = menu->insertItem(SmallIconSet("edit"), i18n("Rename Page..."), this, TQT_SLOT(renameTabPage()));
-		id = menu->insertItem(SmallIconSet("tab_remove"), i18n("Remove Page"), this, TQT_SLOT(removeTabPage()));
+		int id = menu->insertItem(SmallIconSet("tab_new"), i18n("Add Page"), this, TQ_SLOT(addTabPage()) );
+		id = menu->insertItem(SmallIconSet("edit"), i18n("Rename Page..."), this, TQ_SLOT(renameTabPage()));
+		id = menu->insertItem(SmallIconSet("tab_remove"), i18n("Remove Page"), this, TQ_SLOT(removeTabPage()));
 //		if( dynamic_cast<TabWidgetBase*>(m_widget)->count() == 1)
 		if( dynamic_cast<TabWidgetBase*>(widget())->count() == 1)
 			menu->setItemEnabled(id, false);
@@ -679,18 +679,18 @@ ContainerFactory::createMenuActions(const TQCString &classname, TQWidget *w, TQP
 //		m_container = container->form()->objectTree()->lookup(m_widget->name())->parent()->container();
 //		m_container = container->form()->objectTree()->lookup(stack->name())->parent()->container();
 
-		int id = menu->insertItem(SmallIconSet("tab_new"), i18n("Add Page"), this, TQT_SLOT(addStackPage()) );
+		int id = menu->insertItem(SmallIconSet("tab_new"), i18n("Add Page"), this, TQ_SLOT(addStackPage()) );
 
-		id = menu->insertItem(SmallIconSet("tab_remove"), i18n("Remove Page"), this, TQT_SLOT(removeStackPage()) );
+		id = menu->insertItem(SmallIconSet("tab_remove"), i18n("Remove Page"), this, TQ_SLOT(removeStackPage()) );
 //		if( ((TQWidgetStack*)m_widget)->children()->count() == 4) // == the stack has only one page
 		if(stack->childrenListObject().count() == 4) // == the stack has only one page
 			menu->setItemEnabled(id, false);
 
-		id = menu->insertItem(SmallIconSet("go-next"), i18n("Jump to Next Page"), this, TQT_SLOT(nextStackPage()));
+		id = menu->insertItem(SmallIconSet("go-next"), i18n("Jump to Next Page"), this, TQ_SLOT(nextStackPage()));
 		if(!stack->widget(stack->id(stack->visibleWidget())+1))
 			menu->setItemEnabled(id, false);
 
-		id = menu->insertItem(SmallIconSet("go-previous"), i18n("Jump to Previous Page"), this, TQT_SLOT(prevStackPage()));
+		id = menu->insertItem(SmallIconSet("go-previous"), i18n("Jump to Previous Page"), this, TQ_SLOT(prevStackPage()));
 		if(!stack->widget(stack->id(stack->visibleWidget()) -1) )
 			menu->setItemEnabled(id, false);
 		return true;
@@ -752,7 +752,7 @@ ContainerFactory::readSpecialProperty(const TQCString &, TQDomElement &node, TQW
 	if((name == "id") && (w->parentWidget()->isA("TQWidgetStack")))
 	{
 		TQWidgetStack *stack = (TQWidgetStack*)w->parentWidget();
-		int id = KFormDesigner::FormIO::readPropertyValue(node.firstChild(), TQT_TQOBJECT(w), name).toInt();
+		int id = KFormDesigner::FormIO::readPropertyValue(node.firstChild(), w, name).toInt();
 		stack->addWidget(w, id);
 		stack->raiseWidget(w);
 		item->addModifiedProperty("id", id);
