@@ -26,7 +26,7 @@ namespace KFormDesigner {
 
 class KFORMEDITOR_EXPORT KFDPixmapEdit : public KoProperty::PixmapEdit
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 
 	public:
