@@ -46,13 +46,13 @@ RichTextDialog::RichTextDialog(TQWidget *parent, const TQString &text)
 
 	m_fcombo = new TDEFontCombo(m_toolbar);
 	m_toolbar->insertWidget(TBFont, 40, m_fcombo);
-	connect(m_fcombo, TQT_SIGNAL(textChanged(const TQString&)), this, TQT_SLOT(changeFont(const TQString &)));
+	connect(m_fcombo, TQ_SIGNAL(textChanged(const TQString&)), this, TQ_SLOT(changeFont(const TQString &)));
 
 	m_toolbar->insertSeparator();
 
 	m_colCombo = new KColorCombo(m_toolbar);
 	m_toolbar->insertWidget(TBColor, 30, m_colCombo);
-	connect(m_colCombo, TQT_SIGNAL(activated(const TQColor&)), this, TQT_SLOT(changeColor(const TQColor&)));
+	connect(m_colCombo, TQ_SIGNAL(activated(const TQColor&)), this, TQ_SLOT(changeColor(const TQColor&)));
 
 	m_toolbar->insertButton("format-text-bold", TBBold, true, i18n("Bold"));
 	m_toolbar->insertButton("format-text-italic", TBItalic, true, i18n("Italic"));
@@ -82,15 +82,15 @@ RichTextDialog::RichTextDialog(TQWidget *parent, const TQString &text)
 	m_toolbar->setToggle(TBJustify, true);
 	group->addButton(TBJustify);
 
-	connect(m_toolbar, TQT_SIGNAL(toggled(int)), this, TQT_SLOT(buttonToggled(int)));
+	connect(m_toolbar, TQ_SIGNAL(toggled(int)), this, TQ_SLOT(buttonToggled(int)));
 
 	m_edit = new KTextEdit(text, TQString(), frame, "richtext_edit");
 	m_edit->setTextFormat(RichText);
 	m_edit->setFocus();
 
-	connect(m_edit, TQT_SIGNAL(cursorPositionChanged(int, int)), this, TQT_SLOT(cursorPositionChanged(int, int)));
-	connect(m_edit, TQT_SIGNAL(clicked(int, int)), this, TQT_SLOT(cursorPositionChanged(int, int)));
-	connect(m_edit, TQT_SIGNAL(currentVerticalAlignmentChanged(VerticalAlignment)), this, TQT_SLOT(slotVerticalAlignmentChanged(VerticalAlignment)));
+	connect(m_edit, TQ_SIGNAL(cursorPositionChanged(int, int)), this, TQ_SLOT(cursorPositionChanged(int, int)));
+	connect(m_edit, TQ_SIGNAL(clicked(int, int)), this, TQ_SLOT(cursorPositionChanged(int, int)));
+	connect(m_edit, TQ_SIGNAL(currentVerticalAlignmentChanged(VerticalAlignment)), this, TQ_SLOT(slotVerticalAlignmentChanged(VerticalAlignment)));
 
 	m_edit->moveCursor(TQTextEdit::MoveEnd, false);
 	cursorPositionChanged(0, 0);
