@@ -43,7 +43,7 @@ using namespace KFormDesigner;
 //! A class that stores the code and events related to a single form
 class FormScript : public TQObject
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 
 	public:
