@@ -40,7 +40,7 @@ using namespace KFormDesigner;
 
 class ScriptManager : public TQObject
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 
 	public:
