@@ -37,7 +37,7 @@ class ObjectTreeView;
   The tab stops can be arranged automatically (see \ref Form::autoAssignTabStops()). */
 class KFORMEDITOR_EXPORT TabStopDialog : public KDialogBase
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 
 	public:
