@@ -73,7 +73,7 @@ KFDMainWindow::loadUIFile(const KURL &url)
 void
 KFDMainWindow::setupActions()
 {
-	KStdAction::quit(kapp, TQT_SLOT(quit()), actionCollection());
+	KStdAction::quit(kapp, TQ_SLOT(quit()), actionCollection());
 }
 
 bool
