@@ -27,7 +27,7 @@
 
 #include <tdeversion.h>
 #include <tdeaction.h>
-#include <kinstance.h>
+#include <tdeinstance.h>
 #include <tdelocale.h>
 #include <tdeaboutdata.h>
 #include <kdebug.h>
