@@ -256,7 +256,7 @@ class KFORMEDITOR_EXPORT WidgetInfo
   */
 class KFORMEDITOR_EXPORT WidgetFactory : public TQObject
 {
-	Q_OBJECT
+	TQ_OBJECT
 
 	public:
 		//! Options used in createWidget()
