@@ -39,7 +39,7 @@ class MySqlConnectionInternal;
  */
 class MySqlConnection : public Connection
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 
 	public:
