@@ -33,7 +33,7 @@ class DriverManager;
 //! PostgreSQL database driver.
 class pqxxSqlDriver : public Driver
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 	KEXIDB_DRIVER
 
