@@ -141,17 +141,17 @@ class KexiDB::SQLiteCursorData : public SQLiteConnectionInternal
 			else {
 				switch (f->type()) {
 				case Field::Date:
-					return TQDate::fromString( GET_sqlite3_column_text, Qt::ISODate );
+					return TQDate::fromString( GET_sqlite3_column_text, TQt::ISODate );
 				case Field::Time:
 					//TQDateTime - a hack needed because TQVariant(TQTime) has broken isNull()
 					return KexiUtils::stringToHackedTQTime(GET_sqlite3_column_text);
 				case Field::DateTime: {
 					TQString tmp( GET_sqlite3_column_text );
 					tmp[10] = 'T'; //for ISODate compatibility
-					return TQDateTime::fromString( tmp, Qt::ISODate );
+					return TQDateTime::fromString( tmp, TQt::ISODate );
 				}
 				case Field::Boolean:
-					return TQVariant(sqliteStringToBool(GET_sqlite3_column_text), 1);
+					return TQVariant(sqliteStringToBool(GET_sqlite3_column_text));
 				default:
 					return TQVariant(); //TODO
 				}
@@ -166,7 +166,7 @@ class KexiDB::SQLiteCursorData : public SQLiteConnectionInternal
 			case Field::BigInteger:
 				return TQVariant( (TQ_LLONG)sqlite3_column_int64(prepared_st_handle, i) );
 			case Field::Boolean:
-				return TQVariant( sqlite3_column_int(prepared_st_handle, i)!=0, 1 );
+				return TQVariant( sqlite3_column_int(prepared_st_handle, i)!=0 );
 			default:;
 			}
 			if (f->isFPNumericType()) //WEIRD, YEAH?
@@ -480,10 +480,10 @@ void SQLiteCursor::storeCurrentRow(RowData &data) const
 			case Field::BigInteger:
 				data[i] = TQVariant( TQString::fromLatin1(*col).toLongLong() );
 			case Field::Boolean:
-				data[i] = TQVariant( sqliteStringToBool(TQString::fromLatin1(*col)), 1 );
+				data[i] = TQVariant( sqliteStringToBool(TQString::fromLatin1(*col)) );
 				break;
 			case Field::Date:
-				data[i] = TQDate::fromString( TQString::fromLatin1(*col), Qt::ISODate );
+				data[i] = TQDate::fromString( TQString::fromLatin1(*col), TQt::ISODate );
 				break;
 			case Field::Time:
 				//TQDateTime - a hack needed because TQVariant(TQTime) has broken isNull()
@@ -492,7 +492,7 @@ void SQLiteCursor::storeCurrentRow(RowData &data) const
 			case Field::DateTime: {
 				TQString tmp( TQString::fromLatin1(*col) );
 				tmp[10] = 'T';
-				data[i] = TQDateTime::fromString( tmp, Qt::ISODate );
+				data[i] = TQDateTime::fromString( tmp, TQt::ISODate );
 				break;
 			}
 			default:
