@@ -44,7 +44,7 @@ class KProgressDialog;
 */
 class SQLiteVacuum : public TQObject
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 	public:
 		SQLiteVacuum(const TQString& filePath);
