@@ -452,21 +452,21 @@ Field::setDefaultValue(const TQCString& def)
 				m_defaultValue = TQVariant((bool)v);
 			break;
 		}case Date: {//YYYY-MM-DD
-			TQDate date = TQDate::fromString( def, Qt::ISODate );
+			TQDate date = TQDate::fromString( def, TQt::ISODate );
 			if (!date.isValid())
 				m_defaultValue = TQVariant();
 			else
 				m_defaultValue = TQVariant(date);
 			break;
 		}case DateTime: {//YYYY-MM-DDTHH:MM:SS
-			TQDateTime dt = TQDateTime::fromString( def, Qt::ISODate );
+			TQDateTime dt = TQDateTime::fromString( def, TQt::ISODate );
 			if (!dt.isValid())
 				m_defaultValue = TQVariant();
 			else
 				m_defaultValue = TQVariant(dt);
 			break;
 		}case Time: {//HH:MM:SS
-			TQTime time = TQTime::fromString( def, Qt::ISODate );
+			TQTime time = TQTime::fromString( def, TQt::ISODate );
 			if (!time.isValid())
 				m_defaultValue = TQVariant();
 			else
