@@ -314,7 +314,7 @@ class KEXI_DB_EXPORT Field
 		/*! \return (optional) subtype for this field. 
 		 Subtype is a string providing additional hint for field's type. 
 		 E.g. for BLOB type, it can be a MIME type or certain TQVariant type name, 
-		 for example: TQPIXMAP_OBJECT_NAME_STRING, "TQColor" or "TQFont" */
+		 for example: "TQPixmap", "TQColor" or "TQFont" */
 		inline TQString subType() const { return m_subType; }
 
 		/*! Sets (optional) subtype for this field. 
