@@ -23,17 +23,17 @@
 #ifdef __cplusplus
 # include <tdeversion.h> /* this will also include <tdelibs_export.h>, if available */
 #endif 
-/* KDE_EXPORT will be defined multiple times without this on tdelibs 3.3 (tested on 3.3.1) */
-#include <kdemacros.h>
+/* TDE_EXPORT will be defined multiple times without this on tdelibs 3.3 (tested on 3.3.1) */
+#include <tdemacros.h>
 
 /* workaround for KDElibs < 3.2 on !win32 */
-#ifndef KDE_EXPORT
-# define KDE_EXPORT
+#ifndef TDE_EXPORT
+# define TDE_EXPORT
 #endif
 
 /* TODO: #include <koffice_export.h> ??? */
 #ifdef MAKE_KEXI_DB_LIB
-# define KEXI_DB_EXPORT KDE_EXPORT
+# define KEXI_DB_EXPORT TDE_EXPORT
 #elif defined(KDE_MAKE_LIB)
 # define KEXI_DB_EXPORT KDE_IMPORT
 #else
@@ -41,7 +41,7 @@
 #endif
 
 #ifdef MAKE_KEXIMIGR_LIB
-# define KEXIMIGR_EXPORT  KDE_EXPORT
+# define KEXIMIGR_EXPORT  TDE_EXPORT
 #elif defined(KDE_MAKE_LIB)
 # define KEXIMIGR_EXPORT  KDE_IMPORT
 #else
