@@ -21,7 +21,7 @@
 #include "sqlparser.h"
 
 #include <kdebug.h>
-#include <klocale.h>
+#include <tdelocale.h>
 
 #include <tqregexp.h>
 
@@ -84,11 +84,11 @@ void yyerror(const char *str)
 	KexiDBDbg << "at character " << current << " near tooken " << ctoken << endl;
 	parser->setOperation(Parser::OP_Error);
 
-	const bool otherError = (qstrnicmp(str, "other error", 11)==0);
+	const bool otherError = (tqstrnicmp(str, "other error", 11)==0);
 	
 	if (parser->error().type().isEmpty() 
 		&& (str==0 || strlen(str)==0 
-		|| qstrnicmp(str, "syntax error", 12)==0 || qstrnicmp(str, "parse error", 11)==0)
+		|| tqstrnicmp(str, "syntax error", 12)==0 || tqstrnicmp(str, "parse error", 11)==0)
 		|| otherError)
 	{
 		KexiDBDbg << parser->statement() << endl;
@@ -585,7 +585,7 @@ QuerySchema* buildSelectQuery(
 			if (!options->whereExpr->validate(parseInfo)) {
 				setError(parseInfo.errMsg, parseInfo.errDescr);
 				CLEANUP;
-				return false;
+				return 0;
 			}
 			querySchema->setWhereExpression(options->whereExpr);
 		}
