@@ -42,11 +42,11 @@ namespace KexiUtils
 
 	//! \return parent object of \a o that inherits \a className or NULL if no such parent
 	template<class type>
-	inline type* findParent(TQT_BASE_OBJECT_NAME* o, const char* className)
+	inline type* findParent(TQObject* o, const char* className)
 	{
 		if (!o || !className || className[0]=='\0')
 			return 0;
-		while ( ((o=TQT_TQOBJECT(o)->parent())) && !TQT_TQOBJECT(o)->inherits(className) )
+		while ( ((o=o->parent())) && !o->inherits(className) )
 			;
 		return static_cast<type*>(o);
 	}
@@ -67,12 +67,12 @@ namespace KexiUtils
 	 If objName is 0 (the default), all object names match. 
 	 Returned pointer type is casted. */
 	template<class type>
-	type* findFirstChild(TQT_BASE_OBJECT_NAME *o, const char* className, const char* objName = 0)
+	type* findFirstChild(TQObject *o, const char* className, const char* objName = 0)
 	{
 		if (!o || !className || className[0]=='\0')
 			return 0;
-		TQObjectList *l = TQT_TQOBJECT(o)->queryList( className, objName );
-		TQT_BASE_OBJECT_NAME *result = l->first();
+		TQObjectList *l = o->queryList( className, objName );
+		TQObject *result = l->first();
 		delete l;
 		return static_cast<type*>(result);
 	}
@@ -82,8 +82,8 @@ namespace KexiUtils
 	{
 		if (s.isEmpty())
 			return TQDateTime();
-	//		kdDebug() << TQDateTime( TQDate(0,1,2), TQTime::fromString( s, Qt::ISODate ) ).toString(Qt::ISODate) << endl;;
-		return TQDateTime( TQDate(0,1,2), TQTime::fromString( s, Qt::ISODate ) );
+	//		kdDebug() << TQDateTime( TQDate(0,1,2), TQTime::fromString( s, TQt::ISODate ) ).toString(TQt::ISODate) << endl;;
+		return TQDateTime( TQDate(0,1,2), TQTime::fromString( s, TQt::ISODate ) );
 	}
 
 	/*! Sets "wait" cursor with 1 second delay (or 0 seconds if noDelay is true).
@@ -250,7 +250,6 @@ namespace KexiUtils
 	 Copies @p src file to @p dest file.
 	 @return CopySuccess on success, CopyReadError on source file error,
 	 CopyWriteError on destination file error.
-	 @todo remove: TQFile in TQt4 provides this.
 	*/
 	KEXIUTILS_EXPORT CopyFileResult copyFile(const TQString& src, const TQString& dest);
 }
