@@ -27,7 +27,7 @@
 /*! @internal */
 class DelayedCursorHandler : public TQObject
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 	public:
 		DelayedCursorHandler();
