@@ -45,7 +45,7 @@ namespace KexiUtils {
 class KEXIUTILS_EXPORT Validator : public TQValidator
 {
 	public:
-		typedef enum Result { Error = 0, Ok = 1, Warning = 2 };
+		enum Result { Error = 0, Ok = 1, Warning = 2 };
 
 		Validator(TQObject * parent = 0, const char * name = 0);
 		virtual ~Validator();
