@@ -40,7 +40,7 @@ namespace KParts { class Part; }
 
 class KexitStatusBar : public KStatusBar
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 	public:
 		KexitStatusBar( TQWidget *parent=0, const char *name=0 );
