@@ -56,7 +56,7 @@ class KexiSimplePrintingSettings
  The engine allows for random access to any page. */
 class KexiSimplePrintingEngine : public TQObject
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 
 	public:
