@@ -36,7 +36,7 @@ class KexiProject;
 //! @short Internal Kexi Simple Printing Plugin.
 class KexiSimplePrintingPart : public KexiPart::StaticPart
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 
 	public:
