@@ -52,7 +52,7 @@ void KexiSimplePrintPreviewView::paintEvent( TQPaintEvent *pe )
 		return;
 	TQPixmap pm(size()); //dbl buffered
 	TQPainter p;
-	p.begin(TQT_TQPAINTDEVICE(&pm), this);
+	p.begin(&pm, this);
 //! @todo only for screen!
 	p.fillRect(TQRect(TQPoint(0,0),pm.size()), TQBrush(white));//pe->rect(), TQBrush(white));
 	if (m_window->currentPage()>=0)
@@ -169,28 +169,28 @@ KexiSimplePrintPreviewWindow::KexiSimplePrintPreviewWindow(
 	lyr->addWidget(m_toolbar);
 
 	id = m_toolbar->insertWidget( -1, 0, new KPushButton(KStdGuiItem::print(), m_toolbar) );
-	m_toolbar->addConnection(id, TQT_SIGNAL(clicked()), TQT_TQOBJECT(this), TQT_SLOT(slotPrintClicked()));
+	m_toolbar->addConnection(id, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotPrintClicked()));
 	static_cast<KPushButton*>(m_toolbar->getWidget(id))->setAccel(TQt::CTRL|TQt::Key_P);
 	m_toolbar->insertSeparator();
 
 	id = m_toolbar->insertWidget(-1, 0, new KPushButton(i18n("Page Set&up..."), m_toolbar));
-	m_toolbar->addConnection(id, TQT_SIGNAL(clicked()), TQT_TQOBJECT(this), TQT_SLOT(slotPageSetup()));
+	m_toolbar->addConnection(id, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotPageSetup()));
 	m_toolbar->insertSeparator();
 
 
 #ifndef KEXI_NO_UNFINISHED 
 //! @todo unfinished
 	id = m_toolbar->insertWidget( -1, 0, new KPushButton(BarIconSet("zoom-in"), i18n("Zoom In"), m_toolbar));
-	m_toolbar->addConnection(id, TQT_SIGNAL(clicked()), TQT_TQOBJECT(this), TQT_SLOT(slotZoomInClicked()));
+	m_toolbar->addConnection(id, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotZoomInClicked()));
 	m_toolbar->insertSeparator();
 
 	id = m_toolbar->insertWidget( -1, 0, new KPushButton(BarIconSet("zoom-out"), i18n("Zoom Out"), m_toolbar));
-	m_toolbar->addConnection(id, TQT_SIGNAL(clicked()), TQT_TQOBJECT(this), TQT_SLOT(slotZoomOutClicked()));
+	m_toolbar->addConnection(id, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotZoomOutClicked()));
 	m_toolbar->insertSeparator();
 #endif
 
 	id = m_toolbar->insertWidget(-1, 0, new KPushButton(KStdGuiItem::close(), m_toolbar));
-	m_toolbar->addConnection(id, TQT_SIGNAL(clicked()), TQT_TQOBJECT(this), TQT_SLOT(close()));
+	m_toolbar->addConnection(id, TQ_SIGNAL(clicked()), this, TQ_SLOT(close()));
 	m_toolbar->alignItemRight(id);
 
 	m_scrollView = new KexiSimplePrintPreviewScrollView(this);
@@ -214,29 +214,29 @@ KexiSimplePrintPreviewWindow::KexiSimplePrintPreviewWindow(
 	m_navToolbar->setIconText(TDEToolBar::IconTextRight);
 
 	m_idFirst = m_navToolbar->insertWidget( -1, 0, new KPushButton(BarIconSet("go-first"), i18n("First Page"), m_navToolbar));
-	m_navToolbar->addConnection(m_idFirst, TQT_SIGNAL(clicked()), TQT_TQOBJECT(this), TQT_SLOT(slotFirstClicked()));
+	m_navToolbar->addConnection(m_idFirst, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotFirstClicked()));
 	m_navToolbar->insertSeparator();
 
 	m_idPrevious = m_navToolbar->insertWidget( -1, 0, new KPushButton(BarIconSet("go-previous"), i18n("Previous Page"), m_navToolbar));
-	m_navToolbar->addConnection(m_idPrevious, TQT_SIGNAL(clicked()), TQT_TQOBJECT(this), TQT_SLOT(slotPreviousClicked()));
+	m_navToolbar->addConnection(m_idPrevious, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotPreviousClicked()));
 	m_navToolbar->insertSeparator();
 
 	m_idPageNumberLabel = m_navToolbar->insertWidget( -1, 0, new TQLabel(m_navToolbar));
 	m_navToolbar->insertSeparator();
 
 	m_idNext = m_navToolbar->insertWidget( -1, 0, new KPushButton(BarIconSet("go-next"), i18n("Next Page"), m_navToolbar));
-	m_navToolbar->addConnection(m_idNext, TQT_SIGNAL(clicked()), TQT_TQOBJECT(this), TQT_SLOT(slotNextClicked()));
+	m_navToolbar->addConnection(m_idNext, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotNextClicked()));
 	m_navToolbar->insertSeparator();
 
 	m_idLast = m_navToolbar->insertWidget( -1, 0, new KPushButton(BarIconSet("go-last"), i18n("Last Page"), m_navToolbar));
-	m_navToolbar->addConnection(m_idLast, TQT_SIGNAL(clicked()), TQT_TQOBJECT(this), TQT_SLOT(slotLastClicked()));
+	m_navToolbar->addConnection(m_idLast, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotLastClicked()));
 	m_navToolbar->insertSeparator();
 
 	resize(width(), kapp->desktop()->height()*4/5);
 
 //! @todo progress bar...
 
-	TQTimer::singleShot(50, TQT_TQOBJECT(this), TQT_SLOT(initLater()));
+	TQTimer::singleShot(50, this, TQ_SLOT(initLater()));
 }
 
 void KexiSimplePrintPreviewWindow::initLater()
@@ -338,7 +338,7 @@ bool KexiSimplePrintPreviewWindow::event( TQEvent * e )
 {
 	TQEvent::Type t = e->type();
 	if (t==TQEvent::KeyPress) {
-		TQKeyEvent *ke = TQT_TQKEYEVENT(e);
+		TQKeyEvent *ke = static_cast<TQKeyEvent*>(e);
 		const int k = ke->key();
 		bool ok = true;
 		if (k==TQt::Key_Equal || k==TQt::Key_Plus)
@@ -358,7 +358,7 @@ bool KexiSimplePrintPreviewWindow::event( TQEvent * e )
 		}
 	}
 	else if (t==TQEvent::AccelOverride) {
-		TQKeyEvent *ke = TQT_TQKEYEVENT(e);
+		TQKeyEvent *ke = static_cast<TQKeyEvent*>(e);
 		const int k = ke->key();
 		bool ok = true;
 		if (k==TQt::Key_PageUp)
