@@ -119,7 +119,7 @@ KexiConnSelectorWidget::KexiConnSelectorWidget( KexiDBConnectionSet& conn_set,
 //	TQLabel* lbl = new TQLabel(i18n("<b>Select existing Kexi project to open:</b>"), openExistingWidget);
 //	openExistingWidgetLyr->addWidget( lbl );
 	d->prjTypeSelector = new KexiPrjTypeSelector( d->openExistingWidget );
-	connect(d->prjTypeSelector->buttonGroup,TQT_SIGNAL(clicked(int)),this,TQT_SLOT(slotPrjTypeSelected(int)));
+	connect(d->prjTypeSelector->buttonGroup,TQ_SIGNAL(clicked(int)),this,TQ_SLOT(slotPrjTypeSelected(int)));
 	openExistingWidgetLyr->addWidget( d->prjTypeSelector );
 	openExistingWidgetLyr->addSpacing( KDialogBase::spacingHint() );
 	TQFrame* line = new TQFrame( d->openExistingWidget, "line" );
@@ -136,28 +136,28 @@ KexiConnSelectorWidget::KexiConnSelectorWidget( KexiDBConnectionSet& conn_set,
 	m_fileDlg = 0;
 		
 //	addWidget(m_file);
-//	connect(m_file->btn_advanced,TQT_SIGNAL(clicked()),this,TQT_SLOT(showAdvancedConn()));
+//	connect(m_file->btn_advanced,TQ_SIGNAL(clicked()),this,TQ_SLOT(showAdvancedConn()));
 
 	m_remote = new KexiConnSelectorBase(d->stack, "conn_sel");
 	m_remote->icon->setPixmap( DesktopIcon("network") );
 	m_remote->icon->setFixedSize( m_remote->icon->pixmap()->size() );
 //	m_remote->btn_back->setIconSet( SmallIconSet("1uparrow") );
-	connect(m_remote->btn_add, TQT_SIGNAL(clicked()), this, TQT_SLOT(slotRemoteAddBtnClicked()));
-	connect(m_remote->btn_edit, TQT_SIGNAL(clicked()), this, TQT_SLOT(slotRemoteEditBtnClicked()));
-	connect(m_remote->btn_remove, TQT_SIGNAL(clicked()), this, TQT_SLOT(slotRemoteRemoveBtnClicked()));
+	connect(m_remote->btn_add, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotRemoteAddBtnClicked()));
+	connect(m_remote->btn_edit, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotRemoteEditBtnClicked()));
+	connect(m_remote->btn_remove, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotRemoteRemoveBtnClicked()));
 	TQToolTip::add(m_remote->btn_add, i18n("Add a new database connection"));
 	TQToolTip::add(m_remote->btn_edit, i18n("Edit selected database connection"));
 	TQToolTip::add(m_remote->btn_remove, i18n("Remove selected database connections"));
 	d->stack->addWidget(m_remote);
 	if (m_remote->layout())
 		m_remote->layout()->setMargin(0);
-//	connect(m_remote->btn_back,TQT_SIGNAL(clicked()),this,TQT_SLOT(showSimpleConn()));
-	connect(m_remote->list,TQT_SIGNAL(doubleClicked(TQListViewItem*)),
-		this,TQT_SLOT(slotConnectionItemExecuted(TQListViewItem*)));
-	connect(m_remote->list,TQT_SIGNAL(returnPressed(TQListViewItem*)),
-		this,TQT_SLOT(slotConnectionItemExecuted(TQListViewItem*)));
-	connect(m_remote->list,TQT_SIGNAL(selectionChanged()),
-		this,TQT_SLOT(slotConnectionSelectionChanged()));
+//	connect(m_remote->btn_back,TQ_SIGNAL(clicked()),this,TQ_SLOT(showSimpleConn()));
+	connect(m_remote->list,TQ_SIGNAL(doubleClicked(TQListViewItem*)),
+		this,TQ_SLOT(slotConnectionItemExecuted(TQListViewItem*)));
+	connect(m_remote->list,TQ_SIGNAL(returnPressed(TQListViewItem*)),
+		this,TQ_SLOT(slotConnectionItemExecuted(TQListViewItem*)));
+	connect(m_remote->list,TQ_SIGNAL(selectionChanged()),
+		this,TQ_SLOT(slotConnectionSelectionChanged()));
 }
 
 KexiConnSelectorWidget::~KexiConnSelectorWidget()
@@ -167,7 +167,7 @@ KexiConnSelectorWidget::~KexiConnSelectorWidget()
 
 /*void KexiConnSelectorWidget::disconnectShowSimpleConnButton()
 {
-	m_remote->btn_back->disconnect(this,TQT_SLOT(showSimpleConn()));
+	m_remote->btn_back->disconnect(this,TQ_SLOT(showSimpleConn()));
 }*/
 
 void KexiConnSelectorWidget::showAdvancedConn()
@@ -228,9 +228,9 @@ void KexiConnSelectorWidget::showSimpleConn()
 		for (TQWidget *w = parentWidget(true);w;w=w->parentWidget(true)) {
 			if (w->isDialog()) {
 //#ifndef TQ_WS_WIN
-				connect(m_fileDlg,TQT_SIGNAL(rejected()),static_cast<TQDialog*>(w),TQT_SLOT(reject()));
+				connect(m_fileDlg,TQ_SIGNAL(rejected()),static_cast<TQDialog*>(w),TQ_SLOT(reject()));
 //#endif
-//				connect(m_fileDlg,TQT_SIGNAL(cancelled()),static_cast<TQDialog*>(w),TQT_SLOT(reject()));
+//				connect(m_fileDlg,TQ_SIGNAL(cancelled()),static_cast<TQDialog*>(w),TQ_SLOT(reject()));
 				break;
 			}
 		}
