@@ -121,9 +121,9 @@ KexiProjectSelectorWidget::KexiProjectSelectorWidget(
 
 	//show projects
 	setProjectSet( m_prj_set );
-	connect(list,TQT_SIGNAL(doubleClicked(TQListViewItem*)),this,TQT_SLOT(slotItemExecuted(TQListViewItem*)));
-	connect(list,TQT_SIGNAL(returnPressed(TQListViewItem*)),this,TQT_SLOT(slotItemExecuted(TQListViewItem*)));
-	connect(list,TQT_SIGNAL(selectionChanged()),this,TQT_SLOT(slotItemSelected()));
+	connect(list,TQ_SIGNAL(doubleClicked(TQListViewItem*)),this,TQ_SLOT(slotItemExecuted(TQListViewItem*)));
+	connect(list,TQ_SIGNAL(returnPressed(TQListViewItem*)),this,TQ_SLOT(slotItemExecuted(TQListViewItem*)));
+	connect(list,TQ_SIGNAL(selectionChanged()),this,TQ_SLOT(slotItemSelected()));
 }
 
 /*!  
@@ -267,10 +267,10 @@ void KexiProjectSelectorDialog::init(KexiProjectSet* prj_set, bool showProjectNa
 	setIcon(*m_sel->icon());
 	m_sel->setFocus();
 	
-	connect(m_sel,TQT_SIGNAL(projectExecuted(KexiProjectData*)),
-		this,TQT_SLOT(slotProjectExecuted(KexiProjectData*)));
-	connect(m_sel,TQT_SIGNAL(selectionChanged(KexiProjectData*)),
-		this,TQT_SLOT(slotProjectSelectionChanged(KexiProjectData*)));
+	connect(m_sel,TQ_SIGNAL(projectExecuted(KexiProjectData*)),
+		this,TQ_SLOT(slotProjectExecuted(KexiProjectData*)));
+	connect(m_sel,TQ_SIGNAL(selectionChanged(KexiProjectData*)),
+		this,TQ_SLOT(slotProjectSelectionChanged(KexiProjectData*)));
 }
 
 KexiProjectData* KexiProjectSelectorDialog::selectedProjectData() const
