@@ -162,8 +162,8 @@ KexiDBPasswordDialog::KexiDBPasswordDialog(TQWidget *parent, KexiDB::ConnectionD
 
 	setPrompt( msg );
 	if (showDetailsButton) {
-		connect( this, TQT_SIGNAL(user1Clicked()), 
-			this, TQT_SLOT(slotShowConnectionDetails()) );
+		connect( this, TQ_SIGNAL(user1Clicked()), 
+			this, TQ_SLOT(slotShowConnectionDetails()) );
 		setButtonText(KDialogBase::User1, i18n("&Details")+ " >>");
 	}
 	setButtonOK(KGuiItem(i18n("&Open"), "document-open"));
@@ -388,8 +388,8 @@ tristate KexiStartupHandler::init(int /*argc*/, char ** /*argv*/)
 		if (cdata.password.isEmpty()) {
 			delete d->passwordDialog;
 			d->passwordDialog = new KexiDBPasswordDialog(0, cdata, true);
-//			connect( d->passwordDialog, TQT_SIGNAL(user1Clicked()), 
-//				this, TQT_SLOT(slotShowConnectionDetails()) );
+//			connect( d->passwordDialog, TQ_SIGNAL(user1Clicked()), 
+//				this, TQ_SLOT(slotShowConnectionDetails()) );
 			const int ret = d->passwordDialog->exec();
 			if (d->passwordDialog->showConnectionDetailsRequested() || ret == TQDialog::Accepted) {
 //				if ( ret == TQDialog::Accepted ) {
@@ -485,8 +485,8 @@ tristate KexiStartupHandler::init(int /*argc*/, char ** /*argv*/)
 					}
 					d->connDialog = new KexiDBConnectionDialog(
 						*m_projectData, d->shortcutFile->fileName());
-					connect(d->connDialog, TQT_SIGNAL(saveChanges()), 
-						this, TQT_SLOT(slotSaveShortcutFileChanges()));
+					connect(d->connDialog, TQ_SIGNAL(saveChanges()), 
+						this, TQ_SLOT(slotSaveShortcutFileChanges()));
 					int res = d->connDialog->exec();
 					if (res == TQDialog::Accepted) {
 						//get (possibly changed) prj data
@@ -522,8 +522,8 @@ tristate KexiStartupHandler::init(int /*argc*/, char ** /*argv*/)
 							if (!d->connDialog) {
 								d->connDialog = new KexiDBConnectionDialog(
 									cdata, d->connShortcutFile->fileName());
-								connect(d->connDialog, TQT_SIGNAL(saveChanges()), 
-									this, TQT_SLOT(slotSaveShortcutFileChanges()));
+								connect(d->connDialog, TQ_SIGNAL(saveChanges()), 
+									this, TQ_SLOT(slotSaveShortcutFileChanges()));
 							}
 							const int res = d->connDialog->exec();
 							if (res == TQDialog::Accepted) {
@@ -565,8 +565,8 @@ tristate KexiStartupHandler::init(int /*argc*/, char ** /*argv*/)
 	//let's show connection details, user asked for that in the "password dialog"
 	if (d->passwordDialog && d->passwordDialog->showConnectionDetailsRequested()) {
 		d->connDialog = new KexiDBConnectionDialog(*m_projectData);
-//		connect(d->connDialog->tabWidget->mainWidget, TQT_SIGNAL(saveChanges()), 
-//			this, TQT_SLOT(slotSaveShortcutFileChanges()));
+//		connect(d->connDialog->tabWidget->mainWidget, TQ_SIGNAL(saveChanges()), 
+//			this, TQ_SLOT(slotSaveShortcutFileChanges()));
 		int res = d->connDialog->exec();
 
 		if (res == TQDialog::Accepted) {
