@@ -56,7 +56,7 @@ void KexiFormDataProvider::setMainDataSourceWidget(TQWidget* mainWidget)
 		return;
 
 	//find widgets whose will work as data items
-	TQObjectList *l = m_mainWidget->queryList( TQWIDGET_OBJECT_NAME_STRING );
+	TQObjectList *l = m_mainWidget->queryList( "TQWidget" );
 	TQObjectListIt it( *l );
 	TQObject *obj;
 	TQDict<char> tmpSources;
