@@ -48,7 +48,7 @@ class KexiDataSourcePage;
 /*! It just creates a \ref KexiFormView. See there for most of code. */
 class KEXIFORMUTILS_EXPORT KexiFormPart : public KexiPart::Part
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 
 	public:
