@@ -54,7 +54,7 @@ namespace KFormDesigner
 */
 class KEXIFORMUTILS_EXPORT KexiFormView : public KexiDataAwareView
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 
 	public:
