@@ -300,9 +300,9 @@ KexiDBAutoField::setInvalidState( const TQString &text )
 		return;
 	d->widgetType = Auto;
 	createEditor();
-	setFocusPolicy(TQ_NoFocus);
+	setFocusPolicy(TQWidget::NoFocus);
 	if (m_subwidget)
-		m_subwidget->setFocusPolicy(TQ_NoFocus);
+		m_subwidget->setFocusPolicy(TQWidget::NoFocus);
 //! @todo or set this to editor's text?
 	d->label->setText( text );
 }
@@ -667,7 +667,7 @@ KexiDBAutoField::sizeHint() const
 }
 
 void
-KexiDBAutoField::setFocusPolicy( TQ_FocusPolicy policy )
+KexiDBAutoField::setFocusPolicy( TQWidget::FocusPolicy policy )
 {
 	d->focusPolicyChanged = true;
 	TQWidget::setFocusPolicy(policy);
@@ -800,7 +800,7 @@ bool KexiDBAutoField::setProperty( const char * name, const TQVariant & value )
 
 bool KexiDBAutoField::eventFilter( TQObject *o, TQEvent *e )
 {
-	if (TQT_BASE_OBJECT(o)==TQT_BASE_OBJECT(d->label) && d->label->buddy() && e->type()==TQEvent::MouseButtonRelease) {
+	if (o==d->label && d->label->buddy() && e->type()==TQEvent::MouseButtonRelease) {
 		//focus label's buddy when user clicked the label
 		d->label->buddy()->setFocus();
 	}
