@@ -34,7 +34,7 @@
 class KEXIFORMUTILS_EXPORT KexiDBComboBox : 
 	public KexiDBAutoField, public KexiComboBoxBase
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 	TQ_PROPERTY( bool editable READ isEditable WRITE setEditable )
 	//properties from KexiDBAutoField that should not be visible:
