@@ -131,7 +131,7 @@ static void repaintAll(TQWidget *w)
 	TQObjectList *list = w->queryList("TQWidget");
 	TQObjectListIt it(*list);
 	for (TQObject *obj; (obj=it.current()); ++it ) {
-		TQT_TQWIDGET(obj)->repaint();
+		static_cast<TQWidget*>(obj)->repaint();
 	}
 	delete list;
 }
@@ -148,7 +148,7 @@ void
 KexiDBForm::drawRects(const TQValueList<TQRect> &list, int type)
 {
 	TQPainter p;
-	p.begin(TQT_TQPAINTDEVICE(this), true);
+	p.begin(this, true);
 	bool unclipped = testWFlags( WPaintUnclipped );
 	setWFlags( WPaintUnclipped );
 
@@ -192,7 +192,7 @@ void
 KexiDBForm::clearForm()
 {
 	TQPainter p;
-	p.begin(TQT_TQPAINTDEVICE(this), true);
+	p.begin(this, true);
 	bool unclipped = testWFlags( WPaintUnclipped );
 	setWFlags( WPaintUnclipped );
 
@@ -216,7 +216,7 @@ KexiDBForm::highlightWidgets(TQWidget *from, TQWidget *to)//, const TQPoint &poi
 		toPoint = to->parentWidget()->mapTo(this, to->pos());
 
 	TQPainter p;
-	p.begin(TQT_TQPAINTDEVICE(this), true);
+	p.begin(this, true);
 	bool unclipped = testWFlags( WPaintUnclipped );
 	setWFlags( WPaintUnclipped );
 
@@ -320,7 +320,7 @@ void KexiDBForm::updateTabStopsOrder(KFormDesigner::Form* form)
 						kexipluginsdbg << "KexiDBForm::updateTabStopsOrder(): also adding '" 
 							<< childrenIt.current()->className() << " " << childrenIt.current()->name()  
 							<< "' child to filtered widgets" << endl;
-						//it.current()->widget()->installEventFilter(TQT_TQWIDGET(childrenIt.current()));
+						//it.current()->widget()->installEventFilter(childrenIt.current());
 						childrenIt.current()->installEventFilter(this);
 		//			}
 				}
@@ -394,10 +394,10 @@ bool KexiDBForm::eventFilter( TQObject * watched, TQEvent * e )
 		kexipluginsdbg << "RESIZE" << endl;
 	if (e->type()==TQEvent::KeyPress) {
 		if (preview()) {
-			TQKeyEvent *ke = TQT_TQKEYEVENT(e);
+			TQKeyEvent *ke = static_cast<TQKeyEvent*>(e);
 			const int key = ke->key();
-			bool tab = ke->state() == Qt::NoButton && key == TQt::Key_Tab;
-			bool backtab = ((ke->state() == Qt::NoButton || ke->state() == TQt::ShiftButton) && key == TQt::Key_Backtab)
+			bool tab = ke->state() == TQt::NoButton && key == TQt::Key_Tab;
+			bool backtab = ((ke->state() == TQt::NoButton || ke->state() == TQt::ShiftButton) && key == TQt::Key_Backtab)
 				|| (ke->state() == TQt::ShiftButton && key == TQt::Key_Tab);
 			TQObject *o = watched; //focusWidget();
 			TQWidget* realWidget = dynamic_cast<TQWidget*>(o); //will beused below (for tab/backtab handling)
@@ -405,9 +405,9 @@ bool KexiDBForm::eventFilter( TQObject * watched, TQEvent * e )
 			if (!tab && !backtab) {
 				//for buttons, left/up and right/down keys act like tab/backtab (see qbutton.cpp)
 				if (realWidget->inherits("TQButton")) {
-					if (ke->state() == Qt::NoButton && (key == TQt::Key_Right || key == TQt::Key_Down))
+					if (ke->state() == TQt::NoButton && (key == TQt::Key_Right || key == TQt::Key_Down))
 						tab = true;
-					else if (ke->state() == Qt::NoButton && (key == TQt::Key_Left || key == TQt::Key_Up))
+					else if (ke->state() == TQt::NoButton && (key == TQt::Key_Left || key == TQt::Key_Up))
 						backtab = true;
 				}
 			}
@@ -437,7 +437,7 @@ bool KexiDBForm::eventFilter( TQObject * watched, TQEvent * e )
 				int curCol = d->dataAwareObject->currentColumn();
 				bool moveToFirstField; //if true, we'll move focus to the first field (in tab order)
 				bool moveToLastField; //if true, we'll move focus to the first field (in tab order)
-				if (! (ke->state() == Qt::NoButton && (key == TQt::Key_Home 
+				if (! (ke->state() == TQt::NoButton && (key == TQt::Key_Home 
 					     || key == TQt::Key_End || key == TQt::Key_Down || key == TQt::Key_Up)) 
 							    /* ^^ home/end/down/up are already handled by widgets */
 					&& d->dataAwareObject->handleKeyPress(
@@ -474,7 +474,7 @@ bool KexiDBForm::eventFilter( TQObject * watched, TQEvent * e )
 				}
 			}
 			// handle Esc key
-			if (ke->state() == Qt::NoButton && key == TQt::Key_Escape) {
+			if (ke->state() == TQt::NoButton && key == TQt::Key_Escape) {
 				//cancel field editing/row editing if possible
 				if (d->dataAwareObject->cancelEditor())
 					return true;
@@ -495,7 +495,7 @@ bool KexiDBForm::eventFilter( TQObject * watched, TQEvent * e )
 				if (!realWidget)
 					return true; //ignore
 				//the watched widget can be a subwidget of a real widget, e.g. autofield: find it
-				//TQWidget* realWidget = TQT_TQWIDGET(watched);
+				//TQWidget* realWidget = static_cast<TQWidget*>(watched);
 				while (dynamic_cast<KexiDataItemInterface*>(realWidget) && dynamic_cast<KexiDataItemInterface*>(realWidget)->parentInterface())
 					realWidget = dynamic_cast<TQWidget*>( dynamic_cast<KexiDataItemInterface*>(realWidget)->parentInterface() );
 
@@ -548,7 +548,7 @@ bool KexiDBForm::eventFilter( TQObject * watched, TQEvent * e )
 				//behaves differently (e.g. TQLineEdit calls selectAll()) when 
 				//focus event's reason is TQFocusEvent::Tab
 				if (widgetToFocus->focusProxy())
-					widgetToFocus = TQT_TQWIDGET(widgetToFocus->focusProxy());
+					widgetToFocus = widgetToFocus->focusProxy();
 				if (widgetToFocus && d->dataAwareObject->acceptEditor()) {
 					if (tab) {
 						//try to accept this will validate the current input (if any)
@@ -569,7 +569,7 @@ bool KexiDBForm::eventFilter( TQObject * watched, TQEvent * e )
 	}
 	else if (e->type()==TQEvent::FocusIn) {
 		bool focusDataWidget = preview();
-		if (TQT_TQFOCUSEVENT(e)->reason()==TQFocusEvent::Popup) {
+		if (static_cast<TQFocusEvent*>(e)->reason()==TQFocusEvent::Popup) {
 			kdDebug() << "->>> focus IN, popup" <<endl;
 			focusDataWidget = !d->popupFocused;
 			d->popupFocused = false;
@@ -608,7 +608,7 @@ bool KexiDBForm::eventFilter( TQObject * watched, TQEvent * e )
 		}
 	}
 	else if (e->type()==TQEvent::FocusOut) {
-		if (TQT_TQFOCUSEVENT(e)->reason()==TQFocusEvent::Popup) {
+		if (static_cast<TQFocusEvent*>(e)->reason()==TQFocusEvent::Popup) {
 			//d->widgetFocusedBeforePopup = (TQWidget*)watched;
 			d->popupFocused = true;
 		}
@@ -616,7 +616,7 @@ bool KexiDBForm::eventFilter( TQObject * watched, TQEvent * e )
 			d->popupFocused = false;
 //			d->widgetFocusedBeforePopup = 0;
 //		kdDebug() << "e->type()==TQEvent::FocusOut " << watched->className() << " " <<watched->name() << endl;
-//		UNSET_FOCUS_USING_REASON(watched, TQT_TQFOCUSEVENT(e)->reason());
+//		UNSET_FOCUS_USING_REASON(watched, static_cast<TQFocusEvent*>(e)->reason());
 	}
 	return KexiDBFormBase::eventFilter(watched, e);
 }
