@@ -37,7 +37,7 @@ class KEXIFORMUTILS_EXPORT KexiDBImageBox :
 	public KexiFormDataItemInterface, 
 	public KexiSubwidgetInterface
 {
-	Q_OBJECT
+	TQ_OBJECT
 	
 	TQ_PROPERTY( TQString dataSource READ dataSource WRITE setDataSource )
 	TQ_PROPERTY( TQCString dataSourceMimeType READ dataSourceMimeType WRITE setDataSourceMimeType )
@@ -127,14 +127,14 @@ class KEXIFORMUTILS_EXPORT KexiDBImageBox :
 		/*! Overriden to change the policy behaviour a bit:
 		 NoFocus is returned regardless the real focus flag 
 		 if the data source is empty (see dataSource()). */
-		TQ_FocusPolicy focusPolicy() const;
+		TQWidget::FocusPolicy focusPolicy() const;
 
 		//! \return the internal focus policy value, i.e. the one unrelated to data source presence.
-		TQ_FocusPolicy focusPolicyInternal() const;
+		TQWidget::FocusPolicy focusPolicyInternal() const;
 
 		/*! Sets the internal focus policy value. 
 		 "Internal" means that if there is no data source set, real policy becomes NoFocus. */
-		virtual void setFocusPolicy( TQ_FocusPolicy policy );
+		virtual void setFocusPolicy( TQWidget::FocusPolicy policy );
 
 	public slots:
 		void setPixmapId(uint id);
@@ -259,7 +259,7 @@ class KEXIFORMUTILS_EXPORT KexiDBImageBox :
 //			*m_deleteAction, *m_propertiesAction;
 //		TQTimer m_clickTimer;
 		int m_alignment;
-		TQ_FocusPolicy m_focusPolicyInternal; //!< Used for focusPolicyInternal()
+		TQWidget::FocusPolicy m_focusPolicyInternal; //!< Used for focusPolicyInternal()
 		bool m_designMode : 1;
 		bool m_readOnly : 1;
 		bool m_scaledContents : 1;
