@@ -75,7 +75,7 @@ class KexiCSVInfoLabel : public TQWidget
 //! Used by CSV import and export dialogs
 class KexiCSVDelimiterWidget : public TQWidget
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 
 	public:
