@@ -38,7 +38,7 @@ namespace KexiMacro {
 	*/
 	class OpenAction : public KexiAction
 	{
-			Q_OBJECT
+			TQ_OBJECT
   
 
 		public:
