@@ -41,7 +41,7 @@ class KexiTableItem;
  */
 class KexiMacroView : public KexiViewBase
 {
-		Q_OBJECT
+		TQ_OBJECT
   
 	public:
 
