@@ -30,7 +30,7 @@ namespace KoMacroTest {
 	*/
 	class MacroTests : public KUnitTest::SlotTester
 	{
-			Q_OBJECT
+			TQ_OBJECT
   
 		public:
 
