@@ -121,7 +121,7 @@ KexiReportFactory::createMenuActions(const TQCString &classname, TQWidget *w,
 	Q_UNUSED(container);
 	if(classname == "Label") {
 		/*! @todo use TDEAction */
-		menu->insertItem(SmallIconSet("edit"), i18n("Edit Rich Text"), this, TQT_SLOT(editText()));
+		menu->insertItem(SmallIconSet("edit"), i18n("Edit Rich Text"), this, TQ_SLOT(editText()));
 		return true;
 	}
 	return false;
