@@ -62,7 +62,7 @@ void KexiScriptEditor::initialize(Kross::Api::ScriptAction* scriptaction)
     d->scriptaction = scriptaction;
     Q_ASSERT(d->scriptaction);
 
-    disconnect(this, TQT_SIGNAL(textChanged()), this, TQT_SLOT(slotTextChanged()));
+    disconnect(this, TQ_SIGNAL(textChanged()), this, TQ_SLOT(slotTextChanged()));
 
     TQString code = d->scriptaction->getCode();
     if(code.isNull()) {
@@ -85,7 +85,7 @@ void KexiScriptEditor::initialize(Kross::Api::ScriptAction* scriptaction)
 
     clearUndoRedo();
     KexiEditor::setDirty(false);
-    connect(this, TQT_SIGNAL(textChanged()), this, TQT_SLOT(slotTextChanged()));
+    connect(this, TQ_SIGNAL(textChanged()), this, TQ_SLOT(slotTextChanged()));
 }
 
 void KexiScriptEditor::slotTextChanged()
