@@ -35,7 +35,7 @@ namespace Kross { namespace Api {
  */
 class KexiScriptEditor : public KexiEditor
 {
-        Q_OBJECT
+        TQ_OBJECT
   
 
     public:
