@@ -105,10 +105,10 @@ def runGuiApp(copycenter, name):
 			btnbox.setSpacing(6)
 			self.okbtn = tqt.TQPushButton(btnbox)
 			self.okbtn.setText("Ok")
-			#tqt.TQObject.connect(okbtn, tqt.SIGNAL("clicked()"), self.okClicked)
+			#tqt.TQObject.connect(okbtn, tqt.TQ_SIGNAL("clicked()"), self.okClicked)
 			self.cancelbtn = tqt.TQPushButton(btnbox)
 			self.cancelbtn.setText("Cancel")
-			tqt.TQObject.connect(self.cancelbtn, tqt.SIGNAL("clicked()"), self.close)
+			tqt.TQObject.connect(self.cancelbtn, tqt.TQ_SIGNAL("clicked()"), self.close)
 			box.setMinimumSize(tqt.TQSize(460,380))
 		def addItem(self,valuelist,afteritem = None):
 			if afteritem == None:
@@ -136,7 +136,7 @@ def runGuiApp(copycenter, name):
 			self.jobfilecombobox.setEditable(True)
 			self.jobfilecombobox.insertItem("")
 			label.setBuddy(self.jobfilecombobox)
-			tqt.TQObject.connect(self.jobfilecombobox, tqt.SIGNAL("textChanged(const TQString&)"), self.jobfilecomboboxChanged)
+			tqt.TQObject.connect(self.jobfilecombobox, tqt.TQ_SIGNAL("textChanged(const TQString&)"), self.jobfilecomboboxChanged)
 
 			import os
 			import re
@@ -147,10 +147,10 @@ def runGuiApp(copycenter, name):
 
 			loadbtn = tqt.TQPushButton(typebox)
 			loadbtn.setText("Open...")
-			tqt.TQObject.connect(loadbtn, tqt.SIGNAL("clicked()"), self.openClicked)
+			tqt.TQObject.connect(loadbtn, tqt.TQ_SIGNAL("clicked()"), self.openClicked)
 			savebtn = tqt.TQPushButton(typebox)
 			savebtn.setText("Save...")
-			tqt.TQObject.connect(savebtn, tqt.SIGNAL("clicked()"), self.saveClicked)
+			tqt.TQObject.connect(savebtn, tqt.TQ_SIGNAL("clicked()"), self.saveClicked)
 
 			self.listview = tqt.TQListView(self)
 			self.listview.setAllColumnsShowFocus(True)
@@ -159,8 +159,8 @@ def runGuiApp(copycenter, name):
 			self.listview.header().setClickEnabled(False)
 			self.listview.addColumn("Name")
 			self.listview.addColumn("Value")
-			tqt.TQObject.connect(self.listview, tqt.SIGNAL("doubleClicked(TQListViewItem*, const TQPoint&, int)"), self.doubleClicked)
-			#tqt.TQObject.connect(self.listview, tqt.SIGNAL("itemRenamed(TQListViewItem*, int, const TQString&)"), self.itemRenamed)
+			tqt.TQObject.connect(self.listview, tqt.TQ_SIGNAL("doubleClicked(TQListViewItem*, const TQPoint&, int)"), self.doubleClicked)
+			#tqt.TQObject.connect(self.listview, tqt.TQ_SIGNAL("itemRenamed(TQListViewItem*, int, const TQString&)"), self.itemRenamed)
 
 		def doubleClicked(self, **args):
 			print("CopyJobWidget.doubleClicked")
@@ -339,10 +339,10 @@ def runGuiApp(copycenter, name):
 			self.donebtn = tqt.TQPushButton(btnbox)
 			self.donebtn.setText("Done")
 			self.donebtn.setEnabled(False)
-			tqt.TQObject.connect(self.donebtn,tqt.SIGNAL("clicked()"),self.close)
+			tqt.TQObject.connect(self.donebtn,tqt.TQ_SIGNAL("clicked()"),self.close)
 			self.cancelbtn = tqt.TQPushButton(btnbox)
 			self.cancelbtn.setText("Cancel")
-			tqt.TQObject.connect(self.cancelbtn,tqt.SIGNAL("clicked()"),self.close)
+			tqt.TQObject.connect(self.cancelbtn,tqt.TQ_SIGNAL("clicked()"),self.close)
 			box.setMinimumSize( tqt.TQSize(500,380) )
 
 		def updateStates(self):
@@ -375,7 +375,7 @@ def runGuiApp(copycenter, name):
 
 				self.starttime = tqt.TQTime()
 				self.updatetimer = tqt.TQTimer(self)
-				tqt.TQObject.connect(self.updatetimer,tqt.SIGNAL("timeout()"),self.updateStates)
+				tqt.TQObject.connect(self.updatetimer,tqt.TQ_SIGNAL("timeout()"),self.updateStates)
 
 				# Initialize the source
 				sourcename = self.dialog.getSourcePluginName()
@@ -469,7 +469,7 @@ def runGuiApp(copycenter, name):
 			except:
 				import traceback
 				print("".join( traceback.format_exception(sys.exc_info()[0],sys.exc_info()[1],sys.exc_info()[2]) ))
-			tqt.TQObject.connect(self.combobox, tqt.SIGNAL("activated(int)"), self.activated)
+			tqt.TQObject.connect(self.combobox, tqt.TQ_SIGNAL("activated(int)"), self.activated)
 
 		def updatePlugin(self):
 			print("DataSelector.updatePlugin")
@@ -570,10 +570,10 @@ def runGuiApp(copycenter, name):
 			okbtn = tqt.TQPushButton(btnbox)
 			okbtn.setText("Start Copy")
 			okbtn.setDefault(True)
-			tqt.TQObject.connect(okbtn,tqt.SIGNAL("clicked()"),self.startCopy)
+			tqt.TQObject.connect(okbtn,tqt.TQ_SIGNAL("clicked()"),self.startCopy)
 			cancelbtn = tqt.TQPushButton(btnbox)
 			cancelbtn.setText("Cancel")
-			tqt.TQObject.connect(cancelbtn,tqt.SIGNAL("clicked()"),self.close)
+			tqt.TQObject.connect(cancelbtn,tqt.TQ_SIGNAL("clicked()"),self.close)
 
 			self.tab.addTab(self.splitter,"Copy")
 			self.tab.setCurrentPage(1)
@@ -582,7 +582,7 @@ def runGuiApp(copycenter, name):
 			self.helpbrowser.setLinkUnderline(False)
 			self.helpbrowser.setUndoRedoEnabled(False)
 			self.tab.addTab(self.helpbrowser,"Help")
-			tqt.TQObject.connect(self.tab,tqt.SIGNAL("currentChanged(TQWidget*)"),self.currentTabChanged)
+			tqt.TQObject.connect(self.tab,tqt.TQ_SIGNAL("currentChanged(TQWidget*)"),self.currentTabChanged)
 
 			box.setMinimumSize( tqt.TQSize(760,500) )
 
