@@ -49,7 +49,7 @@ class CommandGroup : public KMacroCommand
  We need it to iterate through commands so we can perform a set of ALTER TABLE atomic actions. */
 class CommandHistory : public KCommandHistory
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 	public:
 		CommandHistory(TDEActionCollection *actionCollection, bool withMenus = true);
