@@ -28,10 +28,10 @@
 */
 class KexiFindDialog : public KexiFindDialogBase
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 	public:
-		KexiFindDialog( bool replaceMode, TQWidget* parent = 0, const char* name = 0, bool modal = FALSE );
+		KexiFindDialog( bool replaceMode, TQWidget* parent = 0, const char* name = 0, bool modal = false );
 		virtual ~KexiFindDialog();
 
 #if 0
