@@ -4,7 +4,7 @@
 #include <tqfileinfo.h>
 
 #include <kdebug.h>
-#include <kinstance.h>
+#include <tdeinstance.h>
 
 #include <kexidb/drivermanager.h>
 #include <kexidb/driver.h>
