@@ -50,7 +50,7 @@ class KexiProject;
 //! @short The Main Kexi navigator widget
 class KEXIEXTWIDGETS_EXPORT KexiBrowser : public TQWidget
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 
 	public:
