@@ -27,7 +27,7 @@
 //! Kexi-specific image editor for property editor's item
 class KexiImagePropertyEdit : public KoProperty::PixmapEdit
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 
 	public:
@@ -56,7 +56,7 @@ class KexiImagePropertyEdit : public KoProperty::PixmapEdit
  */
 class KexiIdentifierPropertyEdit : public KoProperty::StringEdit
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 
 	public:
