@@ -31,7 +31,7 @@ class KexiDataSourceWizard;
  */
 class KEXIEXTWIDGETS_EXPORT KexiDSWelcome : public TQWidget
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 
 	public:
