@@ -25,7 +25,7 @@
 //! @short A simple widget with radio buttons with "show file/server-based projects" options
 class KEXIEXTWIDGETS_EXPORT KexiPrjTypeSelector : public KexiPrjTypeSelectorBase
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 
 	public:
