@@ -33,7 +33,7 @@ class KexiRecordNavigator;
  Its contents is resized so the widget can always be resized. */
 class KEXIEXTWIDGETS_EXPORT KexiScrollView : public TQScrollView
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 
 	public:
