@@ -48,7 +48,7 @@ class KexiSectionHeaderPrivate
 		{
 		}
 	
-		Qt::Orientation orientation;
+		TQt::Orientation orientation;
 		TQLabel *lbl;
 		KexiSectionHeader::BoxLayout *lyr;
 		TQHBox *lbl_b;
@@ -56,12 +56,12 @@ class KexiSectionHeaderPrivate
 
 //==========================
 
-KexiSectionHeader::KexiSectionHeader(const TQString &caption, Qt::Orientation o, TQWidget* parent )
+KexiSectionHeader::KexiSectionHeader(const TQString &caption, TQt::Orientation o, TQWidget* parent )
 	: TQWidget(parent, "KexiSectionHeader")
 	, d( new KexiSectionHeaderPrivate() )
 {
 	d->orientation = o;
-	d->lyr = new BoxLayout( this, d->orientation==Qt::Vertical ? TQBoxLayout::TopToBottom : TQBoxLayout::LeftToRight );
+	d->lyr = new BoxLayout( this, d->orientation==TQt::Vertical ? TQBoxLayout::TopToBottom : TQBoxLayout::LeftToRight );
 	d->lyr->setAutoAdd(true);
 	d->lbl_b = new TQHBox(this);
 	d->lbl = new TQLabel(TQString(" ")+caption, d->lbl_b);
@@ -85,7 +85,7 @@ void KexiSectionHeader::addButton(const TQString& icon, const TQString& toolTip,
 	btn->setFocusPolicy(TQWidget::NoFocus);
 	btn->setSizePolicy(TQSizePolicy::Fixed, TQSizePolicy::Preferred);
 	if (receiver && member) {
-		connect(btn, TQT_SIGNAL(clicked()), receiver, member);
+		connect(btn, TQ_SIGNAL(clicked()), receiver, member);
 	}
 
 	if (!icon.isEmpty()) {
@@ -104,7 +104,7 @@ bool KexiSectionHeader::eventFilter( TQObject *o, TQEvent *e )
 	if (o == d->lbl && e->type()==TQEvent::MouseButtonRelease) {//|| e->type()==TQEvent::FocusOut) {// && o->inherits("TQWidget")) {
 		if (d->lyr->view)
 			d->lyr->view->setFocus();
-//		if (KexiUtils::hasParent( this, static_cast<TQWidget*>(o))) {
+//		if (KexiUtils::hasParent( this, o)) {
 //			d->lbl->setPaletteBackgroundColor( e->type()==TQEvent::FocusIn ? red : blue);
 //		}
 	}
@@ -151,7 +151,7 @@ void KexiSectionHeader::BoxLayout::addItem( TQLayoutItem * item )
 		if (item->widget()->inherits("KexiViewBase")) {
 			view = static_cast<KexiViewBase*>(item->widget());
 			KexiSectionHeader *sh = static_cast<KexiSectionHeader*>(mainWidget());
-			connect(view,TQT_SIGNAL(focus(bool)),sh,TQT_SLOT(slotFocus(bool)));
+			connect(view,TQ_SIGNAL(focus(bool)),sh,TQ_SLOT(slotFocus(bool)));
 			sh->d->lbl->setBuddy(item->widget());
 		}
 	}
