@@ -63,8 +63,8 @@ KexiRelationViewTableContainer::KexiRelationViewTableContainer(
 	m_tableHeader->unsetFocus();
 	m_tableHeader->setSizePolicy(TQSizePolicy(TQSizePolicy::Minimum, TQSizePolicy::Fixed));
 	lyr->addWidget(m_tableHeader);
-	connect(m_tableHeader,TQT_SIGNAL(moved()),this,TQT_SLOT(moved()));
-	connect(m_tableHeader, TQT_SIGNAL(endDrag()), this, TQT_SIGNAL(endDrag()));
+	connect(m_tableHeader,TQ_SIGNAL(moved()),this,TQ_SLOT(moved()));
+	connect(m_tableHeader, TQ_SIGNAL(endDrag()), this, TQ_SIGNAL(endDrag()));
 
 	m_tableView = new KexiRelationViewTable(schema, parent, this, "KexiRelationViewTable");
 	//m_tableHeader->setFocusProxy( m_tableView );
@@ -74,9 +74,9 @@ KexiRelationViewTableContainer::KexiRelationViewTableContainer(
 	
 //	m_tableView->resize( m_tableView->sizeHint() );
 	lyr->addWidget(m_tableView, 0);
-	connect(m_tableView, TQT_SIGNAL(tableScrolling()), this, TQT_SLOT(moved()));
-	connect(m_tableView, TQT_SIGNAL(contextMenu(TDEListView*, TQListViewItem*, const TQPoint&)),
-		this, TQT_SLOT(slotContextMenu(TDEListView*, TQListViewItem*, const TQPoint&)));
+	connect(m_tableView, TQ_SIGNAL(tableScrolling()), this, TQ_SLOT(moved()));
+	connect(m_tableView, TQ_SIGNAL(contextMenu(TDEListView*, TQListViewItem*, const TQPoint&)),
+		this, TQ_SLOT(slotContextMenu(TDEListView*, TQListViewItem*, const TQPoint&)));
 }
 
 KexiRelationViewTableContainer::~KexiRelationViewTableContainer()
@@ -208,10 +208,10 @@ bool KexiRelationViewTableContainerHeader::eventFilter(TQObject *, TQEvent *ev)
 {
 	if (ev->type()==TQEvent::MouseMove)
 	{
-		if (m_dragging && TQT_TQMOUSEEVENT(ev)->state()==Qt::LeftButton) {
+		if (m_dragging && static_cast<TQMouseEvent*>(ev)->state()==TQt::LeftButton) {
 			int diffX,diffY;
-			diffX=TQT_TQMOUSEEVENT(ev)->globalPos().x()-m_grabX;
-			diffY=TQT_TQMOUSEEVENT(ev)->globalPos().y()-m_grabY;
+			diffX=static_cast<TQMouseEvent*>(ev)->globalPos().x()-m_grabX;
+			diffY=static_cast<TQMouseEvent*>(ev)->globalPos().y()-m_grabY;
 			if ((abs(diffX)>2) || (abs(diffY)>2))
 			{
 				TQPoint newPos=parentWidget()->pos()+TQPoint(diffX,diffY);
@@ -245,8 +245,8 @@ bool KexiRelationViewTableContainerHeader::eventFilter(TQObject *, TQEvent *ev)
 //move and update helpers
 
 				parentWidget()->move(newPos);
-				m_grabX=TQT_TQMOUSEEVENT(ev)->globalPos().x();
-				m_grabY=TQT_TQMOUSEEVENT(ev)->globalPos().y();
+				m_grabX=static_cast<TQMouseEvent*>(ev)->globalPos().x();
+				m_grabY=static_cast<TQMouseEvent*>(ev)->globalPos().y();
 //				kdDebug()<<"HEADER:emitting moved"<<endl;
 				emit moved();
 			}
@@ -260,7 +260,7 @@ void KexiRelationViewTableContainerHeader::mousePressEvent(TQMouseEvent *ev) {
 	kdDebug()<<"KexiRelationViewTableContainerHeader::Mouse Press Event"<<endl;
 	parentWidget()->setFocus();
 	ev->accept();
-	if (ev->button()==Qt::LeftButton) {
+	if (ev->button()==TQt::LeftButton) {
 		m_dragging=true;
 		m_grabX=ev->globalPos().x();
 		m_grabY=ev->globalPos().y();
@@ -269,7 +269,7 @@ void KexiRelationViewTableContainerHeader::mousePressEvent(TQMouseEvent *ev) {
 		setCursor(TQt::SizeAllCursor);
 		return;
 	}
-	if (ev->button()==Qt::RightButton) {
+	if (ev->button()==TQt::RightButton) {
 		emit static_cast<KexiRelationViewTableContainer*>(parentWidget())
 			->contextMenuRequest(ev->globalPos());
 	}
@@ -278,7 +278,7 @@ void KexiRelationViewTableContainerHeader::mousePressEvent(TQMouseEvent *ev) {
 
 void KexiRelationViewTableContainerHeader::mouseReleaseEvent(TQMouseEvent *ev) {
 	kdDebug()<<"KexiRelationViewTableContainerHeader::Mouse Release Event"<<endl;
-	if (m_dragging && ev->button() & Qt::LeftButton) {
+	if (m_dragging && ev->button() & TQt::LeftButton) {
 		setCursor(TQt::ArrowCursor);
 		m_dragging=false;
 		emit endDrag();
@@ -299,8 +299,8 @@ KexiRelationViewTable::KexiRelationViewTable(KexiDB::TableOrQuerySchema* tableOr
 	setSchema(tableOrQuerySchema);
 	header()->hide();
 
-	connect(this, TQT_SIGNAL(dropped(TQDropEvent *, TQListViewItem *)), this, TQT_SLOT(slotDropped(TQDropEvent *)));
-	connect(this, TQT_SIGNAL(contentsMoving(int, int)), this, TQT_SLOT(slotContentsMoving(int,int)));
+	connect(this, TQ_SIGNAL(dropped(TQDropEvent *, TQListViewItem *)), this, TQ_SLOT(slotDropped(TQDropEvent *)));
+	connect(this, TQ_SIGNAL(contentsMoving(int, int)), this, TQ_SLOT(slotContentsMoving(int,int)));
 }
 
 KexiRelationViewTable::~KexiRelationViewTable()
@@ -413,14 +413,14 @@ void KexiRelationViewTable::contentsMousePressEvent(TQMouseEvent *ev)
 	parentWidget()->setFocus();
 	setFocus();
 	TDEListView::contentsMousePressEvent(ev);
-//	if (ev->button()==Qt::RightButton)
+//	if (ev->button()==TQt::RightButton)
 //		static_cast<KexiRelationView*>(parentWidget())->executePopup(ev->pos());
 }
 
 TQRect KexiRelationViewTable::drawItemHighlighter(TQPainter *painter, TQListViewItem *item)
 {
 	if (painter) {
-		style().tqdrawPrimitive(TQStyle::PE_FocusRect, painter, itemRect(item), colorGroup(),
+		style().drawPrimitive(TQStyle::PE_FocusRect, painter, itemRect(item), colorGroup(),
 			TQStyle::Style_FocusAtBorder);
 	}
 	return itemRect(item);
