@@ -71,9 +71,9 @@ KexiComboBoxTableEdit::KexiComboBoxTableEdit(KexiTableViewColumn &column, TQWidg
 	d->button = new KexiComboBoxDropDownButton( parentWidget() /*usually a viewport*/ );
 	d->button->hide();
 	d->button->setFocusPolicy( TQWidget::NoFocus );
-	connect(d->button, TQT_SIGNAL(clicked()), this, TQT_SLOT(slotButtonClicked()));
+	connect(d->button, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotButtonClicked()));
 
-	connect(m_lineedit, TQT_SIGNAL(textChanged(const TQString&)), this, TQT_SLOT(slotLineEditTextChanged(const TQString&)));
+	connect(m_lineedit, TQ_SIGNAL(textChanged(const TQString&)), this, TQ_SLOT(slotLineEditTextChanged(const TQString&)));
 
 //	m_lineedit = new KLineEdit(this, "lineedit");
 //	m_lineedit->setFrame(false);
@@ -298,7 +298,7 @@ void KexiComboBoxTableEdit::show()
 bool KexiComboBoxTableEdit::handleKeyPress( TQKeyEvent *ke, bool editorActive )
 {
 	const int k = ke->key();
-	if ((ke->state()==Qt::NoButton && k==TQt::Key_F4)
+	if ((ke->state()==TQt::NoButton && k==TQt::Key_F4)
 		|| (ke->state()==AltButton && k==TQt::Key_Down))
 	{
 		//show popup
@@ -348,7 +348,7 @@ int KexiComboBoxTableEdit::widthForValue( TQVariant &val, const TQFontMetrics &f
 bool KexiComboBoxTableEdit::eventFilter( TQObject *o, TQEvent *e )
 {
 	if (!column()->isReadOnly() && e->type()==TQEvent::MouseButtonPress && m_scrollView) {
-		TQPoint gp = TQT_TQMOUSEEVENT(e)->globalPos() 
+		TQPoint gp = static_cast<TQMouseEvent*>(e)->globalPos() 
 			+ TQPoint(m_scrollView->childX(d->button), m_scrollView->childY(d->button));
 		TQRect r(d->button->mapToGlobal(d->button->geometry().topLeft()), 
 			d->button->mapToGlobal(d->button->geometry().bottomRight()));
