@@ -33,7 +33,7 @@
 */
 class KexiDateTimeTableEdit : public KexiInputTableEdit
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 
 	public:
