@@ -32,7 +32,7 @@
 */
 class KEXIDATATABLE_EXPORT KexiInputTableEdit : public KexiTableEdit
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 
 	public:
