@@ -34,7 +34,7 @@
 #include <kexi.h>
 
 #include <kdebug.h>
-#include <klocale.h>
+#include <tdelocale.h>
 
 #include <tqapplication.h>
 
