@@ -31,7 +31,7 @@
 */
 class KexiTimeTableEdit : public KexiInputTableEdit
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 
 	public:
