@@ -28,7 +28,7 @@
 */
 class KEXIGUIUTILS_EXPORT KexiArrowTip : public KexiToolTip
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 	public:
 		KexiArrowTip(const TQString& text, TQWidget* parent);
