@@ -32,7 +32,7 @@ class KivioStencilSpawner;
 
 class KivioIconView : public TQIconView
 {
-  Q_OBJECT
+  TQ_OBJECT
   
   protected:
     KivioStencilSpawnerSet *m_pSpawnerSet;
