@@ -40,14 +40,14 @@
 #include <tqvaluelist.h>
 
 #include <kdebug.h>
-#include <klocale.h>
-#include <kglobal.h>
-#include <kmessagebox.h>
+#include <tdelocale.h>
+#include <tdeglobal.h>
+#include <tdemessagebox.h>
 #include <KoUnit.h>
 #include <KoPoint.h>
 #include <KoRect.h>
 #include <KoZoomHandler.h>
-#include <kapplication.h>
+#include <tdeapplication.h>
 #include <KoXmlWriter.h>
 #include <KoXmlNS.h>
 #include <KoDom.h>
@@ -204,7 +204,7 @@ void KivioPage::saveOasis(KoStore* /*store*/, KoXmlWriter* docWriter, KoGenStyle
 
   TQBuffer layerBuffer;
   layerBuffer.open(IO_WriteOnly);
-  KoXmlWriter layerWriter(TQT_TQIODEVICE(&layerBuffer));
+  KoXmlWriter layerWriter(&layerBuffer);
   layerWriter.startElement("draw:layer-set");
 
   // Iterate through all layers
@@ -1639,7 +1639,7 @@ void KivioPage::saveGuideLines(TQDomElement& element)
     TQDomElement e = element.ownerDocument().createElement("Guideline");
     element.appendChild(e);
     XmlWriteDouble(e, "pos", *it);
-    XmlWriteInt(e, "orient", (int)Qt::Horizontal);
+    XmlWriteInt(e, "orient", (int)TQt::Horizontal);
   }
 
   itEnd = m_vGuideLines.end();
@@ -1648,7 +1648,7 @@ void KivioPage::saveGuideLines(TQDomElement& element)
     TQDomElement e = element.ownerDocument().createElement("Guideline");
     element.appendChild(e);
     XmlWriteDouble(e, "pos", *it);
-    XmlWriteInt(e, "orient", (int)Qt::Vertical);
+    XmlWriteInt(e, "orient", (int)TQt::Vertical);
   }
 }
 
@@ -1662,14 +1662,14 @@ void KivioPage::loadGuideLines(const TQDomElement& element)
   for( ; !e.isNull(); e = e.nextSibling().toElement() )
   {
     double pos = XmlReadDouble(e, "pos", 0.0);
-    Qt::Orientation orient = (Qt::Orientation)XmlReadInt(e, "orient", 0);
+    TQt::Orientation orient = (TQt::Orientation)XmlReadInt(e, "orient", 0);
     addGuideLine(orient, pos);
   }
 }
 
-void KivioPage::addGuideLine(Qt::Orientation orientation, double position)
+void KivioPage::addGuideLine(TQt::Orientation orientation, double position)
 {
-  if(orientation == Qt::Horizontal) {
+  if(orientation == TQt::Horizontal) {
     m_hGuideLines.append(position);
   } else {
     m_vGuideLines.append(position);
