@@ -77,7 +77,7 @@ struct DistributeData
 
 class KIVIO_EXPORT KivioPage : public TQObject
 {
-  Q_OBJECT
+  TQ_OBJECT
   
   public:
     KivioPage( KivioMap *_map, const TQString &pageName,  const char *_name=0L );
@@ -179,7 +179,7 @@ class KIVIO_EXPORT KivioPage : public TQObject
     void setPaintSelected(bool paint = true);
 
     void setGuideLines(const TQValueList<double> hGuideLines, const TQValueList<double> vGuideLines);
-    void addGuideLine(Qt::Orientation orientation, double position);
+    void addGuideLine(TQt::Orientation orientation, double position);
 
   signals:
     void sig_updateView( KivioPage *_page );
