@@ -450,7 +450,7 @@ void KivioView::setupActions()
                                       this, TQ_SLOT( textAlignCenter() ),
                                       actionCollection(), "textAlignCenter" );
   m_textAlignCenter->setExclusiveGroup( "align" );
-  m_textAlignCenter->setChecked( TRUE );
+  m_textAlignCenter->setChecked( true );
   m_textAlignRight = new TDEToggleAction( i18n( "Align &Right" ), "format-text-direction-rtl", CTRL + ALT + Key_R,
                                       this, TQ_SLOT( textAlignRight() ),
                                       actionCollection(), "textAlignRight" );
@@ -847,7 +847,7 @@ int KivioView::canvasYOffset() const
 
 void KivioView::print(KPrinter& ptr)
 {
-  ptr.setFullPage(TRUE);
+  ptr.setFullPage(true);
   m_pDoc->printContent( ptr );
 }
 
