@@ -27,7 +27,7 @@ class AddStencilSetPanel;
 
 class AddStencilSetDialog : public KDialogBase
 {
-  Q_OBJECT
+  TQ_OBJECT
   
   public:
     AddStencilSetDialog(TQWidget *parent = 0, const char *name = 0);
