@@ -7,7 +7,7 @@ class ExportPageDialogBase;
 
 class ExportPageDialog : public KDialogBase
 {
-  Q_OBJECT
+  TQ_OBJECT
   
   public:
     ExportPageDialog(TQWidget* parent=0, const char* name=0);
