@@ -27,7 +27,7 @@ class KivioLayer;
 
 class KivioProtectionPanel : public KivioProtectionPanelBase
 {
-Q_OBJECT
+TQ_OBJECT
   
 
 public:
