@@ -28,7 +28,7 @@ class TQListViewItem;
 namespace Kivio {
   class AddStencilSetPanel : public KivioStencilSetWidget
   {
-    Q_OBJECT
+    TQ_OBJECT
   
     public:
       AddStencilSetPanel(TQWidget *parent = 0, const char *name = 0);
