@@ -32,7 +32,7 @@ class TQColor;
 
 class KivioStencilFormatDlg : public KDialogBase
 {
-  Q_OBJECT
+  TQ_OBJECT
   
   public:
     KivioStencilFormatDlg(KivioView* parent, const char* name = 0);
