@@ -56,12 +56,12 @@ void KivioTextFormatDlg::initFontTab()
 void KivioTextFormatDlg::initPositionTab()
 {
   TQFrame* tab = addPage(i18n("Position"));
-  m_valignBGrp = new TQButtonGroup(1, Qt::Horizontal, i18n("Vertical"), tab);
+  m_valignBGrp = new TQButtonGroup(1, TQt::Horizontal, i18n("Vertical"), tab);
   (void) new TQRadioButton(i18n("&Top"), m_valignBGrp);
   (void) new TQRadioButton(i18n("&Center"), m_valignBGrp);
   (void) new TQRadioButton(i18n("&Bottom"), m_valignBGrp);
   m_valignBGrp->setButton(1);
-  m_halignBGrp = new TQButtonGroup(1, Qt::Vertical, i18n("Horizontal"), tab);
+  m_halignBGrp = new TQButtonGroup(1, TQt::Vertical, i18n("Horizontal"), tab);
   (void) new TQRadioButton(i18n("&Left"), m_halignBGrp);
   (void) new TQRadioButton(i18n("C&enter"), m_halignBGrp);
   (void) new TQRadioButton(i18n("&Right"), m_halignBGrp);
@@ -77,8 +77,8 @@ void KivioTextFormatDlg::initPositionTab()
   gl->addWidget(m_preview, 0, 1);
   gl->addWidget(m_halignBGrp, 1, 1);
 
-  connect(m_valignBGrp, TQT_SIGNAL(clicked(int)), TQT_SLOT(updateVAlign(int)));
-  connect(m_halignBGrp, TQT_SIGNAL(clicked(int)), TQT_SLOT(updateHAlign(int)));
+  connect(m_valignBGrp, TQ_SIGNAL(clicked(int)), TQ_SLOT(updateVAlign(int)));
+  connect(m_halignBGrp, TQ_SIGNAL(clicked(int)), TQ_SLOT(updateHAlign(int)));
 }
 
 void KivioTextFormatDlg::updateVAlign(int i)
@@ -183,7 +183,7 @@ void KivioTextFormatDlg::setTextColor(TQColor c)
 
 void KivioTextFormatDlg::slotDefault()
 {
-  setFont((static_cast<KivioView*>(TQT_TQWIDGET(parent())))->doc()->defaultFont());
+  setFont((static_cast<KivioView*>(parent()))->doc()->defaultFont());
   setTextColor(TQColor(0, 0, 0));
   setHAlign(TQt::AlignHCenter);
   setVAlign(TQt::AlignVCenter);
