@@ -33,7 +33,7 @@ class StencilTextEditorUI;
  */
 class StencilTextEditor : public KDialogBase
 {
-  Q_OBJECT
+  TQ_OBJECT
   
   public:
     StencilTextEditor(const TQString& caption, TQWidget *parent = 0, const char *name = 0);
