@@ -35,7 +35,7 @@ class KoPoint;
 
 class KIVIO_EXPORT TextTool : public Kivio::MouseTool
 {
-  Q_OBJECT
+  TQ_OBJECT
   
   public:
     TextTool( KivioView* parent );
