@@ -21,7 +21,7 @@
 
 #include "kivio_view.h"
 
-#include <kinstance.h>
+#include <tdeinstance.h>
 #include <kiconloader.h>
 
 /***************************************************
