@@ -218,11 +218,11 @@ Navigator::Navigator(bool _selectable, TDEPopupMenu * menu, IconSidePane *_icons
 
   setFocusPolicy( TQWidget::NoFocus );
 
-  connect( this, TQT_SIGNAL( clicked( TQListBoxItem* ) ),
-           TQT_SLOT( slotExecuted( TQListBoxItem* ) ) );
-  connect( this, TQT_SIGNAL( onItem( TQListBoxItem * ) ),
-            TQT_SLOT(  slotMouseOn( TQListBoxItem * ) ) );
-  connect( this, TQT_SIGNAL( onViewport() ), TQT_SLOT(  slotMouseOff() ) );
+  connect( this, TQ_SIGNAL( clicked( TQListBoxItem* ) ),
+           TQ_SLOT( slotExecuted( TQListBoxItem* ) ) );
+  connect( this, TQ_SIGNAL( onItem( TQListBoxItem * ) ),
+            TQ_SLOT(  slotMouseOn( TQListBoxItem * ) ) );
+  connect( this, TQ_SIGNAL( onViewport() ), TQ_SLOT(  slotMouseOff() ) );
 
   TQToolTip::remove( this );
   if ( !mSidePane->showText() )
@@ -247,7 +247,7 @@ bool Navigator::showIcons()
 void Navigator::mouseReleaseEvent(TQMouseEvent *e)
 {
   TDEListBox::mouseReleaseEvent(e);
-  if ( e->button() != Qt::LeftButton || !mLeftMouseButtonPressed )
+  if ( e->button() != TQt::LeftButton || !mLeftMouseButtonPressed )
     return;
   if ( itemAt( e->pos() ) && executedItem == selectedItem() )
     emit itemSelected( currentItem() );
@@ -257,10 +257,10 @@ void Navigator::mouseReleaseEvent(TQMouseEvent *e)
 
 void Navigator::mousePressEvent(TQMouseEvent *e)
 {
-  if ( e->button() != Qt::LeftButton || itemAt( e->pos() ) == 0 )
+  if ( e->button() != TQt::LeftButton || itemAt( e->pos() ) == 0 )
   {
     mLeftMouseButtonPressed = false;
-    if (e->button() == Qt::RightButton)
+    if (e->button() == TQt::RightButton)
       slotShowRMBMenu( 0,mapToGlobal( e->pos() ) );
     return;
   }
@@ -405,7 +405,7 @@ void Navigator::slotShowRMBMenu( TQListBoxItem *, const TQPoint &pos )
 IconSidePane::IconSidePane(TQWidget *parent, const char *name )
   : TQVBox( parent, name )
 {
-  m_buttongroup = new TQButtonGroup(1, Qt::Horizontal, this);
+  m_buttongroup = new TQButtonGroup(1, TQt::Horizontal, this);
   m_buttongroup->setExclusive(true);
   m_buttongroup->hide();
   mWidgetstack = new TQWidgetStack(this);
@@ -485,15 +485,15 @@ void IconSidePane::removeItem( int _grp, int _id )
 int IconSidePane::insertGroup(const TQString &_text, bool _selectable, TQObject *_obj, const char *_slot)
 {
   mCurrentNavigator = new Navigator(_selectable, mPopupMenu, this, mWidgetstack );
-  //connect( mCurrentNavigator, TQT_SIGNAL( itemSelected( int ) ), this, TQT_SLOT( itemSelected( int ) ) );
+  //connect( mCurrentNavigator, TQ_SIGNAL( itemSelected( int ) ), this, TQ_SLOT( itemSelected( int ) ) );
   if ( _obj != 0L && _slot != 0L )
-    connect( mCurrentNavigator, TQT_SIGNAL( itemSelected(int ) ), _obj, _slot );
-  connect( mCurrentNavigator, TQT_SIGNAL( updateAllWidgets() ), this, TQT_SLOT(updateAllWidgets()) );
+    connect( mCurrentNavigator, TQ_SIGNAL( itemSelected(int ) ), _obj, _slot );
+  connect( mCurrentNavigator, TQ_SIGNAL( updateAllWidgets() ), this, TQ_SLOT(updateAllWidgets()) );
   int const id = mWidgetstack->addWidget(mCurrentNavigator);
   mWidgetStackIds.append( id );
   KPushButton *b = new KPushButton( _text, m_buttongroup );
   m_buttongroup->insert( b, id );
-  connect( b, TQT_SIGNAL( clicked() ), this, TQT_SLOT( buttonClicked() ) );
+  connect( b, TQ_SIGNAL( clicked() ), this, TQ_SLOT( buttonClicked() ) );
   b->setToggleButton( true );
   b->setFocusPolicy( TQWidget::NoFocus );
   if (m_buttongroup->count()==1)
