@@ -24,7 +24,7 @@
 
 class KoUnavailPart : public KoDocument
 {
-    Q_OBJECT
+    TQ_OBJECT
   
     TQ_PROPERTY( TQCString mimetype READ nativeFormatMimeType WRITE setMimeType )
     TQ_PROPERTY( TQString unavailReason READ unavailReason WRITE setUnavailReason )
@@ -32,7 +32,7 @@ class KoUnavailPart : public KoDocument
 public:
     KoUnavailPart( TQWidget *parentWidget = 0, const char *widgetName = 0, TQObject* parent = 0, const char* name = 0 );
 
-    virtual void paintContent( TQPainter& painter, const TQRect& rect, bool transparent = FALSE, double zoomX = 1.0, double zoomY = 1.0 );
+    virtual void paintContent( TQPainter& painter, const TQRect& rect, bool transparent = false, double zoomX = 1.0, double zoomY = 1.0 );
 
     virtual bool initDoc(InitDocFlags, TQWidget* = 0) { return true; }
     virtual bool loadOasis( const TQDomDocument& doc, KoOasisStyles& oasisStyles, const TQDomDocument& settings, KoStore* );
@@ -73,7 +73,7 @@ protected:
 
 class KoUnavailView : public KoView
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     KoUnavailView( KoUnavailPart* part, TQWidget* parent = 0, const char* name = 0 );
@@ -90,7 +90,7 @@ class TDEAboutData;
 
 class KoUnavailFactory : public KoFactory
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     KoUnavailFactory( TQObject* parent = 0, const char* name = 0 );
