@@ -33,7 +33,7 @@ AccountsDialog::AccountsDialog(Accounts &acc, TQWidget *p, const char *n)
     setMainWidget(m_panel);
     
     enableButtonOK(false);
-    connect(m_panel, TQT_SIGNAL(changed(bool)), TQT_SLOT(enableButtonOK(bool)));
+    connect(m_panel, TQ_SIGNAL(changed(bool)), TQ_SLOT(enableButtonOK(bool)));
 }
 
 KCommand *AccountsDialog::buildCommand(Part *part) {
