@@ -57,7 +57,7 @@ class ResourceItemPrivate;
 
 class AccountsView : public TQWidget
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
 
