@@ -103,7 +103,7 @@ void DurationWidget::init()
     TQRegExp re(TQString("\\d{1,10}|\\d{1,7}\\") + m_decimalPoint + 
         TQString("\\d{0,10}|\\d{0,7}\\") + m_decimalPoint + 
         TQString("\\d{1,3}"));
-    m_validator = new TQRegExpValidator(re, TQT_TQOBJECT(this));
+    m_validator = new TQRegExpValidator(re, this);
     m_ddd->setValidator(m_validator);
     m_hh->setValidator(m_validator);
     m_mm->setValidator(m_validator);
