@@ -32,7 +32,7 @@ class Part;
 class Task;
 
 class SummaryTaskGeneralPanel : public SummaryTaskGeneralPanelBase {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     SummaryTaskGeneralPanel(Task &task, TQWidget *parent=0, const char *name=0);
