@@ -281,7 +281,7 @@ void KPrBackGround::loadOasis(KoOasisContext & context )
                     strExtension=href.mid(result+1); // As we are using KoPicture, the extension should be without the dot.
                 }
                 TQString filename(href);
-                const KoPictureKey key(filename, TQDateTime::currentDateTime(Qt::UTC));
+                const KoPictureKey key(filename, TQDateTime::currentDateTime(TQt::UTC));
                 backPicture.setKey(key);
 
                 KoStore* store = context.store();
@@ -452,7 +452,7 @@ void KPrBackGround::load( const TQDomElement &element )
                 TQByteArray rawData=_data.utf8(); // XPM is normally ASCII, therefore UTF-8
                 rawData[rawData.size()-1]=char(10); // Replace the NULL character by a LINE FEED
                 TQBuffer buffer(rawData);
-                backPicture.loadXpm(TQT_TQIODEVICE(&buffer));
+                backPicture.loadXpm(&buffer);
             }
 
 #if 0
@@ -524,7 +524,7 @@ void KPrBackGround::drawBackPix( TQPainter *_painter, const TQSize& ext, const T
         double w = _origSize.width();
         w *= ext.width();
 #if KDE_IS_VERSION(3,1,90)
-        TQRect desk = TDEGlobalSettings::desktopGeometry(TQT_TQWIDGET(kapp->activeWindow()));
+        TQRect desk = TDEGlobalSettings::desktopGeometry(kapp->activeWindow());
 #else
         TQRect desk = TQApplication::desktop()->screenGeometry();
 #endif
