@@ -52,8 +52,8 @@ KPrBrushProperty::KPrBrushProperty( TQWidget *parent, const char *name, const KP
 
     m_stack = new TQWidgetStack( this );
     layout->addMultiCellWidget( m_stack, 1, 1, 0, 1 );
-    connect( m_typeCombo, TQT_SIGNAL( activated( int ) ),
-             this, TQT_SLOT( slotTypeChanged( int ) ) );
+    connect( m_typeCombo, TQ_SIGNAL( activated( int ) ),
+             this, TQ_SLOT( slotTypeChanged( int ) ) );
 
     m_brushUI = new BrushPropertyUI( m_stack );
 
@@ -77,10 +77,10 @@ KPrBrushProperty::KPrBrushProperty( TQWidget *parent, const char *name, const KP
     TQWhatsThis::add(m_preview_color, i18n( "This displays a preview of your choices." ) );
     hbox->addWidget(m_preview_color);
 
-    connect( m_brushUI->styleCombo, TQT_SIGNAL( activated( int ) ),
-             this, TQT_SLOT( slotBrushChanged() ) );
-    connect( m_brushUI->colorChooser, TQT_SIGNAL( changed( const TQColor& ) ),
-             this, TQT_SLOT( slotBrushChanged() ) );
+    connect( m_brushUI->styleCombo, TQ_SIGNAL( activated( int ) ),
+             this, TQ_SLOT( slotBrushChanged() ) );
+    connect( m_brushUI->colorChooser, TQ_SIGNAL( changed( const TQColor& ) ),
+             this, TQ_SLOT( slotBrushChanged() ) );
 
     m_stack->addWidget( m_brushUI, 0 );
 
@@ -98,18 +98,18 @@ KPrBrushProperty::KPrBrushProperty( TQWidget *parent, const char *name, const KP
     hbox = new TQHBoxLayout( m_gradientUI->previewPanel );
     hbox->addWidget(m_preview_gradient);
 
-    connect( m_gradientUI->styleCombo, TQT_SIGNAL( activated( int ) ),
-             this, TQT_SLOT( slotBackColorTypeChanged() ) );
-    connect( m_gradientUI->color1Chooser, TQT_SIGNAL( changed( const TQColor& ) ),
-             this, TQT_SLOT( slotColor1Changed() ) );
-    connect( m_gradientUI->color2Chooser, TQT_SIGNAL( changed( const TQColor& ) ),
-             this, TQT_SLOT( slotColor2Changed() ) );
-    connect( m_gradientUI->unbalancedCheckBox, TQT_SIGNAL( clicked() ),
-             this, TQT_SLOT( slotUnbalancedChanged() ) );
-    connect( m_gradientUI->xSlider, TQT_SIGNAL( valueChanged( int ) ),
-             this, TQT_SLOT( slotXFactorChanged() ) );
-    connect( m_gradientUI->ySlider, TQT_SIGNAL( valueChanged( int ) ),
-             this, TQT_SLOT( slotYFactorChanged() ) );
+    connect( m_gradientUI->styleCombo, TQ_SIGNAL( activated( int ) ),
+             this, TQ_SLOT( slotBackColorTypeChanged() ) );
+    connect( m_gradientUI->color1Chooser, TQ_SIGNAL( changed( const TQColor& ) ),
+             this, TQ_SLOT( slotColor1Changed() ) );
+    connect( m_gradientUI->color2Chooser, TQ_SIGNAL( changed( const TQColor& ) ),
+             this, TQ_SLOT( slotColor2Changed() ) );
+    connect( m_gradientUI->unbalancedCheckBox, TQ_SIGNAL( clicked() ),
+             this, TQ_SLOT( slotUnbalancedChanged() ) );
+    connect( m_gradientUI->xSlider, TQ_SIGNAL( valueChanged( int ) ),
+             this, TQ_SLOT( slotXFactorChanged() ) );
+    connect( m_gradientUI->ySlider, TQ_SIGNAL( valueChanged( int ) ),
+             this, TQ_SLOT( slotYFactorChanged() ) );
 
     m_stack->addWidget( m_gradientUI, 1 );
     m_stack->addWidget( new TQFrame(), 2 ); // the transparent case
@@ -139,50 +139,50 @@ TQBrush KPrBrushProperty::getTQBrush() const
     switch ( m_brushUI->styleCombo->currentItem() )
     {
         case 0:
-            brush.setStyle( Qt::SolidPattern );
+            brush.setStyle( TQt::SolidPattern );
             break;
         case 1:
-            brush.setStyle( Qt::Dense1Pattern );
+            brush.setStyle( TQt::Dense1Pattern );
             break;
         case 2:
-            brush.setStyle( Qt::Dense2Pattern );
+            brush.setStyle( TQt::Dense2Pattern );
             break;
         case 3:
-            brush.setStyle( Qt::Dense3Pattern );
+            brush.setStyle( TQt::Dense3Pattern );
             break;
         case 4:
-            brush.setStyle( Qt::Dense4Pattern );
+            brush.setStyle( TQt::Dense4Pattern );
             break;
         case 5:
-            brush.setStyle( Qt::Dense5Pattern );
+            brush.setStyle( TQt::Dense5Pattern );
             break;
         case 6:
-            brush.setStyle( Qt::Dense6Pattern );
+            brush.setStyle( TQt::Dense6Pattern );
             break;
         case 7:
-            brush.setStyle( Qt::Dense7Pattern );
+            brush.setStyle( TQt::Dense7Pattern );
             break;
         case 8:
-            brush.setStyle( Qt::HorPattern );
+            brush.setStyle( TQt::HorPattern );
             break;
         case 9:
-            brush.setStyle( Qt::VerPattern );
+            brush.setStyle( TQt::VerPattern );
             break;
         case 10:
-            brush.setStyle( Qt::CrossPattern );
+            brush.setStyle( TQt::CrossPattern );
             break;
         case 11:
-            brush.setStyle( Qt::BDiagPattern );
+            brush.setStyle( TQt::BDiagPattern );
             break;
         case 12:
-            brush.setStyle( Qt::FDiagPattern );
+            brush.setStyle( TQt::FDiagPattern );
             break;
         case 13:
-            brush.setStyle( Qt::DiagCrossPattern );
+            brush.setStyle( TQt::DiagCrossPattern );
             break;
     }
     if( m_typeCombo->currentItem() == 2)
-        brush.setStyle( Qt::NoBrush );
+        brush.setStyle( TQt::NoBrush );
 
     brush.setColor( m_brushUI->colorChooser->color() );
 
