@@ -35,7 +35,7 @@ class KComboBox;
 
 class KPrBrushProperty : public TQWidget
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     KPrBrushProperty( TQWidget *parent, const char *name, const KPrBrushCmd::Brush &brush );
