@@ -122,7 +122,7 @@ KPrConfig::KPrConfig( KPrView* parent )
         m_ttsPage=new KPrConfigureTTSPage(parent, page);
     } else m_ttsPage = 0;
 
-    connect( this, TQT_SIGNAL( okClicked() ),this, TQT_SLOT( slotApply() ) );
+    connect( this, TQ_SIGNAL( okClicked() ),this, TQ_SLOT( slotApply() ) );
 }
 
 void KPrConfig::openPage(int flags)
@@ -418,7 +418,7 @@ KPrConfigureMiscPage::KPrConfigureMiscPage( KPrView *_view, TQWidget *parent, ch
     m_pView=_view;
     config = KPrFactory::global()->config();
 
-    TQGroupBox* tmpTQGroupBox = new TQGroupBox( 0, Qt::Vertical, i18n("Misc"), this, "GroupBox" );
+    TQGroupBox* tmpTQGroupBox = new TQGroupBox( 0, TQt::Vertical, i18n("Misc"), this, "GroupBox" );
     tmpTQGroupBox->layout()->setSpacing(KDialog::spacingHint());
     tmpTQGroupBox->layout()->setMargin(KDialog::marginHint());
     TQGridLayout *grid = new TQGridLayout( tmpTQGroupBox->layout(), 8, 1 );
@@ -468,7 +468,7 @@ KPrConfigureMiscPage::KPrConfigureMiscPage( KPrView *_view, TQWidget *parent, ch
 
     box->addWidget(tmpTQGroupBox);
 
-    tmpTQGroupBox = new TQGroupBox( 0, Qt::Vertical, i18n("Grid"), this, "GroupBox" );
+    tmpTQGroupBox = new TQGroupBox( 0, TQt::Vertical, i18n("Grid"), this, "GroupBox" );
     tmpTQGroupBox->layout()->setSpacing(KDialog::spacingHint());
     tmpTQGroupBox->layout()->setMargin(KDialog::marginHint());
     grid = new TQGridLayout( tmpTQGroupBox->layout(), 8, 1 );
@@ -630,7 +630,7 @@ KPrConfigureDefaultDocPage::KPrConfigureDefaultDocPage(KPrView *_view, TQWidget
 
     TQPushButton *chooseButton = new TQPushButton(i18n("Choose..."), fontContainer);
     TQWhatsThis::add(chooseButton, i18n( "Click here if you want to set a new font. The TDE default Select Font dialog will then be displayed." ) );
-    connect(chooseButton, TQT_SIGNAL(clicked()), this, TQT_SLOT(selectNewDefaultFont()));
+    connect(chooseButton, TQ_SIGNAL(clicked()), this, TQ_SLOT(selectNewDefaultFont()));
 
     fontLayout->addWidget(fontTitle, 0, 0);
     fontLayout->addWidget(fontName, 0, 1);
@@ -904,7 +904,7 @@ void KPrConfigureToolsPage::apply()
 
 void KPrConfigureToolsPage::slotDefault()
 {
-    KoPenCmd::Pen pen( KoPen(black, 1.0, Qt::SolidLine), L_NORMAL, L_NORMAL );
+    KoPenCmd::Pen pen( KoPen(black, 1.0, TQt::SolidLine), L_NORMAL, L_NORMAL );
     m_confPenDia->setPen( pen );
     m_pView->getActionPenColor()->setCurrentColor( pen.pen.color() );
 
@@ -949,11 +949,11 @@ KPrConfigurePathPage::KPrConfigurePathPage( KPrView *_view, TQWidget *parent, ch
     box->addWidget(m_pPathView);
 
     m_modifyPath = new TQPushButton( i18n("Modify Path..."), this);
-    connect( m_modifyPath, TQT_SIGNAL( clicked ()), this, TQT_SLOT( slotModifyPath()));
-    connect( m_pPathView, TQT_SIGNAL( doubleClicked (TQListViewItem *, const TQPoint &, int )),
-             this, TQT_SLOT( slotModifyPath()));
-    connect( m_pPathView, TQT_SIGNAL( selectionChanged ( TQListViewItem * )),
-             this, TQT_SLOT( slotSelectionChanged(TQListViewItem * )));
+    connect( m_modifyPath, TQ_SIGNAL( clicked ()), this, TQ_SLOT( slotModifyPath()));
+    connect( m_pPathView, TQ_SIGNAL( doubleClicked (TQListViewItem *, const TQPoint &, int )),
+             this, TQ_SLOT( slotModifyPath()));
+    connect( m_pPathView, TQ_SIGNAL( selectionChanged ( TQListViewItem * )),
+             this, TQ_SLOT( slotSelectionChanged(TQListViewItem * )));
     slotSelectionChanged(m_pPathView->currentItem());
     TQWhatsThis::add(m_modifyPath, i18n( "When you click this button, a small dialog will appear and, if Default path is unchecked, you can either enter a path yourself or choose one using the standard TDE file dialog." ) );
     box->addWidget(m_modifyPath);
@@ -1086,9 +1086,9 @@ KPrConfigureTTSPage::KPrConfigureTTSPage( KPrView *_view, TQWidget *parent, char
     m_iniPollingInterval->setValue(config->readNumEntry("PollingInterval", 600));
 
     screenReaderOptionChanged();
-    connect(m_cbSpeakPointerWidget, TQT_SIGNAL(toggled(bool)), this, TQT_SLOT(screenReaderOptionChanged()));
-    connect(m_cbSpeakFocusWidget, TQT_SIGNAL(toggled(bool)), this, TQT_SLOT(screenReaderOptionChanged()));
-    connect(m_cbSpeakAccelerators, TQT_SIGNAL(toggled(bool)), this, TQT_SLOT(screenReaderOptionChanged()));
+    connect(m_cbSpeakPointerWidget, TQ_SIGNAL(toggled(bool)), this, TQ_SLOT(screenReaderOptionChanged()));
+    connect(m_cbSpeakFocusWidget, TQ_SIGNAL(toggled(bool)), this, TQ_SLOT(screenReaderOptionChanged()));
+    connect(m_cbSpeakAccelerators, TQ_SIGNAL(toggled(bool)), this, TQ_SLOT(screenReaderOptionChanged()));
 }
 
 void KPrConfigureTTSPage::slotDefault()
