@@ -1,4 +1,3 @@
-// -*- Mode: c++; c-basic-offset: 4; indent-tabs-mode: nil; tab-width: 4; -*-
 /* This file is part of the KDE project
    Copyright (C) 1998, 1999 Reginald Stadlbauer <reggie@kde.org>
 
@@ -23,7 +22,7 @@
 #include "KPrAboutData.h"
 
 #include <kstandarddirs.h>
-#include <kinstance.h>
+#include <tdeinstance.h>
 
 
 TDEInstance* KPrFactory::s_global = 0;
