@@ -1,4 +1,3 @@
-// -*- Mode: c++; c-basic-offset: 4; indent-tabs-mode: nil; tab-width: 4; -*-
 /* This file is part of the KDE project
    Copyright (C) 2001, Laurent Montel <lmontel@mandrakesoft.com>
 
@@ -41,7 +40,7 @@ class KCommand;
  */
 class KPrFindReplace : public KoFindReplace
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     /**
