@@ -61,14 +61,14 @@ KPrMarginWidget::KPrMarginWidget( TQWidget *parent, const char *name, const KoUn
     m_ui->bottomInput->setUnit( unit );
     m_ui->bottomInput->setMinMaxStep( 0, dMax, dStep );
 
-    connect( m_ui->leftInput, TQT_SIGNAL( valueChanged( double ) ),
-             this, TQT_SLOT( slotValueChanged( double ) ) );
-    connect( m_ui->rightInput, TQT_SIGNAL( valueChanged( double ) ),
-             this, TQT_SLOT( slotValueChanged( double ) ) );
-    connect( m_ui->topInput, TQT_SIGNAL( valueChanged( double ) ),
-             this, TQT_SLOT( slotValueChanged( double ) ) );
-    connect( m_ui->bottomInput, TQT_SIGNAL( valueChanged( double ) ),
-             this, TQT_SLOT( slotValueChanged( double ) ) );
+    connect( m_ui->leftInput, TQ_SIGNAL( valueChanged( double ) ),
+             this, TQ_SLOT( slotValueChanged( double ) ) );
+    connect( m_ui->rightInput, TQ_SIGNAL( valueChanged( double ) ),
+             this, TQ_SLOT( slotValueChanged( double ) ) );
+    connect( m_ui->topInput, TQ_SIGNAL( valueChanged( double ) ),
+             this, TQ_SLOT( slotValueChanged( double ) ) );
+    connect( m_ui->bottomInput, TQ_SIGNAL( valueChanged( double ) ),
+             this, TQ_SLOT( slotValueChanged( double ) ) );
 }
 
 
