@@ -72,7 +72,7 @@ KPrInsertHelpLineDia::KPrInsertHelpLineDia( TQWidget *parent, const KoRect & _pa
     setCaption( i18n("Add New Help Line") );
     TQVBox *page = makeVBoxMainWidget();
     TQButtonGroup *group = new TQButtonGroup( 1, TQt::Horizontal,i18n("Orientation"), page );
-    group->setRadioButtonExclusive( TRUE );
+    group->setRadioButtonExclusive( true );
     group->layout();
     m_rbHoriz = new TQRadioButton( i18n("Horizontal"), group );
     m_rbVert = new TQRadioButton( i18n("Vertical"), group );
