@@ -30,7 +30,7 @@ KPrPBPreview::KPrPBPreview( TQWidget* parent, const char* name, PaintType _paint
     //FIXME zoom
     _zoomHandler=new KoTextZoomHandler();
     paintType = _paintType;
-    pen = KoPen( black, 1, Qt::SolidLine );
+    pen = KoPen( black, 1, TQt::SolidLine );
     brush = TQBrush( white, SolidPattern );
     gradient = new KPrGradient( TQt::red, TQt::green, BCT_GHORZ, false, 100, 100 );
     savedGradient = gradient;
