@@ -1,4 +1,3 @@
-// -*- Mode: c++; c-basic-offset: 4; indent-tabs-mode: nil; tab-width: 4; -*-
 /* This file is part of the KDE project
    Copyright (C) 2002-2004 Laurent MONTEL <montel@kde.org>
    Copyright (C) 2004-2006 Thorsten Zachmann <zachmann@kde.org>
@@ -131,7 +130,7 @@ void KPrPage::saveOasisObject( KoStore *store, KoXmlWriter &xmlWriter, KoSavingC
     KTempFile animationTmpFile;
     animationTmpFile.setAutoDelete( true );
     TQFile* tmpFile = animationTmpFile.file();
-    KoXmlWriter animationTmpWriter( TQT_TQIODEVICE(tmpFile) );
+    KoXmlWriter animationTmpWriter( tmpFile );
     lstMap listObjectAnimation;
     TQPtrListIterator<KPrObject> it( m_objectList );
     for ( ; it.current() ; ++it )
@@ -229,7 +228,7 @@ void KPrPage::saveOasisObject( KoStore *store, KoXmlWriter &xmlWriter, KoSavingC
         }
         animationTmpWriter.endElement();//close "presentation:animations"
         tmpFile->close();
-        xmlWriter.addCompleteElement( TQT_TQIODEVICE(tmpFile) );
+        xmlWriter.addCompleteElement( tmpFile );
 
     }
     else
@@ -627,7 +626,7 @@ TQString KPrPage::saveOasisPageStyle( KoStore *, KoGenStyles& mainStyles ) const
         {
             TQBuffer buffer;
             buffer.open( IO_WriteOnly );
-            KoXmlWriter elementWriter( TQT_TQIODEVICE(&buffer) );  // TODO pass indentation level
+            KoXmlWriter elementWriter( &buffer );  // TODO pass indentation level
             elementWriter.startElement( "presentation:sound" );
             elementWriter.addAttribute( "xlink:href", m_soundFileName );
             elementWriter.addAttribute( "xlink:type", "simple" );
@@ -1007,7 +1006,7 @@ void KPrPage::pasteObjs( const TQByteArray & data,int nbCopy, double angle,
     if ( !data.size() )
         return;
     TQBuffer buffer( data );
-    KoStore* store = KoStore::createStore( TQT_TQIODEVICE(&buffer), KoStore::Read );
+    KoStore* store = KoStore::createStore( &buffer, KoStore::Read );
     int nbNewObject = -1 ;
     KMacroCommand *macro = 0L;
     if ( !store->bad() )
