@@ -55,8 +55,8 @@ KPrPgConfDia::KPrPgConfDia( TQWidget* parent, KPrDocument* doc )
     setupPageGeneral();
     setupPageSlides();
 
-    connect( this, TQT_SIGNAL( okClicked() ), this, TQT_SLOT( confDiaOk() ) );
-    connect( this, TQT_SIGNAL( okClicked() ), this, TQT_SLOT( accept() ) );
+    connect( this, TQ_SIGNAL( okClicked() ), this, TQ_SLOT( confDiaOk() ) );
+    connect( this, TQ_SIGNAL( okClicked() ), this, TQ_SLOT( accept() ) );
 }
 
 void KPrPgConfDia::setupPageGeneral()
@@ -98,8 +98,8 @@ void KPrPgConfDia::setupPageGeneral()
 					"useful if you are running a promotional display.</p>") );
 
     infiniteLoop->setEnabled( !m_doc->spManualSwitch() );
-    connect( m_autoButton, TQT_SIGNAL( toggled(bool) ), infiniteLoop, TQT_SLOT( setEnabled(bool) ) );
-    connect( m_autoButton, TQT_SIGNAL( toggled(bool) ), infiniteLoop, TQT_SLOT( setChecked(bool) ) );
+    connect( m_autoButton, TQ_SIGNAL( toggled(bool) ), infiniteLoop, TQ_SLOT( setEnabled(bool) ) );
+    connect( m_autoButton, TQ_SIGNAL( toggled(bool) ), infiniteLoop, TQ_SLOT( setChecked(bool) ) );
 
     endOfPresentationSlide = new TQCheckBox( i18n( "&Show 'End of presentation' slide" ), generalPage );
     generalLayout->addWidget( endOfPresentationSlide );
@@ -109,7 +109,7 @@ void KPrPgConfDia::setupPageGeneral()
 					"be shown.") );
     endOfPresentationSlide->setChecked( m_doc->spShowEndOfPresentationSlide() );
     endOfPresentationSlide->setDisabled( infiniteLoop->isEnabled() && getInfiniteLoop() );
-    connect( infiniteLoop, TQT_SIGNAL( toggled(bool) ), endOfPresentationSlide, TQT_SLOT( setDisabled(bool) ) );
+    connect( infiniteLoop, TQ_SIGNAL( toggled(bool) ), endOfPresentationSlide, TQ_SLOT( setDisabled(bool) ) );
 
     presentationDuration = new TQCheckBox( i18n( "Measure presentation &duration" ), generalPage );
     generalLayout->addWidget( presentationDuration );
@@ -126,7 +126,7 @@ void KPrPgConfDia::setupPageGeneral()
 
     // presentation pen (color and width)
 
-    TQGroupBox* penGroup = new TQGroupBox( 2, Qt::Horizontal, i18n("Presentation Pen") , generalPage );
+    TQGroupBox* penGroup = new TQGroupBox( 2, TQt::Horizontal, i18n("Presentation Pen") , generalPage );
     generalLayout->addWidget( penGroup );
     TQWhatsThis::add( penGroup, i18n("<p>This part of the dialog allows you to configure the "
 				    "<em>drawing mode</em>, which allows you to add additional "
@@ -169,7 +169,7 @@ void KPrPgConfDia::setupPageSlides()
 
     m_customSlide = new TQRadioButton( i18n( "Custom slide show" ), group, "customslide" );
 
-    connect( m_customSlide, TQT_SIGNAL( clicked () ), this, TQT_SLOT( radioButtonClicked() ) );
+    connect( m_customSlide, TQ_SIGNAL( clicked () ), this, TQ_SLOT( radioButtonClicked() ) );
 
     TQHBox *box = new TQHBox( group );
 
@@ -180,7 +180,7 @@ void KPrPgConfDia::setupPageSlides()
 
     m_selectedSlide = new TQRadioButton( i18n( "Selected pages:" ), group, "selectedslide" );
     slidesLayout->addMultiCellWidget( group, 0,2,0,1 );
-    connect( m_selectedSlide, TQT_SIGNAL( clicked () ), this, TQT_SLOT( radioButtonClicked() ) );
+    connect( m_selectedSlide, TQ_SIGNAL( clicked () ), this, TQ_SLOT( radioButtonClicked() ) );
 
     slides = new TQListView( slidesPage );
     slidesLayout->addMultiCellWidget( slides, 3, 3, 0, 1 );
@@ -202,10 +202,10 @@ void KPrPgConfDia::setupPageSlides()
     buttonGroup->setSpacing( KDialog::spacingHint() );
 
     TQPushButton* selectAllButton = new TQPushButton( i18n( "Select &All" ), buttonGroup );
-    connect( selectAllButton, TQT_SIGNAL( clicked() ), this, TQT_SLOT( selectAllSlides() ) );
+    connect( selectAllButton, TQ_SIGNAL( clicked() ), this, TQ_SLOT( selectAllSlides() ) );
 
     TQPushButton* deselectAllButton = new TQPushButton( i18n( "&Deselect All" ), buttonGroup );
-    connect( deselectAllButton, TQT_SIGNAL( clicked() ), this, TQT_SLOT( deselectAllSlides() ) );
+    connect( deselectAllButton, TQ_SIGNAL( clicked() ), this, TQ_SLOT( deselectAllSlides() ) );
 
     TQWidget* spacer = new TQWidget( buttonGroup );
 
