@@ -35,17 +35,17 @@ KPrPictureProperty::KPrPictureProperty( TQWidget *parent, const char *name, cons
     TQVBoxLayout *layout = new TQVBoxLayout( this );
     layout->addWidget( m_ui = new PicturePropertyUI( this ) );
 
-    connect( m_ui->depth0, TQT_SIGNAL( clicked() ), m_ui->picturePreview, TQT_SLOT( slotPictureDepth0() ) );
-    connect( m_ui->depth1, TQT_SIGNAL( clicked() ), m_ui->picturePreview, TQT_SLOT( slotPictureDepth1() ) );
-    connect( m_ui->depth8, TQT_SIGNAL( clicked() ), m_ui->picturePreview, TQT_SLOT( slotPictureDepth8() ) );
-    connect( m_ui->depth16, TQT_SIGNAL( clicked() ), m_ui->picturePreview, TQT_SLOT( slotPictureDepth16() ) );
-    connect( m_ui->depth32, TQT_SIGNAL( clicked() ), m_ui->picturePreview, TQT_SLOT( slotPictureDepth32() ) );
+    connect( m_ui->depth0, TQ_SIGNAL( clicked() ), m_ui->picturePreview, TQ_SLOT( slotPictureDepth0() ) );
+    connect( m_ui->depth1, TQ_SIGNAL( clicked() ), m_ui->picturePreview, TQ_SLOT( slotPictureDepth1() ) );
+    connect( m_ui->depth8, TQ_SIGNAL( clicked() ), m_ui->picturePreview, TQ_SLOT( slotPictureDepth8() ) );
+    connect( m_ui->depth16, TQ_SIGNAL( clicked() ), m_ui->picturePreview, TQ_SLOT( slotPictureDepth16() ) );
+    connect( m_ui->depth32, TQ_SIGNAL( clicked() ), m_ui->picturePreview, TQ_SLOT( slotPictureDepth32() ) );
 
-    connect( m_ui->swapRGB, TQT_SIGNAL( toggled( bool ) ), m_ui->picturePreview, TQT_SLOT( slotSwapRGBPicture( bool ) ) );
+    connect( m_ui->swapRGB, TQ_SIGNAL( toggled( bool ) ), m_ui->picturePreview, TQ_SLOT( slotSwapRGBPicture( bool ) ) );
 
-    connect( m_ui->grayscale, TQT_SIGNAL( toggled( bool ) ), m_ui->picturePreview, TQT_SLOT( slotGrayscalPicture( bool ) ) );
+    connect( m_ui->grayscale, TQ_SIGNAL( toggled( bool ) ), m_ui->picturePreview, TQ_SLOT( slotGrayscalPicture( bool ) ) );
 
-    connect( m_ui->brightnessInput, TQT_SIGNAL( valueChanged( int ) ), m_ui->picturePreview, TQT_SLOT( slotBrightValue( int ) ) );
+    connect( m_ui->brightnessInput, TQ_SIGNAL( valueChanged( int ) ), m_ui->picturePreview, TQ_SLOT( slotBrightValue( int ) ) );
 
     m_ui->picturePreview->setPicturePixmap( pixmap );
 
