@@ -63,7 +63,7 @@ protected:
     virtual void fillStyle( KoGenStyle& styleObjectAuto, KoGenStyles& mainStyles ) const;
 
     virtual void paint( TQPainter *_painter,KoTextZoomHandler*_zoomHandler,
-                        int /* pageNum */, bool drawingShadow, bool drawContour = FALSE );
+                        int /* pageNum */, bool drawingShadow, bool drawContour = false );
     virtual void updatePoints( double _fx, double _fy );
     virtual KoPointArray getDrawingPoints() const;
 
