@@ -83,7 +83,7 @@ void KPrEffectPreview::setPixmap( const TQPixmap& pixmap )
     setMinimumSize( w, h );
 
     // create smaller pixmap for preview
-    const TQImage img( pixmap.convertToImage().smoothScale( w, h, TQ_ScaleFree ) );
+    const TQImage img( pixmap.convertToImage().smoothScale( w, h, TQImage::ScaleFree ) );
     m_pixmap.convertFromImage( img );
 
     TQLabel::setPixmap( m_pixmap );
@@ -99,7 +99,7 @@ void KPrEffectPreview::run( PageEffect effect, EffectSpeed speed )
     if ( m_pageEffect )
     {
         m_pageEffectTimer.stop();
-        TQObject::disconnect( &m_pageEffectTimer, TQT_SIGNAL( timeout() ), this, TQT_SLOT( slotDoPageEffect() ) );
+        TQObject::disconnect( &m_pageEffectTimer, TQ_SIGNAL( timeout() ), this, TQ_SLOT( slotDoPageEffect() ) );
 
         m_pageEffect->finish();
 
@@ -108,7 +108,7 @@ void KPrEffectPreview::run( PageEffect effect, EffectSpeed speed )
         TQLabel::repaint();
     }
 
-    m_pageEffect = new KPrPageEffects( TQT_TQPAINTDEVICE(this), m_target, effect, speed );
+    m_pageEffect = new KPrPageEffects( this, m_target, effect, speed );
     if ( m_pageEffect->doEffect() )
     {
         delete m_pageEffect;
@@ -117,7 +117,7 @@ void KPrEffectPreview::run( PageEffect effect, EffectSpeed speed )
     }
     else
     {
-        connect( &m_pageEffectTimer, TQT_SIGNAL( timeout() ), TQT_SLOT( slotDoPageEffect() ) );
+        connect( &m_pageEffectTimer, TQ_SIGNAL( timeout() ), TQ_SLOT( slotDoPageEffect() ) );
         m_pageEffectTimer.start( 50, true );
     }
 
@@ -130,7 +130,7 @@ void KPrEffectPreview::slotDoPageEffect()
     if ( m_pageEffect->doEffect() )
     {
         m_pageEffectTimer.stop();
-        TQObject::disconnect( &m_pageEffectTimer, TQT_SIGNAL( timeout() ), this, TQT_SLOT( slotDoPageEffect() ) );
+        TQObject::disconnect( &m_pageEffectTimer, TQ_SIGNAL( timeout() ), this, TQ_SLOT( slotDoPageEffect() ) );
         delete m_pageEffect;
         m_pageEffect = 0;
         TQLabel::update();
@@ -232,8 +232,8 @@ KPrTransEffectDia::KPrTransEffectDia( TQWidget *parent, const char *name,
     if( pageEffect == PEF_RANDOM )
         effectList->setCurrentItem( effectList->count()-1 );
 
-    connect( effectList, TQT_SIGNAL(highlighted(int)), this, TQT_SLOT(effectChanged(int)) );
-    connect( effectList, TQT_SIGNAL( doubleClicked ( TQListBoxItem *) ), this, TQT_SLOT( effectChanged()) );
+    connect( effectList, TQ_SIGNAL(highlighted(int)), this, TQ_SLOT(effectChanged(int)) );
+    connect( effectList, TQ_SIGNAL( doubleClicked ( TQListBoxItem *) ), this, TQ_SLOT( effectChanged()) );
 
     new TQLabel( i18n("Speed:"), leftpart );
 
@@ -249,7 +249,7 @@ KPrTransEffectDia::KPrTransEffectDia( TQWidget *parent, const char *name,
 
     speedCombo->setCurrentItem( speed );
 
-    connect( speedCombo, TQT_SIGNAL(activated(int)), this, TQT_SLOT(speedChanged(int)) );
+    connect( speedCombo, TQ_SIGNAL(activated(int)), this, TQ_SLOT(speedChanged(int)) );
 
 
     TQWidget* previewgrp = new TQWidget( leftpart );
@@ -265,7 +265,7 @@ KPrTransEffectDia::KPrTransEffectDia( TQWidget *parent, const char *name,
 
     previewButton = new TQPushButton( previewgrp );
     previewButton->setText( i18n("Preview") );
-    connect( previewButton, TQT_SIGNAL(clicked()), this, TQT_SLOT(preview()) );
+    connect( previewButton, TQ_SIGNAL(clicked()), this, TQ_SLOT(preview()) );
 
     TQFrame* line = new TQFrame( leftpart );
     line->setFrameStyle( TQFrame::HLine | TQFrame::Sunken );
@@ -275,7 +275,7 @@ KPrTransEffectDia::KPrTransEffectDia( TQWidget *parent, const char *name,
 
     checkSoundEffect = new TQCheckBox( i18n( "Sound effect" ), leftpart );
     checkSoundEffect->setChecked( soundEffect );
-    connect( checkSoundEffect, TQT_SIGNAL( clicked() ), this, TQT_SLOT( soundEffectChanged() ) );
+    connect( checkSoundEffect, TQ_SIGNAL( clicked() ), this, TQ_SLOT( soundEffectChanged() ) );
 
     TQWidget* soundgrp = new TQWidget( leftpart );
     TQBoxLayout* soundLayout = new TQHBoxLayout( soundgrp, KDialog::marginHint(), KDialog::spacingHint() );
@@ -284,22 +284,22 @@ KPrTransEffectDia::KPrTransEffectDia( TQWidget *parent, const char *name,
     lSoundEffect = new TQLabel( i18n( "File name:" ), soundgrp );
     requester = new KURLRequester( soundgrp );
     requester->setURL( soundFileName );
-    connect( requester, TQT_SIGNAL( openFileDialog( KURLRequester * ) ),
-             this, TQT_SLOT( slotRequesterClicked( KURLRequester * ) ) );
-    connect( requester, TQT_SIGNAL( textChanged( const TQString& ) ),
-             this, TQT_SLOT( slotSoundFileChanged( const TQString& ) ) );
+    connect( requester, TQ_SIGNAL( openFileDialog( KURLRequester * ) ),
+             this, TQ_SLOT( slotRequesterClicked( KURLRequester * ) ) );
+    connect( requester, TQ_SIGNAL( textChanged( const TQString& ) ),
+             this, TQ_SLOT( slotSoundFileChanged( const TQString& ) ) );
 
     buttonTestPlaySoundEffect = new TQPushButton( soundgrp );
     buttonTestPlaySoundEffect->setPixmap( BarIcon("1rightarrow", TDEIcon::SizeSmall) );
     TQToolTip::add( buttonTestPlaySoundEffect, i18n("Play") );
 
-    connect( buttonTestPlaySoundEffect, TQT_SIGNAL( clicked() ), this, TQT_SLOT( playSound() ) );
+    connect( buttonTestPlaySoundEffect, TQ_SIGNAL( clicked() ), this, TQ_SLOT( playSound() ) );
 
     buttonTestStopSoundEffect = new TQPushButton( soundgrp );
     buttonTestStopSoundEffect->setPixmap( BarIcon("media-playback-stop", TDEIcon::SizeSmall) );
     TQToolTip::add( buttonTestStopSoundEffect, i18n("Stop") );
 
-    connect( buttonTestStopSoundEffect, TQT_SIGNAL( clicked() ), this, TQT_SLOT( stopSound() ) );
+    connect( buttonTestStopSoundEffect, TQ_SIGNAL( clicked() ), this, TQ_SLOT( stopSound() ) );
 
     soundEffect = pg->getPageSoundEffect();
     setButtonText(KDialogBase::User1,i18n( "Apply &Global" ));
@@ -311,7 +311,7 @@ KPrTransEffectDia::KPrTransEffectDia( TQWidget *parent, const char *name,
     timeSlider = new KIntNumInput( slideTime, rightpart );
     timeSlider->setRange( 1, 600, 1 );
     timeSlider->setSuffix( i18n( " seconds" ) );
-    connect( timeSlider, TQT_SIGNAL(valueChanged(int)), this, TQT_SLOT(timeChanged(int)) );
+    connect( timeSlider, TQ_SIGNAL(valueChanged(int)), this, TQ_SLOT(timeChanged(int)) );
 
     TQWidget* rspacer = new TQWidget( rightpart );
     rspacer->setSizePolicy( TQSizePolicy( TQSizePolicy::Minimum, TQSizePolicy::Expanding ) );
