@@ -713,7 +713,7 @@ protected slots:
     void extraLineEndDoubleLineArrow();
     void setExtraLineEnd(LineEnd le);
 
-    void setExtraPenStyle( Qt::PenStyle style );
+    void setExtraPenStyle( TQt::PenStyle style );
     void setExtraPenWidth( double width );
 
     /**
