@@ -38,7 +38,7 @@ class View;
 
 class ConditionalWidget : public TQWidget
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
  public:
@@ -69,7 +69,7 @@ class ConditionalWidget : public TQWidget
 
 class ConditionalDialog : public KDialogBase
 {
-  Q_OBJECT
+  TQ_OBJECT
   
  public:
   ConditionalDialog( View * parent, const char * name,
