@@ -49,13 +49,13 @@ class View;
 
 class DatabaseDialog : public KWizard
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
  public:
   enum PageId { eDatabase = 0, eSheets = 1, eColumns = 2, eOptions = 3, eResult = 4 };
 
-  DatabaseDialog( View * parent, TQRect const & rect, const char * name = 0, bool modal = FALSE, WFlags fl = 0 );
+  DatabaseDialog( View * parent, TQRect const & rect, const char * name = 0, bool modal = false, WFlags fl = 0 );
   virtual ~DatabaseDialog();
 
  private slots:
