@@ -34,7 +34,7 @@ namespace KSpread
 
 class FindOption : public TQObject
 {
-  Q_OBJECT
+  TQ_OBJECT
   
  public:
     FindOption( TQWidget *parent);
@@ -62,7 +62,7 @@ private:
 
 class FindDlg : public KFindDialog
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
  public:
@@ -80,7 +80,7 @@ class FindDlg : public KFindDialog
 
 class SearchDlg : public KReplaceDialog
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
  public:
