@@ -36,7 +36,7 @@ class View;
 
 class GotoDialog : public KDialogBase
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 public:
   GotoDialog( View* parent, const char* name);
