@@ -38,7 +38,7 @@ class View;
 
 class PaperLayout: public KoPageLayoutDia
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 public:
   PaperLayout( TQWidget* parent, const char* name,
