@@ -46,7 +46,7 @@ class View;
 
 class parameterLocale :  public TQObject
 {
- Q_OBJECT
+ TQ_OBJECT
   
 public:
    parameterLocale( View* _view,TQVBox *box, char *name = 0);
@@ -67,7 +67,7 @@ public slots:
 
 class configure : public TQObject
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 public:
   configure( View* _view,TQVBox *box, char *name = 0 );
@@ -96,7 +96,7 @@ protected:
 
 class miscParameters : public TQObject
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 public:
   miscParameters( View* _view, TQVBox *box, char *name = 0 );
@@ -128,7 +128,7 @@ protected:
 
 class colorParameters : public TQObject
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 public:
   colorParameters( View* _view, TQVBox *box, char *name = 0 );
@@ -143,7 +143,7 @@ protected:
 
 class configureLayoutPage : public TQObject
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 public:
   configureLayoutPage( View* _view,TQVBox *box, char *name = 0 );
@@ -165,7 +165,7 @@ protected:
 
 class configureSpellPage : public TQObject
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 public:
   configureSpellPage( View* _view, TQVBox *box, char *name = 0 );
@@ -181,7 +181,7 @@ protected:
 
 class configureTTSPage : public TQObject
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 public:
   configureTTSPage( View *_view, TQVBox *box, char *name = 0 );
@@ -205,7 +205,7 @@ private:
 
 class PreferenceDialog : public KDialogBase
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 public:
   enum { KS_PREFERENCES = 1, KS_LOCALE = 2, KS_INTERFACE = 4,
