@@ -35,7 +35,7 @@ class View;
 
 class ShowColRow: public KDialogBase
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 public:
   enum Type { Column, Row };
