@@ -48,7 +48,7 @@ class View;
 
 class SortDialog : public KDialogBase
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
  public:
