@@ -38,7 +38,7 @@ class View;
 
 class SubtotalDialog : public KDialogBase
 { 
-  Q_OBJECT
+  TQ_OBJECT
   
 
  public:
