@@ -32,7 +32,7 @@ namespace KSpread
 
 class LinkDialog : public KDialogBase
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
