@@ -30,7 +30,7 @@ class SheetPropertiesBase;
 
 class SheetPropertiesDialog : public KDialogBase
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
