@@ -92,7 +92,7 @@ class KSPREAD_EXPORT Canvas : public TQWidget
     friend class VBorder;
     friend class View;
 
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     /**
@@ -575,7 +575,7 @@ private:
  */
 class HBorder : public TQWidget
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     HBorder( TQWidget *_parent, Canvas *_canvas, View *_view  );
@@ -662,7 +662,7 @@ private:
  */
 class VBorder : public TQWidget
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     VBorder( TQWidget *_parent, Canvas *_canvas, View *_view );
