@@ -41,7 +41,7 @@
 
 #include "kspread_condition.h"
 
-class KLocale;
+class TDELocale;
 class TQDomElement;
 class TQDomDocument;
 class KoXmlWriter;
@@ -211,7 +211,7 @@ public:
     /**
      * Returns the locale setting of this cell.
      */
-    KLocale* locale() const;
+    TDELocale* locale() const;
     /**
      * Returns true if this cell holds a formula.
      */
