@@ -119,7 +119,7 @@ private:
 */
 class FunctionCompletion : public TQObject
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
@@ -166,7 +166,7 @@ private:
  */
 class CellEditor : public TQWidget
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
 
@@ -243,7 +243,7 @@ private:
  */
 class ComboboxLocationEditWidget : public KComboBox
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     ComboboxLocationEditWidget( TQWidget *_parent, View * _canvas );
@@ -263,7 +263,7 @@ private:
  */
 class LocationEditWidget : public KLineEdit
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     LocationEditWidget( TQWidget *_parent, View * _canvas );
@@ -291,7 +291,7 @@ private:
  */
 class EditWidget : public TQLineEdit
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     EditWidget( TQWidget *parent, Canvas *canvas,
