@@ -30,7 +30,7 @@ namespace KSpread
 
 class Factory : public KoFactory
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     Factory( TQObject* parent = 0, const char* name = 0 );
