@@ -1,7 +1,7 @@
 #ifndef KSPREAD_LOCALE_H
 #define KSPREAD_LOCALE_H
 
-#include <klocale.h>
+#include <tdelocale.h>
 
 class TQDomElement;
 class TQDomDocument;
@@ -9,7 +9,7 @@ class TQDomDocument;
 namespace KSpread
 {
 
-class Locale : public KLocale
+class Locale : public TDELocale
 {
 public:
     Locale();
