@@ -76,8 +76,8 @@ SheetPrint::SheetPrint( Sheet* sheet )
     m_maxCheckedNewPageY = 1;
     m_dPrintRepeatColumnsWidth = 0.0;
     m_dPrintRepeatRowsHeight = 0.0;
-    m_printRepeatColumns = tqMakePair( 0, 0 );
-    m_printRepeatRows = tqMakePair( 0, 0 );
+    m_printRepeatColumns = qMakePair( 0, 0 );
+    m_printRepeatRows = qMakePair( 0, 0 );
     m_dZoom = 1.0;
     m_iPageLimitX = 0;
     m_iPageLimitY = 0;
@@ -227,7 +227,7 @@ bool SheetPrint::print( TQPainter &painter, KPrinter *_printer )
     {
         gridPen = TQPen( m_pDoc->gridColor(), 1, TQt::SolidLine );
         TQPen nopen;
-        nopen.setStyle( Qt::NoPen );
+        nopen.setStyle( TQt::NoPen );
         m_pDoc->setGridColor( TQt::white );
     }
 
@@ -1734,7 +1734,7 @@ void SheetPrint::removeColumn( int col, int nbCol )
         //Validity checks
         if ( left < 1 ) left = 1;
         if ( right < 1 ) right = 1;
-        setPrintRepeatColumns ( tqMakePair( left, right ) );
+        setPrintRepeatColumns ( qMakePair( left, right ) );
     }
 }
 
@@ -1772,7 +1772,7 @@ void SheetPrint::removeRow( int row, int nbRow )
         //Validity checks
         if ( top < 1 ) top = 1;
         if ( bottom < 1 ) bottom = 1;
-        setPrintRepeatRows( tqMakePair( top, bottom ) );
+        setPrintRepeatRows( qMakePair( top, bottom ) );
     }
 }
 
