@@ -33,7 +33,7 @@ namespace KSpread
 
 class KOFFICEUI_EXPORT ToolBox : public TQFrame
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     ToolBox( TQWidget* parent = 0, const char* name = 0 );
@@ -55,7 +55,7 @@ private:
 
 class KOFFICEUI_EXPORT KoTransformToolBox : public ToolBox
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     KoTransformToolBox( KoDocumentChild* child, TQWidget* parent = 0, const char* name = 0 );
