@@ -48,7 +48,7 @@
 
 class ConfigDlg : public TQDialog {
 
-Q_OBJECT
+TQ_OBJECT
   
 
 public:
