@@ -29,7 +29,7 @@ class Tester;
 
 class TestRunner : public KDialogBase
 {
-Q_OBJECT
+TQ_OBJECT
   
 
 public:
