@@ -39,7 +39,7 @@ typedef TQValueList<Box*> BoxList;
 
 class Canvas: public TQCanvas
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     Canvas( int w, int h );
