@@ -32,7 +32,7 @@ Detail::Detail( int x, int y, int width, int height, int level, Canvas *canvas )
 {
     props.addProperty( new Property( "Height", 50, i18n( "Height" ), i18n( "Height" ), KoProperty::Integer ), "Detail" );
     props.addProperty( new Property( "Level", 0, i18n( "Level" ), i18n( "Detail Level" ), KoProperty::Integer ), "Detail" );
-    props.addProperty( new Property( "Repeat", TQVariant( false, 3 ), i18n( "Repeat" ), i18n( "Repeat After Page Break" ), KoProperty::Boolean ), "Detail" );
+    props.addProperty( new Property( "Repeat", TQVariant( false ), i18n( "Repeat" ), i18n( "Repeat After Page Break" ), KoProperty::Boolean ), "Detail" );
 
     registerAs( Rtti_Detail );
 }
