@@ -24,7 +24,7 @@ namespace Kugar
 
 class MPageDisplay : public TQWidget
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     /** Constructor */
