@@ -14,7 +14,7 @@ class KugarPart;
 
 class KugarView: public KoView
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
