@@ -105,10 +105,10 @@ KWCanvas::KWCanvas(const TQString& viewMode, TQWidget *parent, KWDocument *d, KW
     m_temporaryStatusBarTextShown = false;
 
     viewport()->setBackgroundMode( PaletteBase );
-    viewport()->setAcceptDrops( TRUE );
+    viewport()->setAcceptDrops( true );
 
-    setKeyCompression( TRUE );
-    viewport()->setMouseTracking( TRUE );
+    setKeyCompression( true );
+    viewport()->setMouseTracking( true );
 
     m_scrollTimer = new TQTimer( this );
     connect( m_scrollTimer, TQ_SIGNAL( timeout() ),
@@ -403,7 +403,7 @@ void KWCanvas::mpCreatePixmap( const TQPoint& normalPoint, bool noGrid  )
         }
         emit docStructChanged(Pictures);
         if ( !m_doc->showGrid() && m_doc->snapToGrid() )
-          repaintContents( FALSE ); //draw the grid over the whole canvas
+          repaintContents( false ); //draw the grid over the whole canvas
     }
 }
 
@@ -812,7 +812,7 @@ void KWCanvas::contentsMouseMoveEvent( TQMouseEvent *e )
                         m_currentTable->resizeColumn( m_rowColResized, docPoint.x() );
                     // Repaint only the changed rects (oldRect U newRect)
                     TQRect newRect( m_viewMode->normalToView( m_doc->zoomRect( m_currentTable->boundingRect() ) ) );
-                    repaintContents( TQRegion(oldRect).unite(newRect).boundingRect(), FALSE );
+                    repaintContents( TQRegion(oldRect).unite(newRect).boundingRect(), false );
                 }
                 else if (m_interactionPolicy) {
                     m_interactionPolicy->handleMouseMove(e->state(),
@@ -1127,7 +1127,7 @@ void KWCanvas::contentsMouseReleaseEvent( TQMouseEvent * e )
         }
 
         if ( old_mouseMove != MM_EDIT && !m_doc->showGrid() && m_doc->snapToGrid() )
-          repaintContents( FALSE ); //draw the grid over the whole canvas
+          repaintContents( false ); //draw the grid over the whole canvas
         m_mousePressed = false;
     }
 }
@@ -1404,7 +1404,7 @@ void KWCanvas::setMouseMode( MouseMode newMouseMode )
 
         m_mouseMode = newMouseMode;
         if ( !m_doc->showGrid() && m_doc->snapToGrid() )
-          repaintContents( FALSE ); //draw the grid over the whole canvas
+          repaintContents( false ); //draw the grid over the whole canvas
     }
     else
         m_mouseMode = newMouseMode;
@@ -1778,11 +1778,11 @@ bool KWCanvas::eventFilter( TQObject *o, TQEvent *e )
                 // Activate this code (and in focusNextPreviousChild() to allow Shift+Tab
                 // out of document window.  Disabled because it conflicts with Shift+Tab inside a table.
                 // else if ( keyev->key() == TQt::Key_BackTab )
-                //    return FALSE;
+                //    return false;
                 else if ( keyev->key() == TDEGlobalSettings::contextMenuKey() ) {
                     // The popups are not available in readonly mode, since the GUI isn't built...
-                    if(!m_doc->isReadWrite()) return TRUE;
-                    if (m_mouseMode != MM_EDIT) return TRUE;
+                    if(!m_doc->isReadWrite()) return true;
+                    if (m_mouseMode != MM_EDIT) return true;
                     KoPoint docPoint = m_doc->unzoomPoint( TQCursor::pos() );
 
                     if ( viewMode()->type()=="ModeText") {
@@ -1804,9 +1804,9 @@ bool KWCanvas::eventFilter( TQObject *o, TQEvent *e )
                     // around before they click or hit Enter.
                     if (m_frameInline)
                         m_lastCaretPos = caretPos();
-                    if (m_lastCaretPos.isNull()) return TRUE;
+                    if (m_lastCaretPos.isNull()) return true;
                     int page = m_doc->pageManager()->pageNumber(m_lastCaretPos);
-                    if(page == -1) return TRUE;
+                    if(page == -1) return true;
                     TQPoint normalPoint = m_doc->zoomPoint(m_lastCaretPos);
                     // Coordinate is at the very top of the caret.  In the case of an
                     // inline frame, adjust slightly down and to the right in order
@@ -1862,7 +1862,7 @@ bool KWCanvas::eventFilter( TQObject *o, TQEvent *e )
                     }
                     else
                         m_currentFrameSetEdit->keyPressEvent( keyev );
-                    return TRUE;
+                    return true;
                 }
 
                 // Because of the dependency on the control key, we need to update the mouse cursor here
@@ -1891,7 +1891,7 @@ bool KWCanvas::eventFilter( TQObject *o, TQEvent *e )
                 if ( m_currentFrameSetEdit && m_mouseMode == MM_EDIT && m_doc->isReadWrite() && !m_printing )
                 {
                     m_currentFrameSetEdit->keyReleaseEvent( keyev );
-                    return TRUE;
+                    return true;
                 }
             }
                 break;
@@ -1923,9 +1923,9 @@ bool KWCanvas::eventFilter( TQObject *o, TQEvent *e )
 bool KWCanvas::focusNextPrevChild( bool next)
 {
     Q_UNUSED(next);
-    return TRUE; // Don't allow to go out of the canvas widget by pressing "Tab"
+    return true; // Don't allow to go out of the canvas widget by pressing "Tab"
     // Don't allow to go out of the canvas widget by pressing Tab, but do allow Shift+Tab.
-    // if (next) return TRUE;
+    // if (next) return true;
     // return TQWidget::focusNextPrevChild( next );
 }
 
@@ -2372,7 +2372,7 @@ void FrameMovePolicy::handleMouseMove(TQt::ButtonState keyState, const KoPoint &
       kdDebug() << " point.x()=" << point.x() << endl; */
 
     TQPtrList<KWTableFrameSet> tablesMoved;
-    tablesMoved.setAutoDelete( FALSE );
+    tablesMoved.setAutoDelete( false );
     TQRegion repaintRegion;
     KoPoint _move=m_boundingRect.topLeft() - oldBoundingRect.topLeft();
 
