@@ -281,7 +281,7 @@ protected:
 
 class KWDocStructTree : public TDEListView
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
@@ -321,7 +321,7 @@ protected:
 
 class KWDocStruct : public TQWidget
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
