@@ -53,7 +53,7 @@ KWEditPersonnalExpression::KWEditPersonnalExpression( TQWidget *parent, const ch
     TQGroupBox *expressionGroupBox = new TQGroupBox( page, "expressionGroupBox" );
     expressionGroupBox->setSizePolicy( TQSizePolicy( (TQSizePolicy::SizeType)5, (TQSizePolicy::SizeType)5, 1, 0, expressionGroupBox->sizePolicy().hasHeightForWidth() ) );
     expressionGroupBox->setTitle( i18n( "Expressions" ) );
-    expressionGroupBox->setColumnLayout(0, Qt::Vertical );
+    expressionGroupBox->setColumnLayout(0, TQt::Vertical );
     expressionGroupBox->layout()->setSpacing( KDialog::spacingHint() );
     expressionGroupBox->layout()->setMargin( KDialog::marginHint() );
     TQVBoxLayout *expressionGroupBoxLayout = new TQVBoxLayout( expressionGroupBox->layout() );
@@ -103,16 +103,16 @@ KWEditPersonnalExpression::KWEditPersonnalExpression( TQWidget *parent, const ch
     else
         initGroupList();
 
-    connect(m_groupList,TQT_SIGNAL(selectionChanged()), this,TQT_SLOT(slotGroupSelected()));
-    connect(m_ExpressionsList,TQT_SIGNAL(selectionChanged()), this,TQT_SLOT(slotExpressionSelected()));
+    connect(m_groupList,TQ_SIGNAL(selectionChanged()), this,TQ_SLOT(slotGroupSelected()));
+    connect(m_ExpressionsList,TQ_SIGNAL(selectionChanged()), this,TQ_SLOT(slotExpressionSelected()));
     if(m_groupList->count() > 0)  m_groupList->setSelected(0, true);
 
-    connect(m_groupLineEdit,TQT_SIGNAL(textChanged(const TQString&)), this,TQT_SLOT(slotUpdateGroupName(const TQString&)));
-    connect(m_expressionLineEdit,TQT_SIGNAL(textChanged(const TQString&)), this,TQT_SLOT(slotUpdateExpression(const TQString&)));
-    connect(m_addExpression, TQT_SIGNAL( clicked() ), this,TQT_SLOT( slotAddExpression() ));
-    connect(m_delExpression, TQT_SIGNAL( clicked() ), this,TQT_SLOT( slotRemoveExpression() ));
-    connect(m_addGroup, TQT_SIGNAL( clicked() ), this,TQT_SLOT( slotAddGroup()));
-    connect(m_delGroup, TQT_SIGNAL( clicked() ), this,TQT_SLOT( slotRemoveGroup() ));
+    connect(m_groupLineEdit,TQ_SIGNAL(textChanged(const TQString&)), this,TQ_SLOT(slotUpdateGroupName(const TQString&)));
+    connect(m_expressionLineEdit,TQ_SIGNAL(textChanged(const TQString&)), this,TQ_SLOT(slotUpdateExpression(const TQString&)));
+    connect(m_addExpression, TQ_SIGNAL( clicked() ), this,TQ_SLOT( slotAddExpression() ));
+    connect(m_delExpression, TQ_SIGNAL( clicked() ), this,TQ_SLOT( slotRemoveExpression() ));
+    connect(m_addGroup, TQ_SIGNAL( clicked() ), this,TQ_SLOT( slotAddGroup()));
+    connect(m_delGroup, TQ_SIGNAL( clicked() ), this,TQ_SLOT( slotRemoveGroup() ));
     updateWidget();
 
     setFocus();
