@@ -49,7 +49,7 @@ class TQRegion;
  * that's the KWDocument)
  */
 class KWFrameViewManager : public TQObject {
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
@@ -97,7 +97,7 @@ public:
      */
     KWFrameView* selectedFrame() const;
 
-    // this should be changed to a real iterator when TQt4 is used.
+    // this should be changed to a real iterator
     const TQValueList<KWFrameView*> frameViewsIterator() const { return m_frames; }
 
     /**
