@@ -50,7 +50,7 @@ KWImportStyleDia::~KWImportStyleDia()
 
 void KWImportStyleDia::loadFile()
 {
-    KFileDialog fd( TQString(), TQString(), 0, 0, TRUE );
+    KFileDialog fd( TQString(), TQString(), 0, 0, true );
     TQStringList lst = "application/x-kword";
 #if 0
     lst << "application/vnd.oasis.opendocument.text";
@@ -206,7 +206,7 @@ TQString KWImportFrameTableStyleDia::generateStyleName( const TQString & templat
 
 void KWImportFrameTableStyleDia::loadFile()
 {
-    KFileDialog fd( TQString(), TQString(), 0, 0, TRUE );
+    KFileDialog fd( TQString(), TQString(), 0, 0, true );
     TQStringList lst = "application/x-kword";
 #if 0
     lst << "application/vnd.oasis.opendocument.text";
