@@ -29,7 +29,7 @@
 
 class KWMailMergeLabelAction : public TDEAction
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 public:
   KWMailMergeLabelAction( const TQString &text, int accel,
