@@ -76,8 +76,8 @@ void KWPartFrameSet::setChild( KWDocumentChild* child )
     assert( !m_child );
     m_child = child;
     m_child->setPartFrameSet( this );
-    TQObject::connect( m_child, TQT_SIGNAL( changed( KoChild * ) ),
-                      this, TQT_SLOT( slotChildChanged() ) );
+    TQObject::connect( m_child, TQ_SIGNAL( changed( KoChild * ) ),
+                      this, TQ_SLOT( slotChildChanged() ) );
 }
 
 KWPartFrameSet::~KWPartFrameSet()
@@ -271,8 +271,8 @@ KWPartFrameSetEdit::KWPartFrameSetEdit( KWPartFrameSet * fs, KWCanvas * canvas )
     kdDebug(32001) << "KWPartFrameSetEdit::KWPartFrameSetEdit " << endl;
     m_dcop=0L;
     fs->startEditing();
-    TQObject::connect( m_canvas->gui()->getView(), TQT_SIGNAL( activated( bool ) ),
-                      this, TQT_SLOT( slotChildActivated( bool ) ) );
+    TQObject::connect( m_canvas->gui()->getView(), TQ_SIGNAL( activated( bool ) ),
+                      this, TQ_SLOT( slotChildActivated( bool ) ) );
 }
 
 KWPartFrameSetEdit::~KWPartFrameSetEdit()
@@ -360,7 +360,7 @@ KoDocument* KWDocumentChild::hitTest( const TQPoint& p, const TQWMatrix& _matrix
 
     // Only activate when it's already selected, and when not clicking on the border.
     // KWFrameView and the part frame policy have that logic already.
-    KWView* kwView = ::tqqt_cast<KWView *>( parentDocument()->hitTestView() );
+    KWView* kwView = ::tqt_cast<KWView *>( parentDocument()->hitTestView() );
     Q_ASSERT( kwView );
     if ( kwView ) {
         KWFrame* frame = m_partFrameSet->frame(0);
