@@ -184,7 +184,7 @@ void KWPictureFrameSet::loadOasis( const TQDomElement& frame, const TQDomElement
     {
         TQCString data = binaryData.toElement().text().latin1();
         m_picture.loadFromBase64( data );
-        key = KoPictureKey("nofile", TQDateTime::currentDateTime(Qt::UTC));
+        key = KoPictureKey("nofile", TQDateTime::currentDateTime(TQt::UTC));
         m_picture.setKey(key);
     }
     else
@@ -199,7 +199,7 @@ void KWPictureFrameSet::loadOasis( const TQDomElement& frame, const TQDomElement
                 strExtension=href.mid(result+1); // As we are using KoPicture, the extension should be without the dot.
             }
             TQString filename(href/*.mid(1)*/);
-            key = KoPictureKey(filename, TQDateTime::currentDateTime(Qt::UTC));
+            key = KoPictureKey(filename, TQDateTime::currentDateTime(TQt::UTC));
             m_picture.setKey(key);
 
             KoStore* store = context.store();
