@@ -25,7 +25,7 @@ class TQRadioButton;
 
 class KWSortDia : public KDialogBase
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     KWSortDia( TQWidget *parent, const char* name );
