@@ -120,7 +120,7 @@ void KWTableDia::setupTab1( int rows, int cols, CellSize wid, CellSize hei, bool
         lHei = new TQLabel( i18n( "Cell heights:" ), tab1 );
         grid->addWidget( lHei, 4, 0 );
 
-        cHei = new TQComboBox( FALSE, tab1 );
+        cHei = new TQComboBox( false, tab1 );
         cHei->insertItem( i18n( "Automatic" ) );
         cHei->insertItem( i18n( "Manual" ) );
         cHei->setCurrentItem( (int)hei );
@@ -129,7 +129,7 @@ void KWTableDia::setupTab1( int rows, int cols, CellSize wid, CellSize hei, bool
         lWid = new TQLabel( i18n( "Cell widths:" ), tab1 );
         grid->addWidget( lWid, 6, 0 );
 
-        cWid = new TQComboBox( FALSE, tab1 );
+        cWid = new TQComboBox( false, tab1 );
         cWid->insertItem( i18n( "Automatic" ) );
         cWid->insertItem( i18n( "Manual" ) );
         cWid->setCurrentItem( (int)wid );
