@@ -30,7 +30,7 @@
 #include "KWFrameStyleManager.h"
 #include "KWStyleManager.h"
 
-#include <klocale.h>
+#include <tdelocale.h>
 #include <kiconloader.h>
 #include <kdebug.h>
 
@@ -53,7 +53,7 @@ KWTableStylePreview::KWTableStylePreview( const TQString& title, const TQString&
 {
     m_zoomHandler = new KoTextZoomHandler;
     TQFont font = KoGlobal::defaultFont();
-    m_textdoc = new KoTextDocument( m_zoomHandler, new KoTextFormatCollection( font, TQColor(),KGlobal::locale()->language(), false ) );
+    m_textdoc = new KoTextDocument( m_zoomHandler, new KoTextFormatCollection( font, TQColor(),TDEGlobal::locale()->language(), false ) );
     KoTextParag * parag = m_textdoc->firstParag();
     parag->insert( 0, text );
 }
@@ -201,7 +201,7 @@ KWTableStyleManager::KWTableStyleManager( TQWidget *_parent, KWDocument *_doc )
     switchStyle();
     setInitialSize( TQSize( 450, 450 ) );
     setButtonText( KDialogBase::User1, i18n("Import From File...") );
-    connect(this, TQT_SIGNAL(user1Clicked()), this, TQT_SLOT(importFromFile()));
+    connect(this, TQ_SIGNAL(user1Clicked()), this, TQ_SLOT(importFromFile()));
 
 }
 
@@ -238,25 +238,25 @@ void KWTableStyleManager::setupWidget()
 
 
     m_moveUpButton = new TQPushButton( frame1, "moveUpButton" );
-    m_moveUpButton->setIconSet( SmallIconSet( "up" ) );
-    connect( m_moveUpButton, TQT_SIGNAL( clicked() ), this, TQT_SLOT( moveUpStyle() ) );
+    m_moveUpButton->setIconSet( SmallIconSet( "go-up" ) );
+    connect( m_moveUpButton, TQ_SIGNAL( clicked() ), this, TQ_SLOT( moveUpStyle() ) );
     frame1Layout->addWidget( m_moveUpButton, 1, 1 );
 
     m_moveDownButton = new TQPushButton( frame1, "moveDownButton" );
-    m_moveDownButton->setIconSet( SmallIconSet( "down" ) );
-    connect( m_moveDownButton, TQT_SIGNAL( clicked() ), this, TQT_SLOT( moveDownStyle() ) );
+    m_moveDownButton->setIconSet( SmallIconSet( "go-down" ) );
+    connect( m_moveDownButton, TQ_SIGNAL( clicked() ), this, TQ_SLOT( moveDownStyle() ) );
     frame1Layout->addWidget( m_moveDownButton, 1, 0 );
 
 
     m_deleteButton = new TQPushButton( frame1, "deleteButton" );
     m_deleteButton->setText( i18n( "&Delete" ) );
-    connect( m_deleteButton, TQT_SIGNAL( clicked() ), this, TQT_SLOT( deleteStyle() ) );
+    connect( m_deleteButton, TQ_SIGNAL( clicked() ), this, TQ_SLOT( deleteStyle() ) );
 
     frame1Layout->addWidget( m_deleteButton, 2, 1 );
 
     m_newButton = new TQPushButton( frame1, "newButton" );
     m_newButton->setText( i18n( "New" ) );
-    connect( m_newButton, TQT_SIGNAL( clicked() ), this, TQT_SLOT( addStyle() ) );
+    connect( m_newButton, TQ_SIGNAL( clicked() ), this, TQ_SLOT( addStyle() ) );
 
     frame1Layout->addWidget( m_newButton, 2, 0 );
 
@@ -266,7 +266,7 @@ void KWTableStyleManager::setupWidget()
 
     frame1Layout->addMultiCellWidget( main, 0, 2, 2, 2 );
 
-    connect( m_stylesList, TQT_SIGNAL( selectionChanged() ), this, TQT_SLOT( switchStyle() ) );
+    connect( m_stylesList, TQ_SIGNAL( selectionChanged() ), this, TQ_SLOT( switchStyle() ) );
 }
 
 void KWTableStyleManager::setupMain()
@@ -281,7 +281,7 @@ void KWTableStyleManager::setupMain()
 
     m_nameString = new TQLineEdit( main );
     m_nameString->resize(m_nameString->sizeHint() );
-    connect( m_nameString, TQT_SIGNAL( textChanged( const TQString &) ), this, TQT_SLOT( renameStyle(const TQString &) ) );
+    connect( m_nameString, TQ_SIGNAL( textChanged( const TQString &) ), this, TQ_SLOT( renameStyle(const TQString &) ) );
 
     mainLayout->addWidget( m_nameString, 0, 1 );
 
@@ -292,7 +292,7 @@ void KWTableStyleManager::setupMain()
 
     mainLayout->addWidget( nameLabel, 0, 0 );
 
-    TQGroupBox *adjustBox = new TQGroupBox( 0, Qt::Vertical, i18n("Adjust"), main);
+    TQGroupBox *adjustBox = new TQGroupBox( 0, TQt::Vertical, i18n("Adjust"), main);
     adjustBox->layout()->setSpacing(KDialog::spacingHint());
     adjustBox->layout()->setMargin(KDialog::marginHint());
     TQGridLayout *adjustLayout = new TQGridLayout( adjustBox->layout() );
@@ -309,16 +309,16 @@ void KWTableStyleManager::setupMain()
     m_style = new TQComboBox( adjustBox );
     updateAllStyleCombos();
 
-    connect( m_frameStyle, TQT_SIGNAL( activated(int) ), this, TQT_SLOT( selectFrameStyle(int) ) );
-    connect( m_style, TQT_SIGNAL( activated(int) ), this, TQT_SLOT( selectStyle(int) ) );
+    connect( m_frameStyle, TQ_SIGNAL( activated(int) ), this, TQ_SLOT( selectFrameStyle(int) ) );
+    connect( m_style, TQ_SIGNAL( activated(int) ), this, TQ_SLOT( selectStyle(int) ) );
 
     m_changeFrameStyleButton = new TQPushButton( adjustBox );
     m_changeFrameStyleButton->setText( i18n( "Change..." ) );
-    connect( m_changeFrameStyleButton, TQT_SIGNAL( clicked() ), this, TQT_SLOT( changeFrameStyle() ) );
+    connect( m_changeFrameStyleButton, TQ_SIGNAL( clicked() ), this, TQ_SLOT( changeFrameStyle() ) );
 
     m_changeStyleButton = new TQPushButton( adjustBox );
     m_changeStyleButton->setText( i18n( "Change..." ) );
-    connect( m_changeStyleButton, TQT_SIGNAL( clicked() ), this, TQT_SLOT( changeStyle() ) );
+    connect( m_changeStyleButton, TQ_SIGNAL( clicked() ), this, TQ_SLOT( changeStyle() ) );
 
     adjustLayout->addWidget( frameStyleLabel, 0, 0 );
     adjustLayout->addWidget( styleLabel, 1, 0 );
