@@ -572,7 +572,7 @@ KWTableTemplateSelector::KWTableTemplateSelector( KWDocument *_doc, TQWidget *_p
     preview = new KWTableTemplatePreview( i18n( "Preview" ), m_doc->tableStyleCollection()->findStyle("Plain"), this );
     grid->addWidget( preview, 0, 1 );
 
-    bgCustomize = new TQButtonGroup( 3,Qt::Horizontal, i18n( "Apply To" ), this );
+    bgCustomize = new TQButtonGroup( 3,TQt::Horizontal, i18n( "Apply To" ), this );
 
     cbFirstRow = new TQCheckBox( i18n( "First row" ), bgCustomize );
     cbLastRow = new TQCheckBox( i18n( "Last row" ), bgCustomize );
@@ -589,13 +589,13 @@ KWTableTemplateSelector::KWTableTemplateSelector( KWDocument *_doc, TQWidget *_p
     grid->setColStretch( 1, 1 );
     grid->activate();
 
-    connect( cbFirstRow, TQT_SIGNAL( toggled( bool ) ), preview, TQT_SLOT( cbFirstRowChanged( bool ) ) );
-    connect( cbFirstCol, TQT_SIGNAL( toggled( bool ) ), preview, TQT_SLOT( cbFirstColChanged( bool ) ) );
-    connect( cbLastRow, TQT_SIGNAL( toggled( bool ) ), preview, TQT_SLOT( cbLastRowChanged( bool ) ) );
-    connect( cbLastCol,  TQT_SIGNAL( toggled( bool ) ), preview, TQT_SLOT( cbLastColChanged( bool ) ) );
-    connect( cbBody,  TQT_SIGNAL( toggled( bool ) ), preview, TQT_SLOT( cbBodyChanged( bool ) ) );
+    connect( cbFirstRow, TQ_SIGNAL( toggled( bool ) ), preview, TQ_SLOT( cbFirstRowChanged( bool ) ) );
+    connect( cbFirstCol, TQ_SIGNAL( toggled( bool ) ), preview, TQ_SLOT( cbFirstColChanged( bool ) ) );
+    connect( cbLastRow, TQ_SIGNAL( toggled( bool ) ), preview, TQ_SLOT( cbLastRowChanged( bool ) ) );
+    connect( cbLastCol,  TQ_SIGNAL( toggled( bool ) ), preview, TQ_SLOT( cbLastColChanged( bool ) ) );
+    connect( cbBody,  TQ_SIGNAL( toggled( bool ) ), preview, TQ_SLOT( cbBodyChanged( bool ) ) );
 
-    connect( lbTemplates, TQT_SIGNAL(  selectionChanged () ), this, TQT_SLOT( changeTableTemplate() ) );
+    connect( lbTemplates, TQ_SIGNAL(  selectionChanged () ), this, TQ_SLOT( changeTableTemplate() ) );
     TQListBoxItem * item = lbTemplates->findItem( _tableTemplate );
     int index = 0;
     if ( item  )
