@@ -33,7 +33,7 @@ KFORMULA_NAMESPACE_BEGIN
  */
 class MatrixDialog : public KDialogBase
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
