@@ -61,7 +61,7 @@ ConfigurePage::ConfigurePage( Document* document, TQWidget* view, TDEConfig* con
     // fonts
 
     TQGroupBox *gbox = new TQGroupBox( i18n( "Fonts" ), box );
-    gbox->setColumnLayout( 0, Qt::Horizontal );
+    gbox->setColumnLayout( 0, TQt::Horizontal );
 
     TQGridLayout* grid = new TQGridLayout( gbox->layout(), 5, 3 );
     grid->setSpacing( KDialog::spacingHint() );
@@ -75,19 +75,19 @@ ConfigurePage::ConfigurePage( Document* document, TQWidget* view, TDEConfig* con
 
     connect( buildFontLine( gbox, grid, 0, defaultFont,
             i18n( "Default font:" ), defaultFontName ),
-            TQT_SIGNAL( clicked() ), TQT_SLOT( selectNewDefaultFont() ) );
+            TQ_SIGNAL( clicked() ), TQ_SLOT( selectNewDefaultFont() ) );
 
     connect( buildFontLine( gbox, grid, 1, nameFont,
             i18n( "Name font:" ), nameFontName ),
-            TQT_SIGNAL( clicked() ), TQT_SLOT( selectNewNameFont() ) );
+            TQ_SIGNAL( clicked() ), TQ_SLOT( selectNewNameFont() ) );
 
     connect( buildFontLine( gbox, grid, 2, numberFont,
             i18n( "Number font:" ), numberFontName ),
-            TQT_SIGNAL( clicked() ), TQT_SLOT( selectNewNumberFont() ) );
+            TQ_SIGNAL( clicked() ), TQ_SLOT( selectNewNumberFont() ) );
 
     connect( buildFontLine( gbox, grid, 3, operatorFont,
             i18n( "Operator font:" ), operatorFontName ),
-            TQT_SIGNAL( clicked() ), TQT_SLOT( selectNewOperatorFont() ) );
+            TQ_SIGNAL( clicked() ), TQ_SLOT( selectNewOperatorFont() ) );
 
     TQLabel* sizeTitle = new TQLabel( i18n( "Default base size:" ), gbox );
     grid->addWidget( sizeTitle, 4, 0 );
@@ -97,8 +97,8 @@ ConfigurePage::ConfigurePage( Document* document, TQWidget* view, TDEConfig* con
 
     grid->addMultiCellWidget( sizeSpin, 4, 4, 1, 2 );
 
-    connect( sizeSpin, TQT_SIGNAL( valueChanged( int ) ),
-            TQT_SLOT( baseSizeChanged( int ) ) );
+    connect( sizeSpin, TQ_SIGNAL( valueChanged( int ) ),
+            TQ_SLOT( baseSizeChanged( int ) ) );
 
     // syntax highlighting
 
@@ -106,7 +106,7 @@ ConfigurePage::ConfigurePage( Document* document, TQWidget* view, TDEConfig* con
     syntaxHighlighting->setChecked( contextStyle.syntaxHighlighting() );
 
 //     hlBox = new TQGroupBox( i18n( "Highlight Colors" ), box );
-//     hlBox->setColumnLayout( 0, Qt::Horizontal );
+//     hlBox->setColumnLayout( 0, TQt::Horizontal );
 
 //     grid = new TQGridLayout( hlBox->layout(), 5, 2 );
 //     grid->setSpacing( KDialog::spacingHint() );
@@ -155,13 +155,13 @@ ConfigurePage::ConfigurePage( Document* document, TQWidget* view, TDEConfig* con
 //     errorColorBtn->setColor( contextStyle.getErrorColorPlain() );
 //     grid->addWidget( errorColorBtn, 4, 1 );
 
-    connect( syntaxHighlighting, TQT_SIGNAL( clicked() ),
-            TQT_SLOT( syntaxHighlightingClicked() ) );
+    connect( syntaxHighlighting, TQ_SIGNAL( clicked() ),
+            TQ_SLOT( syntaxHighlightingClicked() ) );
 
     syntaxHighlightingClicked();
 
-    connect( syntaxHighlighting, TQT_SIGNAL( clicked() ), this, TQT_SLOT( slotChanged() ) );
-    connect( sizeSpin, TQT_SIGNAL( valueChanged( int ) ), this, TQT_SLOT( slotChanged() ) );
+    connect( syntaxHighlighting, TQ_SIGNAL( clicked() ), this, TQ_SLOT( slotChanged() ) );
+    connect( sizeSpin, TQ_SIGNAL( valueChanged( int ) ), this, TQ_SLOT( slotChanged() ) );
 
     Q_ASSERT( !m_changed );
 }
@@ -389,14 +389,14 @@ void ConfigurePage::slotChanged()
 
 //     fontLayout->addLayout( hLayout, 0, 0 );
 
-// //     connect( availableFonts, TQT_SIGNAL( executed( TQListViewItem* ) ),
-// //              this, TQT_SLOT( slotAddFont() ) );
-// //     connect( requestedFonts, TQT_SIGNAL( executed( TQListViewItem* ) ),
-// //              this, TQT_SLOT( slotRemoveFont() ) );
-//     connect( addFont, TQT_SIGNAL( clicked() ), this, TQT_SLOT( slotAddFont() ) );
-//     connect( removeFont, TQT_SIGNAL( clicked() ), this, TQT_SLOT( slotRemoveFont() ) );
-//     connect( moveUp, TQT_SIGNAL( clicked() ), this, TQT_SLOT( slotMoveUp() ) );
-//     connect( moveDown, TQT_SIGNAL( clicked() ), this, TQT_SLOT( slotMoveDown() ) );
+// //     connect( availableFonts, TQ_SIGNAL( executed( TQListViewItem* ) ),
+// //              this, TQ_SLOT( slotAddFont() ) );
+// //     connect( requestedFonts, TQ_SIGNAL( executed( TQListViewItem* ) ),
+// //              this, TQ_SLOT( slotRemoveFont() ) );
+//     connect( addFont, TQ_SIGNAL( clicked() ), this, TQ_SLOT( slotAddFont() ) );
+//     connect( removeFont, TQ_SIGNAL( clicked() ), this, TQ_SLOT( slotRemoveFont() ) );
+//     connect( moveUp, TQ_SIGNAL( clicked() ), this, TQ_SLOT( slotMoveUp() ) );
+//     connect( moveDown, TQ_SIGNAL( clicked() ), this, TQ_SLOT( slotMoveDown() ) );
 
 //     const ContextStyle& contextStyle = document->getContextStyle( true );
 //     const SymbolTable& symbolTable = contextStyle.symbolTable();
