@@ -276,7 +276,7 @@ public:
     virtual BasicElement* getElement() = 0;
 };
 
-typedef std::auto_ptr<ElementIndex> ElementIndexPtr;
+typedef std::unique_ptr<ElementIndex> ElementIndexPtr;
 
 enum RequestID {
     req_addBracket,
