@@ -442,187 +442,187 @@ void DocumentWrapper::createActions( TDEActionCollection* collection )
 
     m_addNegThinSpaceAction = new TDEAction( i18n( "Add Negative Thin Space" ),
                                     0,
-                                    this, TQT_SLOT( addNegThinSpace() ),
+                                    this, TQ_SLOT( addNegThinSpace() ),
                                     collection, "formula_addnegthinspace") ;
     m_addThinSpaceAction = new TDEAction( i18n( "Add Thin Space" ),
                                     0,
-                                    this, TQT_SLOT( addThinSpace() ),
+                                    this, TQ_SLOT( addThinSpace() ),
                                     collection, "formula_addthinspace") ;
     m_addMediumSpaceAction = new TDEAction( i18n( "Add Medium Space" ),
                                     0,
-                                    this, TQT_SLOT( addMediumSpace() ),
+                                    this, TQ_SLOT( addMediumSpace() ),
                                     collection, "formula_addmediumspace" );
     m_addThickSpaceAction = new TDEAction( i18n( "Add Thick Space" ),
                                     0,
-                                    this, TQT_SLOT( addThickSpace() ),
+                                    this, TQ_SLOT( addThickSpace() ),
                                     collection, "formula_addthickspace" );
     m_addQuadSpaceAction = new TDEAction( i18n( "Add Quad Space" ),
                                     0,
-                                    this, TQT_SLOT( addQuadSpace() ),
+                                    this, TQ_SLOT( addQuadSpace() ),
                                     collection, "formula_addquadspace" );
 
     m_addIntegralAction = new TDEAction(i18n("Add Integral"),
                                     "int",
                                     0,
-                                    this, TQT_SLOT(addIntegral()),
+                                    this, TQ_SLOT(addIntegral()),
                                     collection, "formula_addintegral");
     m_addSumAction      = new TDEAction(i18n("Add Sum"),
                                     "sum",
                                     0,
-                                    this, TQT_SLOT(addSum()),
+                                    this, TQ_SLOT(addSum()),
                                     collection, "formula_addsum");
     m_addProductAction  = new TDEAction(i18n("Add Product"),
                                     "prod",
                                     0,
-                                    this, TQT_SLOT(addProduct()),
+                                    this, TQ_SLOT(addProduct()),
                                     collection, "formula_addproduct");
     m_addRootAction     = new TDEAction(i18n("Add Root"),
                                     "sqrt",
                                     0,
-                                    this, TQT_SLOT(addRoot()),
+                                    this, TQ_SLOT(addRoot()),
                                     collection, "formula_addroot");
     m_addFractionAction = new TDEAction(i18n("Add Fraction"),
                                     "frac",
                                     0,
-                                    this, TQT_SLOT(addFraction()),
+                                    this, TQ_SLOT(addFraction()),
                                     collection, "formula_addfrac");
     m_addBracketAction  = new TDEAction(i18n("Add Bracket"),
                                     "paren",
                                     0,
-                                    this, TQT_SLOT(addDefaultBracket()),
+                                    this, TQ_SLOT(addDefaultBracket()),
                                     collection,"formula_addbra");
     m_addSBracketAction = new TDEAction(i18n("Add Square Bracket"),
                                     "brackets",
                                     0,
-                                    this, TQT_SLOT(addSquareBracket()),
+                                    this, TQ_SLOT(addSquareBracket()),
                                     collection,"formula_addsqrbra");
     m_addCBracketAction = new TDEAction(i18n("Add Curly Bracket"),
                                     "math_brace",
                                     0,
-                                    this, TQT_SLOT(addCurlyBracket()),
+                                    this, TQ_SLOT(addCurlyBracket()),
                                     collection,"formula_addcurbra");
     m_addAbsAction      = new TDEAction(i18n("Add Abs"),
                                     "abs",
                                     0,
-                                    this, TQT_SLOT(addLineBracket()),
+                                    this, TQ_SLOT(addLineBracket()),
                                     collection,"formula_addabsbra");
 
     m_addMatrixAction   = new TDEAction(i18n("Add Matrix..."),
                                     "matrix",
                                     0,
-                                    this, TQT_SLOT(addMatrix()),
+                                    this, TQ_SLOT(addMatrix()),
                                     collection, "formula_addmatrix");
 
     m_addOneByTwoMatrixAction   = new TDEAction(i18n("Add 1x2 Matrix"),
                                     "onetwomatrix",
                                     0,
-                                    this, TQT_SLOT(addOneByTwoMatrix()),
+                                    this, TQ_SLOT(addOneByTwoMatrix()),
                                     collection, "formula_add_one_by_two_matrix");
 
 
     m_addUpperLeftAction  = new TDEAction(i18n("Add Upper Left Index"),
                                       "lsup",
                                       0,
-                                      this, TQT_SLOT(addUpperLeftIndex()),
+                                      this, TQ_SLOT(addUpperLeftIndex()),
                                       collection, "formula_addupperleft");
     m_addLowerLeftAction  = new TDEAction(i18n("Add Lower Left Index"),
                                       "lsub",
                                       0,
-                                      this, TQT_SLOT(addLowerLeftIndex()),
+                                      this, TQ_SLOT(addLowerLeftIndex()),
                                       collection, "formula_addlowerleft");
     m_addUpperRightAction = new TDEAction(i18n("Add Upper Right Index"),
                                       "rsup",
                                       0,
-                                      this, TQT_SLOT(addUpperRightIndex()),
+                                      this, TQ_SLOT(addUpperRightIndex()),
                                       collection, "formula_addupperright");
     m_addLowerRightAction = new TDEAction(i18n("Add Lower Right Index"),
                                       "rsub",
                                       0,
-                                      this, TQT_SLOT(addLowerRightIndex()),
+                                      this, TQ_SLOT(addLowerRightIndex()),
                                       collection, "formula_addlowerright");
 
     m_addGenericUpperAction = new TDEAction(i18n("Add Upper Index"),
                                       "gsup",
                                               /*CTRL + Key_U*/0,
-                                      this, TQT_SLOT(addGenericUpperIndex()),
+                                      this, TQ_SLOT(addGenericUpperIndex()),
                                       collection, "formula_addupperindex");
     m_addGenericLowerAction = new TDEAction(i18n("Add Lower Index"),
                                       "gsub",
                                       0,
-                                      this, TQT_SLOT(addGenericLowerIndex()),
+                                      this, TQ_SLOT(addGenericLowerIndex()),
                                       collection, "formula_addlowerindex");
 
     m_addOverlineAction = new TDEAction(i18n("Add Overline"),
                                           "over",
                                           0,
-                                          this, TQT_SLOT(addOverline()),
+                                          this, TQ_SLOT(addOverline()),
                                           collection, "formula_addoverline");
     m_addUnderlineAction = new TDEAction(i18n("Add Underline"),
                                            "under",
                                            0,
-                                           this, TQT_SLOT(addUnderline()),
+                                           this, TQ_SLOT(addUnderline()),
                                            collection, "formula_addunderline");
 
     m_addMultilineAction = new TDEAction(i18n("Add Multiline"),
                                            "multiline",
                                            0,
-                                           this, TQT_SLOT(addMultiline()),
+                                           this, TQ_SLOT(addMultiline()),
                                            collection, "formula_addmultiline");
 
     m_removeEnclosingAction = new TDEAction(i18n("Remove Enclosing Element"),
                                         0,
-                                        this, TQT_SLOT(removeEnclosing()),
+                                        this, TQ_SLOT(removeEnclosing()),
                                         collection, "formula_removeenclosing");
 
     m_makeGreekAction = new TDEAction(i18n("Convert to Greek"),
                                   0,
-                                  this, TQT_SLOT(makeGreek()),
+                                  this, TQ_SLOT(makeGreek()),
                                   collection, "formula_makegreek");
 
     m_appendColumnAction = new TDEAction( i18n( "Append Column" ),
                                             "inscol",
                                             0,
-                                            this, TQT_SLOT( appendColumn() ),
+                                            this, TQ_SLOT( appendColumn() ),
                                             collection, "formula_appendcolumn" );
     m_insertColumnAction = new TDEAction( i18n( "Insert Column" ),
                                             "inscol",
                                             0,
-                                            this, TQT_SLOT( insertColumn() ),
+                                            this, TQ_SLOT( insertColumn() ),
                                             collection, "formula_insertcolumn" );
     m_removeColumnAction = new TDEAction( i18n( "Remove Column" ),
                                             "remcol",
                                             0,
-                                            this, TQT_SLOT( removeColumn() ),
+                                            this, TQ_SLOT( removeColumn() ),
                                             collection, "formula_removecolumn" );
     m_appendRowAction = new TDEAction( i18n( "Append Row" ),
                                          "insrow",
                                          0,
-                                         this, TQT_SLOT( appendRow() ),
+                                         this, TQ_SLOT( appendRow() ),
                                          collection, "formula_appendrow" );
     m_insertRowAction = new TDEAction( i18n( "Insert Row" ),
                                          "insrow",
                                          0,
-                                         this, TQT_SLOT( insertRow() ),
+                                         this, TQ_SLOT( insertRow() ),
                                          collection, "formula_insertrow" );
     m_removeRowAction = new TDEAction( i18n( "Remove Row" ),
                                          "remrow",
                                          0,
-                                         this, TQT_SLOT( removeRow() ),
+                                         this, TQ_SLOT( removeRow() ),
                                          collection, "formula_removerow" );
 
     m_syntaxHighlightingAction = new TDEToggleAction(i18n("Syntax Highlighting"),
                                                  0,
-                                                 this, TQT_SLOT(toggleSyntaxHighlighting()),
+                                                 this, TQ_SLOT(toggleSyntaxHighlighting()),
                                                  collection, "formula_syntaxhighlighting");
     //m_syntaxHighlightingAction->setChecked( m_contextStyle->syntaxHighlighting() );
 
     m_formatBoldAction = new TDEToggleAction( i18n( "&Bold" ), "format-text-bold",
                                                 0, //CTRL + Key_B,
-                                                this, TQT_SLOT( textBold() ),
+                                                this, TQ_SLOT( textBold() ),
                                                 collection, "formula_format_bold" );
     m_formatItalicAction = new TDEToggleAction( i18n( "&Italic" ), "format-text-italic",
                                                   0, //CTRL + Key_I,
-                                                  this, TQT_SLOT( textItalic() ),
+                                                  this, TQ_SLOT( textItalic() ),
                                                   collection, "formula_format_italic" );
     m_formatBoldAction->setEnabled( false );
     m_formatItalicAction->setEnabled( false );
@@ -641,7 +641,7 @@ void DocumentWrapper::createActions( TDEActionCollection* collection )
     delimiter.append(TQString("}"));
     delimiter.append(TQString(">"));
     m_leftBracket = new TDESelectAction(i18n("Left Delimiter"),
-                                    0, this, TQT_SLOT(delimiterLeft()),
+                                    0, this, TQ_SLOT(delimiterLeft()),
                                     collection, "formula_typeleft");
     m_leftBracket->setItems(delimiter);
     //leftBracket->setCurrentItem(0);
@@ -660,7 +660,7 @@ void DocumentWrapper::createActions( TDEActionCollection* collection )
     delimiter.append(TQString("{"));
     delimiter.append(TQString("<"));
     m_rightBracket = new TDESelectAction(i18n("Right Delimiter"),
-                                     0, this, TQT_SLOT(delimiterRight()),
+                                     0, this, TQ_SLOT(delimiterRight()),
                                      collection, "formula_typeright");
     m_rightBracket->setItems(delimiter);
     //rightBracket->setCurrentItem(0);
@@ -668,10 +668,10 @@ void DocumentWrapper::createActions( TDEActionCollection* collection )
     m_insertSymbolAction = new TDEAction(i18n("Insert Symbol"),
                                            "key_enter",
                                            /*CTRL + Key_I*/0,
-                                           this, TQT_SLOT(insertSymbol()),
+                                           this, TQ_SLOT(insertSymbol()),
                                            collection, "formula_insertsymbol");
     m_symbolNamesAction = new SymbolAction(i18n("Symbol Names"),
-                                               0, this, TQT_SLOT(symbolNames()),
+                                               0, this, TQ_SLOT(symbolNames()),
                                                collection, "formula_symbolnames");
 
     TQStringList ff;
@@ -680,7 +680,7 @@ void DocumentWrapper::createActions( TDEActionCollection* collection )
     ff.append( i18n( "Fraktur" ) );
     ff.append( i18n( "Double Struck" ) );
     m_fontFamily = new TDESelectAction(i18n("Font Family"),
-                                         0, this, TQT_SLOT(fontFamily()),
+                                         0, this, TQ_SLOT(fontFamily()),
                                          collection, "formula_fontfamily");
     m_fontFamily->setItems( ff );
     m_fontFamily->setEnabled( false );
@@ -691,7 +691,7 @@ void DocumentWrapper::createActions( TDEActionCollection* collection )
     et.append( i18n( "Number" ) );
     et.append( i18n( "Text" ) );
     m_tokenElement = new TDESelectAction( i18n( "Token Type" ),
-                                     0, this, TQT_SLOT( tokenElement() ),
+                                     0, this, TQ_SLOT( tokenElement() ),
                                      collection, "formula_tokenelement" );
     m_tokenElement->setItems( et );
 //    m_tokenElements->setEnabled( true );
