@@ -36,7 +36,7 @@ class MathML2KFormulaPrivate;
  */
 class MathML2KFormula : public KFInputFilter
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
     friend class MathML2KFormulaPrivate;
