@@ -48,7 +48,7 @@ class Container;
  * is to be drawn into.
  */
 class KOFORMULA_EXPORT View : public TQObject {
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
