@@ -42,7 +42,7 @@ class KoPartMoveHandlerPrivate;
  */
 class KOFFICECORE_EXPORT KoEventHandler : public TQObject
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     KoEventHandler( TQObject* target );
@@ -60,7 +60,7 @@ private:
  */
 class KoPartResizeHandler : public KoEventHandler
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     KoPartResizeHandler( TQWidget* widget, const TQWMatrix& matrix, KoView* view, KoChild* child,
@@ -81,7 +81,7 @@ private:
  */
 class KoPartMoveHandler : public KoEventHandler
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     KoPartMoveHandler( TQWidget* widget, const TQWMatrix& matrix, KoView* view, KoChild* child,
@@ -111,7 +111,7 @@ private:
  */
 class KOFFICECORE_EXPORT KoContainerHandler : public KoEventHandler
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     KoContainerHandler( KoView* view, TQWidget* widget );
