@@ -42,7 +42,7 @@ class KoXmlWriter;
  */
 class KOFFICECORE_EXPORT KoDocumentChild : public KoChild
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 public:
   KoDocumentChild( KoDocument* parent, KoDocument* doc, const TQRect& geometry );
