@@ -682,14 +682,14 @@ bool KoDocumentInfoAbout::saveOasis( KoXmlWriter &xmlWriter )
     if ( m_creationDate.isValid() )
     {
         xmlWriter.startElement( "meta:creation-date" );
-        xmlWriter.addTextNode( m_creationDate.toString( Qt::ISODate ) );
+        xmlWriter.addTextNode( m_creationDate.toString( TQt::ISODate ) );
         xmlWriter.endElement();
     }
 
     if ( m_modificationDate.isValid() )
     {
         xmlWriter.startElement( "dc:date" );
-        xmlWriter.addTextNode( m_modificationDate.toString( Qt::ISODate ) );
+        xmlWriter.addTextNode( m_modificationDate.toString( TQt::ISODate ) );
         xmlWriter.endElement();
     }
     return true;
@@ -729,13 +729,13 @@ bool KoDocumentInfoAbout::loadOasis( const TQDomNode& metaDoc )
 
     e  = KoDom::namedItemNS( metaDoc, KoXmlNS::meta, "creation-date" );
     if ( !e.isNull() && !e.text().isEmpty() )
-        m_creationDate = TQDateTime::fromString( e.text(), Qt::ISODate );
+        m_creationDate = TQDateTime::fromString( e.text(), TQt::ISODate );
     else
         m_creationDate = TQDateTime();
 
     e  = KoDom::namedItemNS( metaDoc, KoXmlNS::dc, "date"  );
     if ( !e.isNull() && !e.text().isEmpty() )
-        m_modificationDate = TQDateTime::fromString( e.text(), Qt::ISODate );
+        m_modificationDate = TQDateTime::fromString( e.text(), TQt::ISODate );
     return true;
 }
 
@@ -760,9 +760,9 @@ bool KoDocumentInfoAbout::load( const TQDomElement& e )
         else if ( e.tagName() == "editing-cycles" )
             m_editingCycles = e.text().toInt();
         else if ( e.tagName() == "creation-date" )
-            m_creationDate = TQDateTime::fromString( e.text(), Qt::ISODate );
+            m_creationDate = TQDateTime::fromString( e.text(), TQt::ISODate );
         else if ( e.tagName() == "date" )
-            m_modificationDate = TQDateTime::fromString( e.text(), Qt::ISODate );
+            m_modificationDate = TQDateTime::fromString( e.text(), TQt::ISODate );
     }
 
     return true;
@@ -800,11 +800,11 @@ TQDomElement KoDocumentInfoAbout::save( TQDomDocument& doc )
 
     t = doc.createElement( "creation-date" );
     e.appendChild( t );
-    t.appendChild( doc.createTextNode( m_creationDate.toString( Qt::ISODate ) ) );
+    t.appendChild( doc.createTextNode( m_creationDate.toString( TQt::ISODate ) ) );
 
     t = doc.createElement( "date" );
     e.appendChild( t );
-    t.appendChild( doc.createTextNode( m_modificationDate.toString( Qt::ISODate ) ) );
+    t.appendChild( doc.createTextNode( m_modificationDate.toString( TQt::ISODate ) ) );
     return e;
 }
 
