@@ -38,7 +38,7 @@ class KoXmlWriter;
 
 class KOFFICECORE_EXPORT KoDocumentInfo : public TQObject
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     KoDocumentInfo( TQObject* parent = 0, const char* name = 0 );
@@ -77,7 +77,7 @@ public:
 
 class KOFFICECORE_EXPORT KoDocumentInfoAuthor : public KoDocumentInfoPage
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     KoDocumentInfoAuthor( KoDocumentInfo* info );
@@ -136,7 +136,7 @@ private:
 
 class KOFFICECORE_EXPORT KoDocumentInfoAbout : public KoDocumentInfoPage
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     KoDocumentInfoAbout( KoDocumentInfo* info );
@@ -180,7 +180,7 @@ private:
 
 class KOFFICECORE_EXPORT KoDocumentInfoUserMetadata : public KoDocumentInfoPage
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     KoDocumentInfoUserMetadata( KoDocumentInfo* info );
