@@ -34,7 +34,7 @@ class KArchiveEntry;
 
 class KOFFICECORE_EXPORT KoDocumentInfoDlg : public TQObject
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 public:
   KoDocumentInfoDlg( KoDocumentInfo *docInfo, TQWidget *parent = 0, const char *name = 0,
@@ -69,7 +69,7 @@ private:
 
 class KOFFICECORE_EXPORT KoDocumentInfoPropsPage : public KPropsDlgPlugin
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 public:
   KoDocumentInfoPropsPage( KPropertiesDialog *props, const char *name = 0,
