@@ -29,7 +29,7 @@ class KoDocument;
  */
 class KoBrowserExtension : public KParts::BrowserExtension
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     KoBrowserExtension( KoDocument * doc, const char * name = 0 );
