@@ -71,7 +71,7 @@ int KoEmbeddingFilter::embedPart( const TQCString& from, TQCString& to,
 
     KTempFile tempIn;
     tempIn.setAutoDelete( true );
-    savePartContents( TQT_TQIODEVICE(tempIn.file()) );
+    savePartContents( tempIn.file() );
     tempIn.file()->close();
 
     KoFilterManager *manager = new KoFilterManager( tempIn.name(), from, m_chain );
