@@ -89,7 +89,7 @@ KoFilterChooser::KoFilterChooser (TQWidget *parent, const TQStringList &mimeType
     m_filterList->centerCurrentItem ();
     m_filterList->setFocus ();
 
-    connect (m_filterList, TQT_SIGNAL (selected (int)), this, TQT_SLOT (slotOk ()));
+    connect (m_filterList, TQ_SIGNAL (selected (int)), this, TQ_SLOT (slotOk ()));
 }
 
 KoFilterChooser::~KoFilterChooser ()
@@ -119,8 +119,8 @@ KoFilterManager::KoFilterManager( KoDocument* document ) :
     d = new KoFilterManager::Private;
     d -> m_batch = false;
     if ( document )
-        TQObject::connect( this, TQT_SIGNAL( sigProgress( int ) ),
-                          document, TQT_SIGNAL( sigProgress( int ) ) );
+        TQObject::connect( this, TQ_SIGNAL( sigProgress( int ) ),
+                          document, TQ_SIGNAL( sigProgress( int ) ) );
 }
 
 
@@ -493,7 +493,7 @@ TQStringList KoFilterManager::mimeFilter( const TQCString& mimetype, Direction d
         const TQStringList outMimes = connected( vertices, (*natit).latin1() );
         //kdDebug(s_area) << k_funcinfo << "output formats connected to mime " << *natit << " : " << outMimes << endl;
         for ( TQStringList::ConstIterator mit = outMimes.begin(); mit != outMimes.end(); ++mit )
-            if ( lst.find( *mit ) == lst.end() ) // append only if not there already. TQt4: TQSet<TQString>?
+            if ( lst.find( *mit ) == lst.end() ) // append only if not there already.
                 lst.append( *mit );
     }
     return lst;
