@@ -43,7 +43,7 @@ class KoDocument;
  */
 class KOFFICECORE_EXPORT KoFilterManager : public TQObject
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     /**
