@@ -362,7 +362,7 @@ void KoFrame::resizeEvent( TQResizeEvent* )
 
 bool KoFrame::eventFilter( TQObject* obj, TQEvent* ev )
 {
-  if ( TQT_BASE_OBJECT(obj) == TQT_BASE_OBJECT(d->m_view) && KParts::PartActivateEvent::test( ev ) )
+  if ( obj == d->m_view && KParts::PartActivateEvent::test( ev ) )
   {
     kdDebug(30003) << "Activate event"<< endl;
     KParts::PartActivateEvent* e = (KParts::PartActivateEvent*)ev;
@@ -374,7 +374,7 @@ bool KoFrame::eventFilter( TQObject* obj, TQEvent* ev )
 	setState( Inactive );
     }
   }
-  else if ( TQT_BASE_OBJECT(obj) == TQT_BASE_OBJECT(d->m_view) && KParts::PartSelectEvent::test( ev ) )
+  else if ( obj == d->m_view && KParts::PartSelectEvent::test( ev ) )
   {
     kdDebug(30003) << "Selected event" << endl;
     KParts::PartSelectEvent* e = (KParts::PartSelectEvent*)ev;
