@@ -664,7 +664,7 @@ TQString KoOasisStyles::saveOasisTimeStyle( KoGenStyles &mainStyles, const TQStr
     KoGenStyle currentStyle( KoGenStyle::STYLE_NUMERIC_TIME );
     TQBuffer buffer;
     buffer.open( IO_WriteOnly );
-    KoXmlWriter elementWriter( TQT_TQIODEVICE(&buffer) );  // TODO pass indentation level
+    KoXmlWriter elementWriter( &buffer );  // TODO pass indentation level
     TQString text;
     if ( klocaleFormat )
     {
@@ -819,7 +819,7 @@ TQString KoOasisStyles::saveOasisDateStyle( KoGenStyles &mainStyles, const TQStr
     KoGenStyle currentStyle( KoGenStyle::STYLE_NUMERIC_DATE );
     TQBuffer buffer;
     buffer.open( IO_WriteOnly );
-    KoXmlWriter elementWriter( TQT_TQIODEVICE(&buffer) );  // TODO pass indentation level
+    KoXmlWriter elementWriter( &buffer );  // TODO pass indentation level
     TQString text;
     if ( klocaleFormat )
     {
@@ -993,7 +993,7 @@ TQString KoOasisStyles::saveOasisFractionStyle( KoGenStyles &mainStyles, const T
     KoGenStyle currentStyle( KoGenStyle::STYLE_NUMERIC_FRACTION );
     TQBuffer buffer;
     buffer.open( IO_WriteOnly );
-    KoXmlWriter elementWriter( TQT_TQIODEVICE(&buffer) );  // TODO pass indentation level
+    KoXmlWriter elementWriter( &buffer );  // TODO pass indentation level
     TQString text;
     int integer = 0;
     int numerator = 0;
@@ -1057,7 +1057,7 @@ TQString KoOasisStyles::saveOasisNumberStyle( KoGenStyles &mainStyles, const TQS
     KoGenStyle currentStyle( KoGenStyle::STYLE_NUMERIC_NUMBER );
     TQBuffer buffer;
     buffer.open( IO_WriteOnly );
-    KoXmlWriter elementWriter( TQT_TQIODEVICE(&buffer) );  // TODO pass indentation level
+    KoXmlWriter elementWriter( &buffer );  // TODO pass indentation level
     TQString text;
     int decimalplaces = 0;
     int integerdigits = 0;
@@ -1106,7 +1106,7 @@ TQString KoOasisStyles::saveOasisPercentageStyle( KoGenStyles &mainStyles, const
     KoGenStyle currentStyle( KoGenStyle::STYLE_NUMERIC_PERCENTAGE );
     TQBuffer buffer;
     buffer.open( IO_WriteOnly );
-    KoXmlWriter elementWriter( TQT_TQIODEVICE(&buffer) );  // TODO pass indentation level
+    KoXmlWriter elementWriter( &buffer );  // TODO pass indentation level
     TQString text;
     int decimalplaces = 0;
     int integerdigits = 0;
@@ -1160,7 +1160,7 @@ TQString KoOasisStyles::saveOasisScientificStyle( KoGenStyles &mainStyles, const
     int decimalplace = 0;
     int integerdigits = 0;
     int exponentdigits = 0;
-    KoXmlWriter elementWriter( TQT_TQIODEVICE(&buffer) );  // TODO pass indentation level
+    KoXmlWriter elementWriter( &buffer );  // TODO pass indentation level
     TQString text;
     bool beforeSeparator = true;
     bool exponential = false;
@@ -1236,7 +1236,7 @@ TQString KoOasisStyles::saveOasisCurrencyStyle( KoGenStyles &mainStyles,
     KoGenStyle currentStyle( KoGenStyle::STYLE_NUMERIC_CURRENCY );
     TQBuffer buffer;
     buffer.open( IO_WriteOnly );
-    KoXmlWriter elementWriter( TQT_TQIODEVICE(&buffer) );  // TODO pass indentation level
+    KoXmlWriter elementWriter( &buffer );  // TODO pass indentation level
     TQString text;
     int decimalplaces = 0;
     int integerdigits = 0;
@@ -1292,7 +1292,7 @@ TQString KoOasisStyles::saveOasisTextStyle( KoGenStyles &mainStyles, const TQStr
     KoGenStyle currentStyle( KoGenStyle::STYLE_NUMERIC_TEXT );
     TQBuffer buffer;
     buffer.open( IO_WriteOnly );
-    KoXmlWriter elementWriter( TQT_TQIODEVICE(&buffer) );  // TODO pass indentation level
+    KoXmlWriter elementWriter( &buffer );  // TODO pass indentation level
     TQString text;
     do
     {
@@ -1431,7 +1431,7 @@ TQBrush KoOasisStyles::loadOasisFillStyle( const KoStyleStack &styleStack, const
     TQBrush tmpBrush;
     if ( fill == "solid" )
     {
-        tmpBrush.setStyle(static_cast<Qt::BrushStyle>( 1 ) );
+        tmpBrush.setStyle(static_cast<TQt::BrushStyle>( 1 ) );
         if ( styleStack.hasAttributeNS( KoXmlNS::draw, "fill-color" ) )
             tmpBrush.setColor(styleStack.attributeNS( KoXmlNS::draw, "fill-color" ) );
         if ( styleStack.hasAttributeNS( KoXmlNS::draw, "transparency" ) )
@@ -1439,35 +1439,35 @@ TQBrush KoOasisStyles::loadOasisFillStyle( const KoStyleStack &styleStack, const
             TQString transparency = styleStack.attributeNS( KoXmlNS::draw, "transparency" );
             if ( transparency == "94%" )
             {
-                tmpBrush.setStyle(Qt::Dense1Pattern);
+                tmpBrush.setStyle(TQt::Dense1Pattern);
             }
             else if ( transparency == "88%" )
             {
-                tmpBrush.setStyle(Qt::Dense2Pattern);
+                tmpBrush.setStyle(TQt::Dense2Pattern);
             }
             else if ( transparency == "63%" )
             {
-                tmpBrush.setStyle(Qt::Dense3Pattern);
+                tmpBrush.setStyle(TQt::Dense3Pattern);
 
             }
             else if ( transparency == "50%" )
             {
-                tmpBrush.setStyle(Qt::Dense4Pattern);
+                tmpBrush.setStyle(TQt::Dense4Pattern);
 
             }
             else if ( transparency == "37%" )
             {
-                tmpBrush.setStyle(Qt::Dense5Pattern);
+                tmpBrush.setStyle(TQt::Dense5Pattern);
 
             }
             else if ( transparency == "12%" )
             {
-                tmpBrush.setStyle(Qt::Dense6Pattern);
+                tmpBrush.setStyle(TQt::Dense6Pattern);
 
             }
             else if ( transparency == "6%" )
             {
-                tmpBrush.setStyle(Qt::Dense7Pattern);
+                tmpBrush.setStyle(TQt::Dense7Pattern);
 
             }
             else
@@ -1514,19 +1514,19 @@ TQBrush KoOasisStyles::loadOasisFillStyle( const KoStyleStack &styleStack, const
                     {
                     case 0:
                     case 180:
-                        tmpBrush.setStyle(Qt::HorPattern );
+                        tmpBrush.setStyle(TQt::HorPattern );
                         break;
                     case 45:
                     case 225:
-                        tmpBrush.setStyle(Qt::BDiagPattern );
+                        tmpBrush.setStyle(TQt::BDiagPattern );
                         break;
                     case 90:
                     case 270:
-                        tmpBrush.setStyle(Qt::VerPattern );
+                        tmpBrush.setStyle(TQt::VerPattern );
                         break;
                     case 135:
                     case 315:
-                        tmpBrush.setStyle(Qt::FDiagPattern );
+                        tmpBrush.setStyle(TQt::FDiagPattern );
                         break;
                     default:
                         //todo fixme when we will have a kopaint
@@ -1542,13 +1542,13 @@ TQBrush KoOasisStyles::loadOasisFillStyle( const KoStyleStack &styleStack, const
                     case 180:
                     case 90:
                     case 270:
-                        tmpBrush.setStyle(Qt::CrossPattern );
+                        tmpBrush.setStyle(TQt::CrossPattern );
                         break;
                     case 45:
                     case 135:
                     case 225:
                     case 315:
-                        tmpBrush.setStyle(Qt::DiagCrossPattern );
+                        tmpBrush.setStyle(TQt::DiagCrossPattern );
                         break;
                     default:
                         //todo fixme when we will have a kopaint
