@@ -28,13 +28,13 @@
 #ifdef TQ_WS_WIN
 
 /* workaround for KDElibs < 3.2 on !win32 */
-#ifndef KDE_EXPORT
-# define KDE_EXPORT
+#ifndef TDE_EXPORT
+# define TDE_EXPORT
 #endif
 
 #ifndef KOFFICECORE_EXPORT
 # ifdef MAKE_KOFFICECORE_LIB
-#  define KOFFICECORE_EXPORT KDE_EXPORT
+#  define KOFFICECORE_EXPORT TDE_EXPORT
 # elif KDE_MAKE_LIB
 #  define KOFFICECORE_EXPORT KDE_IMPORT
 # else
@@ -44,7 +44,7 @@
 
 #ifndef KOFFICEUI_EXPORT
 # ifdef MAKE_KOFFICEUI_LIB
-#  define KOFFICEUI_EXPORT KDE_EXPORT
+#  define KOFFICEUI_EXPORT TDE_EXPORT
 # elif KDE_MAKE_LIB
 #  define KOFFICEUI_EXPORT KDE_IMPORT
 # else
@@ -53,7 +53,7 @@
 #endif
 
 #ifdef MAKE_KOSTORE_LIB
-# define KOSTORE_EXPORT KDE_EXPORT
+# define KOSTORE_EXPORT TDE_EXPORT
 #elif KDE_MAKE_LIB
 # define KOSTORE_EXPORT KDE_IMPORT
 #else
@@ -61,7 +61,7 @@
 #endif
 
 #ifdef MAKE_KOPALETTE_LIB
-# define KOPALETTE_EXPORT KDE_EXPORT
+# define KOPALETTE_EXPORT TDE_EXPORT
 #elif KDE_MAKE_LIB
 # define KOPALETTE_EXPORT KDE_IMPORT
 #else
@@ -69,7 +69,7 @@
 #endif
 
 #ifdef MAKE_KOWMF_LIB
-# define KOWMF_EXPORT KDE_EXPORT
+# define KOWMF_EXPORT TDE_EXPORT
 #elif KDE_MAKE_LIB
 # define KOWMF_EXPORT KDE_IMPORT
 #else
@@ -77,7 +77,7 @@
 #endif
 
 #ifdef MAKE_KWMF_LIB
-# define KWMF_EXPORT KDE_EXPORT
+# define KWMF_EXPORT TDE_EXPORT
 #elif KDE_MAKE_LIB
 # define KWMF_EXPORT KDE_IMPORT
 #else
@@ -85,7 +85,7 @@
 #endif
 
 #ifdef MAKE_KOTEXT_LIB
-# define KOTEXT_EXPORT KDE_EXPORT
+# define KOTEXT_EXPORT TDE_EXPORT
 #elif KDE_MAKE_LIB
 # define KOTEXT_EXPORT KDE_IMPORT
 #else
@@ -93,7 +93,7 @@
 #endif
 
 #ifdef MAKE_KOFORMULA_LIB
-# define KOFORMULA_EXPORT KDE_EXPORT
+# define KOFORMULA_EXPORT TDE_EXPORT
 #elif KDE_MAKE_LIB
 # define KOFORMULA_EXPORT KDE_IMPORT
 #else
@@ -101,7 +101,7 @@
 #endif
 
 #ifdef MAKE_KOPAINTER_LIB
-# define KOPAINTER_EXPORT KDE_EXPORT
+# define KOPAINTER_EXPORT TDE_EXPORT
 #elif KDE_MAKE_LIB
 # define KOPAINTER_EXPORT KDE_IMPORT
 #else
@@ -109,7 +109,7 @@
 #endif
 
 #ifdef MAKE_KWORD_LIB
-# define KWORD_EXPORT KDE_EXPORT
+# define KWORD_EXPORT TDE_EXPORT
 #elif KDE_MAKE_LIB
 # define KWORD_EXPORT KDE_IMPORT
 #else
@@ -117,7 +117,7 @@
 #endif
 
 #ifdef MAKE_KWMAILMERGE_LIB
-# define KWMAILMERGE_EXPORT KDE_EXPORT
+# define KWMAILMERGE_EXPORT TDE_EXPORT
 #elif KDE_MAKE_LIB
 # define KWMAILMERGE_EXPORT KDE_IMPORT
 #else
@@ -126,7 +126,7 @@
 
 #ifndef KOPROPERTY_EXPORT
 # ifdef MAKE_KOPROPERTY_LIB
-#  define KOPROPERTY_EXPORT KDE_EXPORT
+#  define KOPROPERTY_EXPORT TDE_EXPORT
 # elif KDE_MAKE_LIB
 #  define KOPROPERTY_EXPORT KDE_IMPORT
 # else
@@ -134,33 +134,33 @@
 # endif
 #endif
 
-#define KPRESENTER_EXPORT KDE_EXPORT
-#define KCHART_EXPORT KDE_EXPORT
-#define KDCHART_EXPORT KDE_EXPORT
-#define KARBONCOMMON_EXPORT KDE_EXPORT
-#define KARBONBASE_EXPORT KDE_EXPORT
-#define KARBONCOMMAND_EXPORT KDE_EXPORT
-#define KSPREAD_EXPORT KDE_EXPORT
-#define KOSHELL_EXPORT KDE_EXPORT
-#define KPLATO_EXPORT KDE_EXPORT
-#define KPLATOCHART_EXPORT KDE_EXPORT
-#define KUGAR_EXPORT KDE_EXPORT
-#define KUGARDESIGNER_EXPORT KDE_EXPORT
-#define KOFFICETOOLS_EXPORT KDE_EXPORT
-#define KOFFICEFILTER_EXPORT KDE_EXPORT
-#define KOCHARTINTERFACE_EXPORT KDE_EXPORT
-#define KIVIOPLUGINS_EXPORT KDE_EXPORT
-#define KIVIO_EXPORT KDE_EXPORT
-#define KRITA_EXPORT KDE_EXPORT
-#define KRITAUI_EXPORT KDE_EXPORT
-#define KRITACORE_EXPORT KDE_EXPORT
-#define KRITATOOL_EXPORT KDE_EXPORT
-#define KRITAPAINT_EXPORT KDE_EXPORT
-#define EXAMPLE_EXPORT KDE_EXPORT
+#define KPRESENTER_EXPORT TDE_EXPORT
+#define KCHART_EXPORT TDE_EXPORT
+#define KDCHART_EXPORT TDE_EXPORT
+#define KARBONCOMMON_EXPORT TDE_EXPORT
+#define KARBONBASE_EXPORT TDE_EXPORT
+#define KARBONCOMMAND_EXPORT TDE_EXPORT
+#define KSPREAD_EXPORT TDE_EXPORT
+#define KOSHELL_EXPORT TDE_EXPORT
+#define KPLATO_EXPORT TDE_EXPORT
+#define KPLATOCHART_EXPORT TDE_EXPORT
+#define KUGAR_EXPORT TDE_EXPORT
+#define KUGARDESIGNER_EXPORT TDE_EXPORT
+#define KOFFICETOOLS_EXPORT TDE_EXPORT
+#define KOFFICEFILTER_EXPORT TDE_EXPORT
+#define KOCHARTINTERFACE_EXPORT TDE_EXPORT
+#define KIVIOPLUGINS_EXPORT TDE_EXPORT
+#define KIVIO_EXPORT TDE_EXPORT
+#define KRITA_EXPORT TDE_EXPORT
+#define KRITAUI_EXPORT TDE_EXPORT
+#define KRITACORE_EXPORT TDE_EXPORT
+#define KRITATOOL_EXPORT TDE_EXPORT
+#define KRITAPAINT_EXPORT TDE_EXPORT
+#define EXAMPLE_EXPORT TDE_EXPORT
 #else // not windows
 
 #if TDE_VERSION >= TDE_MAKE_VERSION(3,3,90)
-#define KOFFICE_EXPORT KDE_EXPORT
+#define KOFFICE_EXPORT TDE_EXPORT
 #else
 #define KOFFICE_EXPORT
 #endif
