@@ -19,7 +19,7 @@
 
 #include <KoFilterChain.h>
 #include <KoFilterManager.h>
-#include <kinstance.h>
+#include <tdeinstance.h>
 #include <kdebug.h>
 
 int main( int /*argc*/, char ** /*argv*/ )
