@@ -29,7 +29,7 @@ class TQCheckBox;
 
 class KOFFICEUI_EXPORT KoEditPathDia : public KDialogBase
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     KoEditPathDia( const TQString & _path, TQWidget *parent, const char *name );
@@ -42,7 +42,7 @@ private:
 
 class KOFFICEUI_EXPORT KoChangePathDia : public KDialogBase
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     KoChangePathDia( const TQString & _path, TQWidget *parent, const char *name );
