@@ -78,7 +78,7 @@ public:
      *
      * @return the orientation of the added guide line
      */
-    Qt::Orientation orientation() const;
+    TQt::Orientation orientation() const;
 
 protected slots:
     void slotOrientationChanged();
