@@ -79,7 +79,7 @@ const int KoRuler::F_HELPLINES = 4;
 const int KoRuler::F_NORESIZE = 8;
 
 /*================================================================*/
-KoRuler::KoRuler( TQWidget *_parent, TQWidget *_canvas, Qt::Orientation _orientation,
+KoRuler::KoRuler( TQWidget *_parent, TQWidget *_canvas, TQt::Orientation _orientation,
                  const KoPageLayout& _layout, int _flags, KoUnit::Unit _unit, KoTabChooser *_tabChooser )
     : TQFrame( _parent ), buffer( width(), height() ), m_zoom(1.0), m_1_zoom(1.0),
       m_unit( _unit )
@@ -124,7 +124,7 @@ KoRuler::KoRuler( TQWidget *_parent, TQWidget *_canvas, Qt::Orientation _orienta
     d->currTab.type = T_INVALID;
 
     d->removeTab.type = T_INVALID;
-    if ( orientation == Qt::Horizontal ) {
+    if ( orientation == TQt::Horizontal ) {
         frameStart = tqRound( zoomIt(d->layout.ptLeft) );
         d->frameEnd = tqRound( zoomIt(d->layout.ptWidth - d->layout.ptRight) );
     } else {
@@ -136,7 +136,7 @@ KoRuler::KoRuler( TQWidget *_parent, TQWidget *_canvas, Qt::Orientation _orienta
     setupMenu();
 
     // For compatibility, emitting doubleClicked shall emit openPageLayoutDia
-    connect( this, TQT_SIGNAL( doubleClicked() ), this, TQT_SIGNAL( openPageLayoutDia() ) );
+    connect( this, TQ_SIGNAL( doubleClicked() ), this, TQ_SIGNAL( openPageLayoutDia() ) );
 }
 
 /*================================================================*/
@@ -159,7 +159,7 @@ void KoRuler::setMousePos( int mx, int my )
     TQPainter p( this );
     p.setRasterOp( TQt::NotROP );
 
-    if ( orientation == Qt::Horizontal ) {
+    if ( orientation == TQt::Horizontal ) {
         if ( hasToDelete )
             p.drawLine( mposX, 1, mposX, height() - 1 );
         p.drawLine( mx, 1, mx, height() - 1 );
@@ -486,7 +486,7 @@ void KoRuler::mousePressEvent( TQMouseEvent *e )
     d->removeTab.type = T_INVALID;
 
     switch ( e->button() ) {
-    case Qt::RightButton:
+    case TQt::RightButton:
         if(d->currTab.type == T_INVALID || !(d->flags & F_TABS))
             d->rb_menu->setItemEnabled(d->mRemoveTab, false);
         else
@@ -495,11 +495,11 @@ void KoRuler::mousePressEvent( TQMouseEvent *e )
         d->action = A_NONE;
         d->mousePressed = false;
         return;
-    case Qt::MidButton:
+    case TQt::MidButton:
         // MMB shall do like double-click (it opens a dialog).
         handleDoubleClick();
         return;
-    case Qt::LeftButton:
+    case TQt::LeftButton:
         if ( d->action == A_BR_RIGHT || d->action == A_BR_LEFT ) {
             if ( d->action == A_BR_RIGHT )
                 d->whileMovingBorderRight = true;
@@ -571,7 +571,7 @@ void KoRuler::mousePressEvent( TQMouseEvent *e )
         }
         else if ( d->flags & F_HELPLINES )
         {
-	    setCursor( orientation == Qt::Horizontal ?
+	    setCursor( orientation == TQt::Horizontal ?
 		       TQt::sizeVerCursor : TQt::sizeHorCursor );
             d->action = A_HELPLINES;
         }
@@ -655,8 +655,8 @@ void KoRuler::mouseReleaseEvent( TQMouseEvent *e )
     }
     else if( d->action == A_HELPLINES )
     {
-        emit addGuide( e->pos(), orientation == Qt::Horizontal, orientation == Qt::Horizontal ? size().height() : size().width() );
-        emit addHelpline( e->pos(), orientation == Qt::Horizontal);
+        emit addGuide( e->pos(), orientation == TQt::Horizontal, orientation == TQt::Horizontal ? size().height() : size().width() );
+        emit addHelpline( e->pos(), orientation == TQt::Horizontal);
         setCursor( ArrowCursor );
     }
     d->currTab.type = T_INVALID; // added (DF)
@@ -686,7 +686,7 @@ void KoRuler::mouseMoveEvent( TQMouseEvent *e )
 
     TQToolTip::remove( this);
     switch ( orientation ) {
-        case Qt::Horizontal: {
+        case TQt::Horizontal: {
             if ( !d->mousePressed ) {
                 setCursor( ArrowCursor );
                 d->action = A_NONE;
@@ -871,7 +871,7 @@ void KoRuler::mouseMoveEvent( TQMouseEvent *e )
 
             return;
         } break;
-        case Qt::Vertical: {
+        case TQt::Vertical: {
             if ( !d->mousePressed ) {
                 setCursor( ArrowCursor );
                 d->action = A_NONE;
@@ -1014,12 +1014,12 @@ void KoRuler::setupMenu()
         if ( m_unit == unit )
             d->rb_menu->setItemChecked( i, true );
     }
-    connect( d->rb_menu, TQT_SIGNAL( activated( int ) ), TQT_SLOT( slotMenuActivated( int ) ) );
+    connect( d->rb_menu, TQ_SIGNAL( activated( int ) ), TQ_SLOT( slotMenuActivated( int ) ) );
 
     d->rb_menu->insertSeparator();
-    d->mPageLayout=d->rb_menu->insertItem(i18n("Page Layout..."), this, TQT_SLOT(pageLayoutDia()));
+    d->mPageLayout=d->rb_menu->insertItem(i18n("Page Layout..."), this, TQ_SLOT(pageLayoutDia()));
     d->rb_menu->insertSeparator();
-    d->mRemoveTab=d->rb_menu->insertItem(i18n("Remove Tabulator"), this, TQT_SLOT(rbRemoveTab()));
+    d->mRemoveTab=d->rb_menu->insertItem(i18n("Remove Tabulator"), this, TQ_SLOT(rbRemoveTab()));
     d->rb_menu->setItemEnabled( d->mRemoveTab, false );
 }
 
