@@ -50,7 +50,7 @@
 #include <tdeconfig.h>
 
 #include <stdlib.h>
-#include <kinstance.h>
+#include <tdeinstance.h>
 
 
 class KoTemplateCreateDiaPrivate {
