@@ -44,7 +44,7 @@ class ToolArea;
 
 class KOFFICEUI_EXPORT KoToolBox : public TDEToolBar {
 
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
@@ -63,7 +63,7 @@ public:
 
 public slots:
 
-    virtual void setOrientation ( Qt::Orientation o );
+    virtual void setOrientation ( TQt::Orientation o );
     void slotButtonPressed( int id );
     void slotPressButton( int id );
 
@@ -98,7 +98,7 @@ public:
     ToolArea(TQWidget *parent);
     ~ToolArea();
 
-    void  setOrientation ( Qt::Orientation o );
+    void  setOrientation ( TQt::Orientation o );
     void  add(TQWidget *button);
 
     TQWidget* getNextParent();
