@@ -75,30 +75,30 @@ TQPopupMenu* KoColorPanel::createColorPopup( KoColorPanel::MenuStyle style, cons
         TQPainter p( &pixmap );
         p.fillRect( 0, 0, 12, 12, defaultColor );
         p.end();
-        proxy = new KoColorPopupProxy( defaultColor, 0, TQT_TQOBJECT(menu), "color proxy" );
-        connect( proxy, TQT_SIGNAL( colorSelected( const TQColor& ) ), receiver, slot );
-        menu->insertItem( TQIconSet( pixmap ), i18n( "Default Color" ), proxy, TQT_SLOT( slotDefaultColor() ) );
+        proxy = new KoColorPopupProxy( defaultColor, 0, menu, "color proxy" );
+        connect( proxy, TQ_SIGNAL( colorSelected( const TQColor& ) ), receiver, slot );
+        menu->insertItem( TQIconSet( pixmap ), i18n( "Default Color" ), proxy, TQ_SLOT( slotDefaultColor() ) );
         menu->insertSeparator();
     }
 
     KoColorPanel* panel = new KoColorPanel( menu, "default colors" );
     panel->insertDefaultColors();
-    connect( panel, TQT_SIGNAL( colorSelected( const TQColor& ) ), receiver, slot );
+    connect( panel, TQ_SIGNAL( colorSelected( const TQColor& ) ), receiver, slot );
     menu->insertItem( panel );
 
     if ( style == CustomColors ) {
         menu->insertSeparator();
         panel = new KoColorPanel( menu, "custom panel" );
-        connect( panel, TQT_SIGNAL( colorSelected( const TQColor& ) ), receiver, slot );
+        connect( panel, TQ_SIGNAL( colorSelected( const TQColor& ) ), receiver, slot );
         menu->insertItem( panel );
         if ( !proxy ) {
-            proxy = new KoColorPopupProxy( TQColor(), panel, TQT_TQOBJECT(menu), "color proxy" );
-            connect( proxy, TQT_SIGNAL( colorSelected( const TQColor& ) ), receiver, slot );
+            proxy = new KoColorPopupProxy( TQColor(), panel, menu, "color proxy" );
+            connect( proxy, TQ_SIGNAL( colorSelected( const TQColor& ) ), receiver, slot );
         }
         else
             proxy->setRecentColorPanel( panel );
         menu->insertSeparator();
-        menu->insertItem( i18n( "More Colors..." ), proxy, TQT_SLOT( slotMoreColors() ) );
+        menu->insertItem( i18n( "More Colors..." ), proxy, TQ_SLOT( slotMoreColors() ) );
     }
 
     return menu;
@@ -303,7 +303,7 @@ void KoColorPanel::insertDefaultColors()
 
 void KoColorPanel::mousePressEvent( TQMouseEvent* e )
 {
-    if ( e->button() == Qt::LeftButton )
+    if ( e->button() == TQt::LeftButton )
         m_pressedPos = e->pos();
 }
 
@@ -316,7 +316,7 @@ void KoColorPanel::mouseReleaseEvent( TQMouseEvent* )
 
 void KoColorPanel::mouseMoveEvent( TQMouseEvent* e )
 {
-    if ( e->state() & Qt::LeftButton ) {
+    if ( e->state() & TQt::LeftButton ) {
         TQPoint p = m_pressedPos - e->pos();
         if ( p.manhattanLength() > TQApplication::startDragDistance() ) {
             TQColor color( mapToColor( m_pressedPos ) );
@@ -368,7 +368,7 @@ void KoColorPanel::paintEvent( TQPaintEvent* e )
     // The "active" element (if there is one)
     if ( hasFocus() && m_focusPosition.x != -1 && m_focusPosition.y != -1 &&
          mapFromPosition( m_focusPosition ).intersects( e->rect() ) )
-        style().tqdrawPrimitive( TQStyle::PE_Panel, &p, TQRect( m_focusPosition.x << 4, m_focusPosition.y << 4, TILESIZE, TILESIZE ),
+        style().drawPrimitive( TQStyle::PE_Panel, &p, TQRect( m_focusPosition.x << 4, m_focusPosition.y << 4, TILESIZE, TILESIZE ),
                                colorGroup(), TQStyle::Style_Sunken | TQStyle::Style_Enabled );
 
     --lns;  // Attention: We just avoid some lns - 1 statements
@@ -579,7 +579,7 @@ void KoColorPanel::updateFocusPosition( const Position& newPosition )
     TQMap<Position, TQColor>::ConstIterator it = m_colorMap.find( m_focusPosition );
     if ( it != m_colorMap.end() ) {
         // draw at the new focus position
-        style().tqdrawPrimitive( TQStyle::PE_Panel, &p, TQRect( m_focusPosition.x << 4, m_focusPosition.y << 4, TILESIZE, TILESIZE ),
+        style().drawPrimitive( TQStyle::PE_Panel, &p, TQRect( m_focusPosition.x << 4, m_focusPosition.y << 4, TILESIZE, TILESIZE ),
                                colorGroup(), TQStyle::Style_Sunken | TQStyle::Style_Enabled );
         p.fillRect( ( m_focusPosition.x << 4 ) + 2, ( m_focusPosition.y << 4 ) + 2, 12, 12, it.data() );
     }
@@ -636,7 +636,7 @@ void KoColorPopupProxy::slotMoreColors()
     TQColor newColor;
     TQWidget* p = 0;
     if ( parent() && parent()->isWidgetType() )
-        p = TQT_TQWIDGET( parent() );
+        p = static_cast<TQWidget*>( parent() );
 
     if ( KColorDialog::getColor( newColor, p ) == TQDialog::Accepted ) {
         m_recentColors->insertColor( newColor );
@@ -720,7 +720,7 @@ void KoToolButton::drawButton(TQPainter *_painter)
     _painter->setClipping( false );
 
     // ...and the arrow indicating the popup
-    style().tqdrawPrimitive( TQStyle::PE_ArrowDown, _painter, TQRect( width() - ARROW_WIDTH - 1, 0, ARROW_WIDTH, height() ),
+    style().drawPrimitive( TQStyle::PE_ArrowDown, _painter, TQRect( width() - ARROW_WIDTH - 1, 0, ARROW_WIDTH, height() ),
                            cg, flags, opt );
 
     if ( TDEToolBarButton::isRaised() || m_arrowPressed )
@@ -811,7 +811,7 @@ bool KoToolButton::eventFilter( TQObject* o, TQEvent* e )
 {
     if ( o == m_popup ) {
         if ( e->type() == TQEvent::MouseButtonPress )
-            if ( hitArrow( mapFromGlobal( TQT_TQMOUSEEVENT( e )->globalPos() ) ) ) {
+            if ( hitArrow( mapFromGlobal( static_cast<TQMouseEvent*>( e )->globalPos() ) ) ) {
                 kdDebug() << "KoToolButton::eventFilter-------------->" << endl;
                 m_popup->close();
                 m_arrowPressed = false;
@@ -821,7 +821,7 @@ bool KoToolButton::eventFilter( TQObject* o, TQEvent* e )
     }
 
     if ( e->type() == TQEvent::MouseButtonPress ) {
-        m_arrowPressed = hitArrow( TQT_TQMOUSEEVENT( e )->pos() );
+        m_arrowPressed = hitArrow( static_cast<TQMouseEvent*>( e )->pos() );
         if ( m_arrowPressed )
             m_popup->popup( mapToGlobal( TQPoint( 0, height() ) ) );
     }
@@ -832,8 +832,8 @@ bool KoToolButton::eventFilter( TQObject* o, TQEvent* e )
 
 void KoToolButton::init()
 {
-    m_popup = KoColorPanel::createColorPopup( KoColorPanel::CustomColors, TQt::yellow, TQT_TQOBJECT(this),
-                                              TQT_SLOT( colorSelected( const TQColor& ) ),
+    m_popup = KoColorPanel::createColorPopup( KoColorPanel::CustomColors, TQt::yellow, this,
+                                              TQ_SLOT( colorSelected( const TQColor& ) ),
                                               this, "no-name" );
     // We are interested in the mouse clicks on the arrow button
     m_popup->installEventFilter( this );
