@@ -44,7 +44,7 @@ TopLevel::TopLevel( TQWidget* parent, const char* name) : TQMainWindow( parent,
     TQBoxLayout* l = new TQHBoxLayout( w, KDialog::marginHint(), KDialog::spacingHint() );
     TQGroupBox* b1 = new TQVGroupBox( TQString::fromLatin1( "KoColorPanel 1" ), w );
     panel = new KoColorPanel( b1, "panel1" );
-    connect( panel, TQT_SIGNAL( colorSelected( const TQColor& ) ), TQT_SLOT( slotColorSelected( const TQColor& ) ) );
+    connect( panel, TQ_SIGNAL( colorSelected( const TQColor& ) ), TQ_SLOT( slotColorSelected( const TQColor& ) ) );
     //panel->insertDefaultColors();
     l->addWidget( b1 );
 
@@ -57,20 +57,20 @@ TopLevel::TopLevel( TQWidget* parent, const char* name) : TQMainWindow( parent,
     menuBar()->insertItem( "&File", file );
 
     file->insertItem( "Custom + Default", KoColorPanel::createColorPopup( KoColorPanel::CustomColors, TQt::red, this,
-                                                                          TQT_SLOT( slotColorSelected( const TQColor& ) ), file, "blah" ) );
+                                                                          TQ_SLOT( slotColorSelected( const TQColor& ) ), file, "blah" ) );
     file->insertItem( "Custom", KoColorPanel::createColorPopup( KoColorPanel::CustomColors, TQColor(), this,
-                                                                TQT_SLOT( slotColorSelected( const TQColor& ) ), file, "blah" ) );
+                                                                TQ_SLOT( slotColorSelected( const TQColor& ) ), file, "blah" ) );
     file->insertItem( "Plain + Default", KoColorPanel::createColorPopup( KoColorPanel::Plain, TQt::green, this,
-                                                                         TQT_SLOT( slotColorSelected( const TQColor& ) ), file, "blah" ) );
+                                                                         TQ_SLOT( slotColorSelected( const TQColor& ) ), file, "blah" ) );
     file->insertItem( "Plain", KoColorPanel::createColorPopup( KoColorPanel::Plain, TQColor(), this,
-                                                               TQT_SLOT( slotColorSelected( const TQColor& ) ), file, "blah" ) );
+                                                               TQ_SLOT( slotColorSelected( const TQColor& ) ), file, "blah" ) );
     file->insertSeparator();
-    file->insertItem( "Default Colors", this, TQT_SLOT( defaultColors() ), CTRL+Key_D );
-    file->insertItem( "Insert Random Color", this, TQT_SLOT( insertRandomColor() ), CTRL+Key_R );
+    file->insertItem( "Default Colors", this, TQ_SLOT( defaultColors() ), CTRL+Key_D );
+    file->insertItem( "Insert Random Color", this, TQ_SLOT( insertRandomColor() ), CTRL+Key_R );
     file->insertSeparator();
-    file->insertItem( "Clear", this, TQT_SLOT( clearColors() ), CTRL+Key_C );
+    file->insertItem( "Clear", this, TQ_SLOT( clearColors() ), CTRL+Key_C );
     file->insertSeparator();
-    file->insertItem( "&Quit", tqApp, TQT_SLOT( closeAllWindows() ), CTRL+Key_Q );
+    file->insertItem( "&Quit", tqApp, TQ_SLOT( closeAllWindows() ), CTRL+Key_Q );
 
     TDEToolBar* toolBar = new TDEToolBar( this );
     addDockWindow( toolBar );
