@@ -78,7 +78,7 @@ TTDESelectColorAction::TTDESelectColorAction( const TQString& text, Type type,
     d->defaultColor=TQColor();
     setText(text);
     m_type = type;
-    connect( this, TQT_SIGNAL( activated() ), receiver, slot );
+    connect( this, TQ_SIGNAL( activated() ), receiver, slot );
     init();
 }
 
@@ -87,10 +87,10 @@ void TTDESelectColorAction::init()
   m_pStandardColor = new TKColorPanel();
   m_pRecentColor = new TKColorPanel();
 
-  connect(m_pStandardColor,TQT_SIGNAL(colorSelected(const TQColor&)),TQT_SLOT(panelColorSelected(const TQColor&)));
-  connect(m_pStandardColor,TQT_SIGNAL(reject()),TQT_SLOT(panelReject()));
-  connect(m_pRecentColor,TQT_SIGNAL(colorSelected(const TQColor&)),TQT_SLOT(panelColorSelected(const TQColor&)));
-  connect(m_pRecentColor,TQT_SIGNAL(reject()),TQT_SLOT(panelReject()));
+  connect(m_pStandardColor,TQ_SIGNAL(colorSelected(const TQColor&)),TQ_SLOT(panelColorSelected(const TQColor&)));
+  connect(m_pStandardColor,TQ_SIGNAL(reject()),TQ_SLOT(panelReject()));
+  connect(m_pRecentColor,TQ_SIGNAL(colorSelected(const TQColor&)),TQ_SLOT(panelColorSelected(const TQColor&)));
+  connect(m_pRecentColor,TQ_SIGNAL(reject()),TQ_SLOT(panelReject()));
 
   m_pRecentColor->clear();
 
@@ -102,17 +102,17 @@ void TTDESelectColorAction::init()
 
   switch (m_type) {
     case TextColor:
-      m_pMenu->insertItem(i18n("More Text Colors..."),this,TQT_SLOT(selectColorDialog()));
+      m_pMenu->insertItem(i18n("More Text Colors..."),this,TQ_SLOT(selectColorDialog()));
       setCurrentColor(black);
       setIcon("textcolor");
       break;
     case LineColor:
-      m_pMenu->insertItem(i18n("More Line Colors..."),this,TQT_SLOT(selectColorDialog()));
+      m_pMenu->insertItem(i18n("More Line Colors..."),this,TQ_SLOT(selectColorDialog()));
       setCurrentColor(black);
       setIcon("color_line");
       break;
     case FillColor:
-      m_pMenu->insertItem(i18n("More Fill Colors..."),this,TQT_SLOT(selectColorDialog()));
+      m_pMenu->insertItem(i18n("More Fill Colors..."),this,TQ_SLOT(selectColorDialog()));
       setCurrentColor(white);
       setIcon("color_fill");
       break;
@@ -122,11 +122,11 @@ void TTDESelectColorAction::init()
   if(d->defaultColorMenu)
   {
       m_pMenu->insertSeparator();
-      m_pMenu->insertItem(i18n("Default Color"),this,TQT_SLOT(defaultColor()));
+      m_pMenu->insertItem(i18n("Default Color"),this,TQ_SLOT(defaultColor()));
   }
 
-  connect(m_pStandardColor,TQT_SIGNAL(sizeChanged()),m_pMenu,TQT_SLOT(updateItemSize()));
-  connect(m_pRecentColor,TQT_SIGNAL(sizeChanged()),m_pMenu,TQT_SLOT(updateItemSize()));
+  connect(m_pStandardColor,TQ_SIGNAL(sizeChanged()),m_pMenu,TQ_SLOT(updateItemSize()));
+  connect(m_pRecentColor,TQ_SIGNAL(sizeChanged()),m_pMenu,TQ_SLOT(updateItemSize()));
 }
 
 TTDESelectColorAction::~TTDESelectColorAction()
@@ -165,7 +165,7 @@ void TTDESelectColorAction::updatePixmap()
         updatePixmap(static_cast<TTDEToolBarButton*>(r));
       }
     }
-    else if(w->inherits(TQPOPUPMENU_OBJECT_NAME_STRING) ) {
+    else if(w->inherits("TQPopupMenu") ) {
         TQPixmap pix =iconSet(TDEIcon::Small).pixmap(TQIconSet::Automatic,TQIconSet::Active);
   if ( pix.isNull() )
       return;
@@ -240,7 +240,7 @@ void TTDESelectColorAction::selectColorDialog()
 
     if ( d->defaultColorMenu )
     {
-        if ( KColorDialog::getColor(c,d->defaultColor, TQT_TQWIDGET(tqApp->activeWindow())) == TQDialog::Accepted )
+        if ( KColorDialog::getColor(c,d->defaultColor, tqApp->activeWindow()) == TQDialog::Accepted )
         {
             setCurrentColor(c);
             m_pRecentColor->insertColor(m_pCurrentColor);
@@ -250,7 +250,7 @@ void TTDESelectColorAction::selectColorDialog()
     }
     else
     {
-        if ( KColorDialog::getColor(c, TQT_TQWIDGET(tqApp->activeWindow())) == TQDialog::Accepted )
+        if ( KColorDialog::getColor(c, tqApp->activeWindow()) == TQDialog::Accepted )
         {
             setCurrentColor(c);
             m_pRecentColor->insertColor(m_pCurrentColor);
@@ -368,7 +368,7 @@ void TKColorPanel::insertColor( const TQColor& color )
   if ( m_activeColor == color )
       f->setActive(true);
 
-  connect(f,TQT_SIGNAL(selected(const TQColor&)),TQT_SLOT(selected(const TQColor&)));
+  connect(f,TQ_SIGNAL(selected(const TQColor&)),TQ_SLOT(selected(const TQColor&)));
 
   addToGrid(f);
 }
