@@ -42,7 +42,7 @@ class ColorWidget;
 
 class KoColorChooser : public TQWidget
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 public:
   KoColorChooser(TQWidget *parent = 0L, const char *name = 0L);
@@ -82,7 +82,7 @@ private:
 };
 
 class ColorWidget : public TQWidget {
-	Q_OBJECT
+	TQ_OBJECT
   
 
 public:
@@ -100,7 +100,7 @@ protected:
 
 class RGBWidget : public ColorWidget
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 public:
   RGBWidget(TQWidget *parent = 0L);
@@ -138,7 +138,7 @@ private:
 
 class HSVWidget : public ColorWidget
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 public:
   HSVWidget(TQWidget *parent = 0L);
@@ -176,7 +176,7 @@ private:
 
 class GreyWidget : public ColorWidget
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 public:
   GreyWidget(TQWidget *parent = 0L);
@@ -202,7 +202,7 @@ protected:
 
 class LABWidget : public ColorWidget
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 public:
   LABWidget(TQWidget *parent = 0L);
