@@ -28,7 +28,7 @@ class TQString;
 
 class KoFrameButton : public TQLabel
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 public:
   KoFrameButton(TQWidget *parent = 0, const char *name = 0);
