@@ -43,7 +43,7 @@ struct CMYKColor
 class KoCMYKWidget
      : public TQWidget
 {
-    Q_OBJECT
+    TQ_OBJECT
   
     typedef TQWidget super;
 
