@@ -62,7 +62,7 @@ KoPaletteManager::KoPaletteManager(KoView * view, TDEActionCollection *ac, const
     m_widgetNames = new TQStringList();
 
     m_mapper = new TQSignalMapper(this);
-    connect(m_mapper, TQT_SIGNAL(mapped(int)), this, TQT_SLOT(slotTogglePalette(int)));
+    connect(m_mapper, TQ_SIGNAL(mapped(int)), this, TQ_SLOT(slotTogglePalette(int)));
     m_viewActionMenu = new TDEActionMenu(i18n("Palettes"), m_actionCollection, "view_palette_action_menu");
 
     TDEConfig * cfg = TDEGlobal::config();
@@ -74,7 +74,7 @@ KoPaletteManager::KoPaletteManager(KoView * view, TDEActionCollection *ac, const
     if ( palettesShown) {
         m_toggleShowHidePalettes = new TDEToggleAction(i18n("Hide All Palette Windows"),
                                     "CTRL+SHIFT+H", this,
-                                    TQT_SLOT(slotToggleAllPalettes()),
+                                    TQ_SLOT(slotToggleAllPalettes()),
                                     m_actionCollection, "toggleAllPaletteWindows");
 
         m_toggleShowHidePalettes->setCheckedState(i18n("Show Palette Windows Again"));
@@ -82,7 +82,7 @@ KoPaletteManager::KoPaletteManager(KoView * view, TDEActionCollection *ac, const
     else {
         m_toggleShowHidePalettes = new TDEToggleAction(i18n("Show Palette Windows Again"),
                                     "CTRL+SHIFT+H", this,
-                                    TQT_SLOT(slotToggleAllPalettes()),
+                                    TQ_SLOT(slotToggleAllPalettes()),
                                     m_actionCollection, "toggleAllPaletteWindows");
 
         m_toggleShowHidePalettes->setCheckedState(i18n("Hide All Palette Windows"));
@@ -107,7 +107,7 @@ KoPaletteManager::KoPaletteManager(KoView * view, TDEActionCollection *ac, const
 /*
     TDEAction * a = new TDEAction(i18n("Restore Palettes"),
                   0, this,
-                  TQT_SLOT(slotReset()),
+                  TQ_SLOT(slotReset()),
                   this, "restorePalettes");
     m_viewActionMenu->insert(a);
 */
@@ -165,7 +165,7 @@ void KoPaletteManager::addWidget(TQWidget * widget,
     }
 
     TDEToggleAction * a;
-    a = new TDEToggleAction(i18n("Show %1").arg(widget->caption()), 0, m_mapper, TQT_SLOT(map()), m_actionCollection);
+    a = new TDEToggleAction(i18n("Show %1").arg(widget->caption()), 0, m_mapper, TQ_SLOT(map()), m_actionCollection);
     a->setCheckedState(i18n("Hide %1").arg(widget->caption()));
 
     m_mapper->setMapping(a, m_widgetNames->count()); // This is the position at which we'll insert the action
