@@ -62,7 +62,7 @@ class EditorItem;
  */
 class KOPROPERTY_EXPORT Editor : public TDEListView
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 
 	public:
