@@ -133,7 +133,7 @@ class GroupWidgetBase : public TQWidget
 			TQRect r(rect());
 			TQPainter p(this);
 			TQStyle::StyleFlags flags = m_mouseDown ? TQStyle::Style_Down : TQStyle::Style_Default;
-			kapp->style().tqdrawPrimitive(TQStyle::PE_HeaderSection, &p, r, palette().active(), flags);
+			kapp->style().drawPrimitive(TQStyle::PE_HeaderSection, &p, r, palette().active(), flags);
 
 			paintListViewExpander(&p, this, r.height()+2, palette().active(), isOpen());
 			if (!m_miniicon.isNull()) {
@@ -157,8 +157,8 @@ class GroupWidgetBase : public TQWidget
 
 		virtual bool event( TQEvent * e ) {
 			if (e->type()==TQEvent::MouseButtonPress || e->type()==TQEvent::MouseButtonRelease) {
-				TQMouseEvent* me = TQT_TQMOUSEEVENT(e);
-				if (me->button() == Qt::LeftButton) {
+				TQMouseEvent* me = static_cast<TQMouseEvent*>(e);
+				if (me->button() == TQt::LeftButton) {
 					m_mouseDown = e->type()==TQEvent::MouseButtonPress;
 					update();
 				}
@@ -238,8 +238,8 @@ void GroupContainer::setContents( TQWidget* contents )
 
 bool GroupContainer::event( TQEvent * e ) {
 	if (e->type()==TQEvent::MouseButtonPress) {
-		TQMouseEvent* me = TQT_TQMOUSEEVENT(e);
-		if (me->button() == Qt::LeftButton && d->contents && TQT_TQRECT_OBJECT(d->groupWidget->rect()).contains(me->pos())) {
+		TQMouseEvent* me = static_cast<TQMouseEvent*>(e);
+		if (me->button() == TQt::LeftButton && d->contents && d->groupWidget->rect().contains(me->pos())) {
 			d->groupWidget->setOpen(!d->groupWidget->isOpen());
 			if (d->groupWidget->isOpen())
 				d->contents->show();
