@@ -44,7 +44,7 @@ DateEdit::DateEdit(Property *property, TQWidget *parent, const char *name)
 	setLeavesTheSpaceForRevertButton(true);
 
 	setFocusWidget(m_edit);
-	connect(m_edit, TQT_SIGNAL(valueChanged(const TQDate&)), this, TQT_SLOT(slotValueChanged(const TQDate&)));
+	connect(m_edit, TQ_SIGNAL(valueChanged(const TQDate&)), this, TQ_SLOT(slotValueChanged(const TQDate&)));
 }
 
 DateEdit::~DateEdit()
