@@ -29,7 +29,7 @@ namespace KoProperty {
 
 class KOPROPERTY_EXPORT LineStyleEdit : public Widget
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 
 	public:
