@@ -33,7 +33,7 @@ namespace KoProperty {
 
 class KOPROPERTY_EXPORT PixmapEdit : public Widget
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 
 	public:
