@@ -31,7 +31,7 @@ namespace KoProperty {
 
 class KOPROPERTY_EXPORT PointEdit : public Widget
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 
 	public:
