@@ -34,7 +34,7 @@ class DoubleEdit;
 
 class IntSpinBox : public KIntSpinBox
 {
-	Q_OBJECT
+	TQ_OBJECT
 	
 
 	public:
@@ -50,7 +50,7 @@ class IntSpinBox : public KIntSpinBox
 
 class KOPROPERTY_EXPORT IntEdit : public Widget
 {
-	Q_OBJECT
+	TQ_OBJECT
 	
 
 	public:
@@ -76,7 +76,7 @@ class KOPROPERTY_EXPORT IntEdit : public Widget
 
 class DoubleSpinBox : public KDoubleSpinBox
 {
-	Q_OBJECT
+	TQ_OBJECT
 	
 
 	public:
@@ -94,7 +94,7 @@ class DoubleSpinBox : public KDoubleSpinBox
 
 class KOPROPERTY_EXPORT DoubleEdit : public Widget
 {
-	Q_OBJECT
+	TQ_OBJECT
 	
 
 	public:
