@@ -32,7 +32,7 @@ namespace KoProperty {
 
 class KOPROPERTY_EXPORT StringListEdit : public Widget
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 
 	public:
