@@ -50,8 +50,8 @@ SymbolCombo::SymbolCombo(Property *property, TQWidget *parent, const char *name)
 	m_select->setMinimumHeight(5);
 	l->addWidget(m_select);
 
-	connect(m_select, TQT_SIGNAL(clicked()), this, TQT_SLOT(selectChar()));
-	connect(m_edit, TQT_SIGNAL(textChanged(const TQString&)), this, TQT_SLOT(slotValueChanged(const TQString&)));
+	connect(m_select, TQ_SIGNAL(clicked()), this, TQ_SLOT(selectChar()));
+	connect(m_edit, TQ_SIGNAL(textChanged(const TQString&)), this, TQ_SLOT(slotValueChanged(const TQString&)));
 }
 
 SymbolCombo::~SymbolCombo()
