@@ -439,21 +439,21 @@ Set::typeName() const
 Buffer::Buffer()
 	:Set(false)
 {
-	connect( this, TQT_SIGNAL( propertyChanged( KoProperty::Set&, KoProperty::Property& ) ),
-	         this, TQT_SLOT(intersectedChanged( KoProperty::Set&, KoProperty::Property& ) ) );
+	connect( this, TQ_SIGNAL( propertyChanged( KoProperty::Set&, KoProperty::Property& ) ),
+	         this, TQ_SLOT(intersectedChanged( KoProperty::Set&, KoProperty::Property& ) ) );
 
-	connect( this, TQT_SIGNAL( propertyReset( KoProperty::Set&, KoProperty::Property& ) ),
-	         this, TQT_SLOT(intersectedReset( KoProperty::Set&, KoProperty::Property& ) ) );
+	connect( this, TQ_SIGNAL( propertyReset( KoProperty::Set&, KoProperty::Property& ) ),
+	         this, TQ_SLOT(intersectedReset( KoProperty::Set&, KoProperty::Property& ) ) );
 }
 
 Buffer::Buffer(const Set *set)
 	:Set(false)
 {
-	connect( this, TQT_SIGNAL( propertyChanged( KoProperty::Set&, KoProperty::Property& ) ),
-	         this, TQT_SLOT(intersectedChanged( KoProperty::Set&, KoProperty::Property& ) ) );
+	connect( this, TQ_SIGNAL( propertyChanged( KoProperty::Set&, KoProperty::Property& ) ),
+	         this, TQ_SLOT(intersectedChanged( KoProperty::Set&, KoProperty::Property& ) ) );
 
-	connect( this, TQT_SIGNAL( propertyReset( KoProperty::Set&, KoProperty::Property& ) ),
-	         this, TQT_SLOT(intersectedReset( KoProperty::Set&, KoProperty::Property& ) ) );
+	connect( this, TQ_SIGNAL( propertyReset( KoProperty::Set&, KoProperty::Property& ) ),
+	         this, TQ_SLOT(intersectedReset( KoProperty::Set&, KoProperty::Property& ) ) );
 
 	initialSet( set );
 }
