@@ -39,7 +39,7 @@ class SetPrivate;
  */
 class KOPROPERTY_EXPORT Set : public TQObject
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 
 	public:
@@ -233,7 +233,7 @@ class KOPROPERTY_EXPORT Set : public TQObject
  */
 class KOPROPERTY_EXPORT Buffer : public Set
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 
 	public:
