@@ -35,7 +35,7 @@
  */
 class Test : public TDEMainWindow
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 	public:
 	    Test();
