@@ -4,7 +4,7 @@
 
 class DateFormatWidget : public TimeDateFormatWidgetPrototype
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
