@@ -31,7 +31,7 @@
 #include <tdeversion.h>
 #include <kdebug.h>
 #include <tdelocale.h>
-#include <kinstance.h>
+#include <tdeinstance.h>
 #include <tdeconfig.h>
 #include <kstandarddirs.h>
 #include <tdeglobal.h>
