@@ -44,8 +44,8 @@ KoAutoFormatLineEdit::KoAutoFormatLineEdit ( TQWidget * parent, const char * nam
 
 void KoAutoFormatLineEdit::keyPressEvent ( TQKeyEvent *ke )
 {
-    if( ke->key()  == Qt::Key_Return ||
-        ke->key()  == Qt::Key_Enter )
+    if( ke->key()  == TQt::Key_Return ||
+        ke->key()  == TQt::Key_Enter )
     {
         emit keyReturnPressed();
         return;
@@ -71,18 +71,18 @@ KoAutoFormatExceptionWidget::KoAutoFormatExceptionWidget(TQWidget *parent, const
     exceptionLine = new KoAutoFormatLineEdit( this );
     grid->addWidget(exceptionLine,1,0);
 
-    connect(exceptionLine,TQT_SIGNAL(keyReturnPressed()),TQT_SLOT(slotAddException()));
-    connect(exceptionLine ,TQT_SIGNAL(textChanged ( const TQString & )),
-            TQT_SLOT(textChanged ( const TQString & )));
+    connect(exceptionLine,TQ_SIGNAL(keyReturnPressed()),TQ_SLOT(slotAddException()));
+    connect(exceptionLine ,TQ_SIGNAL(textChanged ( const TQString & )),
+            TQ_SLOT(textChanged ( const TQString & )));
 
     pbAddException=new TQPushButton(i18n("Add"),this);
-    connect(pbAddException, TQT_SIGNAL(clicked()),TQT_SLOT(slotAddException()));
+    connect(pbAddException, TQ_SIGNAL(clicked()),TQ_SLOT(slotAddException()));
     grid->addWidget(pbAddException,1,1);
 
     pbAddException->setEnabled(false);
 
     pbRemoveException=new TQPushButton(i18n("Remove"),this);
-    connect(pbRemoveException, TQT_SIGNAL(clicked()),TQT_SLOT(slotRemoveException()));
+    connect(pbRemoveException, TQ_SIGNAL(clicked()),TQ_SLOT(slotRemoveException()));
     grid->addWidget(pbRemoveException,2,1,TQt::AlignTop);
 
     exceptionList=new TQListBox(this);
@@ -92,8 +92,8 @@ KoAutoFormatExceptionWidget::KoAutoFormatExceptionWidget(TQWidget *parent, const
 
     grid->setRowStretch( 2, 1 );
 
-    connect( exceptionList , TQT_SIGNAL(selectionChanged () ),
-            this,TQT_SLOT(slotExceptionListSelected()) );
+    connect( exceptionList , TQ_SIGNAL(selectionChanged () ),
+            this,TQ_SLOT(slotExceptionListSelected()) );
 
     pbRemoveException->setEnabled( exceptionList->currentItem()!=-1);
 
@@ -188,7 +188,7 @@ KoAutoFormatDia::KoAutoFormatDia( TQWidget *parent, const char *name,
     setupTab3();
     setupTab4();
     setInitialSize( TQSize(500, 300) );
-    connect( this, TQT_SIGNAL( user1Clicked() ), this, TQT_SLOT(slotResetConf()));
+    connect( this, TQ_SIGNAL( user1Clicked() ), this, TQ_SLOT(slotResetConf()));
     noSignal=false;
 }
 
@@ -322,8 +322,8 @@ void KoAutoFormatDia::setupTab1()
             "formatting means that a correct bullet is used to draw the list."
             ) );
 
-    connect( cbUseBulletStyle, TQT_SIGNAL( toggled( bool ) ),
-            TQT_SLOT( slotBulletStyleToggled( bool ) ) );
+    connect( cbUseBulletStyle, TQ_SIGNAL( toggled( bool ) ),
+            TQ_SLOT( slotBulletStyleToggled( bool ) ) );
 
     vbox->addWidget(cbUseBulletStyle);
     TQHBoxLayout *hbox = new TQHBoxLayout();
@@ -345,9 +345,9 @@ void KoAutoFormatDia::setupTab1()
 
     initTab1();
 
-    connect( pbBulletStyle, TQT_SIGNAL( clicked() ), TQT_SLOT( chooseBulletStyle() ) );
-    connect( pbDefaultBulletStyle, TQT_SIGNAL( clicked()),
-            TQT_SLOT( defaultBulletStyle() ) );
+    connect( pbBulletStyle, TQ_SIGNAL( clicked() ), TQ_SLOT( chooseBulletStyle() ) );
+    connect( pbDefaultBulletStyle, TQ_SIGNAL( clicked()),
+            TQ_SLOT( defaultBulletStyle() ) );
 }
 
 void KoAutoFormatDia::initTab1()
@@ -384,8 +384,8 @@ void KoAutoFormatDia::setupTab2()
     cbTypographicDoubleQuotes->setText( i18n(
             "Replace &double quotes with typographical quotes" ) );
 
-    connect( cbTypographicDoubleQuotes,TQT_SIGNAL(toggled ( bool)),
-            TQT_SLOT(slotChangeStateDouble(bool)));
+    connect( cbTypographicDoubleQuotes,TQ_SIGNAL(toggled ( bool)),
+            TQ_SLOT(slotChangeStateDouble(bool)));
 
     vbox->addWidget( cbTypographicDoubleQuotes );
 
@@ -415,9 +415,9 @@ void KoAutoFormatDia::setupTab2()
 
     hbox->addStretch( 1 );
 
-    connect(pbDoubleQuote1, TQT_SIGNAL( clicked() ), TQT_SLOT( chooseDoubleQuote1() ));
-    connect(pbDoubleQuote2, TQT_SIGNAL( clicked() ), TQT_SLOT( chooseDoubleQuote2() ));
-    connect(pbDoubleDefault, TQT_SIGNAL( clicked()), TQT_SLOT( defaultDoubleQuote() ));
+    connect(pbDoubleQuote1, TQ_SIGNAL( clicked() ), TQ_SLOT( chooseDoubleQuote1() ));
+    connect(pbDoubleQuote2, TQ_SIGNAL( clicked() ), TQ_SLOT( chooseDoubleQuote2() ));
+    connect(pbDoubleDefault, TQ_SIGNAL( clicked()), TQ_SLOT( defaultDoubleQuote() ));
 
     vbox->addItem( hbox );
 
@@ -425,8 +425,8 @@ void KoAutoFormatDia::setupTab2()
     cbTypographicSimpleQuotes->setText( i18n(
             "Replace &single quotes with typographical quotes" ) );
 
-    connect( cbTypographicSimpleQuotes,TQT_SIGNAL(toggled ( bool)),
-            TQT_SLOT(slotChangeStateSimple(bool)));
+    connect( cbTypographicSimpleQuotes,TQ_SIGNAL(toggled ( bool)),
+            TQ_SLOT(slotChangeStateSimple(bool)));
 
     vbox->addWidget( cbTypographicSimpleQuotes );
 
@@ -456,9 +456,9 @@ void KoAutoFormatDia::setupTab2()
 
     hbox->addStretch( 1 );
 
-    connect(pbSimpleQuote1, TQT_SIGNAL( clicked() ), TQT_SLOT( chooseSimpleQuote1() ));
-    connect(pbSimpleQuote2, TQT_SIGNAL( clicked() ), TQT_SLOT( chooseSimpleQuote2() ));
-    connect(pbSimpleDefault, TQT_SIGNAL( clicked()), TQT_SLOT( defaultSimpleQuote() ));
+    connect(pbSimpleQuote1, TQ_SIGNAL( clicked() ), TQ_SLOT( chooseSimpleQuote1() ));
+    connect(pbSimpleQuote2, TQ_SIGNAL( clicked() ), TQ_SLOT( chooseSimpleQuote2() ));
+    connect(pbSimpleDefault, TQ_SIGNAL( clicked()), TQ_SLOT( defaultSimpleQuote() ));
 
     vbox->addItem( hbox );
     vbox->addStretch( 1 );
@@ -524,7 +524,7 @@ void KoAutoFormatDia::setupTab3()
     }
     autoFormatLanguage->insertStringList(lst);
 
-    connect(autoFormatLanguage->listBox(), TQT_SIGNAL(selected ( const TQString & )), this, TQT_SLOT(changeAutoformatLanguage(const TQString & )));
+    connect(autoFormatLanguage->listBox(), TQ_SIGNAL(selected ( const TQString & )), this, TQ_SLOT(changeAutoformatLanguage(const TQString & )));
 
     grid->addMultiCellWidget( autoFormatLanguage, 0, 0, 4, 6 );
     TQLabel *lblAutoFormatLanguage = new TQLabel( i18n("Replacements and exceptions for language:"), tab3);
@@ -532,7 +532,7 @@ void KoAutoFormatDia::setupTab3()
 
     cbAdvancedAutoCorrection = new TQCheckBox( tab3 );
     cbAdvancedAutoCorrection->setText( i18n("Enable word replacement") );
-    connect( cbAdvancedAutoCorrection, TQT_SIGNAL(clicked ()), this, TQT_SLOT( slotChangeAdvancedAutoCorrection()));
+    connect( cbAdvancedAutoCorrection, TQ_SIGNAL(clicked ()), this, TQ_SLOT( slotChangeAdvancedAutoCorrection()));
     grid->addMultiCellWidget( cbAdvancedAutoCorrection, 1, 1, 0, 6 );
 
     cbAutoCorrectionWithFormat = new TQCheckBox( tab3 );
@@ -547,17 +547,17 @@ void KoAutoFormatDia::setupTab3()
 
     lblFind->setBuddy( m_find );
 
-    connect( m_find, TQT_SIGNAL( textChanged( const TQString & ) ),
-	     TQT_SLOT( slotfind( const TQString & ) ) );
-    connect( m_find, TQT_SIGNAL( keyReturnPressed() ),
-             TQT_SLOT( slotAddEntry()));
+    connect( m_find, TQ_SIGNAL( textChanged( const TQString & ) ),
+	     TQ_SLOT( slotfind( const TQString & ) ) );
+    connect( m_find, TQ_SIGNAL( keyReturnPressed() ),
+             TQ_SLOT( slotAddEntry()));
 
     pbSpecialChar1 = new TQPushButton( "...", tab3 );
     TQToolTip::add( pbSpecialChar1, i18n( "Insert a special character..." ) );
     pbSpecialChar1->setFixedWidth( 40 );
     grid->addWidget( pbSpecialChar1, 3, 2 );
 
-    connect(pbSpecialChar1,TQT_SIGNAL(clicked()), TQT_SLOT(chooseSpecialChar1()));
+    connect(pbSpecialChar1,TQ_SIGNAL(clicked()), TQ_SLOT(chooseSpecialChar1()));
 
     lblReplace = new TQLabel( i18n( "&Replace:" ), tab3 );
     grid->addWidget( lblReplace, 3, 3 );
@@ -567,22 +567,22 @@ void KoAutoFormatDia::setupTab3()
 
     lblReplace->setBuddy( m_replace );
 
-    connect( m_replace, TQT_SIGNAL( textChanged( const TQString & ) ),
-	        TQT_SLOT( slotfind2( const TQString & ) ) );
-    connect( m_replace, TQT_SIGNAL( keyReturnPressed() ),
-            TQT_SLOT( slotAddEntry()));
+    connect( m_replace, TQ_SIGNAL( textChanged( const TQString & ) ),
+	        TQ_SLOT( slotfind2( const TQString & ) ) );
+    connect( m_replace, TQ_SIGNAL( keyReturnPressed() ),
+            TQ_SLOT( slotAddEntry()));
 
     pbSpecialChar2 = new TQPushButton( "...", tab3 );
     TQToolTip::add( pbSpecialChar2, i18n( "Insert a special character..." ) );
     pbSpecialChar2->setFixedWidth( 40 );
     grid->addWidget( pbSpecialChar2, 3, 5 );
 
-    connect(pbSpecialChar2,TQT_SIGNAL(clicked()), TQT_SLOT(chooseSpecialChar2()));
+    connect(pbSpecialChar2,TQ_SIGNAL(clicked()), TQ_SLOT(chooseSpecialChar2()));
 
     pbAdd = new TQPushButton( i18n( "&Add"), tab3  );
     grid->addWidget( pbAdd, 3, 6 );
 
-    connect(pbAdd,TQT_SIGNAL(clicked()),this, TQT_SLOT(slotAddEntry()));
+    connect(pbAdd,TQ_SIGNAL(clicked()),this, TQ_SLOT(slotAddEntry()));
 
     m_pListView = new TDEListView( tab3 );
     m_pListView->addColumn( i18n( "Find" ) );
@@ -590,25 +590,25 @@ void KoAutoFormatDia::setupTab3()
     m_pListView->setAllColumnsShowFocus( true );
     grid->addMultiCellWidget( m_pListView, 4, 10, 0, 5 );
 
-    connect(m_pListView, TQT_SIGNAL(doubleClicked ( TQListViewItem * )),
-             TQT_SLOT(slotChangeTextFormatEntry()) );
-    connect(m_pListView, TQT_SIGNAL(clicked ( TQListViewItem * ) ),
-             TQT_SLOT(slotEditEntry()) );
+    connect(m_pListView, TQ_SIGNAL(doubleClicked ( TQListViewItem * )),
+             TQ_SLOT(slotChangeTextFormatEntry()) );
+    connect(m_pListView, TQ_SIGNAL(clicked ( TQListViewItem * ) ),
+             TQ_SLOT(slotEditEntry()) );
 
     pbRemove = new TQPushButton( i18n( "Remove" ), tab3 );
     grid->addWidget( pbRemove, 4, 6, TQt::AlignTop );
 
-    connect(pbRemove,TQT_SIGNAL(clicked()), TQT_SLOT(slotRemoveEntry()));
+    connect(pbRemove,TQ_SIGNAL(clicked()), TQ_SLOT(slotRemoveEntry()));
 
     pbChangeFormat= new TQPushButton( i18n( "Change Format..." ), tab3 );
     grid->addWidget( pbChangeFormat, 5, 6, TQt::AlignTop );
 
-    connect( pbChangeFormat, TQT_SIGNAL(clicked()), TQT_SLOT(slotChangeTextFormatEntry()));
+    connect( pbChangeFormat, TQ_SIGNAL(clicked()), TQ_SLOT(slotChangeTextFormatEntry()));
 
     pbClearFormat= new TQPushButton( i18n( "Clear Format" ), tab3 );
     grid->addWidget( pbClearFormat, 6, 6, TQt::AlignTop );
 
-    connect( pbClearFormat, TQT_SIGNAL(clicked()), TQT_SLOT(slotClearTextFormatEntry()));
+    connect( pbClearFormat, TQ_SIGNAL(clicked()), TQ_SLOT(slotClearTextFormatEntry()));
     grid->setRowStretch( 10, 1 );
 
     initTab3();
