@@ -28,7 +28,7 @@ class TQPushButton;
 
 class KOTEXT_EXPORT KoChangeCaseDia : public KDialogBase
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     KoChangeCaseDia( TQWidget *parent, const char *name );
