@@ -35,7 +35,7 @@ KoCreateStyleDia::KoCreateStyleDia( const TQStringList & _list, TQWidget *parent
     m_styleName = new TQLineEdit( page );
     m_styleName->setMinimumWidth( m_styleName->sizeHint().width() * 3 );
 
-    connect( m_styleName, TQT_SIGNAL(textChanged ( const TQString & )), this, TQT_SLOT(nameChanged( const TQString &)));
+    connect( m_styleName, TQ_SIGNAL(textChanged ( const TQString & )), this, TQ_SLOT(nameChanged( const TQString &)));
     m_styleName->setFocus();
     enableButtonOK( false );
 }
