@@ -34,11 +34,11 @@ KoDecorationTab::KoDecorationTab( TQWidget* parent, const char* name, WFlags fl
 {
     shadowDistanceKDoubleNumInput->setRange(0, 9, 0.5, false);
 
-    connect( textKColorButton, TQT_SIGNAL( changed( const TQColor& ) ), this, TQT_SIGNAL( fontColorChanged( const TQColor& ) ) );
-    connect( backgroundKColorButton, TQT_SIGNAL( changed( const TQColor& ) ), this, TQT_SIGNAL( backgroundColorChanged( const TQColor& ) ) );
-    connect( shadowKColorButton, TQT_SIGNAL( changed( const TQColor& ) ), this, TQT_SIGNAL( shadowColorChanged( const TQColor& ) ) );
-    connect( shadowDistanceKDoubleNumInput, TQT_SIGNAL( valueChanged( double ) ), this, TQT_SIGNAL( shadowDistanceChanged( double ) ) );
-    connect( shadowDirectionButtonGroup, TQT_SIGNAL( clicked( int ) ), this, TQT_SIGNAL( shadowDirectionChanged( int ) ) );
+    connect( textKColorButton, TQ_SIGNAL( changed( const TQColor& ) ), this, TQ_SIGNAL( fontColorChanged( const TQColor& ) ) );
+    connect( backgroundKColorButton, TQ_SIGNAL( changed( const TQColor& ) ), this, TQ_SIGNAL( backgroundColorChanged( const TQColor& ) ) );
+    connect( shadowKColorButton, TQ_SIGNAL( changed( const TQColor& ) ), this, TQ_SIGNAL( shadowColorChanged( const TQColor& ) ) );
+    connect( shadowDistanceKDoubleNumInput, TQ_SIGNAL( valueChanged( double ) ), this, TQ_SIGNAL( shadowDistanceChanged( double ) ) );
+    connect( shadowDirectionButtonGroup, TQ_SIGNAL( clicked( int ) ), this, TQ_SIGNAL( shadowDirectionChanged( int ) ) );
 }
 
 KoDecorationTab::~KoDecorationTab()
