@@ -41,7 +41,7 @@ class TQComboBox;
 
 class KOTEXT_EXPORT KoFontDia : public KDialogBase
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
 
