@@ -29,7 +29,7 @@ class TQPushButton;
 
 class KOTEXT_EXPORT KoImportStyleDia : public KDialogBase
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     /// @param currentCollection collection of styles already present in the document
