@@ -25,7 +25,7 @@
 
 class KoLayoutTab : public KoLayoutTabBase
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
