@@ -269,7 +269,7 @@ void KoParagCounter::saveOasis( KoGenStyle& listStyle, bool savingStyle ) const
     // Prepare a sub-xmlwriter for the list-level-style-* element
     TQBuffer buffer;
     buffer.open( IO_WriteOnly );
-    KoXmlWriter listLevelWriter( TQT_TQIODEVICE(&buffer), 3 /*indentation*/ );
+    KoXmlWriter listLevelWriter( &buffer, 3 /*indentation*/ );
     const char* tagName = isBullet() ? "text:list-level-style-bullet" : "text:list-level-style-number";
     listLevelWriter.startElement( tagName );
 
