@@ -71,7 +71,7 @@ class KoParagDecorationTab; // From KoParagDecorationTab.ui
  */
 class KOTEXT_EXPORT KoParagLayoutWidget : public TQWidget
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     // Constructor: parent widget, flag (PD_SOMETHING) and name
@@ -107,7 +107,7 @@ private:
  */
 class KOTEXT_EXPORT KoIndentSpacingWidget : public KoParagLayoutWidget
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     KoIndentSpacingWidget( KoUnit::Unit unit, double _frameWidth, TQWidget * parent,const char * name = 0 );
@@ -151,7 +151,7 @@ private:
  */
 class KOTEXT_EXPORT KoParagAlignWidget : public KoParagLayoutWidget
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     KoParagAlignWidget(bool breakLine, TQWidget * parent, const char * name = 0 );
@@ -185,7 +185,7 @@ private:
  */
 class KOTEXT_EXPORT KoParagDecorationWidget : public KoParagLayoutWidget
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     KoParagDecorationWidget( TQWidget * parent, const char * name = 0 );
@@ -262,7 +262,7 @@ private:
 
 class KOTEXT_EXPORT KoCounterStyleWidget : public TQWidget
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     KoCounterStyleWidget( bool displayDepth= true, bool onlyStyleTypeLetter = false, bool disableAll=false, TQWidget* parent = 0, const char* name = 0 );
@@ -344,7 +344,7 @@ private:
  */
 class KOTEXT_EXPORT KoParagCounterWidget : public KoParagLayoutWidget
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
 
@@ -389,7 +389,7 @@ private:
  */
 class KoTabulatorsLineEdit : public KoUnitDoubleSpinBox
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     KoTabulatorsLineEdit( TQWidget *parent, double lower, double upper, double step, double value = 0.0,
@@ -406,7 +406,7 @@ protected:
  */
 class KOTEXT_EXPORT KoParagTabulatorsWidget : public KoParagLayoutWidget
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     KoParagTabulatorsWidget( KoUnit::Unit unit, double _frameWidth, TQWidget * parent, const char * name = 0 );
@@ -467,7 +467,7 @@ private:
  */
 class KoStylePreview : public TQGroupBox
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
@@ -497,7 +497,7 @@ protected:
  */
 class KOTEXT_EXPORT KoParagDia : public KDialogBase
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
