@@ -35,7 +35,7 @@ class TQPainter;
 /******************************************************************/
 class KoSpinBox : public TQSpinBox
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
@@ -58,7 +58,7 @@ public:
 /******************************************************************/
 class KPagePreview : public TQGroupBox
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
@@ -92,7 +92,7 @@ protected:
 
 class KPagePreview2 : public TQGroupBox
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
@@ -115,7 +115,7 @@ protected:
 
 class KoBorderPreview : public TQFrame/*TQGroupBox*/
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
