@@ -27,8 +27,8 @@
 #include <KoDom.h>
 #include <KoGenStyles.h>
 
-#include <kglobal.h>
-#include <klocale.h>
+#include <tdeglobal.h>
+#include <tdelocale.h>
 #include <kdebug.h>
 #include <tqdom.h>
 #include <tqbuffer.h>
@@ -164,7 +164,7 @@ void KoParagLayout::loadParagLayout( KoParagLayout& layout, const TQDomElement&
             tab.ptWidth = getAttribute( element, "width", 0.5 );
             TQString alignCharStr = element.attribute("alignchar");
             if ( alignCharStr.isEmpty() )
-                tab.alignChar = KGlobal::locale()->decimalSymbol()[0];
+                tab.alignChar = TDEGlobal::locale()->decimalSymbol()[0];
             else
                 tab.alignChar = alignCharStr[0];
             tabList.append( tab );
@@ -843,7 +843,7 @@ void KoParagLayout::saveOasis( KoGenStyle& gs, KoSavingContext& context, bool sa
 
     TQBuffer buffer;
     buffer.open( IO_WriteOnly );
-    KoXmlWriter tabsWriter( TQT_TQIODEVICE(&buffer), 4 ); // indent==4: root,autostyle,style,parag-props
+    KoXmlWriter tabsWriter( &buffer, 4 ); // indent==4: root,autostyle,style,parag-props
     tabsWriter.startElement( "style:tab-stops" );
     KoTabulatorList::ConstIterator it = m_tabList.begin();
     for ( ; it != m_tabList.end() ; it++ )
