@@ -44,7 +44,7 @@ namespace KSpell2
  */
 class KOTEXT_EXPORT KoSpell : public KSpell2::BackgroundChecker
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
