@@ -197,7 +197,7 @@ void KoStyleManager::addGeneralTab( int flags ) {
 
     tabLayout->addWidget( nameLabel, 0, 0 );
 
-    m_styleCombo = new TQComboBox( FALSE, tab, "styleCombo" );
+    m_styleCombo = new TQComboBox( false, tab, "styleCombo" );
 
     tabLayout->addWidget( m_styleCombo, 1, 1 );
 
@@ -207,7 +207,7 @@ void KoStyleManager::addGeneralTab( int flags ) {
 
     tabLayout->addWidget( nextStyleLabel, 1, 0 );
 
-    m_inheritCombo = new TQComboBox( FALSE, tab, "inheritCombo" );
+    m_inheritCombo = new TQComboBox( false, tab, "inheritCombo" );
     tabLayout->addWidget( m_inheritCombo, 2, 1 );
 
     TQLabel *inheritStyleLabel = new TQLabel( tab );
