@@ -53,12 +53,12 @@ public:
     virtual Placement placement() const { return PlaceInline; }
     bool placeInline() { return placement() == PlaceInline; }
 
-    virtual bool ownLine() const { return FALSE; }
+    virtual bool ownLine() const { return false; }
     // Called for "ownline" items
     virtual void resize( int nwidth ) { width = nwidth; }
     virtual void invalidate() {};
 
-    virtual bool isNested() const { return FALSE; }
+    virtual bool isNested() const { return false; }
     virtual int minimumWidth() const { return 0; }
     virtual int widthHint() const { return 0; }
     virtual int ascent() const { return height; }
@@ -70,7 +70,7 @@ public:
 
     TQRect geometry() const { return TQRect( xpos, ypos, width, height ); }
 
-    virtual bool enter( KoTextCursor *, KoTextDocument *&doc, KoTextParag *&parag, int &idx, int &ox, int &oy, bool atEnd = FALSE );
+    virtual bool enter( KoTextCursor *, KoTextDocument *&doc, KoTextParag *&parag, int &idx, int &ox, int &oy, bool atEnd = false );
     virtual bool enterAt( KoTextCursor *, KoTextDocument *&doc, KoTextParag *&parag, int &idx, int &ox, int &oy, const TQPoint & );
     virtual bool next( KoTextCursor *, KoTextDocument *&doc, KoTextParag *&parag, int &idx, int &ox, int &oy );
     virtual bool prev( KoTextCursor *, KoTextDocument *&doc, KoTextParag *&parag, int &idx, int &ox, int &oy );
