@@ -35,7 +35,7 @@ class KoTextView;
  */
 class KOTEXT_EXPORT KoTextIterator : public TQObject
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     /**
