@@ -42,7 +42,7 @@
 #include <kdialogbase.h>
 #include <tdeconfig.h>
 #include <tdeversion.h>
-#include <kinstance.h>
+#include <tdeinstance.h>
 #include <kcalendarsystem.h>
 #include <tdeaboutdata.h>
 
@@ -125,13 +125,13 @@ void KoVariableSettings::saveOasis( KoXmlWriter &settingsWriter ) const
     // style:page-number in the first parag of a page (see KoTextParag), or
     // style:first-page-number in style:page-layout, for spreadsheets etc.
     if ( d->m_lastPrintingDate.isValid())
-        settingsWriter.addConfigItem("lastPrintingDate", d->m_lastPrintingDate.toString(Qt::ISODate));
+        settingsWriter.addConfigItem("lastPrintingDate", d->m_lastPrintingDate.toString(TQt::ISODate));
 
     if ( d->m_creationDate.isValid())
-        settingsWriter.addConfigItem("creationDate", d->m_creationDate.toString(Qt::ISODate));
+        settingsWriter.addConfigItem("creationDate", d->m_creationDate.toString(TQt::ISODate));
 
     if ( d->m_modificationDate.isValid())
-        settingsWriter.addConfigItem("modificationDate", d->m_modificationDate.toString(Qt::ISODate));
+        settingsWriter.addConfigItem("modificationDate", d->m_modificationDate.toString(TQt::ISODate));
 
     settingsWriter.endElement(); // config:config-item-set
 }
@@ -148,18 +148,18 @@ void KoVariableSettings::loadOasis(const KoOasisSettings&settingsDoc)
 
         TQString str = configurationSettings.parseConfigItemString( "lastPrintingDate" );
         if ( !str.isEmpty() )
-            d->m_lastPrintingDate = TQDateTime::fromString( str, Qt::ISODate );
+            d->m_lastPrintingDate = TQDateTime::fromString( str, TQt::ISODate );
         else
             d->m_lastPrintingDate.setTime_t(0); // 1970-01-01 00:00:00.000 locale time
 
         str = configurationSettings.parseConfigItemString( "creationDate" );
         if ( !str.isEmpty() ) {
-            d->m_creationDate = TQDateTime::fromString( str, Qt::ISODate );
+            d->m_creationDate = TQDateTime::fromString( str, TQt::ISODate );
         }
 
         str = configurationSettings.parseConfigItemString( "modificationDate" );
         if ( !str.isEmpty() )
-            d->m_modificationDate = TQDateTime::fromString( str, Qt::ISODate );
+            d->m_modificationDate = TQDateTime::fromString( str, TQt::ISODate );
 
         // m_startingPageNumber isn't loaded from OASIS here. KWTextParag::loadOasis does it.
     }
@@ -179,13 +179,13 @@ void KoVariableSettings::save( TQDomElement &parentElem )
     elem.setAttribute("displayfieldcode", (int)m_displayFieldCode);
 
     if ( d->m_lastPrintingDate.isValid())
-        elem.setAttribute("lastPrintingDate", d->m_lastPrintingDate.toString(Qt::ISODate));
+        elem.setAttribute("lastPrintingDate", d->m_lastPrintingDate.toString(TQt::ISODate));
 
     if ( d->m_creationDate.isValid())
-        elem.setAttribute("creationDate", d->m_creationDate.toString(Qt::ISODate));
+        elem.setAttribute("creationDate", d->m_creationDate.toString(TQt::ISODate));
 
     if ( d->m_modificationDate.isValid())
-        elem.setAttribute("modificationDate", d->m_modificationDate.toString(Qt::ISODate));
+        elem.setAttribute("modificationDate", d->m_modificationDate.toString(TQt::ISODate));
 }
 
 void KoVariableSettings::load( TQDomElement &elem )
@@ -205,16 +205,16 @@ void KoVariableSettings::load( TQDomElement &elem )
             m_displayFieldCode=(bool)e.attribute("displayfieldcode").toInt();
 
         if (e.hasAttribute("lastPrintingDate"))
-            d->m_lastPrintingDate = TQDateTime::fromString( e.attribute( "lastPrintingDate" ), Qt::ISODate );
+            d->m_lastPrintingDate = TQDateTime::fromString( e.attribute( "lastPrintingDate" ), TQt::ISODate );
         else
             d->m_lastPrintingDate.setTime_t(0); // 1970-01-01 00:00:00.000 locale time
 
         if (e.hasAttribute("creationDate")) {
-            d->m_creationDate = TQDateTime::fromString( e.attribute( "creationDate" ), Qt::ISODate );
+            d->m_creationDate = TQDateTime::fromString( e.attribute( "creationDate" ), TQt::ISODate );
         }
 
         if (e.hasAttribute("modificationDate"))
-            d->m_modificationDate = TQDateTime::fromString( e.attribute( "modificationDate" ), Qt::ISODate );
+            d->m_modificationDate = TQDateTime::fromString( e.attribute( "modificationDate" ), TQt::ISODate );
     }
 }
 
@@ -584,7 +584,7 @@ TQPtrList<TDEAction> KoVariableCollection::popupActionList() const
             // We store the subtype number as the action name
             TQCString name; name.setNum(i);
             TDEToggleAction * act = new TDEToggleAction( *it, TDEShortcut(), 0, name );
-            connect( act, TQT_SIGNAL(activated()), this, TQT_SLOT(slotChangeSubType()) );
+            connect( act, TQ_SIGNAL(activated()), this, TQ_SLOT(slotChangeSubType()) );
             if ( i == m_varSelected->subType() )
                 act->setChecked( true );
             //m_subTextMap.insert( act, i );
@@ -608,7 +608,7 @@ TQPtrList<TDEAction> KoVariableCollection::popupActionList() const
             TQString text = format->convert( m_varSelected->varValue() );
             // We store the raw format as the action name
             TDEToggleAction * act = new TDEToggleAction(text, TDEShortcut(), 0, (*it).utf8());
-            connect( act, TQT_SIGNAL(activated()), this, TQT_SLOT(slotChangeFormat()) );
+            connect( act, TQ_SIGNAL(activated()), this, TQ_SLOT(slotChangeFormat()) );
             if ( (*it) == currentFormat )
                 act->setChecked( true );
             listAction.append( act );
@@ -1292,7 +1292,7 @@ void KoDateVariable::saveOasis( KoXmlWriter& writer, KoSavingContext& context )
         writer.startElement( "text:date" );
         if ( m_subtype == VST_DATE_FIX )
         {
-            writer.addAttribute( "text:date-value", m_varValue.toDate().toString( Qt::ISODate) );
+            writer.addAttribute( "text:date-value", m_varValue.toDate().toString( TQt::ISODate) );
             writer.addAttribute( "text:fixed", "true" );
         }
         break;
@@ -1340,7 +1340,7 @@ void KoDateVariable::loadOasis( const TQDomElement &elem, KoOasisContext& /*cont
         const TQString dateValue = elem.attributeNS( KoXmlNS::text, "date-value", TQString());
         TQDateTime dt;
         if ( !dateValue.isEmpty() ) // avoid TQDate warning
-            dt = TQDate::fromString(dateValue, Qt::ISODate);
+            dt = TQDate::fromString(dateValue, TQt::ISODate);
 
         bool fixed = (elem.hasAttributeNS( KoXmlNS::text, "fixed") && elem.attributeNS( KoXmlNS::text, "fixed", TQString())=="true");
         if (!dt.isValid())
@@ -1539,8 +1539,8 @@ void KoTimeVariable::loadOasis( const TQDomElement &elem, KoOasisContext& /*cont
     Q_ASSERT( localName == "time" ); // caller checked for it
     if ( localName == "time" ) // current (or fixed) time
     {
-        // Use TQDateTime to work around a possible problem of TQTime::fromString in TQt 3.2.2
-        TQDateTime dt(TQDateTime::fromString(elem.attributeNS( KoXmlNS::text, "time-value", TQString()), Qt::ISODate));
+        // Use TQDateTime to work around a possible problem of TQTime::fromString in Qt 3.2.2
+        TQDateTime dt(TQDateTime::fromString(elem.attributeNS( KoXmlNS::text, "time-value", TQString()), TQt::ISODate));
 
         bool fixed = (elem.hasAttributeNS( KoXmlNS::text, "fixed") && elem.attributeNS( KoXmlNS::text, "fixed", TQString())=="true");
         if (!dt.isValid())
@@ -1563,7 +1563,7 @@ void KoTimeVariable::saveOasis( KoXmlWriter& writer, KoSavingContext& context )
     if (m_subtype == VST_TIME_FIX )
     {
         writer.addAttribute( "text:fixed", "true" );
-        writer.addAttribute( "text:time-value", m_varValue.toTime().toString( Qt::ISODate ) );
+        writer.addAttribute( "text:time-value", m_varValue.toTime().toString( TQt::ISODate ) );
     }
 
     TQString value(  m_varFormat->formatProperties() );
@@ -2527,7 +2527,7 @@ void KoNoteVariable::loadOasis( const TQDomElement &elem, KoOasisContext& /*cont
     if ( localName == "annotation" && elem.namespaceURI() == KoXmlNS::office )
     {
         TQDomElement date = KoDom::namedItemNS( elem, KoXmlNS::dc, "date" );
-        m_createdNoteDate = TQDate::fromString( date.text(), Qt::ISODate );
+        m_createdNoteDate = TQDate::fromString( date.text(), TQt::ISODate );
         TQDomNode text = KoDom::namedItemNS( elem, KoXmlNS::text, "p" );
         for ( ; !text.isNull(); text = text.nextSibling() )
         {
@@ -2546,7 +2546,7 @@ void KoNoteVariable::saveOasis( KoXmlWriter& writer, KoSavingContext& /*context*
 //    <office:annotation><dc:date>2004-11-10</dc:date><text:p/><text:p>---- 10/11/2004, 16:18 ----</text:p><text:p>dfgsdfsdfg</text:p><text:p>---- 10/11/2004, 16:18 ----</text:p><text:p/><text:p>---- 10/11/2004, 16:18 ----</text:p><text:p>gs</text:p><text:p>---- 10/11/2004, 16:18 ----</text:p><text:p>fg</text:p></office:annotation>
     writer.startElement( "office:annotation" );
     writer.startElement( "dc:date" );
-    writer.addTextNode( m_createdNoteDate.toString(Qt::ISODate) );
+    writer.addTextNode( m_createdNoteDate.toString(TQt::ISODate) );
     writer.endElement();
     TQStringList text = TQStringList::split( "\n", m_varValue.toString() );
     for ( TQStringList::Iterator it = text.begin(); it != text.end(); ++it ) {
