@@ -19,11 +19,11 @@
 #ifndef KOUSERSTYLETESTER_H
 #define KOUSERSTYLETESTER_H
 
-#include <kunittest/tester.h>
+#include <tdeunittest/tester.h>
 
 class KoUserStyleTester : public KUnitTest::SlotTester {
-    Q_OBJECT
-  TQ_OBJECT
+    TQ_OBJECT
+  
 private slots:
     void testEmptyCollection();
     void testAddStyle();
