@@ -84,7 +84,7 @@ Manager::Manager()
     if(! pythonlib.isEmpty()) { // If the Kross Python plugin exists we offer it as supported scripting language.
         InterpreterInfo::Option::Map pythonoptions;
         pythonoptions.replace("restricted",
-            new InterpreterInfo::Option("Restricted", "Restricted Python interpreter", TQVariant(false,0))
+            new InterpreterInfo::Option("Restricted", "Restricted Python interpreter", TQVariant(false))
         );
         d->interpreterinfos.replace("python",
             new InterpreterInfo("python",
