@@ -40,7 +40,7 @@ namespace Kross { namespace Api {
         : public TDEAction
         , public Kross::Api::ScriptContainer
     {
-            Q_OBJECT
+            TQ_OBJECT
   
 
             /// The name of the interpreter used to execute the scripting code.
