@@ -36,7 +36,7 @@ class WdgScriptsManagerPrivate;
 */
 class WdgScriptsManager : public WdgScriptsManagerBase
 {
-    Q_OBJECT
+    TQ_OBJECT
   
     public:
         WdgScriptsManager(ScriptGUIClient* scr, TQWidget* parent = 0, const char* name = 0, WFlags fl = 0);
