@@ -496,28 +496,28 @@ namespace Kross {
 #if 0
     /// \internal
     template<>
-    struct RubyType<TQVariantMap>
+    struct RubyType<TQStringVariantMap>
     {
-        inline static VALUE toVALUE(const TQVariantMap& map) {
+        inline static VALUE toVALUE(const TQStringVariantMap& map) {
             VALUE h = rb_hash_new();
-            TQMap<TQString, TQVariant>::ConstIterator it(map.constBegin()), end(map.end());
+            TQStringVariantMap::ConstIterator it(map.constBegin()), end(map.end());
             for(; it != end; ++it)
                 rb_hash_aset(h, RubyType<TQString>::toVALUE(it.key()), RubyType<TQVariant>::toVALUE(it.value()) );
             return h;
         }
         inline static int convertHash(VALUE key, VALUE value, VALUE  vmap) {
-            TQVariantMap* map; 
-            Data_Get_Struct(vmap, TQVariantMap, map);
+            TQStringVariantMap* map;
+            Data_Get_Struct(vmap, TQStringVariantMap, map);
             if (key != TQundef)
                 map->insert(STR2CSTR(key), RubyType<TQVariant>::toVariant(value));
             return ST_CONTINUE;
         }
-        inline static TQVariantMap toVariant(VALUE value) {
+        inline static TQStringVariantMap toVariant(VALUE value) {
             if( TYPE(value) != T_HASH ) {
-                rb_raise(rb_eTypeError, "TQVariantMap must be a hash");
-                return TQVariantMap();
+                rb_raise(rb_eTypeError, "TQStringVariantMap must be a hash");
+                return TQStringVariantMap();
             }
-            TQVariantMap map;
+            TQStringVariantMap map;
             VALUE vmap = Data_Wrap_Struct(rb_cObject, 0,0, &map);
             rb_hash_foreach(value, (int (*)(...))convertHash, vmap);
             return map;
