@@ -26,7 +26,7 @@
 #include <tqfile.h>
 
 // KDE
-#include <kinstance.h>
+#include <tdeinstance.h>
 #include <tdeapplication.h>
 #include <tdecmdlineargs.h>
 #include <tdeaboutdata.h>
