@@ -39,7 +39,7 @@
 #include <tqfile.h>
 
 // KDE
-#include <kinstance.h>
+#include <tdeinstance.h>
 #include <tdeapplication.h>
 #include <tdecmdlineargs.h>
 #include <tdeaboutdata.h>
@@ -114,8 +114,8 @@ void runInterpreter(const TQString& interpretername, const TQString& scriptcode)
 
 /*
         // Connect TQObject signal with scriptfunction.
-        scriptcontainer->connect(testobject, TQT_SIGNAL(testSignal()), "testobjectCallback");
-        scriptcontainer->connect(testobject, TQT_SIGNAL(testSignalString(const TQString&)), "testobjectCallbackWithParams");
+        scriptcontainer->connect(testobject, TQ_SIGNAL(testSignal()), "testobjectCallback");
+        scriptcontainer->connect(testobject, TQ_SIGNAL(testSignalString(const TQString&)), "testobjectCallbackWithParams");
         // Call the testSlot to emit the testSignal.
         testobject->testSlot();
 */
