@@ -27,7 +27,7 @@
 
 class TestObject : public TQObject
 {
-        Q_OBJECT
+        TQ_OBJECT
   
 
         TQ_PROPERTY(TQString testProperty READ testProperty WRITE setTestProperty)
