@@ -126,7 +126,7 @@ bool KoTarStore::openWrite( const TQString& /*name*/ )
 {
     // Prepare memory buffer for writing
     m_byteArray.resize( 0 );
-    m_stream = TQT_TQIODEVICE(new TQBuffer( m_byteArray ));
+    m_stream = new TQBuffer( m_byteArray );
     m_stream->open( IO_WriteOnly );
     return true;
 }
