@@ -22,7 +22,7 @@
 #include <tdemessagebox.h>
 #include <tdelocale.h>
 #include <kdebug.h>
-#include <kinstance.h>
+#include <tdeinstance.h>
 #include <tdeconfig.h>
 #include <kgenericfactory.h>
 #include <klibloader.h>
