@@ -62,7 +62,7 @@ class TQToolButton;
 
 class Thesaurus : public KDataTool
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
