@@ -28,7 +28,7 @@ class KoDocument;
 
 class KOfficeCreator : public TQObject, public ThumbCreator
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     KOfficeCreator();
